/* phone-details.c generated by valac 0.15.1.20-908e, the Vala compiler
 * generated from phone-details.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <folks-test.h>
#include <eds-test.h>
#include <folks/folks.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <folks/folks-eds.h>


#define TYPE_PHONE_DETAILS_TESTS (phone_details_tests_get_type ())
#define PHONE_DETAILS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHONE_DETAILS_TESTS, PhoneDetailsTests))
#define PHONE_DETAILS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHONE_DETAILS_TESTS, PhoneDetailsTestsClass))
#define IS_PHONE_DETAILS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHONE_DETAILS_TESTS))
#define IS_PHONE_DETAILS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHONE_DETAILS_TESTS))
#define PHONE_DETAILS_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHONE_DETAILS_TESTS, PhoneDetailsTestsClass))

typedef struct _PhoneDetailsTests PhoneDetailsTests;
typedef struct _PhoneDetailsTestsClass PhoneDetailsTestsClass;
typedef struct _PhoneDetailsTestsPrivate PhoneDetailsTestsPrivate;
#define _eds_test_backend_unref0(var) ((var == NULL) ? NULL : (var = (eds_test_backend_unref (var), NULL)))
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define __vala_GValue_free0(var) ((var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _PhoneDetailsTestsTestPhoneNumbersAsyncData PhoneDetailsTestsTestPhoneNumbersAsyncData;

struct _PhoneDetailsTests {
	FolksTestCase parent_instance;
	PhoneDetailsTestsPrivate * priv;
};

struct _PhoneDetailsTestsClass {
	FolksTestCaseClass parent_class;
};

struct _PhoneDetailsTestsPrivate {
	EdsTestBackend* _eds_backend;
	GMainLoop* _main_loop;
	FolksIndividualAggregator* _aggregator;
	gint _phones_count;
	GeeHashSet* _phone_types;
	GeeHashMap* _c1;
	GeeHashMap* _c2;
};

struct _PhoneDetailsTestsTestPhoneNumbersAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	PhoneDetailsTests* self;
	EdsTestBackend* _tmp0_;
	FolksBackendStore* _tmp1_;
	FolksBackendStore* store;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	FolksIndividualAggregator* _tmp4_;
	GError* e;
	GError* _tmp5_;
	const gchar* _tmp6_;
	GError * _inner_error_;
};


static gpointer phone_details_tests_parent_class = NULL;

GType phone_details_tests_get_type (void) G_GNUC_CONST;
#define PHONE_DETAILS_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_PHONE_DETAILS_TESTS, PhoneDetailsTestsPrivate))
enum  {
	PHONE_DETAILS_TESTS_DUMMY_PROPERTY
};
PhoneDetailsTests* phone_details_tests_new (void);
PhoneDetailsTests* phone_details_tests_construct (GType object_type);
void phone_details_tests_test_phone_numbers (PhoneDetailsTests* self);
static void _phone_details_tests_test_phone_numbers_folks_test_case_test_method (gpointer self);
static void phone_details_tests_real_set_up (FolksTestCase* base);
static void phone_details_tests_real_tear_down (FolksTestCase* base);
static GValue* _g_value_dup (GValue* self);
static void _vala_GValue_free (GValue* self);
static void _phone_details_tests_test_phone_numbers_async (PhoneDetailsTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _phone_details_tests_test_phone_numbers_finish (PhoneDetailsTests* self, GAsyncResult* _res_);
static gboolean __lambda2_ (PhoneDetailsTests* self);
static gboolean ___lambda2__gsource_func (gpointer self);
static gboolean _vala_string_array_contains (const gchar** stack, int stack_length, const gchar* needle);
static void _phone_details_tests_test_phone_numbers_async_data_free (gpointer _data);
static gboolean _phone_details_tests_test_phone_numbers_async_co (PhoneDetailsTestsTestPhoneNumbersAsyncData* _data_);
static void _phone_details_tests_test_phone_numbers_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _phone_details_tests_individuals_changed_cb (PhoneDetailsTests* self, GeeMultiMap* changes);
static void __phone_details_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void phone_details_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _phone_details_tests_test_phone_numbers_folks_test_case_test_method (gpointer self) {
#line 39 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	phone_details_tests_test_phone_numbers (self);
#line 125 "phone-details.c"
}


PhoneDetailsTests* phone_details_tests_construct (GType object_type) {
	PhoneDetailsTests * self = NULL;
#line 37 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	self = (PhoneDetailsTests*) folks_test_case_construct (object_type, "PhoneDetails");
#line 39 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "phone details interface", _phone_details_tests_test_phone_numbers_folks_test_case_test_method, self);
#line 35 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	return self;
#line 137 "phone-details.c"
}


PhoneDetailsTests* phone_details_tests_new (void) {
#line 35 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	return phone_details_tests_construct (TYPE_PHONE_DETAILS_TESTS);
#line 144 "phone-details.c"
}


static void phone_details_tests_real_set_up (FolksTestCase* base) {
	PhoneDetailsTests * self;
	EdsTestBackend* _tmp0_;
	EdsTestBackend* _tmp1_;
	EdsTestBackend* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	gchar* _tmp5_ = NULL;
	gchar* config_val;
#line 42 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	self = (PhoneDetailsTests*) base;
#line 44 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp0_ = eds_test_backend_new ();
#line 44 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_eds_test_backend_unref0 (self->priv->_eds_backend);
#line 44 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	self->priv->_eds_backend = _tmp0_;
#line 45 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp1_ = self->priv->_eds_backend;
#line 45 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	eds_test_backend_set_up (_tmp1_, FALSE);
#line 48 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp2_ = self->priv->_eds_backend;
#line 48 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp3_ = eds_test_backend_get_address_book_uid (_tmp2_);
#line 48 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp4_ = _tmp3_;
#line 48 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp5_ = g_strdup_printf ("eds:%s", _tmp4_);
#line 48 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	config_val = _tmp5_;
#line 49 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	g_setenv ("FOLKS_PRIMARY_STORE", config_val, TRUE);
#line 42 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_g_free0 (config_val);
#line 183 "phone-details.c"
}


static void phone_details_tests_real_tear_down (FolksTestCase* base) {
	PhoneDetailsTests * self;
	EdsTestBackend* _tmp0_;
#line 52 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	self = (PhoneDetailsTests*) base;
#line 54 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp0_ = self->priv->_eds_backend;
#line 54 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	eds_test_backend_tear_down (_tmp0_);
#line 196 "phone-details.c"
}


static GValue* _g_value_dup (GValue* self) {
#line 62 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	return g_boxed_copy (G_TYPE_VALUE, self);
#line 203 "phone-details.c"
}


static void _vala_GValue_free (GValue* self) {
#line 62 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	g_value_unset (self);
#line 62 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	g_free (self);
#line 212 "phone-details.c"
}


static gpointer __g_value_dup0 (gpointer self) {
#line 69 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	return self ? _g_value_dup (self) : NULL;
#line 219 "phone-details.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 81 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	return self ? g_object_ref (self) : NULL;
#line 226 "phone-details.c"
}


static gboolean __lambda2_ (PhoneDetailsTests* self) {
	gboolean result = FALSE;
	GMainLoop* _tmp0_;
#line 101 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp0_ = self->priv->_main_loop;
#line 101 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	g_main_loop_quit (_tmp0_);
#line 102 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	result = FALSE;
#line 102 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	return result;
#line 241 "phone-details.c"
}


static gboolean ___lambda2__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda2_ (self);
#line 99 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	return result;
#line 250 "phone-details.c"
}


static gboolean _vala_string_array_contains (const gchar** stack, int stack_length, const gchar* needle) {
	int i;
#line 114 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	for (i = 0; i < stack_length; i++) {
#line 114 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		if (g_strcmp0 (stack[i], needle) == 0) {
#line 114 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			return TRUE;
#line 262 "phone-details.c"
		}
	}
#line 114 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	return FALSE;
#line 267 "phone-details.c"
}


void phone_details_tests_test_phone_numbers (PhoneDetailsTests* self) {
	GHashFunc _tmp0_;
	GEqualFunc _tmp1_;
	GeeHashSet* _tmp2_;
	GeeHashMap* _tmp3_;
	GeeHashMap* _tmp4_;
	GMainLoop* _tmp5_;
	GValue* v = NULL;
	EdsTestBackend* _tmp6_;
	GValue _tmp7_ = {0};
	GValue _tmp8_;
	GValue* _tmp9_;
	GValue* _tmp10_;
	GeeHashMap* _tmp11_;
	GValue* _tmp12_;
	GValue* _tmp13_;
	GValue _tmp14_ = {0};
	GValue _tmp15_;
	GValue* _tmp16_;
	GValue* _tmp17_;
	GeeHashMap* _tmp18_;
	GValue* _tmp19_;
	GValue* _tmp20_;
	GValue _tmp21_ = {0};
	GValue _tmp22_;
	GValue* _tmp23_;
	GValue* _tmp24_;
	GeeHashMap* _tmp25_;
	GValue* _tmp26_;
	GValue* _tmp27_;
	GValue _tmp28_ = {0};
	GValue _tmp29_;
	GValue* _tmp30_;
	GValue* _tmp31_;
	GeeHashMap* _tmp32_;
	GValue* _tmp33_;
	GValue* _tmp34_;
	EdsTestBackend* _tmp35_;
	GeeHashMap* _tmp36_;
	GeeHashMap* _tmp37_;
	GValue _tmp38_ = {0};
	GValue _tmp39_;
	GValue* _tmp40_;
	GValue* _tmp41_;
	GeeHashMap* _tmp42_;
	GValue* _tmp43_;
	GValue* _tmp44_;
	GValue _tmp45_ = {0};
	GValue _tmp46_;
	GValue* _tmp47_;
	GValue* _tmp48_;
	GeeHashMap* _tmp49_;
	GValue* _tmp50_;
	GValue* _tmp51_;
	GValue _tmp52_ = {0};
	GValue _tmp53_;
	GValue* _tmp54_;
	GValue* _tmp55_;
	GeeHashMap* _tmp56_;
	GValue* _tmp57_;
	GValue* _tmp58_;
	GValue _tmp59_ = {0};
	GValue _tmp60_;
	GValue* _tmp61_;
	GValue* _tmp62_;
	GeeHashMap* _tmp63_;
	GValue* _tmp64_;
	GValue* _tmp65_;
	EdsTestBackend* _tmp66_;
	GeeHashMap* _tmp67_;
	GeeHashMap* _tmp68_;
	GMainLoop* _tmp69_;
	gint _tmp70_;
	GeeHashSet* _tmp71_;
	gint _tmp72_;
	gint _tmp73_;
	GeeHashMap* _tmp74_;
	gint _tmp75_;
	gint _tmp76_;
	GeeHashMap* _tmp77_;
	gint _tmp78_;
	gint _tmp79_;
#line 57 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	g_return_if_fail (self != NULL);
#line 59 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	self->priv->_phones_count = 0;
#line 60 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp0_ = g_str_hash;
#line 60 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp1_ = g_str_equal;
#line 60 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp2_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, _tmp0_, _tmp1_);
#line 60 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_g_object_unref0 (self->priv->_phone_types);
#line 60 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	self->priv->_phone_types = _tmp2_;
#line 62 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp3_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL);
#line 62 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_g_object_unref0 (self->priv->_c1);
#line 62 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	self->priv->_c1 = _tmp3_;
#line 63 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp4_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL);
#line 63 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_g_object_unref0 (self->priv->_c2);
#line 63 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	self->priv->_c2 = _tmp4_;
#line 64 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp5_ = g_main_loop_new (NULL, FALSE);
#line 64 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 64 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	self->priv->_main_loop = _tmp5_;
#line 67 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp6_ = self->priv->_eds_backend;
#line 67 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	eds_test_backend_reset (_tmp6_);
#line 69 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	g_value_init (&_tmp7_, G_TYPE_STRING);
#line 69 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp8_ = _tmp7_;
#line 69 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp9_ = __g_value_dup0 (&_tmp8_);
#line 69 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (v);
#line 69 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	v = _tmp9_;
#line 69 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	G_IS_VALUE (&_tmp8_) ? (g_value_unset (&_tmp8_), NULL) : NULL;
#line 70 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp10_ = v;
#line 70 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	g_value_set_string (_tmp10_, "bernie h. innocenti");
#line 71 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp11_ = self->priv->_c1;
#line 71 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp12_ = v;
#line 71 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	v = NULL;
#line 71 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp13_ = _tmp12_;
#line 71 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp11_, "full_name", _tmp13_);
#line 71 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (_tmp13_);
#line 72 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	g_value_init (&_tmp14_, G_TYPE_STRING);
#line 72 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp15_ = _tmp14_;
#line 72 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp16_ = __g_value_dup0 (&_tmp15_);
#line 72 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (v);
#line 72 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	v = _tmp16_;
#line 72 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	G_IS_VALUE (&_tmp15_) ? (g_value_unset (&_tmp15_), NULL) : NULL;
#line 73 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp17_ = v;
#line 73 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	g_value_set_string (_tmp17_, "123");
#line 74 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp18_ = self->priv->_c1;
#line 74 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp19_ = v;
#line 74 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	v = NULL;
#line 74 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp20_ = _tmp19_;
#line 74 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp18_, "car_phone", _tmp20_);
#line 74 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (_tmp20_);
#line 75 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	g_value_init (&_tmp21_, G_TYPE_STRING);
#line 75 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp22_ = _tmp21_;
#line 75 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp23_ = __g_value_dup0 (&_tmp22_);
#line 75 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (v);
#line 75 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	v = _tmp23_;
#line 75 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	G_IS_VALUE (&_tmp22_) ? (g_value_unset (&_tmp22_), NULL) : NULL;
#line 76 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp24_ = v;
#line 76 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	g_value_set_string (_tmp24_, "1234");
#line 77 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp25_ = self->priv->_c1;
#line 77 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp26_ = v;
#line 77 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	v = NULL;
#line 77 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp27_ = _tmp26_;
#line 77 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp25_, "company_phone", _tmp27_);
#line 77 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (_tmp27_);
#line 78 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	g_value_init (&_tmp28_, G_TYPE_STRING);
#line 78 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp29_ = _tmp28_;
#line 78 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp30_ = __g_value_dup0 (&_tmp29_);
#line 78 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (v);
#line 78 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	v = _tmp30_;
#line 78 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	G_IS_VALUE (&_tmp29_) ? (g_value_unset (&_tmp29_), NULL) : NULL;
#line 79 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp31_ = v;
#line 79 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	g_value_set_string (_tmp31_, "12345");
#line 80 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp32_ = self->priv->_c1;
#line 80 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp33_ = v;
#line 80 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	v = NULL;
#line 80 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp34_ = _tmp33_;
#line 80 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp32_, "home_phone", _tmp34_);
#line 80 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (_tmp34_);
#line 81 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp35_ = self->priv->_eds_backend;
#line 81 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp36_ = self->priv->_c1;
#line 81 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp37_ = _g_object_ref0 (_tmp36_);
#line 81 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	eds_test_backend_add_contact (_tmp35_, _tmp37_);
#line 83 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	g_value_init (&_tmp38_, G_TYPE_STRING);
#line 83 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp39_ = _tmp38_;
#line 83 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp40_ = __g_value_dup0 (&_tmp39_);
#line 83 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (v);
#line 83 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	v = _tmp40_;
#line 83 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	G_IS_VALUE (&_tmp39_) ? (g_value_unset (&_tmp39_), NULL) : NULL;
#line 84 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp41_ = v;
#line 84 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	g_value_set_string (_tmp41_, "richard m. stallman");
#line 85 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp42_ = self->priv->_c2;
#line 85 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp43_ = v;
#line 85 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	v = NULL;
#line 85 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp44_ = _tmp43_;
#line 85 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp42_, "full_name", _tmp44_);
#line 85 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (_tmp44_);
#line 86 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	g_value_init (&_tmp45_, G_TYPE_STRING);
#line 86 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp46_ = _tmp45_;
#line 86 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp47_ = __g_value_dup0 (&_tmp46_);
#line 86 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (v);
#line 86 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	v = _tmp47_;
#line 86 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	G_IS_VALUE (&_tmp46_) ? (g_value_unset (&_tmp46_), NULL) : NULL;
#line 87 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp48_ = v;
#line 87 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	g_value_set_string (_tmp48_, "54321");
#line 88 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp49_ = self->priv->_c2;
#line 88 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp50_ = v;
#line 88 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	v = NULL;
#line 88 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp51_ = _tmp50_;
#line 88 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp49_, "car_phone", _tmp51_);
#line 88 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (_tmp51_);
#line 89 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	g_value_init (&_tmp52_, G_TYPE_STRING);
#line 89 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp53_ = _tmp52_;
#line 89 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp54_ = __g_value_dup0 (&_tmp53_);
#line 89 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (v);
#line 89 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	v = _tmp54_;
#line 89 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	G_IS_VALUE (&_tmp53_) ? (g_value_unset (&_tmp53_), NULL) : NULL;
#line 90 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp55_ = v;
#line 90 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	g_value_set_string (_tmp55_, "4321");
#line 91 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp56_ = self->priv->_c2;
#line 91 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp57_ = v;
#line 91 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	v = NULL;
#line 91 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp58_ = _tmp57_;
#line 91 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp56_, "company_phone", _tmp58_);
#line 91 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (_tmp58_);
#line 92 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	g_value_init (&_tmp59_, G_TYPE_STRING);
#line 92 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp60_ = _tmp59_;
#line 92 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp61_ = __g_value_dup0 (&_tmp60_);
#line 92 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (v);
#line 92 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	v = _tmp61_;
#line 92 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	G_IS_VALUE (&_tmp60_) ? (g_value_unset (&_tmp60_), NULL) : NULL;
#line 93 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp62_ = v;
#line 93 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	g_value_set_string (_tmp62_, "321");
#line 94 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp63_ = self->priv->_c2;
#line 94 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp64_ = v;
#line 94 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	v = NULL;
#line 94 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp65_ = _tmp64_;
#line 94 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp63_, "home_phone", _tmp65_);
#line 94 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (_tmp65_);
#line 95 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp66_ = self->priv->_eds_backend;
#line 95 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp67_ = self->priv->_c2;
#line 95 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp68_ = _g_object_ref0 (_tmp67_);
#line 95 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	eds_test_backend_add_contact (_tmp66_, _tmp68_);
#line 97 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_phone_details_tests_test_phone_numbers_async (self, NULL, NULL);
#line 99 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) 5, ___lambda2__gsource_func, g_object_ref (self), g_object_unref);
#line 105 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp69_ = self->priv->_main_loop;
#line 105 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	g_main_loop_run (_tmp69_);
#line 107 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp70_ = self->priv->_phones_count;
#line 107 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	g_assert (_tmp70_ == 6);
#line 108 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp71_ = self->priv->_phone_types;
#line 108 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp72_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp71_);
#line 108 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp73_ = _tmp72_;
#line 108 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	g_assert (_tmp73_ == 3);
#line 109 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp74_ = self->priv->_c1;
#line 109 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp75_ = gee_abstract_map_get_size ((GeeMap*) _tmp74_);
#line 109 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp76_ = _tmp75_;
#line 109 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	g_assert (_tmp76_ == 0);
#line 110 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp77_ = self->priv->_c2;
#line 110 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp78_ = gee_abstract_map_get_size ((GeeMap*) _tmp77_);
#line 110 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp79_ = _tmp78_;
#line 110 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	g_assert (_tmp79_ == 0);
#line 665 "phone-details.c"
	{
		GeeHashSet* _tmp80_;
		GeeIterator* _tmp81_ = NULL;
		GeeIterator* _pt_it;
#line 112 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		_tmp80_ = self->priv->_phone_types;
#line 112 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		_tmp81_ = gee_abstract_collection_iterator ((GeeAbstractCollection*) _tmp80_);
#line 112 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		_pt_it = _tmp81_;
#line 112 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		while (TRUE) {
#line 678 "phone-details.c"
			GeeIterator* _tmp82_;
			gboolean _tmp83_ = FALSE;
			GeeIterator* _tmp84_;
			gpointer _tmp85_ = NULL;
			gchar* pt;
			const gchar* _tmp86_;
#line 112 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			_tmp82_ = _pt_it;
#line 112 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			_tmp83_ = gee_iterator_next (_tmp82_);
#line 112 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			if (!_tmp83_) {
#line 112 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
				break;
#line 693 "phone-details.c"
			}
#line 112 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			_tmp84_ = _pt_it;
#line 112 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			_tmp85_ = gee_iterator_get (_tmp84_);
#line 112 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			pt = (gchar*) _tmp85_;
#line 114 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			_tmp86_ = pt;
#line 114 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			g_assert (_vala_string_array_contains (EDSF_PERSONA_phone_fields, G_N_ELEMENTS (EDSF_PERSONA_phone_fields), _tmp86_));
#line 112 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			_g_free0 (pt);
#line 707 "phone-details.c"
		}
#line 112 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		_g_object_unref0 (_pt_it);
#line 711 "phone-details.c"
	}
#line 57 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (v);
#line 715 "phone-details.c"
}


static void _phone_details_tests_test_phone_numbers_async_data_free (gpointer _data) {
	PhoneDetailsTestsTestPhoneNumbersAsyncData* _data_;
	_data_ = _data;
#line 25 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_g_object_unref0 (_data_->self);
#line 25 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	g_slice_free (PhoneDetailsTestsTestPhoneNumbersAsyncData, _data_);
#line 726 "phone-details.c"
}


static void _phone_details_tests_test_phone_numbers_async (PhoneDetailsTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	PhoneDetailsTestsTestPhoneNumbersAsyncData* _data_;
	PhoneDetailsTests* _tmp0_;
#line 25 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_data_ = g_slice_new0 (PhoneDetailsTestsTestPhoneNumbersAsyncData);
#line 25 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _phone_details_tests_test_phone_numbers_async);
#line 25 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _phone_details_tests_test_phone_numbers_async_data_free);
#line 25 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 25 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_data_->self = _tmp0_;
#line 25 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_phone_details_tests_test_phone_numbers_async_co (_data_);
#line 745 "phone-details.c"
}


static void _phone_details_tests_test_phone_numbers_finish (PhoneDetailsTests* self, GAsyncResult* _res_) {
	PhoneDetailsTestsTestPhoneNumbersAsyncData* _data_;
#line 25 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 753 "phone-details.c"
}


static void _phone_details_tests_test_phone_numbers_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	PhoneDetailsTestsTestPhoneNumbersAsyncData* _data_;
#line 121 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_data_ = _user_data_;
#line 121 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_data_->_source_object_ = source_object;
#line 121 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_data_->_res_ = _res_;
#line 121 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_phone_details_tests_test_phone_numbers_async_co (_data_);
#line 767 "phone-details.c"
}


static void __phone_details_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 126 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_phone_details_tests_individuals_changed_cb (self, changes);
#line 774 "phone-details.c"
}


static gboolean _phone_details_tests_test_phone_numbers_async_co (PhoneDetailsTestsTestPhoneNumbersAsyncData* _data_) {
#line 118 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	switch (_data_->_state_) {
#line 118 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		case 0:
#line 783 "phone-details.c"
		goto _state_0;
#line 118 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		case 1:
#line 787 "phone-details.c"
		goto _state_1;
#line 118 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		case 2:
#line 791 "phone-details.c"
		goto _state_2;
#line 118 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		case 3:
#line 795 "phone-details.c"
		goto _state_3;
		default:
#line 118 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		g_assert_not_reached ();
#line 800 "phone-details.c"
	}
	_state_0:
#line 121 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_data_->_tmp0_ = _data_->self->priv->_eds_backend;
#line 121 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_data_->_state_ = 1;
#line 121 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	eds_test_backend_commit_contacts_to_addressbook (_data_->_tmp0_, _phone_details_tests_test_phone_numbers_async_ready, _data_);
#line 121 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	return FALSE;
#line 811 "phone-details.c"
	_state_1:
#line 121 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	eds_test_backend_commit_contacts_to_addressbook_finish (_data_->_tmp0_, _data_->_res_);
#line 123 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_data_->_tmp1_ = NULL;
#line 123 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_data_->_tmp1_ = folks_backend_store_dup ();
#line 123 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_data_->store = _data_->_tmp1_;
#line 124 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_data_->_state_ = 2;
#line 124 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	folks_backend_store_prepare (_data_->store, _phone_details_tests_test_phone_numbers_async_ready, _data_);
#line 124 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	return FALSE;
#line 827 "phone-details.c"
	_state_2:
#line 124 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 125 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_data_->_tmp2_ = folks_individual_aggregator_new ();
#line 125 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 125 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_data_->self->priv->_aggregator = _data_->_tmp2_;
#line 126 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 126 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	g_signal_connect_object (_data_->_tmp3_, "individuals-changed-detailed", (GCallback) __phone_details_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 841 "phone-details.c"
	{
#line 130 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		_data_->_tmp4_ = _data_->self->priv->_aggregator;
#line 130 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		_data_->_state_ = 3;
#line 130 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		folks_individual_aggregator_prepare (_data_->_tmp4_, _phone_details_tests_test_phone_numbers_async_ready, _data_);
#line 130 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		return FALSE;
#line 851 "phone-details.c"
		_state_3:
#line 130 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp4_, _data_->_res_, &_data_->_inner_error_);
#line 130 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		if (_data_->_inner_error_ != NULL) {
#line 857 "phone-details.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 128 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		_data_->e = _data_->_inner_error_;
#line 128 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		_data_->_inner_error_ = NULL;
#line 134 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		_data_->_tmp5_ = _data_->e;
#line 134 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		_data_->_tmp6_ = _data_->_tmp5_->message;
#line 134 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		g_warning ("phone-details.vala:134: Error when calling prepare: %s\n", _data_->_tmp6_);
#line 128 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		_g_error_free0 (_data_->e);
#line 876 "phone-details.c"
	}
	__finally0:
#line 128 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	if (_data_->_inner_error_ != NULL) {
#line 128 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		_g_object_unref0 (_data_->store);
#line 128 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 128 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		g_clear_error (&_data_->_inner_error_);
#line 128 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		return FALSE;
#line 889 "phone-details.c"
	}
#line 118 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_g_object_unref0 (_data_->store);
#line 118 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	if (_data_->_state_ == 0) {
#line 118 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 897 "phone-details.c"
	} else {
#line 118 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 901 "phone-details.c"
	}
#line 118 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	g_object_unref (_data_->_async_result);
#line 118 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	return FALSE;
#line 907 "phone-details.c"
}


static void _phone_details_tests_individuals_changed_cb (PhoneDetailsTests* self, GeeMultiMap* changes) {
	GeeMultiMap* _tmp0_;
	GeeCollection* _tmp1_ = NULL;
	GeeCollection* added;
	GeeMultiMap* _tmp2_;
	GeeSet* _tmp3_ = NULL;
	GeeSet* removed;
	gint _tmp67_;
	GeeSet* _tmp69_;
	gint _tmp70_;
	gint _tmp71_;
#line 138 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	g_return_if_fail (self != NULL);
#line 138 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	g_return_if_fail (changes != NULL);
#line 141 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp0_ = changes;
#line 141 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 141 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	added = _tmp1_;
#line 142 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp2_ = changes;
#line 142 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 142 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	removed = _tmp3_;
#line 938 "phone-details.c"
	{
		GeeCollection* _tmp4_;
		GeeIterator* _tmp5_ = NULL;
		GeeIterator* _i_it;
#line 144 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		_tmp4_ = added;
#line 144 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 144 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		_i_it = _tmp5_;
#line 144 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		while (TRUE) {
#line 951 "phone-details.c"
			GeeIterator* _tmp6_;
			gboolean _tmp7_ = FALSE;
			GeeIterator* _tmp8_;
			gpointer _tmp9_ = NULL;
			FolksIndividual* i;
			FolksIndividual* _tmp10_;
			GeeHashMap* contact;
			FolksIndividual* _tmp11_;
			GeeSet* _tmp12_;
			GeeSet* _tmp13_;
			gint _tmp14_;
			gint _tmp15_;
			FolksIndividual* _tmp16_;
			const gchar* _tmp17_;
			const gchar* _tmp18_;
			GeeHashMap* _tmp24_;
			GeeHashMap* _tmp25_;
			FolksIndividual* _tmp26_;
			FolksPhoneDetails* _tmp27_;
			FolksPhoneDetails* phone_numbers;
#line 144 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			_tmp6_ = _i_it;
#line 144 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 144 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			if (!_tmp7_) {
#line 144 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
				break;
#line 980 "phone-details.c"
			}
#line 144 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			_tmp8_ = _i_it;
#line 144 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 144 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			i = (FolksIndividual*) _tmp9_;
#line 146 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			_tmp10_ = i;
#line 146 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			g_assert (_tmp10_ != NULL);
#line 148 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			contact = NULL;
#line 149 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			_tmp11_ = i;
#line 149 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			_tmp12_ = folks_individual_get_personas (_tmp11_);
#line 149 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			_tmp13_ = _tmp12_;
#line 149 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			_tmp14_ = gee_collection_get_size ((GeeCollection*) _tmp13_);
#line 149 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			_tmp15_ = _tmp14_;
#line 149 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			g_assert (_tmp15_ == 1);
#line 151 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			_tmp16_ = i;
#line 151 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			_tmp17_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp16_);
#line 151 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			_tmp18_ = _tmp17_;
#line 151 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			if (g_strcmp0 (_tmp18_, "bernie h. innocenti") == 0) {
#line 1014 "phone-details.c"
				GeeHashMap* _tmp19_;
#line 153 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
				_tmp19_ = self->priv->_c1;
#line 153 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
				contact = _tmp19_;
#line 1020 "phone-details.c"
			} else {
				FolksIndividual* _tmp20_;
				const gchar* _tmp21_;
				const gchar* _tmp22_;
#line 155 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
				_tmp20_ = i;
#line 155 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
				_tmp21_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp20_);
#line 155 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
				_tmp22_ = _tmp21_;
#line 155 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
				if (g_strcmp0 (_tmp22_, "richard m. stallman") == 0) {
#line 1033 "phone-details.c"
					GeeHashMap* _tmp23_;
#line 157 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
					_tmp23_ = self->priv->_c2;
#line 157 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
					contact = _tmp23_;
#line 1039 "phone-details.c"
				}
			}
#line 160 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			_tmp24_ = contact;
#line 160 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			if (_tmp24_ == NULL) {
#line 162 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
				_g_object_unref0 (i);
#line 162 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
				continue;
#line 1050 "phone-details.c"
			}
#line 165 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			_tmp25_ = contact;
#line 165 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			gee_abstract_map_unset ((GeeAbstractMap*) _tmp25_, "full_name", NULL);
#line 166 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			_tmp26_ = i;
#line 166 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			_tmp27_ = _g_object_ref0 (FOLKS_PHONE_DETAILS (_tmp26_));
#line 166 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			phone_numbers = _tmp27_;
#line 1062 "phone-details.c"
			{
				FolksPhoneDetails* _tmp28_;
				GeeSet* _tmp29_;
				GeeSet* _tmp30_;
				GeeIterator* _tmp31_ = NULL;
				GeeIterator* _phone_fd_it;
#line 167 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
				_tmp28_ = phone_numbers;
#line 167 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
				_tmp29_ = folks_phone_details_get_phone_numbers (_tmp28_);
#line 167 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
				_tmp30_ = _tmp29_;
#line 167 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
				_tmp31_ = gee_iterable_iterator ((GeeIterable*) _tmp30_);
#line 167 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
				_phone_fd_it = _tmp31_;
#line 167 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
				while (TRUE) {
#line 1081 "phone-details.c"
					GeeIterator* _tmp32_;
					gboolean _tmp33_ = FALSE;
					GeeIterator* _tmp34_;
					gpointer _tmp35_ = NULL;
					FolksPhoneFieldDetails* phone_fd;
					gint _tmp36_;
#line 167 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
					_tmp32_ = _phone_fd_it;
#line 167 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
					_tmp33_ = gee_iterator_next (_tmp32_);
#line 167 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
					if (!_tmp33_) {
#line 167 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
						break;
#line 1096 "phone-details.c"
					}
#line 167 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
					_tmp34_ = _phone_fd_it;
#line 167 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
					_tmp35_ = gee_iterator_get (_tmp34_);
#line 167 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
					phone_fd = (FolksPhoneFieldDetails*) _tmp35_;
#line 169 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
					_tmp36_ = self->priv->_phones_count;
#line 169 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
					self->priv->_phones_count = _tmp36_ + 1;
#line 1108 "phone-details.c"
					{
						FolksPhoneFieldDetails* _tmp37_;
						FolksPhoneFieldDetails* _tmp38_;
						GeeCollection* _tmp39_ = NULL;
						GeeCollection* _tmp40_;
						GeeIterator* _tmp41_ = NULL;
						GeeIterator* _tmp42_;
						GeeIterator* _t_it;
#line 170 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
						_tmp37_ = phone_fd;
#line 170 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
						_tmp38_ = phone_fd;
#line 170 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
						_tmp39_ = folks_abstract_field_details_get_parameter_values ((FolksAbstractFieldDetails*) _tmp37_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE);
#line 170 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
						_tmp40_ = _tmp39_;
#line 170 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
						_tmp41_ = gee_iterable_iterator ((GeeIterable*) _tmp40_);
#line 170 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
						_tmp42_ = _tmp41_;
#line 170 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
						_g_object_unref0 (_tmp40_);
#line 170 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
						_t_it = _tmp42_;
#line 170 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
						while (TRUE) {
#line 1135 "phone-details.c"
							GeeIterator* _tmp43_;
							gboolean _tmp44_ = FALSE;
							GeeIterator* _tmp45_;
							gpointer _tmp46_ = NULL;
							gchar* t;
							gchar* v;
							const gchar* _tmp47_;
							const gchar* _tmp54_;
							GeeHashSet* _tmp55_;
							const gchar* _tmp56_;
							GeeHashMap* _tmp57_;
							const gchar* _tmp58_;
							gpointer _tmp59_ = NULL;
							GValue* _tmp60_;
							const gchar* _tmp61_ = NULL;
							FolksPhoneFieldDetails* _tmp62_;
							gconstpointer _tmp63_;
							const gchar* _tmp64_;
							GeeHashMap* _tmp65_;
							const gchar* _tmp66_;
#line 170 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
							_tmp43_ = _t_it;
#line 170 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
							_tmp44_ = gee_iterator_next (_tmp43_);
#line 170 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
							if (!_tmp44_) {
#line 170 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
								break;
#line 1164 "phone-details.c"
							}
#line 170 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
							_tmp45_ = _t_it;
#line 170 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
							_tmp46_ = gee_iterator_get (_tmp45_);
#line 170 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
							t = (gchar*) _tmp46_;
#line 173 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
							v = NULL;
#line 175 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
							_tmp47_ = t;
#line 175 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
							if (g_strcmp0 (_tmp47_, "car") == 0) {
#line 1178 "phone-details.c"
								gchar* _tmp48_;
#line 177 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
								_tmp48_ = g_strdup ("car_phone");
#line 177 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
								_g_free0 (v);
#line 177 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
								v = _tmp48_;
#line 1186 "phone-details.c"
							} else {
								const gchar* _tmp49_;
								FolksPhoneFieldDetails* _tmp50_;
#line 179 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
								_tmp49_ = t;
#line 179 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
								_tmp50_ = phone_fd;
#line 179 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
								if (g_strcmp0 (_tmp49_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_HOME) == 0) {
#line 1196 "phone-details.c"
									gchar* _tmp51_;
#line 181 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
									_tmp51_ = g_strdup ("home_phone");
#line 181 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
									_g_free0 (v);
#line 181 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
									v = _tmp51_;
#line 1204 "phone-details.c"
								} else {
									const gchar* _tmp52_;
#line 183 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
									_tmp52_ = t;
#line 183 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
									if (g_strcmp0 (_tmp52_, "x-evolution-company") == 0) {
#line 1211 "phone-details.c"
										gchar* _tmp53_;
#line 185 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
										_tmp53_ = g_strdup ("company_phone");
#line 185 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
										_g_free0 (v);
#line 185 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
										v = _tmp53_;
#line 1219 "phone-details.c"
									}
								}
							}
#line 188 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
							_tmp54_ = v;
#line 188 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
							if (_tmp54_ == NULL) {
#line 190 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
								_g_free0 (v);
#line 190 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
								_g_free0 (t);
#line 190 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
								continue;
#line 1233 "phone-details.c"
							}
#line 193 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
							_tmp55_ = self->priv->_phone_types;
#line 193 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
							_tmp56_ = v;
#line 193 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
							gee_abstract_collection_add ((GeeAbstractCollection*) _tmp55_, _tmp56_);
#line 194 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
							_tmp57_ = contact;
#line 194 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
							_tmp58_ = v;
#line 194 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
							_tmp59_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp57_, _tmp58_);
#line 194 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
							_tmp60_ = (GValue*) _tmp59_;
#line 194 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
							_tmp61_ = g_value_get_string (_tmp60_);
#line 194 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
							_tmp62_ = phone_fd;
#line 194 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
							_tmp63_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp62_);
#line 194 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
							_tmp64_ = _tmp63_;
#line 194 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
							g_assert (g_strcmp0 (_tmp61_, (const gchar*) _tmp64_) == 0);
#line 194 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
							__vala_GValue_free0 (_tmp60_);
#line 195 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
							_tmp65_ = contact;
#line 195 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
							_tmp66_ = v;
#line 195 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
							gee_abstract_map_unset ((GeeAbstractMap*) _tmp65_, _tmp66_, NULL);
#line 170 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
							_g_free0 (v);
#line 170 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
							_g_free0 (t);
#line 1271 "phone-details.c"
						}
#line 170 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
						_g_object_unref0 (_t_it);
#line 1275 "phone-details.c"
					}
#line 167 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
					_g_object_unref0 (phone_fd);
#line 1279 "phone-details.c"
				}
#line 167 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
				_g_object_unref0 (_phone_fd_it);
#line 1283 "phone-details.c"
			}
#line 144 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			_g_object_unref0 (phone_numbers);
#line 144 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			_g_object_unref0 (i);
#line 1289 "phone-details.c"
		}
#line 144 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		_g_object_unref0 (_i_it);
#line 1293 "phone-details.c"
	}
#line 200 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp67_ = self->priv->_phones_count;
#line 200 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	if (_tmp67_ == 6) {
#line 1299 "phone-details.c"
		GMainLoop* _tmp68_;
#line 202 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		_tmp68_ = self->priv->_main_loop;
#line 202 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		g_main_loop_quit (_tmp68_);
#line 1305 "phone-details.c"
	}
#line 205 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp69_ = removed;
#line 205 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp70_ = gee_collection_get_size ((GeeCollection*) _tmp69_);
#line 205 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp71_ = _tmp70_;
#line 205 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	g_assert (_tmp71_ == 1);
#line 1315 "phone-details.c"
	{
		GeeSet* _tmp72_;
		GeeIterator* _tmp73_ = NULL;
		GeeIterator* _i_it;
#line 207 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		_tmp72_ = removed;
#line 207 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		_tmp73_ = gee_iterable_iterator ((GeeIterable*) _tmp72_);
#line 207 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		_i_it = _tmp73_;
#line 207 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		while (TRUE) {
#line 1328 "phone-details.c"
			GeeIterator* _tmp74_;
			gboolean _tmp75_ = FALSE;
			GeeIterator* _tmp76_;
			gpointer _tmp77_ = NULL;
			FolksIndividual* i;
			FolksIndividual* _tmp78_;
#line 207 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			_tmp74_ = _i_it;
#line 207 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			_tmp75_ = gee_iterator_next (_tmp74_);
#line 207 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			if (!_tmp75_) {
#line 207 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
				break;
#line 1343 "phone-details.c"
			}
#line 207 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			_tmp76_ = _i_it;
#line 207 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			_tmp77_ = gee_iterator_get (_tmp76_);
#line 207 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			i = (FolksIndividual*) _tmp77_;
#line 209 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			_tmp78_ = i;
#line 209 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			g_assert (_tmp78_ == NULL);
#line 207 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
			_g_object_unref0 (i);
#line 1357 "phone-details.c"
		}
#line 207 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
		_g_object_unref0 (_i_it);
#line 1361 "phone-details.c"
	}
#line 138 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_g_object_unref0 (removed);
#line 138 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_g_object_unref0 (added);
#line 1367 "phone-details.c"
}


static void phone_details_tests_class_init (PhoneDetailsTestsClass * klass) {
#line 25 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	phone_details_tests_parent_class = g_type_class_peek_parent (klass);
#line 25 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	g_type_class_add_private (klass, sizeof (PhoneDetailsTestsPrivate));
#line 25 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	FOLKS_TEST_CASE_CLASS (klass)->set_up = phone_details_tests_real_set_up;
#line 25 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	FOLKS_TEST_CASE_CLASS (klass)->tear_down = phone_details_tests_real_tear_down;
#line 25 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	G_OBJECT_CLASS (klass)->finalize = phone_details_tests_finalize;
#line 1382 "phone-details.c"
}


static void phone_details_tests_instance_init (PhoneDetailsTests * self) {
#line 25 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	self->priv = PHONE_DETAILS_TESTS_GET_PRIVATE (self);
#line 1389 "phone-details.c"
}


static void phone_details_tests_finalize (GObject* obj) {
	PhoneDetailsTests * self;
#line 25 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	self = PHONE_DETAILS_TESTS (obj);
#line 27 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_eds_test_backend_unref0 (self->priv->_eds_backend);
#line 28 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 29 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 31 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_g_object_unref0 (self->priv->_phone_types);
#line 32 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_g_object_unref0 (self->priv->_c1);
#line 33 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_g_object_unref0 (self->priv->_c2);
#line 25 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	G_OBJECT_CLASS (phone_details_tests_parent_class)->finalize (obj);
#line 1411 "phone-details.c"
}


GType phone_details_tests_get_type (void) {
	static volatile gsize phone_details_tests_type_id__volatile = 0;
	if (g_once_init_enter (&phone_details_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PhoneDetailsTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) phone_details_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PhoneDetailsTests), 0, (GInstanceInitFunc) phone_details_tests_instance_init, NULL };
		GType phone_details_tests_type_id;
		phone_details_tests_type_id = g_type_register_static (FOLKS_TYPE_TEST_CASE, "PhoneDetailsTests", &g_define_type_info, 0);
		g_once_init_leave (&phone_details_tests_type_id__volatile, phone_details_tests_type_id);
	}
	return phone_details_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	GTestSuite* _tmp0_ = NULL;
	GTestSuite* root;
	PhoneDetailsTests* _tmp1_;
	PhoneDetailsTests* _tmp2_;
	GTestSuite* _tmp3_ = NULL;
#line 216 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	g_test_init (&args_length1, &args, NULL);
#line 218 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp0_ = g_test_get_root ();
#line 218 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	root = _tmp0_;
#line 219 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp1_ = phone_details_tests_new ();
#line 219 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp2_ = _tmp1_;
#line 219 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_tmp3_ = folks_test_case_get_suite ((FolksTestCase*) _tmp2_);
#line 219 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	g_test_suite_add_suite (root, _tmp3_);
#line 219 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	_g_object_unref0 (_tmp2_);
#line 221 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	g_test_run ();
#line 223 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	result = 0;
#line 223 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	return result;
#line 1456 "phone-details.c"
}


int main (int argc, char ** argv) {
#line 214 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	g_type_init ();
#line 214 "/opt/gnome2/source/folks/tests/eds/phone-details.vala"
	return _vala_main (argv, argc);
#line 1465 "phone-details.c"
}



