/* set-birthday.c generated by valac 0.15.1.20-908e, the Vala compiler
 * generated from set-birthday.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <folks-test.h>
#include <tracker-test.h>
#include <folks/folks.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <folks/folks-tracker.h>
#include <gio/gio.h>


#define TYPE_SET_BIRTHDAY_TESTS (set_birthday_tests_get_type ())
#define SET_BIRTHDAY_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SET_BIRTHDAY_TESTS, SetBirthdayTests))
#define SET_BIRTHDAY_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SET_BIRTHDAY_TESTS, SetBirthdayTestsClass))
#define IS_SET_BIRTHDAY_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SET_BIRTHDAY_TESTS))
#define IS_SET_BIRTHDAY_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SET_BIRTHDAY_TESTS))
#define SET_BIRTHDAY_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SET_BIRTHDAY_TESTS, SetBirthdayTestsClass))

typedef struct _SetBirthdayTests SetBirthdayTests;
typedef struct _SetBirthdayTestsClass SetBirthdayTestsClass;
typedef struct _SetBirthdayTestsPrivate SetBirthdayTestsPrivate;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _tracker_test_backend_unref0(var) ((var == NULL) ? NULL : (var = (tracker_test_backend_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_date_time_unref0(var) ((var == NULL) ? NULL : (var = (g_date_time_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _SetBirthdayTestsTestSetBdayAsyncData SetBirthdayTestsTestSetBdayAsyncData;

struct _SetBirthdayTests {
	FolksTestCase parent_instance;
	SetBirthdayTestsPrivate * priv;
};

struct _SetBirthdayTestsClass {
	FolksTestCaseClass parent_class;
};

struct _SetBirthdayTestsPrivate {
	GMainLoop* _main_loop;
	TrackerTestBackend* _tracker_backend;
	FolksIndividualAggregator* _aggregator;
	gchar* _persona_fullname;
	gboolean _bday_found;
	GDateTime* _bday;
	gchar* _birthday;
};

struct _SetBirthdayTestsTestSetBdayAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	SetBirthdayTests* self;
	FolksBackendStore* _tmp0_;
	FolksBackendStore* store;
	FolksIndividualAggregator* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	GError* e;
	GError* _tmp4_;
	const gchar* _tmp5_;
	GError * _inner_error_;
};


static gpointer set_birthday_tests_parent_class = NULL;

GType set_birthday_tests_get_type (void) G_GNUC_CONST;
#define SET_BIRTHDAY_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_SET_BIRTHDAY_TESTS, SetBirthdayTestsPrivate))
enum  {
	SET_BIRTHDAY_TESTS_DUMMY_PROPERTY
};
SetBirthdayTests* set_birthday_tests_new (void);
SetBirthdayTests* set_birthday_tests_construct (GType object_type);
void set_birthday_tests_test_set_bday (SetBirthdayTests* self);
static void _set_birthday_tests_test_set_bday_folks_test_case_test_method (gpointer self);
static void set_birthday_tests_real_set_up (FolksTestCase* base);
static void set_birthday_tests_real_tear_down (FolksTestCase* base);
static void _set_birthday_tests_test_set_bday_async (SetBirthdayTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _set_birthday_tests_test_set_bday_finish (SetBirthdayTests* self, GAsyncResult* _res_);
static gboolean __lambda2_ (SetBirthdayTests* self);
static gboolean ___lambda2__gsource_func (gpointer self);
static void _set_birthday_tests_test_set_bday_async_data_free (gpointer _data);
static gboolean _set_birthday_tests_test_set_bday_async_co (SetBirthdayTestsTestSetBdayAsyncData* _data_);
static void _set_birthday_tests_test_set_bday_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _set_birthday_tests_individuals_changed_cb (SetBirthdayTests* self, GeeMultiMap* changes);
static void __set_birthday_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void _set_birthday_tests_notify_bday_cb (SetBirthdayTests* self, GObject* individual_obj, GParamSpec* ps);
static void __set_birthday_tests_notify_bday_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void set_birthday_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _set_birthday_tests_test_set_bday_folks_test_case_test_method (gpointer self) {
#line 42 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	set_birthday_tests_test_set_bday (self);
#line 123 "set-birthday.c"
}


SetBirthdayTests* set_birthday_tests_construct (GType object_type) {
	SetBirthdayTests * self = NULL;
	TrackerTestBackend* _tmp0_;
#line 38 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	self = (SetBirthdayTests*) folks_test_case_construct (object_type, "SetBirthdayTests");
#line 40 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_tmp0_ = tracker_test_backend_new ();
#line 40 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_tracker_test_backend_unref0 (self->priv->_tracker_backend);
#line 40 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	self->priv->_tracker_backend = _tmp0_;
#line 42 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "test setting bithday ", _set_birthday_tests_test_set_bday_folks_test_case_test_method, self);
#line 36 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	return self;
#line 142 "set-birthday.c"
}


SetBirthdayTests* set_birthday_tests_new (void) {
#line 36 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	return set_birthday_tests_construct (TYPE_SET_BIRTHDAY_TESTS);
#line 149 "set-birthday.c"
}


static void set_birthday_tests_real_set_up (FolksTestCase* base) {
	SetBirthdayTests * self;
#line 46 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	self = (SetBirthdayTests*) base;
#line 157 "set-birthday.c"
}


static void set_birthday_tests_real_tear_down (FolksTestCase* base) {
	SetBirthdayTests * self;
#line 50 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	self = (SetBirthdayTests*) base;
#line 165 "set-birthday.c"
}


static gboolean __lambda2_ (SetBirthdayTests* self) {
	gboolean result = FALSE;
	GMainLoop* _tmp0_;
#line 76 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_tmp0_ = self->priv->_main_loop;
#line 76 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	g_main_loop_quit (_tmp0_);
#line 77 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	g_assert_not_reached ();
#line 74 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	return result;
#line 180 "set-birthday.c"
}


static gboolean ___lambda2__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda2_ (self);
#line 74 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	return result;
#line 189 "set-birthday.c"
}


void set_birthday_tests_test_set_bday (SetBirthdayTests* self) {
	GMainLoop* _tmp0_;
	GeeHashMap* _tmp1_;
	GeeHashMap* c1;
	gchar* _tmp2_;
	const gchar* _tmp3_;
	TrackerTestBackend* _tmp4_;
	gchar* _tmp5_;
	GTimeVal t = {0};
	const gchar* _tmp6_;
	GTimeVal _tmp7_;
	GDateTime* _tmp8_;
	TrackerTestBackend* _tmp9_;
	GMainLoop* _tmp10_;
	gboolean _tmp11_;
	TrackerTestBackend* _tmp12_;
#line 54 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	g_return_if_fail (self != NULL);
#line 56 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 56 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 56 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	self->priv->_main_loop = _tmp0_;
#line 57 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_tmp1_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL);
#line 57 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	c1 = _tmp1_;
#line 58 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_tmp2_ = g_strdup ("persona #1");
#line 58 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_g_free0 (self->priv->_persona_fullname);
#line 58 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	self->priv->_persona_fullname = _tmp2_;
#line 60 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_tmp3_ = self->priv->_persona_fullname;
#line 60 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, TRF_ONTOLOGY_DEFS_NCO_FULLNAME, _tmp3_);
#line 61 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_tmp4_ = self->priv->_tracker_backend;
#line 61 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	tracker_test_backend_add_contact (_tmp4_, c1);
#line 63 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_tmp5_ = g_strdup ("2001-10-26T20:32:52Z");
#line 63 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_g_free0 (self->priv->_birthday);
#line 63 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	self->priv->_birthday = _tmp5_;
#line 64 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	g_get_current_time (&t);
#line 65 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_tmp6_ = self->priv->_birthday;
#line 65 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	g_time_val_from_iso8601 (_tmp6_, &t);
#line 66 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_tmp7_ = t;
#line 66 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_tmp8_ = g_date_time_new_from_timeval_utc (&_tmp7_);
#line 66 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_g_date_time_unref0 (self->priv->_bday);
#line 66 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	self->priv->_bday = _tmp8_;
#line 68 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_tmp9_ = self->priv->_tracker_backend;
#line 68 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	tracker_test_backend_set_up (_tmp9_);
#line 70 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	self->priv->_bday_found = FALSE;
#line 72 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_set_birthday_tests_test_set_bday_async (self, NULL, NULL);
#line 74 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) 5, ___lambda2__gsource_func, g_object_ref (self), g_object_unref);
#line 80 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_tmp10_ = self->priv->_main_loop;
#line 80 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	g_main_loop_run (_tmp10_);
#line 82 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_tmp11_ = self->priv->_bday_found;
#line 82 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	g_assert (_tmp11_);
#line 84 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_tmp12_ = self->priv->_tracker_backend;
#line 84 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	tracker_test_backend_tear_down (_tmp12_);
#line 54 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_g_object_unref0 (c1);
#line 279 "set-birthday.c"
}


static void _set_birthday_tests_test_set_bday_async_data_free (gpointer _data) {
	SetBirthdayTestsTestSetBdayAsyncData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	g_slice_free (SetBirthdayTestsTestSetBdayAsyncData, _data_);
#line 290 "set-birthday.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 26 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	return self ? g_object_ref (self) : NULL;
#line 297 "set-birthday.c"
}


static void _set_birthday_tests_test_set_bday_async (SetBirthdayTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	SetBirthdayTestsTestSetBdayAsyncData* _data_;
	SetBirthdayTests* _tmp0_;
#line 26 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_data_ = g_slice_new0 (SetBirthdayTestsTestSetBdayAsyncData);
#line 26 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _set_birthday_tests_test_set_bday_async);
#line 26 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _set_birthday_tests_test_set_bday_async_data_free);
#line 26 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_set_birthday_tests_test_set_bday_async_co (_data_);
#line 316 "set-birthday.c"
}


static void _set_birthday_tests_test_set_bday_finish (SetBirthdayTests* self, GAsyncResult* _res_) {
	SetBirthdayTestsTestSetBdayAsyncData* _data_;
#line 26 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 324 "set-birthday.c"
}


static void _set_birthday_tests_test_set_bday_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	SetBirthdayTestsTestSetBdayAsyncData* _data_;
#line 90 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_data_ = _user_data_;
#line 90 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_data_->_source_object_ = source_object;
#line 90 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_data_->_res_ = _res_;
#line 90 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_set_birthday_tests_test_set_bday_async_co (_data_);
#line 338 "set-birthday.c"
}


static void __set_birthday_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 92 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_set_birthday_tests_individuals_changed_cb (self, changes);
#line 345 "set-birthday.c"
}


static gboolean _set_birthday_tests_test_set_bday_async_co (SetBirthdayTestsTestSetBdayAsyncData* _data_) {
#line 87 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	switch (_data_->_state_) {
#line 87 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
		case 0:
#line 354 "set-birthday.c"
		goto _state_0;
#line 87 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
		case 1:
#line 358 "set-birthday.c"
		goto _state_1;
#line 87 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
		case 2:
#line 362 "set-birthday.c"
		goto _state_2;
		default:
#line 87 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
		g_assert_not_reached ();
#line 367 "set-birthday.c"
	}
	_state_0:
#line 89 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_data_->_tmp0_ = NULL;
#line 89 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_data_->_tmp0_ = folks_backend_store_dup ();
#line 89 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_data_->store = _data_->_tmp0_;
#line 90 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_data_->_state_ = 1;
#line 90 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	folks_backend_store_prepare (_data_->store, _set_birthday_tests_test_set_bday_async_ready, _data_);
#line 90 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	return FALSE;
#line 382 "set-birthday.c"
	_state_1:
#line 90 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 91 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_data_->_tmp1_ = folks_individual_aggregator_new ();
#line 91 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 91 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_data_->self->priv->_aggregator = _data_->_tmp1_;
#line 92 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_data_->_tmp2_ = _data_->self->priv->_aggregator;
#line 92 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	g_signal_connect_object (_data_->_tmp2_, "individuals-changed-detailed", (GCallback) __set_birthday_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 396 "set-birthday.c"
	{
#line 96 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
		_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 96 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
		_data_->_state_ = 2;
#line 96 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
		folks_individual_aggregator_prepare (_data_->_tmp3_, _set_birthday_tests_test_set_bday_async_ready, _data_);
#line 96 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
		return FALSE;
#line 406 "set-birthday.c"
		_state_2:
#line 96 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp3_, _data_->_res_, &_data_->_inner_error_);
#line 96 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
		if (_data_->_inner_error_ != NULL) {
#line 412 "set-birthday.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 94 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
		_data_->e = _data_->_inner_error_;
#line 94 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
		_data_->_inner_error_ = NULL;
#line 100 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
		_data_->_tmp4_ = _data_->e;
#line 100 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
		_data_->_tmp5_ = _data_->_tmp4_->message;
#line 100 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
		g_warning ("set-birthday.vala:100: Error when calling prepare: %s\n", _data_->_tmp5_);
#line 94 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
		_g_error_free0 (_data_->e);
#line 431 "set-birthday.c"
	}
	__finally0:
#line 94 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	if (_data_->_inner_error_ != NULL) {
#line 94 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
		_g_object_unref0 (_data_->store);
#line 94 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 94 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
		g_clear_error (&_data_->_inner_error_);
#line 94 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
		return FALSE;
#line 444 "set-birthday.c"
	}
#line 87 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_g_object_unref0 (_data_->store);
#line 87 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	if (_data_->_state_ == 0) {
#line 87 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 452 "set-birthday.c"
	} else {
#line 87 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 456 "set-birthday.c"
	}
#line 87 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	g_object_unref (_data_->_async_result);
#line 87 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	return FALSE;
#line 462 "set-birthday.c"
}


static void __set_birthday_tests_notify_bday_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 116 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_set_birthday_tests_notify_bday_cb (self, _sender, pspec);
#line 469 "set-birthday.c"
}


static void _set_birthday_tests_individuals_changed_cb (SetBirthdayTests* self, GeeMultiMap* changes) {
	GeeMultiMap* _tmp0_;
	GeeCollection* _tmp1_ = NULL;
	GeeCollection* added;
	GeeMultiMap* _tmp2_;
	GeeSet* _tmp3_ = NULL;
	GeeSet* removed;
	GeeSet* _tmp29_;
	gint _tmp30_;
	gint _tmp31_;
#line 104 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	g_return_if_fail (self != NULL);
#line 104 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	g_return_if_fail (changes != NULL);
#line 107 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_tmp0_ = changes;
#line 107 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 107 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	added = _tmp1_;
#line 108 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_tmp2_ = changes;
#line 108 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 108 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	removed = _tmp3_;
#line 499 "set-birthday.c"
	{
		GeeCollection* _tmp4_;
		GeeIterator* _tmp5_ = NULL;
		GeeIterator* _i_it;
#line 110 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
		_tmp4_ = added;
#line 110 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 110 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
		_i_it = _tmp5_;
#line 110 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
		while (TRUE) {
#line 512 "set-birthday.c"
			GeeIterator* _tmp6_;
			gboolean _tmp7_ = FALSE;
			GeeIterator* _tmp8_;
			gpointer _tmp9_ = NULL;
			FolksIndividual* i;
			FolksIndividual* _tmp10_;
			FolksIndividual* _tmp11_;
			const gchar* _tmp12_;
			const gchar* _tmp13_;
			const gchar* _tmp14_;
#line 110 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
			_tmp6_ = _i_it;
#line 110 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 110 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
			if (!_tmp7_) {
#line 110 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
				break;
#line 531 "set-birthday.c"
			}
#line 110 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
			_tmp8_ = _i_it;
#line 110 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 110 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
			i = (FolksIndividual*) _tmp9_;
#line 112 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
			_tmp10_ = i;
#line 112 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
			g_assert (_tmp10_ != NULL);
#line 114 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
			_tmp11_ = i;
#line 114 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
			_tmp12_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp11_);
#line 114 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
			_tmp13_ = _tmp12_;
#line 114 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
			_tmp14_ = self->priv->_persona_fullname;
#line 114 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
			if (g_strcmp0 (_tmp13_, _tmp14_) == 0) {
#line 553 "set-birthday.c"
				FolksIndividual* _tmp15_;
				GTimeVal t = {0};
				const gchar* _tmp16_;
				GTimeVal _tmp17_;
				GDateTime* _tmp18_;
				GDateTime* bday;
#line 116 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
				_tmp15_ = i;
#line 116 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
				g_signal_connect_object ((GObject*) _tmp15_, "notify::birthday", (GCallback) __set_birthday_tests_notify_bday_cb_g_object_notify, self, 0);
#line 118 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
				g_get_current_time (&t);
#line 119 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
				_tmp16_ = self->priv->_birthday;
#line 119 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
				g_time_val_from_iso8601 (_tmp16_, &t);
#line 120 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
				_tmp17_ = t;
#line 120 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
				_tmp18_ = g_date_time_new_from_timeval_utc (&_tmp17_);
#line 120 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
				bday = _tmp18_;
#line 576 "set-birthday.c"
				{
					FolksIndividual* _tmp19_;
					GeeSet* _tmp20_;
					GeeSet* _tmp21_;
					GeeIterator* _tmp22_ = NULL;
					GeeIterator* _p_it;
#line 122 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
					_tmp19_ = i;
#line 122 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
					_tmp20_ = folks_individual_get_personas (_tmp19_);
#line 122 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
					_tmp21_ = _tmp20_;
#line 122 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
					_tmp22_ = gee_iterable_iterator ((GeeIterable*) _tmp21_);
#line 122 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
					_p_it = _tmp22_;
#line 122 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
					while (TRUE) {
#line 595 "set-birthday.c"
						GeeIterator* _tmp23_;
						gboolean _tmp24_ = FALSE;
						GeeIterator* _tmp25_;
						gpointer _tmp26_ = NULL;
						FolksPersona* p;
						FolksPersona* _tmp27_;
						GDateTime* _tmp28_;
#line 122 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
						_tmp23_ = _p_it;
#line 122 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
						_tmp24_ = gee_iterator_next (_tmp23_);
#line 122 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
						if (!_tmp24_) {
#line 122 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
							break;
#line 611 "set-birthday.c"
						}
#line 122 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
						_tmp25_ = _p_it;
#line 122 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
						_tmp26_ = gee_iterator_get (_tmp25_);
#line 122 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
						p = (FolksPersona*) _tmp26_;
#line 124 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
						_tmp27_ = p;
#line 124 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
						_tmp28_ = bday;
#line 124 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
						folks_birthday_details_set_birthday (FOLKS_BIRTHDAY_DETAILS (_tmp27_), _tmp28_);
#line 122 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
						_g_object_unref0 (p);
#line 627 "set-birthday.c"
					}
#line 122 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
					_g_object_unref0 (_p_it);
#line 631 "set-birthday.c"
				}
#line 114 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
				_g_date_time_unref0 (bday);
#line 635 "set-birthday.c"
			}
#line 110 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
			_g_object_unref0 (i);
#line 639 "set-birthday.c"
		}
#line 110 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
		_g_object_unref0 (_i_it);
#line 643 "set-birthday.c"
	}
#line 129 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_tmp29_ = removed;
#line 129 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_tmp30_ = gee_collection_get_size ((GeeCollection*) _tmp29_);
#line 129 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_tmp31_ = _tmp30_;
#line 129 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	g_assert (_tmp31_ == 1);
#line 653 "set-birthday.c"
	{
		GeeSet* _tmp32_;
		GeeIterator* _tmp33_ = NULL;
		GeeIterator* _i_it;
#line 131 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
		_tmp32_ = removed;
#line 131 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
		_tmp33_ = gee_iterable_iterator ((GeeIterable*) _tmp32_);
#line 131 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
		_i_it = _tmp33_;
#line 131 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
		while (TRUE) {
#line 666 "set-birthday.c"
			GeeIterator* _tmp34_;
			gboolean _tmp35_ = FALSE;
			GeeIterator* _tmp36_;
			gpointer _tmp37_ = NULL;
			FolksIndividual* i;
			FolksIndividual* _tmp38_;
#line 131 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
			_tmp34_ = _i_it;
#line 131 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
			_tmp35_ = gee_iterator_next (_tmp34_);
#line 131 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
			if (!_tmp35_) {
#line 131 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
				break;
#line 681 "set-birthday.c"
			}
#line 131 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
			_tmp36_ = _i_it;
#line 131 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
			_tmp37_ = gee_iterator_get (_tmp36_);
#line 131 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
			i = (FolksIndividual*) _tmp37_;
#line 133 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
			_tmp38_ = i;
#line 133 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
			g_assert (_tmp38_ == NULL);
#line 131 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
			_g_object_unref0 (i);
#line 695 "set-birthday.c"
		}
#line 131 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
		_g_object_unref0 (_i_it);
#line 699 "set-birthday.c"
	}
#line 104 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_g_object_unref0 (removed);
#line 104 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_g_object_unref0 (added);
#line 705 "set-birthday.c"
}


static void _set_birthday_tests_notify_bday_cb (SetBirthdayTests* self, GObject* individual_obj, GParamSpec* ps) {
	GObject* _tmp0_;
	FolksIndividual* _tmp1_;
	FolksIndividual* i;
	FolksIndividual* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	const gchar* _tmp5_;
#line 137 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	g_return_if_fail (self != NULL);
#line 137 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	g_return_if_fail (individual_obj != NULL);
#line 137 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	g_return_if_fail (ps != NULL);
#line 139 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_tmp0_ = individual_obj;
#line 139 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_tmp1_ = _g_object_ref0 (FOLKS_INDIVIDUAL (_tmp0_));
#line 139 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	i = _tmp1_;
#line 140 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_tmp2_ = i;
#line 140 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_tmp3_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp2_);
#line 140 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_tmp4_ = _tmp3_;
#line 140 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_tmp5_ = self->priv->_persona_fullname;
#line 140 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	if (g_strcmp0 (_tmp4_, _tmp5_) == 0) {
#line 739 "set-birthday.c"
		gboolean _tmp6_ = FALSE;
		FolksIndividual* _tmp7_;
		GDateTime* _tmp8_;
		GDateTime* _tmp9_;
		gboolean _tmp15_;
#line 142 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
		_tmp7_ = i;
#line 142 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
		_tmp8_ = folks_birthday_details_get_birthday ((FolksBirthdayDetails*) _tmp7_);
#line 142 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
		_tmp9_ = _tmp8_;
#line 142 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
		if (_tmp9_ != NULL) {
#line 753 "set-birthday.c"
			FolksIndividual* _tmp10_;
			GDateTime* _tmp11_;
			GDateTime* _tmp12_;
			GDateTime* _tmp13_;
			gint _tmp14_ = 0;
#line 143 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
			_tmp10_ = i;
#line 143 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
			_tmp11_ = folks_birthday_details_get_birthday ((FolksBirthdayDetails*) _tmp10_);
#line 143 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
			_tmp12_ = _tmp11_;
#line 143 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
			_tmp13_ = self->priv->_bday;
#line 143 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
			_tmp14_ = g_date_time_compare (_tmp12_, _tmp13_);
#line 143 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
			_tmp6_ = _tmp14_ == 0;
#line 771 "set-birthday.c"
		} else {
#line 142 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
			_tmp6_ = FALSE;
#line 775 "set-birthday.c"
		}
#line 142 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
		_tmp15_ = _tmp6_;
#line 142 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
		if (_tmp15_) {
#line 781 "set-birthday.c"
			GMainLoop* _tmp16_;
#line 145 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
			self->priv->_bday_found = TRUE;
#line 146 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
			_tmp16_ = self->priv->_main_loop;
#line 146 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
			g_main_loop_quit (_tmp16_);
#line 789 "set-birthday.c"
		}
	}
#line 137 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_g_object_unref0 (i);
#line 794 "set-birthday.c"
}


static void set_birthday_tests_class_init (SetBirthdayTestsClass * klass) {
#line 26 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	set_birthday_tests_parent_class = g_type_class_peek_parent (klass);
#line 26 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	g_type_class_add_private (klass, sizeof (SetBirthdayTestsPrivate));
#line 26 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	FOLKS_TEST_CASE_CLASS (klass)->set_up = set_birthday_tests_real_set_up;
#line 26 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	FOLKS_TEST_CASE_CLASS (klass)->tear_down = set_birthday_tests_real_tear_down;
#line 26 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	G_OBJECT_CLASS (klass)->finalize = set_birthday_tests_finalize;
#line 809 "set-birthday.c"
}


static void set_birthday_tests_instance_init (SetBirthdayTests * self) {
#line 26 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	self->priv = SET_BIRTHDAY_TESTS_GET_PRIVATE (self);
#line 816 "set-birthday.c"
}


static void set_birthday_tests_finalize (GObject* obj) {
	SetBirthdayTests * self;
#line 26 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	self = SET_BIRTHDAY_TESTS (obj);
#line 28 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 29 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_tracker_test_backend_unref0 (self->priv->_tracker_backend);
#line 30 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 31 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_g_free0 (self->priv->_persona_fullname);
#line 33 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_g_date_time_unref0 (self->priv->_bday);
#line 34 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_g_free0 (self->priv->_birthday);
#line 26 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	G_OBJECT_CLASS (set_birthday_tests_parent_class)->finalize (obj);
#line 838 "set-birthday.c"
}


GType set_birthday_tests_get_type (void) {
	static volatile gsize set_birthday_tests_type_id__volatile = 0;
	if (g_once_init_enter (&set_birthday_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SetBirthdayTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) set_birthday_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SetBirthdayTests), 0, (GInstanceInitFunc) set_birthday_tests_instance_init, NULL };
		GType set_birthday_tests_type_id;
		set_birthday_tests_type_id = g_type_register_static (FOLKS_TYPE_TEST_CASE, "SetBirthdayTests", &g_define_type_info, 0);
		g_once_init_leave (&set_birthday_tests_type_id__volatile, set_birthday_tests_type_id);
	}
	return set_birthday_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	GTestSuite* _tmp0_ = NULL;
	GTestSuite* root;
	SetBirthdayTests* _tmp1_;
	SetBirthdayTests* _tmp2_;
	GTestSuite* _tmp3_ = NULL;
#line 154 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	g_test_init (&args_length1, &args, NULL);
#line 156 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_tmp0_ = g_test_get_root ();
#line 156 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	root = _tmp0_;
#line 157 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_tmp1_ = set_birthday_tests_new ();
#line 157 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_tmp2_ = _tmp1_;
#line 157 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_tmp3_ = folks_test_case_get_suite ((FolksTestCase*) _tmp2_);
#line 157 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	g_test_suite_add_suite (root, _tmp3_);
#line 157 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	_g_object_unref0 (_tmp2_);
#line 159 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	g_test_run ();
#line 161 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	result = 0;
#line 161 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	return result;
#line 883 "set-birthday.c"
}


int main (int argc, char ** argv) {
#line 152 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	g_type_init ();
#line 152 "/opt/gnome2/source/folks/tests/tracker/set-birthday.vala"
	return _vala_main (argv, argc);
#line 892 "set-birthday.c"
}



