/* link-personas-via-local-ids.c generated by valac 0.15.1.20-908e, the Vala compiler
 * generated from link-personas-via-local-ids.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <folks-test.h>
#include <tracker-test.h>
#include <folks/folks.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <gio/gio.h>


#define TYPE_LINK_PERSONAS_VIA_LOCAL_IDS_TESTS (link_personas_via_local_ids_tests_get_type ())
#define LINK_PERSONAS_VIA_LOCAL_IDS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LINK_PERSONAS_VIA_LOCAL_IDS_TESTS, LinkPersonasViaLocalIDsTests))
#define LINK_PERSONAS_VIA_LOCAL_IDS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LINK_PERSONAS_VIA_LOCAL_IDS_TESTS, LinkPersonasViaLocalIDsTestsClass))
#define IS_LINK_PERSONAS_VIA_LOCAL_IDS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LINK_PERSONAS_VIA_LOCAL_IDS_TESTS))
#define IS_LINK_PERSONAS_VIA_LOCAL_IDS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LINK_PERSONAS_VIA_LOCAL_IDS_TESTS))
#define LINK_PERSONAS_VIA_LOCAL_IDS_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LINK_PERSONAS_VIA_LOCAL_IDS_TESTS, LinkPersonasViaLocalIDsTestsClass))

typedef struct _LinkPersonasViaLocalIDsTests LinkPersonasViaLocalIDsTests;
typedef struct _LinkPersonasViaLocalIDsTestsClass LinkPersonasViaLocalIDsTestsClass;
typedef struct _LinkPersonasViaLocalIDsTestsPrivate LinkPersonasViaLocalIDsTestsPrivate;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _tracker_test_backend_unref0(var) ((var == NULL) ? NULL : (var = (tracker_test_backend_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _LinkPersonasViaLocalIdsTestsTestLinkingPersonasViaLocalIdsAsyncData LinkPersonasViaLocalIdsTestsTestLinkingPersonasViaLocalIdsAsyncData;
#define __vala_GValue_free0(var) ((var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL)))
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))
typedef struct _LinkPersonasViaLocalIdsTestsAddPersonasData LinkPersonasViaLocalIdsTestsAddPersonasData;

struct _LinkPersonasViaLocalIDsTests {
	FolksTestCase parent_instance;
	LinkPersonasViaLocalIDsTestsPrivate * priv;
};

struct _LinkPersonasViaLocalIDsTestsClass {
	FolksTestCaseClass parent_class;
};

struct _LinkPersonasViaLocalIDsTestsPrivate {
	GMainLoop* _main_loop;
	TrackerTestBackend* _tracker_backend;
	FolksIndividualAggregator* _aggregator;
	gchar* _persona_fullname_1;
	gchar* _persona_fullname_2;
	gboolean _linking_fired;
	gboolean _persona_found_1;
	gboolean _persona_found_2;
	gchar* _persona_iid_1;
	gchar* _persona_iid_2;
	GeeHashSet* _personas;
	gint _removed_individuals;
	GeeHashSet* _local_ids;
};

struct _LinkPersonasViaLocalIdsTestsTestLinkingPersonasViaLocalIdsAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	LinkPersonasViaLocalIDsTests* self;
	FolksBackendStore* _tmp0_;
	FolksBackendStore* store;
	FolksIndividualAggregator* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	FolksPersonaStore* pstore;
	GeeMap* _tmp4_;
	GeeMap* _tmp5_;
	GeeCollection* _tmp6_;
	GeeCollection* _tmp7_;
	GeeCollection* _tmp8_;
	GeeIterator* _tmp9_;
	GeeIterator* _tmp10_;
	GeeIterator* _backend_it;
	GeeIterator* _tmp11_;
	gboolean _tmp12_;
	GeeIterator* _tmp13_;
	gpointer _tmp14_;
	FolksBackend* backend;
	FolksBackend* _tmp15_;
	GeeMap* _tmp16_;
	GeeMap* _tmp17_;
	gpointer _tmp18_;
	FolksPersonaStore* _tmp19_;
	FolksPersonaStore* _tmp20_;
	FolksPersonaStore* _tmp21_;
	GError* e;
	GError* _tmp22_;
	const gchar* _tmp23_;
	GError * _inner_error_;
};

struct _LinkPersonasViaLocalIdsTestsAddPersonasData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	LinkPersonasViaLocalIDsTests* self;
	FolksPersonaStore* pstore;
	GHashFunc _tmp0_;
	GEqualFunc _tmp1_;
	GHashTable* _tmp2_;
	GHashTable* details1;
	GValue _tmp3_;
	GValue _tmp4_;
	GValue* _tmp5_;
	GValue* _tmp6_;
	GValue* v1;
	GValue* _tmp7_;
	const gchar* _tmp8_;
	GHashTable* _tmp9_;
	gchar* _tmp10_;
	GValue* _tmp11_;
	GHashFunc _tmp12_;
	GEqualFunc _tmp13_;
	GHashTable* _tmp14_;
	GHashTable* details2;
	GValue _tmp15_;
	GValue _tmp16_;
	GValue* _tmp17_;
	GValue* _tmp18_;
	GValue* v2;
	GValue* _tmp19_;
	const gchar* _tmp20_;
	GHashTable* _tmp21_;
	gchar* _tmp22_;
	GValue* _tmp23_;
	FolksIndividualAggregator* _tmp24_;
	FolksPersonaStore* _tmp25_;
	GHashTable* _tmp26_;
	FolksPersona* _tmp27_;
	FolksPersona* _tmp28_;
	FolksIndividualAggregator* _tmp29_;
	FolksPersonaStore* _tmp30_;
	GHashTable* _tmp31_;
	FolksPersona* _tmp32_;
	FolksPersona* _tmp33_;
	GError* e;
	GError* _tmp34_;
	const gchar* _tmp35_;
	GError * _inner_error_;
};


static gpointer link_personas_via_local_ids_tests_parent_class = NULL;

GType link_personas_via_local_ids_tests_get_type (void) G_GNUC_CONST;
#define LINK_PERSONAS_VIA_LOCAL_IDS_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_LINK_PERSONAS_VIA_LOCAL_IDS_TESTS, LinkPersonasViaLocalIDsTestsPrivate))
enum  {
	LINK_PERSONAS_VIA_LOCAL_IDS_TESTS_DUMMY_PROPERTY
};
LinkPersonasViaLocalIDsTests* link_personas_via_local_ids_tests_new (void);
LinkPersonasViaLocalIDsTests* link_personas_via_local_ids_tests_construct (GType object_type);
void link_personas_via_local_ids_tests_test_linking_personas_via_local_ids (LinkPersonasViaLocalIDsTests* self);
static void _link_personas_via_local_ids_tests_test_linking_personas_via_local_ids_folks_test_case_test_method (gpointer self);
static void link_personas_via_local_ids_tests_real_set_up (FolksTestCase* base);
static void link_personas_via_local_ids_tests_real_tear_down (FolksTestCase* base);
static void _link_personas_via_local_ids_tests_test_linking_personas_via_local_ids_async (LinkPersonasViaLocalIDsTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _link_personas_via_local_ids_tests_test_linking_personas_via_local_ids_finish (LinkPersonasViaLocalIDsTests* self, GAsyncResult* _res_);
static gboolean __lambda3_ (LinkPersonasViaLocalIDsTests* self);
static gboolean ___lambda3__gsource_func (gpointer self);
static void _link_personas_via_local_ids_tests_test_linking_personas_via_local_ids_async_data_free (gpointer _data);
static gboolean _link_personas_via_local_ids_tests_test_linking_personas_via_local_ids_async_co (LinkPersonasViaLocalIdsTestsTestLinkingPersonasViaLocalIdsAsyncData* _data_);
static void _link_personas_via_local_ids_tests_test_linking_personas_via_local_ids_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _link_personas_via_local_ids_tests_individuals_changed_cb (LinkPersonasViaLocalIDsTests* self, GeeMultiMap* changes);
static void __link_personas_via_local_ids_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void _link_personas_via_local_ids_tests_add_personas (LinkPersonasViaLocalIDsTests* self, FolksPersonaStore* pstore, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _link_personas_via_local_ids_tests_add_personas_finish (LinkPersonasViaLocalIDsTests* self, GAsyncResult* _res_);
static void _link_personas_via_local_ids_tests_add_personas_data_free (gpointer _data);
static gboolean _link_personas_via_local_ids_tests_add_personas_co (LinkPersonasViaLocalIdsTestsAddPersonasData* _data_);
static void _g_free0_ (gpointer var);
static void _vala_GValue_free (GValue* self);
static void __vala_GValue_free0_ (gpointer var);
static GValue* _g_value_dup (GValue* self);
static void _link_personas_via_local_ids_tests_add_personas_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _link_personas_via_local_ids_tests_notify_cb (LinkPersonasViaLocalIDsTests* self, GObject* individual_obj, GParamSpec* ps);
static void __link_personas_via_local_ids_tests_notify_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _link_personas_via_local_ids_tests_check_personas (LinkPersonasViaLocalIDsTests* self, FolksIndividual* i);
static gboolean ___lambda2_ (LinkPersonasViaLocalIDsTests* self);
static gboolean ____lambda2__gsource_func (gpointer self);
static void link_personas_via_local_ids_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _link_personas_via_local_ids_tests_test_linking_personas_via_local_ids_folks_test_case_test_method (gpointer self) {
#line 48 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	link_personas_via_local_ids_tests_test_linking_personas_via_local_ids (self);
#line 214 "link-personas-via-local-ids.c"
}


LinkPersonasViaLocalIDsTests* link_personas_via_local_ids_tests_construct (GType object_type) {
	LinkPersonasViaLocalIDsTests * self = NULL;
	TrackerTestBackend* _tmp0_;
#line 44 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	self = (LinkPersonasViaLocalIDsTests*) folks_test_case_construct (object_type, "LinkPersonasViaLocalIDsTests");
#line 46 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp0_ = tracker_test_backend_new ();
#line 46 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tracker_test_backend_unref0 (self->priv->_tracker_backend);
#line 46 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	self->priv->_tracker_backend = _tmp0_;
#line 48 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "test linking personas", _link_personas_via_local_ids_tests_test_linking_personas_via_local_ids_folks_test_case_test_method, self);
#line 42 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	return self;
#line 233 "link-personas-via-local-ids.c"
}


LinkPersonasViaLocalIDsTests* link_personas_via_local_ids_tests_new (void) {
#line 42 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	return link_personas_via_local_ids_tests_construct (TYPE_LINK_PERSONAS_VIA_LOCAL_IDS_TESTS);
#line 240 "link-personas-via-local-ids.c"
}


static void link_personas_via_local_ids_tests_real_set_up (FolksTestCase* base) {
	LinkPersonasViaLocalIDsTests * self;
	TrackerTestBackend* _tmp0_;
#line 52 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	self = (LinkPersonasViaLocalIDsTests*) base;
#line 54 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	g_setenv ("FOLKS_PRIMARY_STORE", "tracker", TRUE);
#line 60 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp0_ = self->priv->_tracker_backend;
#line 60 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	tracker_test_backend_set_up (_tmp0_);
#line 255 "link-personas-via-local-ids.c"
}


static void link_personas_via_local_ids_tests_real_tear_down (FolksTestCase* base) {
	LinkPersonasViaLocalIDsTests * self;
	TrackerTestBackend* _tmp0_;
#line 63 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	self = (LinkPersonasViaLocalIDsTests*) base;
#line 65 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp0_ = self->priv->_tracker_backend;
#line 65 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	tracker_test_backend_tear_down (_tmp0_);
#line 67 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	g_unsetenv ("FOLKS_PRIMARY_STORE");
#line 270 "link-personas-via-local-ids.c"
}


static gboolean __lambda3_ (LinkPersonasViaLocalIDsTests* self) {
	gboolean result = FALSE;
	GMainLoop* _tmp0_;
#line 90 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp0_ = self->priv->_main_loop;
#line 90 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	g_main_loop_quit (_tmp0_);
#line 91 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	g_assert_not_reached ();
#line 88 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	return result;
#line 285 "link-personas-via-local-ids.c"
}


static gboolean ___lambda3__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda3_ (self);
#line 88 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	return result;
#line 294 "link-personas-via-local-ids.c"
}


void link_personas_via_local_ids_tests_test_linking_personas_via_local_ids (LinkPersonasViaLocalIDsTests* self) {
	GMainLoop* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	GeeHashSet* _tmp3_;
	GeeHashSet* _tmp4_;
	GMainLoop* _tmp5_;
	GeeHashSet* _tmp6_;
	gint _tmp7_;
	gint _tmp8_;
	gint _tmp9_;
#line 70 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	g_return_if_fail (self != NULL);
#line 72 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 72 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 72 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	self->priv->_main_loop = _tmp0_;
#line 73 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp1_ = g_strdup ("persona #1");
#line 73 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_g_free0 (self->priv->_persona_fullname_1);
#line 73 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	self->priv->_persona_fullname_1 = _tmp1_;
#line 74 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp2_ = g_strdup ("persona #2");
#line 74 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_g_free0 (self->priv->_persona_fullname_2);
#line 74 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	self->priv->_persona_fullname_2 = _tmp2_;
#line 75 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp3_ = gee_hash_set_new (FOLKS_TYPE_PERSONA, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL);
#line 75 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_g_object_unref0 (self->priv->_personas);
#line 75 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	self->priv->_personas = _tmp3_;
#line 77 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	self->priv->_persona_found_1 = FALSE;
#line 78 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	self->priv->_persona_found_2 = FALSE;
#line 79 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	self->priv->_linking_fired = FALSE;
#line 81 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp4_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL);
#line 81 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_g_object_unref0 (self->priv->_local_ids);
#line 81 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	self->priv->_local_ids = _tmp4_;
#line 83 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_link_personas_via_local_ids_tests_test_linking_personas_via_local_ids_async (self, NULL, NULL);
#line 88 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) 8, ___lambda3__gsource_func, g_object_ref (self), g_object_unref);
#line 94 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp5_ = self->priv->_main_loop;
#line 94 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	g_main_loop_run (_tmp5_);
#line 98 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp6_ = self->priv->_local_ids;
#line 98 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp7_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp6_);
#line 98 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp8_ = _tmp7_;
#line 98 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	g_assert (_tmp8_ == 0);
#line 99 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp9_ = self->priv->_removed_individuals;
#line 99 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	g_assert (_tmp9_ == 2);
#line 367 "link-personas-via-local-ids.c"
}


static void _link_personas_via_local_ids_tests_test_linking_personas_via_local_ids_async_data_free (gpointer _data) {
	LinkPersonasViaLocalIdsTestsTestLinkingPersonasViaLocalIdsAsyncData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	g_slice_free (LinkPersonasViaLocalIdsTestsTestLinkingPersonasViaLocalIdsAsyncData, _data_);
#line 378 "link-personas-via-local-ids.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 26 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	return self ? g_object_ref (self) : NULL;
#line 385 "link-personas-via-local-ids.c"
}


static void _link_personas_via_local_ids_tests_test_linking_personas_via_local_ids_async (LinkPersonasViaLocalIDsTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	LinkPersonasViaLocalIdsTestsTestLinkingPersonasViaLocalIdsAsyncData* _data_;
	LinkPersonasViaLocalIDsTests* _tmp0_;
#line 26 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_ = g_slice_new0 (LinkPersonasViaLocalIdsTestsTestLinkingPersonasViaLocalIdsAsyncData);
#line 26 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _link_personas_via_local_ids_tests_test_linking_personas_via_local_ids_async);
#line 26 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _link_personas_via_local_ids_tests_test_linking_personas_via_local_ids_async_data_free);
#line 26 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_link_personas_via_local_ids_tests_test_linking_personas_via_local_ids_async_co (_data_);
#line 404 "link-personas-via-local-ids.c"
}


static void _link_personas_via_local_ids_tests_test_linking_personas_via_local_ids_finish (LinkPersonasViaLocalIDsTests* self, GAsyncResult* _res_) {
	LinkPersonasViaLocalIdsTestsTestLinkingPersonasViaLocalIdsAsyncData* _data_;
#line 26 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 412 "link-personas-via-local-ids.c"
}


static void _link_personas_via_local_ids_tests_test_linking_personas_via_local_ids_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	LinkPersonasViaLocalIdsTestsTestLinkingPersonasViaLocalIdsAsyncData* _data_;
#line 105 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_ = _user_data_;
#line 105 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->_source_object_ = source_object;
#line 105 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->_res_ = _res_;
#line 105 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_link_personas_via_local_ids_tests_test_linking_personas_via_local_ids_async_co (_data_);
#line 426 "link-personas-via-local-ids.c"
}


static void __link_personas_via_local_ids_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 107 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_link_personas_via_local_ids_tests_individuals_changed_cb (self, changes);
#line 433 "link-personas-via-local-ids.c"
}


static gboolean _link_personas_via_local_ids_tests_test_linking_personas_via_local_ids_async_co (LinkPersonasViaLocalIdsTestsTestLinkingPersonasViaLocalIdsAsyncData* _data_) {
#line 102 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	switch (_data_->_state_) {
#line 102 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		case 0:
#line 442 "link-personas-via-local-ids.c"
		goto _state_0;
#line 102 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		case 1:
#line 446 "link-personas-via-local-ids.c"
		goto _state_1;
#line 102 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		case 2:
#line 450 "link-personas-via-local-ids.c"
		goto _state_2;
#line 102 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		case 3:
#line 454 "link-personas-via-local-ids.c"
		goto _state_3;
		default:
#line 102 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		g_assert_not_reached ();
#line 459 "link-personas-via-local-ids.c"
	}
	_state_0:
#line 104 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->_tmp0_ = NULL;
#line 104 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->_tmp0_ = folks_backend_store_dup ();
#line 104 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->store = _data_->_tmp0_;
#line 105 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->_state_ = 1;
#line 105 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	folks_backend_store_prepare (_data_->store, _link_personas_via_local_ids_tests_test_linking_personas_via_local_ids_async_ready, _data_);
#line 105 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	return FALSE;
#line 474 "link-personas-via-local-ids.c"
	_state_1:
#line 105 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 106 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->_tmp1_ = folks_individual_aggregator_new ();
#line 106 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 106 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->self->priv->_aggregator = _data_->_tmp1_;
#line 107 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->_tmp2_ = _data_->self->priv->_aggregator;
#line 107 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	g_signal_connect_object (_data_->_tmp2_, "individuals-changed-detailed", (GCallback) __link_personas_via_local_ids_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 488 "link-personas-via-local-ids.c"
	{
#line 111 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 111 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_data_->_state_ = 2;
#line 111 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		folks_individual_aggregator_prepare (_data_->_tmp3_, _link_personas_via_local_ids_tests_test_linking_personas_via_local_ids_async_ready, _data_);
#line 111 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		return FALSE;
#line 498 "link-personas-via-local-ids.c"
		_state_2:
#line 111 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp3_, _data_->_res_, &_data_->_inner_error_);
#line 111 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		if (_data_->_inner_error_ != NULL) {
#line 504 "link-personas-via-local-ids.c"
			goto __catch0_g_error;
		}
#line 113 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_data_->pstore = NULL;
#line 509 "link-personas-via-local-ids.c"
		{
#line 114 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_data_->_tmp4_ = folks_backend_store_get_enabled_backends (_data_->store);
#line 114 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_data_->_tmp5_ = _data_->_tmp4_;
#line 114 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_data_->_tmp6_ = gee_map_get_values (_data_->_tmp5_);
#line 114 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_data_->_tmp7_ = _data_->_tmp6_;
#line 114 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_data_->_tmp8_ = _data_->_tmp7_;
#line 114 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_data_->_tmp9_ = NULL;
#line 114 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_data_->_tmp9_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp8_);
#line 114 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_data_->_tmp10_ = _data_->_tmp9_;
#line 114 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_g_object_unref0 (_data_->_tmp8_);
#line 114 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_data_->_backend_it = _data_->_tmp10_;
#line 114 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			while (TRUE) {
#line 114 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
				_data_->_tmp11_ = _data_->_backend_it;
#line 114 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
				_data_->_tmp12_ = FALSE;
#line 114 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
				_data_->_tmp12_ = gee_iterator_next (_data_->_tmp11_);
#line 114 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
				if (!_data_->_tmp12_) {
#line 114 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
					break;
#line 543 "link-personas-via-local-ids.c"
				}
#line 114 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
				_data_->_tmp13_ = _data_->_backend_it;
#line 114 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
				_data_->_tmp14_ = NULL;
#line 114 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
				_data_->_tmp14_ = gee_iterator_get (_data_->_tmp13_);
#line 114 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
				_data_->backend = (FolksBackend*) _data_->_tmp14_;
#line 116 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
				_data_->_tmp15_ = _data_->backend;
#line 116 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
				_data_->_tmp16_ = folks_backend_get_persona_stores (_data_->_tmp15_);
#line 116 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
				_data_->_tmp17_ = _data_->_tmp16_;
#line 116 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
				_data_->_tmp18_ = NULL;
#line 116 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
				_data_->_tmp18_ = gee_map_get (_data_->_tmp17_, "tracker");
#line 116 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
				_g_object_unref0 (_data_->pstore);
#line 116 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
				_data_->pstore = (FolksPersonaStore*) _data_->_tmp18_;
#line 117 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
				_data_->_tmp19_ = _data_->pstore;
#line 117 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
				if (_data_->_tmp19_ != NULL) {
#line 118 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
					_g_object_unref0 (_data_->backend);
#line 118 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
					break;
#line 575 "link-personas-via-local-ids.c"
				}
#line 114 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
				_g_object_unref0 (_data_->backend);
#line 579 "link-personas-via-local-ids.c"
			}
#line 114 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_g_object_unref0 (_data_->_backend_it);
#line 583 "link-personas-via-local-ids.c"
		}
#line 120 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_data_->_tmp20_ = _data_->pstore;
#line 120 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		g_assert (_data_->_tmp20_ != NULL);
#line 122 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_data_->_tmp21_ = _data_->pstore;
#line 122 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_data_->_state_ = 3;
#line 122 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_link_personas_via_local_ids_tests_add_personas (_data_->self, _data_->_tmp21_, _link_personas_via_local_ids_tests_test_linking_personas_via_local_ids_async_ready, _data_);
#line 122 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		return FALSE;
#line 597 "link-personas-via-local-ids.c"
		_state_3:
#line 122 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_link_personas_via_local_ids_tests_add_personas_finish (_data_->self, _data_->_res_);
#line 109 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_g_object_unref0 (_data_->pstore);
#line 603 "link-personas-via-local-ids.c"
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 109 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_data_->e = _data_->_inner_error_;
#line 109 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_data_->_inner_error_ = NULL;
#line 126 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_data_->_tmp22_ = _data_->e;
#line 126 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_data_->_tmp23_ = _data_->_tmp22_->message;
#line 126 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		g_warning ("link-personas-via-local-ids.vala:126: Error when calling prepare: %s\n", _data_->_tmp23_);
#line 109 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_g_error_free0 (_data_->e);
#line 620 "link-personas-via-local-ids.c"
	}
	__finally0:
#line 109 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	if (_data_->_inner_error_ != NULL) {
#line 109 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_g_object_unref0 (_data_->store);
#line 109 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 109 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		g_clear_error (&_data_->_inner_error_);
#line 109 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		return FALSE;
#line 633 "link-personas-via-local-ids.c"
	}
#line 102 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_g_object_unref0 (_data_->store);
#line 102 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	if (_data_->_state_ == 0) {
#line 102 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 641 "link-personas-via-local-ids.c"
	} else {
#line 102 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 645 "link-personas-via-local-ids.c"
	}
#line 102 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	g_object_unref (_data_->_async_result);
#line 102 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	return FALSE;
#line 651 "link-personas-via-local-ids.c"
}


static void _link_personas_via_local_ids_tests_add_personas_data_free (gpointer _data) {
	LinkPersonasViaLocalIdsTestsAddPersonasData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_g_object_unref0 (_data_->pstore);
#line 26 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	g_slice_free (LinkPersonasViaLocalIdsTestsAddPersonasData, _data_);
#line 664 "link-personas-via-local-ids.c"
}


static void _link_personas_via_local_ids_tests_add_personas (LinkPersonasViaLocalIDsTests* self, FolksPersonaStore* pstore, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	LinkPersonasViaLocalIdsTestsAddPersonasData* _data_;
	LinkPersonasViaLocalIDsTests* _tmp0_;
	FolksPersonaStore* _tmp1_;
	FolksPersonaStore* _tmp2_;
#line 26 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_ = g_slice_new0 (LinkPersonasViaLocalIdsTestsAddPersonasData);
#line 26 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _link_personas_via_local_ids_tests_add_personas);
#line 26 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _link_personas_via_local_ids_tests_add_personas_data_free);
#line 26 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp1_ = pstore;
#line 26 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 26 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->pstore = _tmp2_;
#line 26 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_link_personas_via_local_ids_tests_add_personas_co (_data_);
#line 691 "link-personas-via-local-ids.c"
}


static void _link_personas_via_local_ids_tests_add_personas_finish (LinkPersonasViaLocalIDsTests* self, GAsyncResult* _res_) {
	LinkPersonasViaLocalIdsTestsAddPersonasData* _data_;
#line 26 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 699 "link-personas-via-local-ids.c"
}


static void _g_free0_ (gpointer var) {
#line 140 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	var = (g_free (var), NULL);
#line 706 "link-personas-via-local-ids.c"
}


static void _vala_GValue_free (GValue* self) {
#line 140 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	g_value_unset (self);
#line 140 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	g_free (self);
#line 715 "link-personas-via-local-ids.c"
}


static void __vala_GValue_free0_ (gpointer var) {
#line 140 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	(var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL));
#line 722 "link-personas-via-local-ids.c"
}


static GValue* _g_value_dup (GValue* self) {
#line 142 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	return g_boxed_copy (G_TYPE_VALUE, self);
#line 729 "link-personas-via-local-ids.c"
}


static gpointer __g_value_dup0 (gpointer self) {
#line 142 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	return self ? _g_value_dup (self) : NULL;
#line 736 "link-personas-via-local-ids.c"
}


static void _link_personas_via_local_ids_tests_add_personas_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	LinkPersonasViaLocalIdsTestsAddPersonasData* _data_;
#line 154 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_ = _user_data_;
#line 154 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->_source_object_ = source_object;
#line 154 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->_res_ = _res_;
#line 154 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_link_personas_via_local_ids_tests_add_personas_co (_data_);
#line 750 "link-personas-via-local-ids.c"
}


static gboolean _link_personas_via_local_ids_tests_add_personas_co (LinkPersonasViaLocalIdsTestsAddPersonasData* _data_) {
#line 138 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	switch (_data_->_state_) {
#line 138 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		case 0:
#line 759 "link-personas-via-local-ids.c"
		goto _state_0;
#line 138 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		case 1:
#line 763 "link-personas-via-local-ids.c"
		goto _state_1;
#line 138 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		case 2:
#line 767 "link-personas-via-local-ids.c"
		goto _state_2;
		default:
#line 138 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		g_assert_not_reached ();
#line 772 "link-personas-via-local-ids.c"
	}
	_state_0:
#line 140 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->_tmp0_ = g_str_hash;
#line 140 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->_tmp1_ = g_str_equal;
#line 140 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->_tmp2_ = g_hash_table_new_full (_data_->_tmp0_, _data_->_tmp1_, _g_free0_, __vala_GValue_free0_);
#line 140 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->details1 = _data_->_tmp2_;
#line 142 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	memset (&_data_->_tmp3_, 0, sizeof (GValue));
#line 142 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	g_value_init (&_data_->_tmp3_, G_TYPE_STRING);
#line 142 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->_tmp4_ = _data_->_tmp3_;
#line 142 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->_tmp5_ = __g_value_dup0 (&_data_->_tmp4_);
#line 142 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->_tmp6_ = _data_->_tmp5_;
#line 142 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	G_IS_VALUE (&_data_->_tmp4_) ? (g_value_unset (&_data_->_tmp4_), NULL) : NULL;
#line 142 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->v1 = _data_->_tmp6_;
#line 143 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->_tmp7_ = _data_->v1;
#line 143 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->_tmp8_ = _data_->self->priv->_persona_fullname_1;
#line 143 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	g_value_set_string (_data_->_tmp7_, _data_->_tmp8_);
#line 144 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->_tmp9_ = _data_->details1;
#line 144 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->_tmp10_ = g_strdup ("full-name");
#line 144 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->_tmp11_ = _data_->v1;
#line 144 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->v1 = NULL;
#line 144 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	g_hash_table_insert (_data_->_tmp9_, _data_->_tmp10_, _data_->_tmp11_);
#line 146 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->_tmp12_ = g_str_hash;
#line 146 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->_tmp13_ = g_str_equal;
#line 146 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->_tmp14_ = g_hash_table_new_full (_data_->_tmp12_, _data_->_tmp13_, _g_free0_, __vala_GValue_free0_);
#line 146 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->details2 = _data_->_tmp14_;
#line 148 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	memset (&_data_->_tmp15_, 0, sizeof (GValue));
#line 148 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	g_value_init (&_data_->_tmp15_, G_TYPE_STRING);
#line 148 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->_tmp16_ = _data_->_tmp15_;
#line 148 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->_tmp17_ = __g_value_dup0 (&_data_->_tmp16_);
#line 148 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->_tmp18_ = _data_->_tmp17_;
#line 148 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	G_IS_VALUE (&_data_->_tmp16_) ? (g_value_unset (&_data_->_tmp16_), NULL) : NULL;
#line 148 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->v2 = _data_->_tmp18_;
#line 149 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->_tmp19_ = _data_->v2;
#line 149 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->_tmp20_ = _data_->self->priv->_persona_fullname_2;
#line 149 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	g_value_set_string (_data_->_tmp19_, _data_->_tmp20_);
#line 150 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->_tmp21_ = _data_->details2;
#line 150 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->_tmp22_ = g_strdup ("full-name");
#line 150 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->_tmp23_ = _data_->v2;
#line 150 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_data_->v2 = NULL;
#line 150 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	g_hash_table_insert (_data_->_tmp21_, _data_->_tmp22_, _data_->_tmp23_);
#line 851 "link-personas-via-local-ids.c"
	{
#line 154 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_data_->_tmp24_ = _data_->self->priv->_aggregator;
#line 154 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_data_->_tmp25_ = _data_->pstore;
#line 154 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_data_->_tmp26_ = _data_->details1;
#line 154 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_data_->_state_ = 1;
#line 154 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		folks_individual_aggregator_add_persona_from_details (_data_->_tmp24_, NULL, _data_->_tmp25_, _data_->_tmp26_, _link_personas_via_local_ids_tests_add_personas_ready, _data_);
#line 154 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		return FALSE;
#line 865 "link-personas-via-local-ids.c"
		_state_1:
#line 154 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_data_->_tmp27_ = NULL;
#line 154 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_data_->_tmp27_ = folks_individual_aggregator_add_persona_from_details_finish (_data_->_tmp24_, _data_->_res_, &_data_->_inner_error_);
#line 154 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_data_->_tmp28_ = _data_->_tmp27_;
#line 154 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_g_object_unref0 (_data_->_tmp28_);
#line 154 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		if (_data_->_inner_error_ != NULL) {
#line 154 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			if (_data_->_inner_error_->domain == FOLKS_INDIVIDUAL_AGGREGATOR_ERROR) {
#line 879 "link-personas-via-local-ids.c"
				goto __catch1_folks_individual_aggregator_error;
			}
#line 154 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			__vala_GValue_free0 (_data_->v2);
#line 154 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_g_hash_table_unref0 (_data_->details2);
#line 154 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			__vala_GValue_free0 (_data_->v1);
#line 154 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_g_hash_table_unref0 (_data_->details1);
#line 154 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 154 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			g_clear_error (&_data_->_inner_error_);
#line 154 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			return FALSE;
#line 896 "link-personas-via-local-ids.c"
		}
#line 157 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_data_->_tmp29_ = _data_->self->priv->_aggregator;
#line 157 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_data_->_tmp30_ = _data_->pstore;
#line 157 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_data_->_tmp31_ = _data_->details2;
#line 157 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_data_->_state_ = 2;
#line 157 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		folks_individual_aggregator_add_persona_from_details (_data_->_tmp29_, NULL, _data_->_tmp30_, _data_->_tmp31_, _link_personas_via_local_ids_tests_add_personas_ready, _data_);
#line 157 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		return FALSE;
#line 910 "link-personas-via-local-ids.c"
		_state_2:
#line 157 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_data_->_tmp32_ = NULL;
#line 157 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_data_->_tmp32_ = folks_individual_aggregator_add_persona_from_details_finish (_data_->_tmp29_, _data_->_res_, &_data_->_inner_error_);
#line 157 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_data_->_tmp33_ = _data_->_tmp32_;
#line 157 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_g_object_unref0 (_data_->_tmp33_);
#line 157 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		if (_data_->_inner_error_ != NULL) {
#line 157 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			if (_data_->_inner_error_->domain == FOLKS_INDIVIDUAL_AGGREGATOR_ERROR) {
#line 924 "link-personas-via-local-ids.c"
				goto __catch1_folks_individual_aggregator_error;
			}
#line 157 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			__vala_GValue_free0 (_data_->v2);
#line 157 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_g_hash_table_unref0 (_data_->details2);
#line 157 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			__vala_GValue_free0 (_data_->v1);
#line 157 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_g_hash_table_unref0 (_data_->details1);
#line 157 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 157 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			g_clear_error (&_data_->_inner_error_);
#line 157 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			return FALSE;
#line 941 "link-personas-via-local-ids.c"
		}
	}
	goto __finally1;
	__catch1_folks_individual_aggregator_error:
	{
#line 152 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_data_->e = _data_->_inner_error_;
#line 152 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_data_->_inner_error_ = NULL;
#line 162 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_data_->_tmp34_ = _data_->e;
#line 162 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_data_->_tmp35_ = _data_->_tmp34_->message;
#line 162 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		g_warning ("link-personas-via-local-ids.vala:162: [AddPersonaError] add_persona_fr" \
"om_details: %s\n", _data_->_tmp35_);
#line 152 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_g_error_free0 (_data_->e);
#line 959 "link-personas-via-local-ids.c"
	}
	__finally1:
#line 152 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	if (_data_->_inner_error_ != NULL) {
#line 152 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		__vala_GValue_free0 (_data_->v2);
#line 152 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_g_hash_table_unref0 (_data_->details2);
#line 152 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		__vala_GValue_free0 (_data_->v1);
#line 152 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_g_hash_table_unref0 (_data_->details1);
#line 152 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 152 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		g_clear_error (&_data_->_inner_error_);
#line 152 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		return FALSE;
#line 978 "link-personas-via-local-ids.c"
	}
#line 138 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	__vala_GValue_free0 (_data_->v2);
#line 138 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_g_hash_table_unref0 (_data_->details2);
#line 138 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	__vala_GValue_free0 (_data_->v1);
#line 138 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_g_hash_table_unref0 (_data_->details1);
#line 138 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	if (_data_->_state_ == 0) {
#line 138 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 992 "link-personas-via-local-ids.c"
	} else {
#line 138 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 996 "link-personas-via-local-ids.c"
	}
#line 138 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	g_object_unref (_data_->_async_result);
#line 138 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	return FALSE;
#line 1002 "link-personas-via-local-ids.c"
}


static void __link_personas_via_local_ids_tests_notify_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 184 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_link_personas_via_local_ids_tests_notify_cb (self, _sender, pspec);
#line 1009 "link-personas-via-local-ids.c"
}


static void _link_personas_via_local_ids_tests_individuals_changed_cb (LinkPersonasViaLocalIDsTests* self, GeeMultiMap* changes) {
	GeeMultiMap* _tmp0_;
	GeeCollection* _tmp1_ = NULL;
	GeeCollection* added;
	GeeMultiMap* _tmp2_;
	GeeSet* _tmp3_ = NULL;
	GeeSet* removed;
#line 167 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	g_return_if_fail (self != NULL);
#line 167 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	g_return_if_fail (changes != NULL);
#line 170 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp0_ = changes;
#line 170 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 170 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	added = _tmp1_;
#line 171 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp2_ = changes;
#line 171 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 171 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	removed = _tmp3_;
#line 1036 "link-personas-via-local-ids.c"
	{
		GeeCollection* _tmp4_;
		GeeIterator* _tmp5_ = NULL;
		GeeIterator* _i_it;
#line 173 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_tmp4_ = added;
#line 173 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 173 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_i_it = _tmp5_;
#line 173 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		while (TRUE) {
#line 1049 "link-personas-via-local-ids.c"
			GeeIterator* _tmp6_;
			gboolean _tmp7_ = FALSE;
			GeeIterator* _tmp8_;
			gpointer _tmp9_ = NULL;
			FolksIndividual* i;
			FolksIndividual* _tmp10_;
			FolksIndividual* _tmp11_;
			gboolean _tmp12_;
			gboolean _tmp13_;
#line 173 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_tmp6_ = _i_it;
#line 173 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 173 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			if (!_tmp7_) {
#line 173 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
				break;
#line 1067 "link-personas-via-local-ids.c"
			}
#line 173 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_tmp8_ = _i_it;
#line 173 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 173 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			i = (FolksIndividual*) _tmp9_;
#line 175 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_tmp10_ = i;
#line 175 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			if (_tmp10_ == NULL) {
#line 177 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
				_g_object_unref0 (i);
#line 177 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
				continue;
#line 1083 "link-personas-via-local-ids.c"
			}
#line 182 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_tmp11_ = i;
#line 182 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_tmp12_ = folks_individual_get_is_user (_tmp11_);
#line 182 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_tmp13_ = _tmp12_;
#line 182 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			if (!_tmp13_) {
#line 1093 "link-personas-via-local-ids.c"
				FolksIndividual* _tmp14_;
				FolksIndividual* _tmp15_;
				FolksIndividual* _tmp16_;
#line 184 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
				_tmp14_ = i;
#line 184 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
				g_signal_connect_object ((GObject*) _tmp14_, "notify::full-name", (GCallback) __link_personas_via_local_ids_tests_notify_cb_g_object_notify, self, 0);
#line 185 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
				_tmp15_ = i;
#line 185 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
				g_signal_connect_object ((GObject*) _tmp15_, "notify::local-ids", (GCallback) __link_personas_via_local_ids_tests_notify_cb_g_object_notify, self, 0);
#line 186 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
				_tmp16_ = i;
#line 186 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
				_link_personas_via_local_ids_tests_check_personas (self, _tmp16_);
#line 1109 "link-personas-via-local-ids.c"
			}
#line 173 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_g_object_unref0 (i);
#line 1113 "link-personas-via-local-ids.c"
		}
#line 173 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_g_object_unref0 (_i_it);
#line 1117 "link-personas-via-local-ids.c"
	}
	{
		GeeSet* _tmp17_;
		GeeIterator* _tmp18_ = NULL;
		GeeIterator* _i_it;
#line 190 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_tmp17_ = removed;
#line 190 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_tmp18_ = gee_iterable_iterator ((GeeIterable*) _tmp17_);
#line 190 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_i_it = _tmp18_;
#line 190 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		while (TRUE) {
#line 1131 "link-personas-via-local-ids.c"
			GeeIterator* _tmp19_;
			gboolean _tmp20_ = FALSE;
			GeeIterator* _tmp21_;
			gpointer _tmp22_ = NULL;
			FolksIndividual* i;
			FolksIndividual* _tmp23_;
			gint _tmp24_;
#line 190 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_tmp19_ = _i_it;
#line 190 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_tmp20_ = gee_iterator_next (_tmp19_);
#line 190 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			if (!_tmp20_) {
#line 190 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
				break;
#line 1147 "link-personas-via-local-ids.c"
			}
#line 190 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_tmp21_ = _i_it;
#line 190 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_tmp22_ = gee_iterator_get (_tmp21_);
#line 190 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			i = (FolksIndividual*) _tmp22_;
#line 192 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_tmp23_ = i;
#line 192 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			if (_tmp23_ == NULL) {
#line 194 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
				_g_object_unref0 (i);
#line 194 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
				continue;
#line 1163 "link-personas-via-local-ids.c"
			}
#line 197 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_tmp24_ = self->priv->_removed_individuals;
#line 197 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			self->priv->_removed_individuals = _tmp24_ + 1;
#line 190 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_g_object_unref0 (i);
#line 1171 "link-personas-via-local-ids.c"
		}
#line 190 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_g_object_unref0 (_i_it);
#line 1175 "link-personas-via-local-ids.c"
	}
#line 167 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_g_object_unref0 (removed);
#line 167 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_g_object_unref0 (added);
#line 1181 "link-personas-via-local-ids.c"
}


static void _link_personas_via_local_ids_tests_notify_cb (LinkPersonasViaLocalIDsTests* self, GObject* individual_obj, GParamSpec* ps) {
	GObject* _tmp0_;
	FolksIndividual* _tmp1_;
	FolksIndividual* i;
#line 201 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	g_return_if_fail (self != NULL);
#line 201 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	g_return_if_fail (individual_obj != NULL);
#line 201 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	g_return_if_fail (ps != NULL);
#line 203 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp0_ = individual_obj;
#line 203 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp1_ = _g_object_ref0 (FOLKS_INDIVIDUAL (_tmp0_));
#line 203 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	i = _tmp1_;
#line 204 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_link_personas_via_local_ids_tests_check_personas (self, i);
#line 201 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_g_object_unref0 (i);
#line 1205 "link-personas-via-local-ids.c"
}


static gboolean ___lambda2_ (LinkPersonasViaLocalIDsTests* self) {
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_;
	GeeHashSet* _tmp1_;
#line 268 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp0_ = self->priv->_aggregator;
#line 268 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp1_ = self->priv->_personas;
#line 268 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	folks_individual_aggregator_link_personas (_tmp0_, (GeeSet*) _tmp1_, NULL, NULL);
#line 269 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	result = FALSE;
#line 269 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	return result;
#line 1223 "link-personas-via-local-ids.c"
}


static gboolean ____lambda2__gsource_func (gpointer self) {
	gboolean result;
	result = ___lambda2_ (self);
#line 266 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	return result;
#line 1232 "link-personas-via-local-ids.c"
}


static void _link_personas_via_local_ids_tests_check_personas (LinkPersonasViaLocalIDsTests* self, FolksIndividual* i) {
	FolksPersona* first_persona;
	gboolean _tmp8_ = FALSE;
	FolksIndividual* _tmp9_;
	const gchar* _tmp10_;
	const gchar* _tmp11_;
	const gchar* _tmp12_;
	gboolean _tmp14_;
	gboolean _tmp60_ = FALSE;
	GeeHashSet* _tmp61_;
	gint _tmp62_;
	gint _tmp63_;
	gboolean _tmp65_;
#line 217 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	g_return_if_fail (self != NULL);
#line 217 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	g_return_if_fail (i != NULL);
#line 219 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	first_persona = NULL;
#line 1255 "link-personas-via-local-ids.c"
	{
		FolksIndividual* _tmp0_;
		GeeSet* _tmp1_;
		GeeSet* _tmp2_;
		GeeIterator* _tmp3_ = NULL;
		GeeIterator* _p_it;
#line 220 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_tmp0_ = i;
#line 220 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_tmp1_ = folks_individual_get_personas (_tmp0_);
#line 220 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_tmp2_ = _tmp1_;
#line 220 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_tmp3_ = gee_iterable_iterator ((GeeIterable*) _tmp2_);
#line 220 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_p_it = _tmp3_;
#line 220 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		while (TRUE) {
#line 1274 "link-personas-via-local-ids.c"
			gboolean _tmp4_ = FALSE;
			gpointer _tmp5_ = NULL;
			FolksPersona* p;
			FolksPersona* _tmp6_;
			FolksPersona* _tmp7_;
#line 220 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_tmp4_ = gee_iterator_next (_p_it);
#line 220 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			if (!_tmp4_) {
#line 220 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
				break;
#line 1286 "link-personas-via-local-ids.c"
			}
#line 220 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_tmp5_ = gee_iterator_get (_p_it);
#line 220 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			p = (FolksPersona*) _tmp5_;
#line 222 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_tmp6_ = p;
#line 222 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_tmp7_ = _g_object_ref0 (_tmp6_);
#line 222 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_g_object_unref0 (first_persona);
#line 222 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			first_persona = _tmp7_;
#line 223 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_g_object_unref0 (p);
#line 223 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			break;
#line 1304 "link-personas-via-local-ids.c"
		}
#line 220 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_g_object_unref0 (_p_it);
#line 1308 "link-personas-via-local-ids.c"
	}
#line 226 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp9_ = i;
#line 226 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp10_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp9_);
#line 226 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp11_ = _tmp10_;
#line 226 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp12_ = self->priv->_persona_fullname_1;
#line 226 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	if (g_strcmp0 (_tmp11_, _tmp12_) == 0) {
#line 1320 "link-personas-via-local-ids.c"
		const gchar* _tmp13_;
#line 227 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_tmp13_ = self->priv->_persona_iid_1;
#line 227 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_tmp8_ = g_strcmp0 (_tmp13_, "") == 0;
#line 1326 "link-personas-via-local-ids.c"
	} else {
#line 226 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_tmp8_ = FALSE;
#line 1330 "link-personas-via-local-ids.c"
	}
#line 226 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp14_ = _tmp8_;
#line 226 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	if (_tmp14_) {
#line 1336 "link-personas-via-local-ids.c"
		FolksPersona* _tmp15_;
		const gchar* _tmp16_;
		const gchar* _tmp17_;
		gchar* _tmp18_;
		GeeHashSet* _tmp19_;
		FolksPersona* _tmp20_;
		GeeHashSet* _tmp21_;
		const gchar* _tmp22_;
#line 229 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_tmp15_ = first_persona;
#line 229 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_tmp16_ = folks_persona_get_iid (_tmp15_);
#line 229 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_tmp17_ = _tmp16_;
#line 229 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_tmp18_ = g_strdup (_tmp17_);
#line 229 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_g_free0 (self->priv->_persona_iid_1);
#line 229 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		self->priv->_persona_iid_1 = _tmp18_;
#line 230 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_tmp19_ = self->priv->_personas;
#line 230 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_tmp20_ = first_persona;
#line 230 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		gee_abstract_collection_add ((GeeAbstractCollection*) _tmp19_, _tmp20_);
#line 231 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_tmp21_ = self->priv->_local_ids;
#line 231 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_tmp22_ = self->priv->_persona_iid_1;
#line 231 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		gee_abstract_collection_add ((GeeAbstractCollection*) _tmp21_, _tmp22_);
#line 1369 "link-personas-via-local-ids.c"
	} else {
		gboolean _tmp23_ = FALSE;
		FolksIndividual* _tmp24_;
		const gchar* _tmp25_;
		const gchar* _tmp26_;
		const gchar* _tmp27_;
		gboolean _tmp29_;
#line 233 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_tmp24_ = i;
#line 233 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_tmp25_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp24_);
#line 233 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_tmp26_ = _tmp25_;
#line 233 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_tmp27_ = self->priv->_persona_fullname_2;
#line 233 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		if (g_strcmp0 (_tmp26_, _tmp27_) == 0) {
#line 1387 "link-personas-via-local-ids.c"
			const gchar* _tmp28_;
#line 234 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_tmp28_ = self->priv->_persona_iid_2;
#line 234 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_tmp23_ = g_strcmp0 (_tmp28_, "") == 0;
#line 1393 "link-personas-via-local-ids.c"
		} else {
#line 233 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_tmp23_ = FALSE;
#line 1397 "link-personas-via-local-ids.c"
		}
#line 233 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_tmp29_ = _tmp23_;
#line 233 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		if (_tmp29_) {
#line 1403 "link-personas-via-local-ids.c"
			FolksPersona* _tmp30_;
			const gchar* _tmp31_;
			const gchar* _tmp32_;
			gchar* _tmp33_;
			GeeHashSet* _tmp34_;
			FolksPersona* _tmp35_;
			GeeHashSet* _tmp36_;
			const gchar* _tmp37_;
#line 236 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_tmp30_ = first_persona;
#line 236 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_tmp31_ = folks_persona_get_iid (_tmp30_);
#line 236 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_tmp32_ = _tmp31_;
#line 236 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_tmp33_ = g_strdup (_tmp32_);
#line 236 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_g_free0 (self->priv->_persona_iid_2);
#line 236 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			self->priv->_persona_iid_2 = _tmp33_;
#line 237 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_tmp34_ = self->priv->_personas;
#line 237 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_tmp35_ = first_persona;
#line 237 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _tmp34_, _tmp35_);
#line 238 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_tmp36_ = self->priv->_local_ids;
#line 238 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_tmp37_ = self->priv->_persona_iid_2;
#line 238 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _tmp36_, _tmp37_);
#line 1436 "link-personas-via-local-ids.c"
		} else {
			FolksIndividual* _tmp38_;
			GeeSet* _tmp39_;
			GeeSet* _tmp40_;
			gint _tmp41_;
			gint _tmp42_;
#line 240 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_tmp38_ = i;
#line 240 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_tmp39_ = folks_individual_get_personas (_tmp38_);
#line 240 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_tmp40_ = _tmp39_;
#line 240 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_tmp41_ = gee_collection_get_size ((GeeCollection*) _tmp40_);
#line 240 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			_tmp42_ = _tmp41_;
#line 240 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
			if (_tmp42_ > 1) {
#line 1455 "link-personas-via-local-ids.c"
				GeeHashSet* _tmp56_;
				gint _tmp57_;
				gint _tmp58_;
				{
					FolksIndividual* _tmp43_;
					GeeSet* _tmp44_;
					GeeSet* _tmp45_;
					GeeIterator* _tmp46_ = NULL;
					GeeIterator* _id_it;
#line 243 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
					_tmp43_ = i;
#line 243 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
					_tmp44_ = folks_local_id_details_get_local_ids ((FolksLocalIdDetails*) _tmp43_);
#line 243 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
					_tmp45_ = _tmp44_;
#line 243 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
					_tmp46_ = gee_iterable_iterator ((GeeIterable*) _tmp45_);
#line 243 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
					_id_it = _tmp46_;
#line 243 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
					while (TRUE) {
#line 1477 "link-personas-via-local-ids.c"
						GeeIterator* _tmp47_;
						gboolean _tmp48_ = FALSE;
						GeeIterator* _tmp49_;
						gpointer _tmp50_ = NULL;
						gchar* id;
						GeeHashSet* _tmp51_;
						const gchar* _tmp52_;
						gboolean _tmp53_ = FALSE;
#line 243 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
						_tmp47_ = _id_it;
#line 243 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
						_tmp48_ = gee_iterator_next (_tmp47_);
#line 243 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
						if (!_tmp48_) {
#line 243 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
							break;
#line 1494 "link-personas-via-local-ids.c"
						}
#line 243 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
						_tmp49_ = _id_it;
#line 243 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
						_tmp50_ = gee_iterator_get (_tmp49_);
#line 243 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
						id = (gchar*) _tmp50_;
#line 245 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
						_tmp51_ = self->priv->_local_ids;
#line 245 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
						_tmp52_ = id;
#line 245 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
						_tmp53_ = gee_abstract_collection_contains ((GeeAbstractCollection*) _tmp51_, _tmp52_);
#line 245 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
						if (_tmp53_) {
#line 1510 "link-personas-via-local-ids.c"
							GeeHashSet* _tmp54_;
							const gchar* _tmp55_;
#line 247 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
							_tmp54_ = self->priv->_local_ids;
#line 247 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
							_tmp55_ = id;
#line 247 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
							gee_abstract_collection_remove ((GeeAbstractCollection*) _tmp54_, _tmp55_);
#line 1519 "link-personas-via-local-ids.c"
						}
#line 243 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
						_g_free0 (id);
#line 1523 "link-personas-via-local-ids.c"
					}
#line 243 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
					_g_object_unref0 (_id_it);
#line 1527 "link-personas-via-local-ids.c"
				}
#line 251 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
				_tmp56_ = self->priv->_local_ids;
#line 251 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
				_tmp57_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp56_);
#line 251 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
				_tmp58_ = _tmp57_;
#line 251 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
				if (_tmp58_ == 0) {
#line 1537 "link-personas-via-local-ids.c"
					GMainLoop* _tmp59_;
#line 253 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
					_tmp59_ = self->priv->_main_loop;
#line 253 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
					g_main_loop_quit (_tmp59_);
#line 1543 "link-personas-via-local-ids.c"
				}
			}
		}
	}
#line 259 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp61_ = self->priv->_personas;
#line 259 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp62_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp61_);
#line 259 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp63_ = _tmp62_;
#line 259 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	if (_tmp63_ == 2) {
#line 1556 "link-personas-via-local-ids.c"
		gboolean _tmp64_;
#line 260 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_tmp64_ = self->priv->_linking_fired;
#line 260 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_tmp60_ = _tmp64_ == FALSE;
#line 1562 "link-personas-via-local-ids.c"
	} else {
#line 259 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		_tmp60_ = FALSE;
#line 1566 "link-personas-via-local-ids.c"
	}
#line 259 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp65_ = _tmp60_;
#line 259 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	if (_tmp65_) {
#line 262 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		self->priv->_linking_fired = TRUE;
#line 266 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
		g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) 2, ____lambda2__gsource_func, g_object_ref (self), g_object_unref);
#line 1576 "link-personas-via-local-ids.c"
	}
#line 217 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_g_object_unref0 (first_persona);
#line 1580 "link-personas-via-local-ids.c"
}


static void link_personas_via_local_ids_tests_class_init (LinkPersonasViaLocalIDsTestsClass * klass) {
#line 26 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	link_personas_via_local_ids_tests_parent_class = g_type_class_peek_parent (klass);
#line 26 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	g_type_class_add_private (klass, sizeof (LinkPersonasViaLocalIDsTestsPrivate));
#line 26 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	FOLKS_TEST_CASE_CLASS (klass)->set_up = link_personas_via_local_ids_tests_real_set_up;
#line 26 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	FOLKS_TEST_CASE_CLASS (klass)->tear_down = link_personas_via_local_ids_tests_real_tear_down;
#line 26 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	G_OBJECT_CLASS (klass)->finalize = link_personas_via_local_ids_tests_finalize;
#line 1595 "link-personas-via-local-ids.c"
}


static void link_personas_via_local_ids_tests_instance_init (LinkPersonasViaLocalIDsTests * self) {
	gchar* _tmp0_;
	gchar* _tmp1_;
#line 26 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	self->priv = LINK_PERSONAS_VIA_LOCAL_IDS_TESTS_GET_PRIVATE (self);
#line 36 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp0_ = g_strdup ("");
#line 36 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	self->priv->_persona_iid_1 = _tmp0_;
#line 37 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp1_ = g_strdup ("");
#line 37 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	self->priv->_persona_iid_2 = _tmp1_;
#line 39 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	self->priv->_removed_individuals = 0;
#line 1614 "link-personas-via-local-ids.c"
}


static void link_personas_via_local_ids_tests_finalize (GObject* obj) {
	LinkPersonasViaLocalIDsTests * self;
#line 26 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	self = LINK_PERSONAS_VIA_LOCAL_IDS_TESTS (obj);
#line 28 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 29 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tracker_test_backend_unref0 (self->priv->_tracker_backend);
#line 30 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 31 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_g_free0 (self->priv->_persona_fullname_1);
#line 32 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_g_free0 (self->priv->_persona_fullname_2);
#line 36 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_g_free0 (self->priv->_persona_iid_1);
#line 37 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_g_free0 (self->priv->_persona_iid_2);
#line 38 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_g_object_unref0 (self->priv->_personas);
#line 40 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_g_object_unref0 (self->priv->_local_ids);
#line 26 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	G_OBJECT_CLASS (link_personas_via_local_ids_tests_parent_class)->finalize (obj);
#line 1642 "link-personas-via-local-ids.c"
}


GType link_personas_via_local_ids_tests_get_type (void) {
	static volatile gsize link_personas_via_local_ids_tests_type_id__volatile = 0;
	if (g_once_init_enter (&link_personas_via_local_ids_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (LinkPersonasViaLocalIDsTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) link_personas_via_local_ids_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (LinkPersonasViaLocalIDsTests), 0, (GInstanceInitFunc) link_personas_via_local_ids_tests_instance_init, NULL };
		GType link_personas_via_local_ids_tests_type_id;
		link_personas_via_local_ids_tests_type_id = g_type_register_static (FOLKS_TYPE_TEST_CASE, "LinkPersonasViaLocalIDsTests", &g_define_type_info, 0);
		g_once_init_leave (&link_personas_via_local_ids_tests_type_id__volatile, link_personas_via_local_ids_tests_type_id);
	}
	return link_personas_via_local_ids_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	GTestSuite* _tmp0_ = NULL;
	GTestSuite* root;
	LinkPersonasViaLocalIDsTests* _tmp1_;
	LinkPersonasViaLocalIDsTests* _tmp2_;
	GTestSuite* _tmp3_ = NULL;
#line 277 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	g_test_init (&args_length1, &args, NULL);
#line 279 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp0_ = g_test_get_root ();
#line 279 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	root = _tmp0_;
#line 280 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp1_ = link_personas_via_local_ids_tests_new ();
#line 280 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp2_ = _tmp1_;
#line 280 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_tmp3_ = folks_test_case_get_suite ((FolksTestCase*) _tmp2_);
#line 280 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	g_test_suite_add_suite (root, _tmp3_);
#line 280 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	_g_object_unref0 (_tmp2_);
#line 282 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	g_test_run ();
#line 284 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	result = 0;
#line 284 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	return result;
#line 1687 "link-personas-via-local-ids.c"
}


int main (int argc, char ** argv) {
#line 275 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	g_type_init ();
#line 275 "/opt/gnome2/source/folks/tests/tracker/link-personas-via-local-ids.vala"
	return _vala_main (argv, argc);
#line 1696 "link-personas-via-local-ids.c"
}



