/* name-details.c generated by valac 0.15.1.20-908e, the Vala compiler
 * generated from name-details.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <folks-test.h>
#include <eds-test.h>
#include <folks/folks.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>


#define TYPE_NAME_DETAILS_TESTS (name_details_tests_get_type ())
#define NAME_DETAILS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_NAME_DETAILS_TESTS, NameDetailsTests))
#define NAME_DETAILS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_NAME_DETAILS_TESTS, NameDetailsTestsClass))
#define IS_NAME_DETAILS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_NAME_DETAILS_TESTS))
#define IS_NAME_DETAILS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_NAME_DETAILS_TESTS))
#define NAME_DETAILS_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_NAME_DETAILS_TESTS, NameDetailsTestsClass))

typedef struct _NameDetailsTests NameDetailsTests;
typedef struct _NameDetailsTestsClass NameDetailsTestsClass;
typedef struct _NameDetailsTestsPrivate NameDetailsTestsPrivate;
#define _eds_test_backend_unref0(var) ((var == NULL) ? NULL : (var = (eds_test_backend_unref (var), NULL)))
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define __vala_GValue_free0(var) ((var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _NameDetailsTestsTestNamesAsyncData NameDetailsTestsTestNamesAsyncData;

struct _NameDetailsTests {
	FolksTestCase parent_instance;
	NameDetailsTestsPrivate * priv;
};

struct _NameDetailsTestsClass {
	FolksTestCaseClass parent_class;
};

struct _NameDetailsTestsPrivate {
	EdsTestBackend* _eds_backend;
	GMainLoop* _main_loop;
	FolksIndividualAggregator* _aggregator;
	gint _names_count;
	GeeHashMap* _c1;
	GeeHashMap* _c2;
};

struct _NameDetailsTestsTestNamesAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	NameDetailsTests* self;
	EdsTestBackend* _tmp0_;
	FolksBackendStore* _tmp1_;
	FolksBackendStore* store;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	FolksIndividualAggregator* _tmp4_;
	GError* e;
	GError* _tmp5_;
	const gchar* _tmp6_;
	GError * _inner_error_;
};


static gpointer name_details_tests_parent_class = NULL;

GType name_details_tests_get_type (void) G_GNUC_CONST;
#define NAME_DETAILS_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_NAME_DETAILS_TESTS, NameDetailsTestsPrivate))
enum  {
	NAME_DETAILS_TESTS_DUMMY_PROPERTY
};
NameDetailsTests* name_details_tests_new (void);
NameDetailsTests* name_details_tests_construct (GType object_type);
void name_details_tests_test_names (NameDetailsTests* self);
static void _name_details_tests_test_names_folks_test_case_test_method (gpointer self);
static void name_details_tests_real_set_up (FolksTestCase* base);
static void name_details_tests_real_tear_down (FolksTestCase* base);
static GValue* _g_value_dup (GValue* self);
static void _vala_GValue_free (GValue* self);
static void _name_details_tests_test_names_async (NameDetailsTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _name_details_tests_test_names_finish (NameDetailsTests* self, GAsyncResult* _res_);
static gboolean __lambda2_ (NameDetailsTests* self);
static gboolean ___lambda2__gsource_func (gpointer self);
static void _name_details_tests_test_names_async_data_free (gpointer _data);
static gboolean _name_details_tests_test_names_async_co (NameDetailsTestsTestNamesAsyncData* _data_);
static void _name_details_tests_test_names_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _name_details_tests_individuals_changed_cb (NameDetailsTests* self, GeeMultiMap* changes);
static void __name_details_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void name_details_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _name_details_tests_test_names_folks_test_case_test_method (gpointer self) {
#line 38 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	name_details_tests_test_names (self);
#line 122 "name-details.c"
}


NameDetailsTests* name_details_tests_construct (GType object_type) {
	NameDetailsTests * self = NULL;
#line 36 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	self = (NameDetailsTests*) folks_test_case_construct (object_type, "NameDetails");
#line 38 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "name details interface", _name_details_tests_test_names_folks_test_case_test_method, self);
#line 34 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	return self;
#line 134 "name-details.c"
}


NameDetailsTests* name_details_tests_new (void) {
#line 34 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	return name_details_tests_construct (TYPE_NAME_DETAILS_TESTS);
#line 141 "name-details.c"
}


static void name_details_tests_real_set_up (FolksTestCase* base) {
	NameDetailsTests * self;
	EdsTestBackend* _tmp0_;
	EdsTestBackend* _tmp1_;
	EdsTestBackend* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	gchar* _tmp5_ = NULL;
	gchar* config_val;
#line 41 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	self = (NameDetailsTests*) base;
#line 43 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp0_ = eds_test_backend_new ();
#line 43 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_eds_test_backend_unref0 (self->priv->_eds_backend);
#line 43 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	self->priv->_eds_backend = _tmp0_;
#line 44 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp1_ = self->priv->_eds_backend;
#line 44 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	eds_test_backend_set_up (_tmp1_, FALSE);
#line 47 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp2_ = self->priv->_eds_backend;
#line 47 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp3_ = eds_test_backend_get_address_book_uid (_tmp2_);
#line 47 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp4_ = _tmp3_;
#line 47 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp5_ = g_strdup_printf ("eds:%s", _tmp4_);
#line 47 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	config_val = _tmp5_;
#line 48 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_setenv ("FOLKS_PRIMARY_STORE", config_val, TRUE);
#line 41 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_g_free0 (config_val);
#line 180 "name-details.c"
}


static void name_details_tests_real_tear_down (FolksTestCase* base) {
	NameDetailsTests * self;
	EdsTestBackend* _tmp0_;
#line 51 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	self = (NameDetailsTests*) base;
#line 53 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp0_ = self->priv->_eds_backend;
#line 53 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	eds_test_backend_tear_down (_tmp0_);
#line 193 "name-details.c"
}


static GValue* _g_value_dup (GValue* self) {
#line 58 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	return g_boxed_copy (G_TYPE_VALUE, self);
#line 200 "name-details.c"
}


static void _vala_GValue_free (GValue* self) {
#line 58 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_value_unset (self);
#line 58 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_free (self);
#line 209 "name-details.c"
}


static gpointer __g_value_dup0 (gpointer self) {
#line 67 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	return self ? _g_value_dup (self) : NULL;
#line 216 "name-details.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 88 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	return self ? g_object_ref (self) : NULL;
#line 223 "name-details.c"
}


static gboolean __lambda2_ (NameDetailsTests* self) {
	gboolean result = FALSE;
	GMainLoop* _tmp0_;
#line 105 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp0_ = self->priv->_main_loop;
#line 105 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_main_loop_quit (_tmp0_);
#line 106 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	result = FALSE;
#line 106 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	return result;
#line 238 "name-details.c"
}


static gboolean ___lambda2__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda2_ (self);
#line 103 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	return result;
#line 247 "name-details.c"
}


void name_details_tests_test_names (NameDetailsTests* self) {
	GeeHashMap* _tmp0_;
	GeeHashMap* _tmp1_;
	GMainLoop* _tmp2_;
	GValue* v = NULL;
	EdsTestBackend* _tmp3_;
	GValue _tmp4_ = {0};
	GValue _tmp5_;
	GValue* _tmp6_;
	GValue* _tmp7_;
	GeeHashMap* _tmp8_;
	GValue* _tmp9_;
	GValue* _tmp10_;
	GValue _tmp11_ = {0};
	GValue _tmp12_;
	GValue* _tmp13_;
	GValue* _tmp14_;
	GeeHashMap* _tmp15_;
	GValue* _tmp16_;
	GValue* _tmp17_;
	GValue _tmp18_ = {0};
	GValue _tmp19_;
	GValue* _tmp20_;
	GValue* _tmp21_;
	GeeHashMap* _tmp22_;
	GValue* _tmp23_;
	GValue* _tmp24_;
	GValue _tmp25_ = {0};
	GValue _tmp26_;
	GValue* _tmp27_;
	GValue* _tmp28_;
	GeeHashMap* _tmp29_;
	GValue* _tmp30_;
	GValue* _tmp31_;
	GValue _tmp32_ = {0};
	GValue _tmp33_;
	GValue* _tmp34_;
	GValue* _tmp35_;
	GeeHashMap* _tmp36_;
	GValue* _tmp37_;
	GValue* _tmp38_;
	GValue _tmp39_ = {0};
	GValue _tmp40_;
	GValue* _tmp41_;
	GValue* _tmp42_;
	GeeHashMap* _tmp43_;
	GValue* _tmp44_;
	GValue* _tmp45_;
	GValue _tmp46_ = {0};
	GValue _tmp47_;
	GValue* _tmp48_;
	GValue* _tmp49_;
	GeeHashMap* _tmp50_;
	GValue* _tmp51_;
	GValue* _tmp52_;
	EdsTestBackend* _tmp53_;
	GeeHashMap* _tmp54_;
	GeeHashMap* _tmp55_;
	GValue _tmp56_ = {0};
	GValue _tmp57_;
	GValue* _tmp58_;
	GValue* _tmp59_;
	GeeHashMap* _tmp60_;
	GValue* _tmp61_;
	GValue* _tmp62_;
	GValue _tmp63_ = {0};
	GValue _tmp64_;
	GValue* _tmp65_;
	GValue* _tmp66_;
	GeeHashMap* _tmp67_;
	GValue* _tmp68_;
	GValue* _tmp69_;
	GValue _tmp70_ = {0};
	GValue _tmp71_;
	GValue* _tmp72_;
	GValue* _tmp73_;
	GeeHashMap* _tmp74_;
	GValue* _tmp75_;
	GValue* _tmp76_;
	EdsTestBackend* _tmp77_;
	GeeHashMap* _tmp78_;
	GeeHashMap* _tmp79_;
	GMainLoop* _tmp80_;
	gint _tmp81_;
	GeeHashMap* _tmp82_;
	gint _tmp83_;
	gint _tmp84_;
	GeeHashMap* _tmp85_;
	gint _tmp86_;
	gint _tmp87_;
#line 56 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_return_if_fail (self != NULL);
#line 58 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp0_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL);
#line 58 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_g_object_unref0 (self->priv->_c1);
#line 58 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	self->priv->_c1 = _tmp0_;
#line 59 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp1_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL);
#line 59 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_g_object_unref0 (self->priv->_c2);
#line 59 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	self->priv->_c2 = _tmp1_;
#line 60 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	self->priv->_names_count = 0;
#line 61 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp2_ = g_main_loop_new (NULL, FALSE);
#line 61 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 61 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	self->priv->_main_loop = _tmp2_;
#line 64 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp3_ = self->priv->_eds_backend;
#line 64 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	eds_test_backend_reset (_tmp3_);
#line 67 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_value_init (&_tmp4_, G_TYPE_STRING);
#line 67 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp5_ = _tmp4_;
#line 67 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp6_ = __g_value_dup0 (&_tmp5_);
#line 67 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (v);
#line 67 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	v = _tmp6_;
#line 67 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	G_IS_VALUE (&_tmp5_) ? (g_value_unset (&_tmp5_), NULL) : NULL;
#line 68 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp7_ = v;
#line 68 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_value_set_string (_tmp7_, "bernie h. innocenti");
#line 69 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp8_ = self->priv->_c1;
#line 69 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp9_ = v;
#line 69 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	v = NULL;
#line 69 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp10_ = _tmp9_;
#line 69 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp8_, "full_name", _tmp10_);
#line 69 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp10_);
#line 70 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_value_init (&_tmp11_, G_TYPE_STRING);
#line 70 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp12_ = _tmp11_;
#line 70 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp13_ = __g_value_dup0 (&_tmp12_);
#line 70 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (v);
#line 70 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	v = _tmp13_;
#line 70 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	G_IS_VALUE (&_tmp12_) ? (g_value_unset (&_tmp12_), NULL) : NULL;
#line 71 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp14_ = v;
#line 71 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_value_set_string (_tmp14_, "bernie");
#line 72 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp15_ = self->priv->_c1;
#line 72 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp16_ = v;
#line 72 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	v = NULL;
#line 72 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp17_ = _tmp16_;
#line 72 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp15_, "nickname", _tmp17_);
#line 72 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp17_);
#line 73 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_value_init (&_tmp18_, G_TYPE_STRING);
#line 73 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp19_ = _tmp18_;
#line 73 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp20_ = __g_value_dup0 (&_tmp19_);
#line 73 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (v);
#line 73 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	v = _tmp20_;
#line 73 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	G_IS_VALUE (&_tmp19_) ? (g_value_unset (&_tmp19_), NULL) : NULL;
#line 74 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp21_ = v;
#line 74 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_value_set_string (_tmp21_, "Innocenti");
#line 75 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp22_ = self->priv->_c1;
#line 75 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp23_ = v;
#line 75 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	v = NULL;
#line 75 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp24_ = _tmp23_;
#line 75 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp22_, "contact_name_family", _tmp24_);
#line 75 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp24_);
#line 76 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_value_init (&_tmp25_, G_TYPE_STRING);
#line 76 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp26_ = _tmp25_;
#line 76 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp27_ = __g_value_dup0 (&_tmp26_);
#line 76 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (v);
#line 76 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	v = _tmp27_;
#line 76 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	G_IS_VALUE (&_tmp26_) ? (g_value_unset (&_tmp26_), NULL) : NULL;
#line 77 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp28_ = v;
#line 77 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_value_set_string (_tmp28_, "Bernardo");
#line 78 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp29_ = self->priv->_c1;
#line 78 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp30_ = v;
#line 78 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	v = NULL;
#line 78 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp31_ = _tmp30_;
#line 78 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp29_, "contact_name_given", _tmp31_);
#line 78 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp31_);
#line 79 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_value_init (&_tmp32_, G_TYPE_STRING);
#line 79 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp33_ = _tmp32_;
#line 79 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp34_ = __g_value_dup0 (&_tmp33_);
#line 79 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (v);
#line 79 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	v = _tmp34_;
#line 79 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	G_IS_VALUE (&_tmp33_) ? (g_value_unset (&_tmp33_), NULL) : NULL;
#line 80 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp35_ = v;
#line 80 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_value_set_string (_tmp35_, "H.");
#line 81 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp36_ = self->priv->_c1;
#line 81 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp37_ = v;
#line 81 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	v = NULL;
#line 81 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp38_ = _tmp37_;
#line 81 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp36_, "contact_name_additional", _tmp38_);
#line 81 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp38_);
#line 82 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_value_init (&_tmp39_, G_TYPE_STRING);
#line 82 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp40_ = _tmp39_;
#line 82 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp41_ = __g_value_dup0 (&_tmp40_);
#line 82 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (v);
#line 82 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	v = _tmp41_;
#line 82 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	G_IS_VALUE (&_tmp40_) ? (g_value_unset (&_tmp40_), NULL) : NULL;
#line 83 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp42_ = v;
#line 83 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_value_set_string (_tmp42_, "Mr.");
#line 84 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp43_ = self->priv->_c1;
#line 84 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp44_ = v;
#line 84 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	v = NULL;
#line 84 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp45_ = _tmp44_;
#line 84 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp43_, "contact_name_prefixes", _tmp45_);
#line 84 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp45_);
#line 85 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_value_init (&_tmp46_, G_TYPE_STRING);
#line 85 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp47_ = _tmp46_;
#line 85 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp48_ = __g_value_dup0 (&_tmp47_);
#line 85 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (v);
#line 85 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	v = _tmp48_;
#line 85 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	G_IS_VALUE (&_tmp47_) ? (g_value_unset (&_tmp47_), NULL) : NULL;
#line 86 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp49_ = v;
#line 86 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_value_set_string (_tmp49_, "(sysadmin FSF)");
#line 87 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp50_ = self->priv->_c1;
#line 87 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp51_ = v;
#line 87 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	v = NULL;
#line 87 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp52_ = _tmp51_;
#line 87 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp50_, "contact_name_suffixes", _tmp52_);
#line 87 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp52_);
#line 88 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp53_ = self->priv->_eds_backend;
#line 88 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp54_ = self->priv->_c1;
#line 88 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp55_ = _g_object_ref0 (_tmp54_);
#line 88 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	eds_test_backend_add_contact (_tmp53_, _tmp55_);
#line 90 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_value_init (&_tmp56_, G_TYPE_STRING);
#line 90 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp57_ = _tmp56_;
#line 90 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp58_ = __g_value_dup0 (&_tmp57_);
#line 90 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (v);
#line 90 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	v = _tmp58_;
#line 90 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	G_IS_VALUE (&_tmp57_) ? (g_value_unset (&_tmp57_), NULL) : NULL;
#line 91 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp59_ = v;
#line 91 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_value_set_string (_tmp59_, "richard m. stallman");
#line 92 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp60_ = self->priv->_c2;
#line 92 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp61_ = v;
#line 92 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	v = NULL;
#line 92 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp62_ = _tmp61_;
#line 92 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp60_, "full_name", _tmp62_);
#line 92 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp62_);
#line 93 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_value_init (&_tmp63_, G_TYPE_STRING);
#line 93 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp64_ = _tmp63_;
#line 93 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp65_ = __g_value_dup0 (&_tmp64_);
#line 93 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (v);
#line 93 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	v = _tmp65_;
#line 93 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	G_IS_VALUE (&_tmp64_) ? (g_value_unset (&_tmp64_), NULL) : NULL;
#line 94 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp66_ = v;
#line 94 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_value_set_string (_tmp66_, "Stallman");
#line 95 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp67_ = self->priv->_c2;
#line 95 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp68_ = v;
#line 95 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	v = NULL;
#line 95 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp69_ = _tmp68_;
#line 95 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp67_, "contact_name_family", _tmp69_);
#line 95 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp69_);
#line 96 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_value_init (&_tmp70_, G_TYPE_STRING);
#line 96 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp71_ = _tmp70_;
#line 96 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp72_ = __g_value_dup0 (&_tmp71_);
#line 96 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (v);
#line 96 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	v = _tmp72_;
#line 96 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	G_IS_VALUE (&_tmp71_) ? (g_value_unset (&_tmp71_), NULL) : NULL;
#line 97 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp73_ = v;
#line 97 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_value_set_string (_tmp73_, "Richard M.");
#line 98 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp74_ = self->priv->_c2;
#line 98 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp75_ = v;
#line 98 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	v = NULL;
#line 98 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp76_ = _tmp75_;
#line 98 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp74_, "contact_name_given", _tmp76_);
#line 98 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp76_);
#line 99 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp77_ = self->priv->_eds_backend;
#line 99 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp78_ = self->priv->_c2;
#line 99 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp79_ = _g_object_ref0 (_tmp78_);
#line 99 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	eds_test_backend_add_contact (_tmp77_, _tmp79_);
#line 101 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_name_details_tests_test_names_async (self, NULL, NULL);
#line 103 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) 5, ___lambda2__gsource_func, g_object_ref (self), g_object_unref);
#line 109 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp80_ = self->priv->_main_loop;
#line 109 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_main_loop_run (_tmp80_);
#line 111 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp81_ = self->priv->_names_count;
#line 111 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_assert (_tmp81_ == 2);
#line 112 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp82_ = self->priv->_c1;
#line 112 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp83_ = gee_abstract_map_get_size ((GeeMap*) _tmp82_);
#line 112 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp84_ = _tmp83_;
#line 112 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_assert (_tmp84_ == 0);
#line 113 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp85_ = self->priv->_c2;
#line 113 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp86_ = gee_abstract_map_get_size ((GeeMap*) _tmp85_);
#line 113 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp87_ = _tmp86_;
#line 113 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_assert (_tmp87_ == 0);
#line 56 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (v);
#line 693 "name-details.c"
}


static void _name_details_tests_test_names_async_data_free (gpointer _data) {
	NameDetailsTestsTestNamesAsyncData* _data_;
	_data_ = _data;
#line 25 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_g_object_unref0 (_data_->self);
#line 25 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_slice_free (NameDetailsTestsTestNamesAsyncData, _data_);
#line 704 "name-details.c"
}


static void _name_details_tests_test_names_async (NameDetailsTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	NameDetailsTestsTestNamesAsyncData* _data_;
	NameDetailsTests* _tmp0_;
#line 25 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_data_ = g_slice_new0 (NameDetailsTestsTestNamesAsyncData);
#line 25 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _name_details_tests_test_names_async);
#line 25 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _name_details_tests_test_names_async_data_free);
#line 25 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 25 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_data_->self = _tmp0_;
#line 25 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_name_details_tests_test_names_async_co (_data_);
#line 723 "name-details.c"
}


static void _name_details_tests_test_names_finish (NameDetailsTests* self, GAsyncResult* _res_) {
	NameDetailsTestsTestNamesAsyncData* _data_;
#line 25 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 731 "name-details.c"
}


static void _name_details_tests_test_names_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	NameDetailsTestsTestNamesAsyncData* _data_;
#line 119 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_data_ = _user_data_;
#line 119 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_data_->_source_object_ = source_object;
#line 119 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_data_->_res_ = _res_;
#line 119 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_name_details_tests_test_names_async_co (_data_);
#line 745 "name-details.c"
}


static void __name_details_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 124 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_name_details_tests_individuals_changed_cb (self, changes);
#line 752 "name-details.c"
}


static gboolean _name_details_tests_test_names_async_co (NameDetailsTestsTestNamesAsyncData* _data_) {
#line 116 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	switch (_data_->_state_) {
#line 116 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		case 0:
#line 761 "name-details.c"
		goto _state_0;
#line 116 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		case 1:
#line 765 "name-details.c"
		goto _state_1;
#line 116 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		case 2:
#line 769 "name-details.c"
		goto _state_2;
#line 116 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		case 3:
#line 773 "name-details.c"
		goto _state_3;
		default:
#line 116 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		g_assert_not_reached ();
#line 778 "name-details.c"
	}
	_state_0:
#line 119 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_data_->_tmp0_ = _data_->self->priv->_eds_backend;
#line 119 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_data_->_state_ = 1;
#line 119 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	eds_test_backend_commit_contacts_to_addressbook (_data_->_tmp0_, _name_details_tests_test_names_async_ready, _data_);
#line 119 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	return FALSE;
#line 789 "name-details.c"
	_state_1:
#line 119 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	eds_test_backend_commit_contacts_to_addressbook_finish (_data_->_tmp0_, _data_->_res_);
#line 121 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_data_->_tmp1_ = NULL;
#line 121 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_data_->_tmp1_ = folks_backend_store_dup ();
#line 121 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_data_->store = _data_->_tmp1_;
#line 122 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_data_->_state_ = 2;
#line 122 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	folks_backend_store_prepare (_data_->store, _name_details_tests_test_names_async_ready, _data_);
#line 122 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	return FALSE;
#line 805 "name-details.c"
	_state_2:
#line 122 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 123 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_data_->_tmp2_ = folks_individual_aggregator_new ();
#line 123 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 123 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_data_->self->priv->_aggregator = _data_->_tmp2_;
#line 124 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 124 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_signal_connect_object (_data_->_tmp3_, "individuals-changed-detailed", (GCallback) __name_details_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 819 "name-details.c"
	{
#line 128 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		_data_->_tmp4_ = _data_->self->priv->_aggregator;
#line 128 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		_data_->_state_ = 3;
#line 128 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		folks_individual_aggregator_prepare (_data_->_tmp4_, _name_details_tests_test_names_async_ready, _data_);
#line 128 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		return FALSE;
#line 829 "name-details.c"
		_state_3:
#line 128 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp4_, _data_->_res_, &_data_->_inner_error_);
#line 128 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		if (_data_->_inner_error_ != NULL) {
#line 835 "name-details.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 126 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		_data_->e = _data_->_inner_error_;
#line 126 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		_data_->_inner_error_ = NULL;
#line 132 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		_data_->_tmp5_ = _data_->e;
#line 132 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		_data_->_tmp6_ = _data_->_tmp5_->message;
#line 132 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		g_warning ("name-details.vala:132: Error when calling prepare: %s\n", _data_->_tmp6_);
#line 126 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		_g_error_free0 (_data_->e);
#line 854 "name-details.c"
	}
	__finally0:
#line 126 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	if (_data_->_inner_error_ != NULL) {
#line 126 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		_g_object_unref0 (_data_->store);
#line 126 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 126 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		g_clear_error (&_data_->_inner_error_);
#line 126 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		return FALSE;
#line 867 "name-details.c"
	}
#line 116 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_g_object_unref0 (_data_->store);
#line 116 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	if (_data_->_state_ == 0) {
#line 116 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 875 "name-details.c"
	} else {
#line 116 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 879 "name-details.c"
	}
#line 116 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_object_unref (_data_->_async_result);
#line 116 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	return FALSE;
#line 885 "name-details.c"
}


static void _name_details_tests_individuals_changed_cb (NameDetailsTests* self, GeeMultiMap* changes) {
	GeeMultiMap* _tmp0_;
	GeeCollection* _tmp1_ = NULL;
	GeeCollection* added;
	GeeMultiMap* _tmp2_;
	GeeSet* _tmp3_ = NULL;
	GeeSet* removed;
	GeeSet* _tmp147_;
	gint _tmp148_;
	gint _tmp149_;
	gboolean _tmp157_ = FALSE;
	GeeHashMap* _tmp158_;
	gint _tmp159_;
	gint _tmp160_;
	gboolean _tmp164_;
#line 136 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_return_if_fail (self != NULL);
#line 136 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_return_if_fail (changes != NULL);
#line 139 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp0_ = changes;
#line 139 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 139 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	added = _tmp1_;
#line 140 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp2_ = changes;
#line 140 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 140 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	removed = _tmp3_;
#line 920 "name-details.c"
	{
		GeeCollection* _tmp4_;
		GeeIterator* _tmp5_ = NULL;
		GeeIterator* _i_it;
#line 142 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		_tmp4_ = added;
#line 142 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 142 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		_i_it = _tmp5_;
#line 142 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		while (TRUE) {
#line 933 "name-details.c"
			GeeIterator* _tmp6_;
			gboolean _tmp7_ = FALSE;
			GeeIterator* _tmp8_;
			gpointer _tmp9_ = NULL;
			FolksIndividual* i;
			FolksIndividual* _tmp10_;
			gchar* s = NULL;
			FolksIndividual* _tmp11_;
			GeeSet* _tmp12_;
			GeeSet* _tmp13_;
			gint _tmp14_;
			gint _tmp15_;
			FolksIndividual* _tmp16_;
			FolksNameDetails* _tmp17_;
			FolksNameDetails* name;
			FolksIndividual* _tmp18_;
			const gchar* _tmp19_;
			const gchar* _tmp20_;
			gint _tmp146_;
#line 142 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
			_tmp6_ = _i_it;
#line 142 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 142 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
			if (!_tmp7_) {
#line 142 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				break;
#line 961 "name-details.c"
			}
#line 142 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
			_tmp8_ = _i_it;
#line 142 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 142 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
			i = (FolksIndividual*) _tmp9_;
#line 144 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
			_tmp10_ = i;
#line 144 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
			g_assert (_tmp10_ != NULL);
#line 148 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
			_tmp11_ = i;
#line 148 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
			_tmp12_ = folks_individual_get_personas (_tmp11_);
#line 148 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
			_tmp13_ = _tmp12_;
#line 148 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
			_tmp14_ = gee_collection_get_size ((GeeCollection*) _tmp13_);
#line 148 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
			_tmp15_ = _tmp14_;
#line 148 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
			g_assert (_tmp15_ == 1);
#line 150 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
			_tmp16_ = i;
#line 150 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
			_tmp17_ = _g_object_ref0 (FOLKS_NAME_DETAILS (_tmp16_));
#line 150 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
			name = _tmp17_;
#line 152 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
			_tmp18_ = i;
#line 152 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
			_tmp19_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp18_);
#line 152 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
			_tmp20_ = _tmp19_;
#line 152 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
			if (g_strcmp0 (_tmp20_, "bernie h. innocenti") == 0) {
#line 999 "name-details.c"
				FolksNameDetails* _tmp21_;
				FolksStructuredName* _tmp22_;
				FolksStructuredName* _tmp23_;
				gboolean _tmp24_ = FALSE;
				GeeHashMap* _tmp25_;
				gpointer _tmp26_ = NULL;
				GValue* _tmp27_;
				const gchar* _tmp28_ = NULL;
				gchar* _tmp29_;
				FolksNameDetails* _tmp30_;
				const gchar* _tmp31_;
				const gchar* _tmp32_;
				const gchar* _tmp33_;
				GeeHashMap* _tmp34_;
				GeeHashMap* _tmp35_;
				gpointer _tmp36_ = NULL;
				GValue* _tmp37_;
				const gchar* _tmp38_ = NULL;
				gchar* _tmp39_;
				FolksNameDetails* _tmp40_;
				const gchar* _tmp41_;
				const gchar* _tmp42_;
				const gchar* _tmp43_;
				GeeHashMap* _tmp44_;
				GeeHashMap* _tmp45_;
				gpointer _tmp46_ = NULL;
				GValue* _tmp47_;
				const gchar* _tmp48_ = NULL;
				gchar* _tmp49_;
				FolksNameDetails* _tmp50_;
				FolksStructuredName* _tmp51_;
				FolksStructuredName* _tmp52_;
				const gchar* _tmp53_;
				const gchar* _tmp54_;
				const gchar* _tmp55_;
				GeeHashMap* _tmp56_;
				GeeHashMap* _tmp57_;
				gpointer _tmp58_ = NULL;
				GValue* _tmp59_;
				const gchar* _tmp60_ = NULL;
				gchar* _tmp61_;
				FolksNameDetails* _tmp62_;
				FolksStructuredName* _tmp63_;
				FolksStructuredName* _tmp64_;
				const gchar* _tmp65_;
				const gchar* _tmp66_;
				const gchar* _tmp67_;
				GeeHashMap* _tmp68_;
				GeeHashMap* _tmp69_;
				gpointer _tmp70_ = NULL;
				GValue* _tmp71_;
				const gchar* _tmp72_ = NULL;
				gchar* _tmp73_;
				FolksNameDetails* _tmp74_;
				FolksStructuredName* _tmp75_;
				FolksStructuredName* _tmp76_;
				const gchar* _tmp77_;
				const gchar* _tmp78_;
				const gchar* _tmp79_;
				GeeHashMap* _tmp80_;
				GeeHashMap* _tmp81_;
				gpointer _tmp82_ = NULL;
				GValue* _tmp83_;
				const gchar* _tmp84_ = NULL;
				gchar* _tmp85_;
				FolksNameDetails* _tmp86_;
				FolksStructuredName* _tmp87_;
				FolksStructuredName* _tmp88_;
				const gchar* _tmp89_;
				const gchar* _tmp90_;
				const gchar* _tmp91_;
				GeeHashMap* _tmp92_;
				GeeHashMap* _tmp93_;
				gpointer _tmp94_ = NULL;
				GValue* _tmp95_;
				const gchar* _tmp96_ = NULL;
				gchar* _tmp97_;
				FolksNameDetails* _tmp98_;
				FolksStructuredName* _tmp99_;
				FolksStructuredName* _tmp100_;
				const gchar* _tmp101_;
				const gchar* _tmp102_;
				const gchar* _tmp103_;
				GeeHashMap* _tmp104_;
#line 154 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp21_ = name;
#line 154 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp22_ = folks_name_details_get_structured_name (_tmp21_);
#line 154 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp23_ = _tmp22_;
#line 154 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp24_ = folks_structured_name_is_empty (_tmp23_);
#line 154 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				g_assert (_tmp24_ == FALSE);
#line 156 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp25_ = self->priv->_c1;
#line 156 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp26_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp25_, "full_name");
#line 156 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp27_ = (GValue*) _tmp26_;
#line 156 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp28_ = g_value_get_string (_tmp27_);
#line 156 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp29_ = g_strdup (_tmp28_);
#line 156 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_g_free0 (s);
#line 156 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				s = _tmp29_;
#line 156 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				__vala_GValue_free0 (_tmp27_);
#line 157 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp30_ = name;
#line 157 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp31_ = folks_name_details_get_full_name (_tmp30_);
#line 157 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp32_ = _tmp31_;
#line 157 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp33_ = s;
#line 157 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				g_assert (g_strcmp0 (_tmp32_, _tmp33_) == 0);
#line 158 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp34_ = self->priv->_c1;
#line 158 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				gee_abstract_map_unset ((GeeAbstractMap*) _tmp34_, "full_name", NULL);
#line 160 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp35_ = self->priv->_c1;
#line 160 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp36_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp35_, "nickname");
#line 160 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp37_ = (GValue*) _tmp36_;
#line 160 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp38_ = g_value_get_string (_tmp37_);
#line 160 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp39_ = g_strdup (_tmp38_);
#line 160 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_g_free0 (s);
#line 160 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				s = _tmp39_;
#line 160 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				__vala_GValue_free0 (_tmp37_);
#line 161 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp40_ = name;
#line 161 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp41_ = folks_name_details_get_nickname (_tmp40_);
#line 161 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp42_ = _tmp41_;
#line 161 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp43_ = s;
#line 161 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				g_assert (g_strcmp0 (_tmp42_, _tmp43_) == 0);
#line 162 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp44_ = self->priv->_c1;
#line 162 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				gee_abstract_map_unset ((GeeAbstractMap*) _tmp44_, "nickname", NULL);
#line 164 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp45_ = self->priv->_c1;
#line 164 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp46_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp45_, "contact_name_family");
#line 164 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp47_ = (GValue*) _tmp46_;
#line 164 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp48_ = g_value_get_string (_tmp47_);
#line 164 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp49_ = g_strdup (_tmp48_);
#line 164 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_g_free0 (s);
#line 164 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				s = _tmp49_;
#line 164 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				__vala_GValue_free0 (_tmp47_);
#line 165 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp50_ = name;
#line 165 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp51_ = folks_name_details_get_structured_name (_tmp50_);
#line 165 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp52_ = _tmp51_;
#line 165 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp53_ = folks_structured_name_get_family_name (_tmp52_);
#line 165 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp54_ = _tmp53_;
#line 165 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp55_ = s;
#line 165 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				g_assert (g_strcmp0 (_tmp54_, _tmp55_) == 0);
#line 166 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp56_ = self->priv->_c1;
#line 166 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				gee_abstract_map_unset ((GeeAbstractMap*) _tmp56_, "contact_name_family", NULL);
#line 168 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp57_ = self->priv->_c1;
#line 168 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp58_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp57_, "contact_name_given");
#line 168 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp59_ = (GValue*) _tmp58_;
#line 168 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp60_ = g_value_get_string (_tmp59_);
#line 168 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp61_ = g_strdup (_tmp60_);
#line 168 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_g_free0 (s);
#line 168 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				s = _tmp61_;
#line 168 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				__vala_GValue_free0 (_tmp59_);
#line 169 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp62_ = name;
#line 169 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp63_ = folks_name_details_get_structured_name (_tmp62_);
#line 169 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp64_ = _tmp63_;
#line 169 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp65_ = folks_structured_name_get_given_name (_tmp64_);
#line 169 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp66_ = _tmp65_;
#line 169 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp67_ = s;
#line 169 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				g_assert (g_strcmp0 (_tmp66_, _tmp67_) == 0);
#line 170 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp68_ = self->priv->_c1;
#line 170 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				gee_abstract_map_unset ((GeeAbstractMap*) _tmp68_, "contact_name_given", NULL);
#line 172 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp69_ = self->priv->_c1;
#line 172 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp70_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp69_, "contact_name_additional");
#line 172 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp71_ = (GValue*) _tmp70_;
#line 172 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp72_ = g_value_get_string (_tmp71_);
#line 172 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp73_ = g_strdup (_tmp72_);
#line 172 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_g_free0 (s);
#line 172 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				s = _tmp73_;
#line 172 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				__vala_GValue_free0 (_tmp71_);
#line 173 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp74_ = name;
#line 173 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp75_ = folks_name_details_get_structured_name (_tmp74_);
#line 173 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp76_ = _tmp75_;
#line 173 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp77_ = folks_structured_name_get_additional_names (_tmp76_);
#line 173 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp78_ = _tmp77_;
#line 173 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp79_ = s;
#line 173 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				g_assert (g_strcmp0 (_tmp78_, _tmp79_) == 0);
#line 174 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp80_ = self->priv->_c1;
#line 174 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				gee_abstract_map_unset ((GeeAbstractMap*) _tmp80_, "contact_name_additional", NULL);
#line 176 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp81_ = self->priv->_c1;
#line 176 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp82_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp81_, "contact_name_prefixes");
#line 176 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp83_ = (GValue*) _tmp82_;
#line 176 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp84_ = g_value_get_string (_tmp83_);
#line 176 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp85_ = g_strdup (_tmp84_);
#line 176 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_g_free0 (s);
#line 176 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				s = _tmp85_;
#line 176 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				__vala_GValue_free0 (_tmp83_);
#line 177 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp86_ = name;
#line 177 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp87_ = folks_name_details_get_structured_name (_tmp86_);
#line 177 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp88_ = _tmp87_;
#line 177 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp89_ = folks_structured_name_get_prefixes (_tmp88_);
#line 177 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp90_ = _tmp89_;
#line 177 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp91_ = s;
#line 177 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				g_assert (g_strcmp0 (_tmp90_, _tmp91_) == 0);
#line 178 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp92_ = self->priv->_c1;
#line 178 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				gee_abstract_map_unset ((GeeAbstractMap*) _tmp92_, "contact_name_prefixes", NULL);
#line 180 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp93_ = self->priv->_c1;
#line 180 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp94_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp93_, "contact_name_suffixes");
#line 180 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp95_ = (GValue*) _tmp94_;
#line 180 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp96_ = g_value_get_string (_tmp95_);
#line 180 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp97_ = g_strdup (_tmp96_);
#line 180 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_g_free0 (s);
#line 180 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				s = _tmp97_;
#line 180 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				__vala_GValue_free0 (_tmp95_);
#line 181 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp98_ = name;
#line 181 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp99_ = folks_name_details_get_structured_name (_tmp98_);
#line 181 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp100_ = _tmp99_;
#line 181 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp101_ = folks_structured_name_get_suffixes (_tmp100_);
#line 181 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp102_ = _tmp101_;
#line 181 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp103_ = s;
#line 181 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				g_assert (g_strcmp0 (_tmp102_, _tmp103_) == 0);
#line 182 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp104_ = self->priv->_c1;
#line 182 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				gee_abstract_map_unset ((GeeAbstractMap*) _tmp104_, "contact_name_suffixes", NULL);
#line 1324 "name-details.c"
			} else {
				FolksIndividual* _tmp105_;
				const gchar* _tmp106_;
				const gchar* _tmp107_;
#line 184 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp105_ = i;
#line 184 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp106_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp105_);
#line 184 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				_tmp107_ = _tmp106_;
#line 184 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				if (g_strcmp0 (_tmp107_, "richard m. stallman") == 0) {
#line 1337 "name-details.c"
					FolksNameDetails* _tmp108_;
					FolksStructuredName* _tmp109_;
					FolksStructuredName* _tmp110_;
					gboolean _tmp111_ = FALSE;
					GeeHashMap* _tmp112_;
					gpointer _tmp113_ = NULL;
					GValue* _tmp114_;
					const gchar* _tmp115_ = NULL;
					gchar* _tmp116_;
					FolksNameDetails* _tmp117_;
					const gchar* _tmp118_;
					const gchar* _tmp119_;
					const gchar* _tmp120_;
					GeeHashMap* _tmp121_;
					GeeHashMap* _tmp122_;
					gpointer _tmp123_ = NULL;
					GValue* _tmp124_;
					const gchar* _tmp125_ = NULL;
					gchar* _tmp126_;
					FolksNameDetails* _tmp127_;
					FolksStructuredName* _tmp128_;
					FolksStructuredName* _tmp129_;
					const gchar* _tmp130_;
					const gchar* _tmp131_;
					const gchar* _tmp132_;
					GeeHashMap* _tmp133_;
					GeeHashMap* _tmp134_;
					gpointer _tmp135_ = NULL;
					GValue* _tmp136_;
					const gchar* _tmp137_ = NULL;
					gchar* _tmp138_;
					FolksNameDetails* _tmp139_;
					FolksStructuredName* _tmp140_;
					FolksStructuredName* _tmp141_;
					const gchar* _tmp142_;
					const gchar* _tmp143_;
					const gchar* _tmp144_;
					GeeHashMap* _tmp145_;
#line 186 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_tmp108_ = name;
#line 186 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_tmp109_ = folks_name_details_get_structured_name (_tmp108_);
#line 186 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_tmp110_ = _tmp109_;
#line 186 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_tmp111_ = folks_structured_name_is_empty (_tmp110_);
#line 186 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					g_assert (_tmp111_ == FALSE);
#line 188 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_tmp112_ = self->priv->_c2;
#line 188 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_tmp113_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp112_, "full_name");
#line 188 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_tmp114_ = (GValue*) _tmp113_;
#line 188 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_tmp115_ = g_value_get_string (_tmp114_);
#line 188 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_tmp116_ = g_strdup (_tmp115_);
#line 188 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_g_free0 (s);
#line 188 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					s = _tmp116_;
#line 188 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					__vala_GValue_free0 (_tmp114_);
#line 189 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_tmp117_ = name;
#line 189 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_tmp118_ = folks_name_details_get_full_name (_tmp117_);
#line 189 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_tmp119_ = _tmp118_;
#line 189 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_tmp120_ = s;
#line 189 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					g_assert (g_strcmp0 (_tmp119_, _tmp120_) == 0);
#line 190 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_tmp121_ = self->priv->_c2;
#line 190 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					gee_abstract_map_unset ((GeeAbstractMap*) _tmp121_, "full_name", NULL);
#line 192 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_tmp122_ = self->priv->_c2;
#line 192 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_tmp123_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp122_, "contact_name_family");
#line 192 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_tmp124_ = (GValue*) _tmp123_;
#line 192 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_tmp125_ = g_value_get_string (_tmp124_);
#line 192 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_tmp126_ = g_strdup (_tmp125_);
#line 192 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_g_free0 (s);
#line 192 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					s = _tmp126_;
#line 192 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					__vala_GValue_free0 (_tmp124_);
#line 193 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_tmp127_ = name;
#line 193 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_tmp128_ = folks_name_details_get_structured_name (_tmp127_);
#line 193 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_tmp129_ = _tmp128_;
#line 193 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_tmp130_ = folks_structured_name_get_family_name (_tmp129_);
#line 193 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_tmp131_ = _tmp130_;
#line 193 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_tmp132_ = s;
#line 193 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					g_assert (g_strcmp0 (_tmp131_, _tmp132_) == 0);
#line 194 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_tmp133_ = self->priv->_c2;
#line 194 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					gee_abstract_map_unset ((GeeAbstractMap*) _tmp133_, "contact_name_family", NULL);
#line 196 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_tmp134_ = self->priv->_c2;
#line 196 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_tmp135_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp134_, "contact_name_given");
#line 196 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_tmp136_ = (GValue*) _tmp135_;
#line 196 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_tmp137_ = g_value_get_string (_tmp136_);
#line 196 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_tmp138_ = g_strdup (_tmp137_);
#line 196 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_g_free0 (s);
#line 196 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					s = _tmp138_;
#line 196 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					__vala_GValue_free0 (_tmp136_);
#line 197 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_tmp139_ = name;
#line 197 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_tmp140_ = folks_name_details_get_structured_name (_tmp139_);
#line 197 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_tmp141_ = _tmp140_;
#line 197 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_tmp142_ = folks_structured_name_get_given_name (_tmp141_);
#line 197 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_tmp143_ = _tmp142_;
#line 197 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_tmp144_ = s;
#line 197 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					g_assert (g_strcmp0 (_tmp143_, _tmp144_) == 0);
#line 198 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					_tmp145_ = self->priv->_c2;
#line 198 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
					gee_abstract_map_unset ((GeeAbstractMap*) _tmp145_, "contact_name_given", NULL);
#line 1484 "name-details.c"
				}
			}
#line 201 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
			_tmp146_ = self->priv->_names_count;
#line 201 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
			self->priv->_names_count = _tmp146_ + 1;
#line 142 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
			_g_object_unref0 (name);
#line 142 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
			_g_free0 (s);
#line 142 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
			_g_object_unref0 (i);
#line 1497 "name-details.c"
		}
#line 142 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		_g_object_unref0 (_i_it);
#line 1501 "name-details.c"
	}
#line 204 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp147_ = removed;
#line 204 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp148_ = gee_collection_get_size ((GeeCollection*) _tmp147_);
#line 204 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp149_ = _tmp148_;
#line 204 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_assert (_tmp149_ == 1);
#line 1511 "name-details.c"
	{
		GeeSet* _tmp150_;
		GeeIterator* _tmp151_ = NULL;
		GeeIterator* _i_it;
#line 206 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		_tmp150_ = removed;
#line 206 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		_tmp151_ = gee_iterable_iterator ((GeeIterable*) _tmp150_);
#line 206 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		_i_it = _tmp151_;
#line 206 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		while (TRUE) {
#line 1524 "name-details.c"
			GeeIterator* _tmp152_;
			gboolean _tmp153_ = FALSE;
			GeeIterator* _tmp154_;
			gpointer _tmp155_ = NULL;
			FolksIndividual* i;
			FolksIndividual* _tmp156_;
#line 206 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
			_tmp152_ = _i_it;
#line 206 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
			_tmp153_ = gee_iterator_next (_tmp152_);
#line 206 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
			if (!_tmp153_) {
#line 206 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
				break;
#line 1539 "name-details.c"
			}
#line 206 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
			_tmp154_ = _i_it;
#line 206 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
			_tmp155_ = gee_iterator_get (_tmp154_);
#line 206 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
			i = (FolksIndividual*) _tmp155_;
#line 208 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
			_tmp156_ = i;
#line 208 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
			g_assert (_tmp156_ == NULL);
#line 206 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
			_g_object_unref0 (i);
#line 1553 "name-details.c"
		}
#line 206 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		_g_object_unref0 (_i_it);
#line 1557 "name-details.c"
	}
#line 211 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp158_ = self->priv->_c1;
#line 211 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp159_ = gee_abstract_map_get_size ((GeeMap*) _tmp158_);
#line 211 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp160_ = _tmp159_;
#line 211 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	if (_tmp160_ == 0) {
#line 1567 "name-details.c"
		GeeHashMap* _tmp161_;
		gint _tmp162_;
		gint _tmp163_;
#line 212 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		_tmp161_ = self->priv->_c2;
#line 212 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		_tmp162_ = gee_abstract_map_get_size ((GeeMap*) _tmp161_);
#line 212 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		_tmp163_ = _tmp162_;
#line 212 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		_tmp157_ = _tmp163_ == 0;
#line 1579 "name-details.c"
	} else {
#line 211 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		_tmp157_ = FALSE;
#line 1583 "name-details.c"
	}
#line 211 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp164_ = _tmp157_;
#line 211 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	if (_tmp164_) {
#line 1589 "name-details.c"
		GMainLoop* _tmp165_;
#line 214 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		_tmp165_ = self->priv->_main_loop;
#line 214 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
		g_main_loop_quit (_tmp165_);
#line 1595 "name-details.c"
	}
#line 136 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_g_object_unref0 (removed);
#line 136 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_g_object_unref0 (added);
#line 1601 "name-details.c"
}


static void name_details_tests_class_init (NameDetailsTestsClass * klass) {
#line 25 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	name_details_tests_parent_class = g_type_class_peek_parent (klass);
#line 25 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_type_class_add_private (klass, sizeof (NameDetailsTestsPrivate));
#line 25 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	FOLKS_TEST_CASE_CLASS (klass)->set_up = name_details_tests_real_set_up;
#line 25 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	FOLKS_TEST_CASE_CLASS (klass)->tear_down = name_details_tests_real_tear_down;
#line 25 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	G_OBJECT_CLASS (klass)->finalize = name_details_tests_finalize;
#line 1616 "name-details.c"
}


static void name_details_tests_instance_init (NameDetailsTests * self) {
#line 25 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	self->priv = NAME_DETAILS_TESTS_GET_PRIVATE (self);
#line 1623 "name-details.c"
}


static void name_details_tests_finalize (GObject* obj) {
	NameDetailsTests * self;
#line 25 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	self = NAME_DETAILS_TESTS (obj);
#line 27 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_eds_test_backend_unref0 (self->priv->_eds_backend);
#line 28 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 29 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 31 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_g_object_unref0 (self->priv->_c1);
#line 32 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_g_object_unref0 (self->priv->_c2);
#line 25 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	G_OBJECT_CLASS (name_details_tests_parent_class)->finalize (obj);
#line 1643 "name-details.c"
}


GType name_details_tests_get_type (void) {
	static volatile gsize name_details_tests_type_id__volatile = 0;
	if (g_once_init_enter (&name_details_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (NameDetailsTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) name_details_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (NameDetailsTests), 0, (GInstanceInitFunc) name_details_tests_instance_init, NULL };
		GType name_details_tests_type_id;
		name_details_tests_type_id = g_type_register_static (FOLKS_TYPE_TEST_CASE, "NameDetailsTests", &g_define_type_info, 0);
		g_once_init_leave (&name_details_tests_type_id__volatile, name_details_tests_type_id);
	}
	return name_details_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	GTestSuite* _tmp0_ = NULL;
	GTestSuite* root;
	NameDetailsTests* _tmp1_;
	NameDetailsTests* _tmp2_;
	GTestSuite* _tmp3_ = NULL;
#line 221 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_test_init (&args_length1, &args, NULL);
#line 223 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp0_ = g_test_get_root ();
#line 223 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	root = _tmp0_;
#line 224 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp1_ = name_details_tests_new ();
#line 224 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp2_ = _tmp1_;
#line 224 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_tmp3_ = folks_test_case_get_suite ((FolksTestCase*) _tmp2_);
#line 224 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_test_suite_add_suite (root, _tmp3_);
#line 224 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	_g_object_unref0 (_tmp2_);
#line 226 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_test_run ();
#line 228 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	result = 0;
#line 228 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	return result;
#line 1688 "name-details.c"
}


int main (int argc, char ** argv) {
#line 219 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	g_type_init ();
#line 219 "/opt/gnome2/source/folks/tests/eds/name-details.vala"
	return _vala_main (argv, argc);
#line 1697 "name-details.c"
}



