/* set-roles.c generated by valac 0.15.1.20-908e, the Vala compiler
 * generated from set-roles.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <folks-test.h>
#include <eds-test.h>
#include <folks/folks.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <gio/gio.h>


#define TYPE_SET_ROLES_TESTS (set_roles_tests_get_type ())
#define SET_ROLES_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SET_ROLES_TESTS, SetRolesTests))
#define SET_ROLES_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SET_ROLES_TESTS, SetRolesTestsClass))
#define IS_SET_ROLES_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SET_ROLES_TESTS))
#define IS_SET_ROLES_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SET_ROLES_TESTS))
#define SET_ROLES_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SET_ROLES_TESTS, SetRolesTestsClass))

typedef struct _SetRolesTests SetRolesTests;
typedef struct _SetRolesTestsClass SetRolesTestsClass;
typedef struct _SetRolesTestsPrivate SetRolesTestsPrivate;
#define _eds_test_backend_unref0(var) ((var == NULL) ? NULL : (var = (eds_test_backend_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define __vala_GValue_free0(var) ((var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _SetRolesTestsTestSetRolesAsyncData SetRolesTestsTestSetRolesAsyncData;

struct _SetRolesTests {
	FolksTestCase parent_instance;
	SetRolesTestsPrivate * priv;
};

struct _SetRolesTestsClass {
	FolksTestCaseClass parent_class;
};

struct _SetRolesTestsPrivate {
	EdsTestBackend* _eds_backend;
	FolksIndividualAggregator* _aggregator;
	GMainLoop* _main_loop;
	gboolean _found_before_update;
	gboolean _found_after_update;
};

struct _SetRolesTestsTestSetRolesAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	SetRolesTests* self;
	EdsTestBackend* _tmp0_;
	FolksBackendStore* _tmp1_;
	FolksBackendStore* store;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	FolksIndividualAggregator* _tmp4_;
	GError* e;
	GError* _tmp5_;
	const gchar* _tmp6_;
	GError * _inner_error_;
};


static gpointer set_roles_tests_parent_class = NULL;

GType set_roles_tests_get_type (void) G_GNUC_CONST;
#define SET_ROLES_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_SET_ROLES_TESTS, SetRolesTestsPrivate))
enum  {
	SET_ROLES_TESTS_DUMMY_PROPERTY
};
SetRolesTests* set_roles_tests_new (void);
SetRolesTests* set_roles_tests_construct (GType object_type);
static void set_roles_tests_test_set_roles (SetRolesTests* self);
static void _set_roles_tests_test_set_roles_folks_test_case_test_method (gpointer self);
static void set_roles_tests_real_set_up (FolksTestCase* base);
static void set_roles_tests_real_tear_down (FolksTestCase* base);
static GValue* _g_value_dup (GValue* self);
static void _vala_GValue_free (GValue* self);
static void _set_roles_tests_test_set_roles_async (SetRolesTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _set_roles_tests_test_set_roles_finish (SetRolesTests* self, GAsyncResult* _res_);
static gboolean __lambda2_ (SetRolesTests* self);
static gboolean ___lambda2__gsource_func (gpointer self);
static void _set_roles_tests_test_set_roles_async_data_free (gpointer _data);
static gboolean _set_roles_tests_test_set_roles_async_co (SetRolesTestsTestSetRolesAsyncData* _data_);
static void _set_roles_tests_test_set_roles_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _set_roles_tests_individuals_changed_cb (SetRolesTests* self, GeeMultiMap* changes);
static void __set_roles_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void _set_roles_tests_notify_roles_cb (SetRolesTests* self, GObject* individual_obj, GParamSpec* ps);
static void __set_roles_tests_notify_roles_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void set_roles_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _set_roles_tests_test_set_roles_folks_test_case_test_method (gpointer self) {
#line 38 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	set_roles_tests_test_set_roles (self);
#line 123 "set-roles.c"
}


SetRolesTests* set_roles_tests_construct (GType object_type) {
	SetRolesTests * self = NULL;
#line 36 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	self = (SetRolesTests*) folks_test_case_construct (object_type, "SetRoles");
#line 38 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "setting roles on e-d-s persona", _set_roles_tests_test_set_roles_folks_test_case_test_method, self);
#line 34 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	return self;
#line 135 "set-roles.c"
}


SetRolesTests* set_roles_tests_new (void) {
#line 34 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	return set_roles_tests_construct (TYPE_SET_ROLES_TESTS);
#line 142 "set-roles.c"
}


static void set_roles_tests_real_set_up (FolksTestCase* base) {
	SetRolesTests * self;
	EdsTestBackend* _tmp0_;
	EdsTestBackend* _tmp1_;
	EdsTestBackend* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	gchar* _tmp5_ = NULL;
	gchar* config_val;
#line 42 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	self = (SetRolesTests*) base;
#line 44 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_tmp0_ = eds_test_backend_new ();
#line 44 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_eds_test_backend_unref0 (self->priv->_eds_backend);
#line 44 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	self->priv->_eds_backend = _tmp0_;
#line 45 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_tmp1_ = self->priv->_eds_backend;
#line 45 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	eds_test_backend_set_up (_tmp1_, FALSE);
#line 48 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_tmp2_ = self->priv->_eds_backend;
#line 48 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_tmp3_ = eds_test_backend_get_address_book_uid (_tmp2_);
#line 48 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_tmp4_ = _tmp3_;
#line 48 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_tmp5_ = g_strdup_printf ("eds:%s", _tmp4_);
#line 48 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	config_val = _tmp5_;
#line 49 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	g_setenv ("FOLKS_PRIMARY_STORE", config_val, TRUE);
#line 42 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_g_free0 (config_val);
#line 181 "set-roles.c"
}


static void set_roles_tests_real_tear_down (FolksTestCase* base) {
	SetRolesTests * self;
	EdsTestBackend* _tmp0_;
#line 52 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	self = (SetRolesTests*) base;
#line 54 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_tmp0_ = self->priv->_eds_backend;
#line 54 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	eds_test_backend_tear_down (_tmp0_);
#line 194 "set-roles.c"
}


static GValue* _g_value_dup (GValue* self) {
#line 59 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	return g_boxed_copy (G_TYPE_VALUE, self);
#line 201 "set-roles.c"
}


static void _vala_GValue_free (GValue* self) {
#line 59 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	g_value_unset (self);
#line 59 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	g_free (self);
#line 210 "set-roles.c"
}


static gpointer __g_value_dup0 (gpointer self) {
#line 68 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	return self ? _g_value_dup (self) : NULL;
#line 217 "set-roles.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 71 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	return self ? g_object_ref (self) : NULL;
#line 224 "set-roles.c"
}


static gboolean __lambda2_ (SetRolesTests* self) {
	gboolean result = FALSE;
	GMainLoop* _tmp0_;
#line 76 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_tmp0_ = self->priv->_main_loop;
#line 76 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	g_main_loop_quit (_tmp0_);
#line 77 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	g_assert_not_reached ();
#line 75 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	return result;
#line 239 "set-roles.c"
}


static gboolean ___lambda2__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda2_ (self);
#line 75 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	return result;
#line 248 "set-roles.c"
}


static void set_roles_tests_test_set_roles (SetRolesTests* self) {
	GeeHashMap* _tmp0_;
	GeeHashMap* c1;
	GMainLoop* _tmp1_;
	GValue* v = NULL;
	EdsTestBackend* _tmp2_;
	GValue _tmp3_ = {0};
	GValue _tmp4_;
	GValue* _tmp5_;
	GValue* _tmp6_;
	GValue* _tmp7_;
	GValue* _tmp8_;
	EdsTestBackend* _tmp9_;
	GeeHashMap* _tmp10_;
	GMainLoop* _tmp11_;
	gboolean _tmp12_;
	gboolean _tmp13_;
#line 57 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	g_return_if_fail (self != NULL);
#line 59 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_tmp0_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL);
#line 59 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	c1 = _tmp0_;
#line 60 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_tmp1_ = g_main_loop_new (NULL, FALSE);
#line 60 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 60 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	self->priv->_main_loop = _tmp1_;
#line 63 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	self->priv->_found_before_update = FALSE;
#line 64 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	self->priv->_found_after_update = FALSE;
#line 66 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_tmp2_ = self->priv->_eds_backend;
#line 66 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	eds_test_backend_reset (_tmp2_);
#line 68 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	g_value_init (&_tmp3_, G_TYPE_STRING);
#line 68 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_tmp4_ = _tmp3_;
#line 68 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_tmp5_ = __g_value_dup0 (&_tmp4_);
#line 68 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	__vala_GValue_free0 (v);
#line 68 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	v = _tmp5_;
#line 68 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	G_IS_VALUE (&_tmp4_) ? (g_value_unset (&_tmp4_), NULL) : NULL;
#line 69 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_tmp6_ = v;
#line 69 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	g_value_set_string (_tmp6_, "The Guard");
#line 70 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_tmp7_ = v;
#line 70 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	v = NULL;
#line 70 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_tmp8_ = _tmp7_;
#line 70 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, "full_name", _tmp8_);
#line 70 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	__vala_GValue_free0 (_tmp8_);
#line 71 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_tmp9_ = self->priv->_eds_backend;
#line 71 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_tmp10_ = _g_object_ref0 (c1);
#line 71 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	eds_test_backend_add_contact (_tmp9_, _tmp10_);
#line 73 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_set_roles_tests_test_set_roles_async (self, NULL, NULL);
#line 75 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) 5, ___lambda2__gsource_func, g_object_ref (self), g_object_unref);
#line 80 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_tmp11_ = self->priv->_main_loop;
#line 80 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	g_main_loop_run (_tmp11_);
#line 82 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_tmp12_ = self->priv->_found_before_update;
#line 82 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	g_assert (_tmp12_);
#line 83 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_tmp13_ = self->priv->_found_after_update;
#line 83 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	g_assert (_tmp13_);
#line 57 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	__vala_GValue_free0 (v);
#line 57 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_g_object_unref0 (c1);
#line 341 "set-roles.c"
}


static void _set_roles_tests_test_set_roles_async_data_free (gpointer _data) {
	SetRolesTestsTestSetRolesAsyncData* _data_;
	_data_ = _data;
#line 25 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_g_object_unref0 (_data_->self);
#line 25 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	g_slice_free (SetRolesTestsTestSetRolesAsyncData, _data_);
#line 352 "set-roles.c"
}


static void _set_roles_tests_test_set_roles_async (SetRolesTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	SetRolesTestsTestSetRolesAsyncData* _data_;
	SetRolesTests* _tmp0_;
#line 25 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_data_ = g_slice_new0 (SetRolesTestsTestSetRolesAsyncData);
#line 25 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _set_roles_tests_test_set_roles_async);
#line 25 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _set_roles_tests_test_set_roles_async_data_free);
#line 25 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 25 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_data_->self = _tmp0_;
#line 25 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_set_roles_tests_test_set_roles_async_co (_data_);
#line 371 "set-roles.c"
}


static void _set_roles_tests_test_set_roles_finish (SetRolesTests* self, GAsyncResult* _res_) {
	SetRolesTestsTestSetRolesAsyncData* _data_;
#line 25 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 379 "set-roles.c"
}


static void _set_roles_tests_test_set_roles_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	SetRolesTestsTestSetRolesAsyncData* _data_;
#line 88 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_data_ = _user_data_;
#line 88 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_data_->_source_object_ = source_object;
#line 88 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_data_->_res_ = _res_;
#line 88 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_set_roles_tests_test_set_roles_async_co (_data_);
#line 393 "set-roles.c"
}


static void __set_roles_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 93 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_set_roles_tests_individuals_changed_cb (self, changes);
#line 400 "set-roles.c"
}


static gboolean _set_roles_tests_test_set_roles_async_co (SetRolesTestsTestSetRolesAsyncData* _data_) {
#line 86 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	switch (_data_->_state_) {
#line 86 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
		case 0:
#line 409 "set-roles.c"
		goto _state_0;
#line 86 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
		case 1:
#line 413 "set-roles.c"
		goto _state_1;
#line 86 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
		case 2:
#line 417 "set-roles.c"
		goto _state_2;
#line 86 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
		case 3:
#line 421 "set-roles.c"
		goto _state_3;
		default:
#line 86 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
		g_assert_not_reached ();
#line 426 "set-roles.c"
	}
	_state_0:
#line 88 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_data_->_tmp0_ = _data_->self->priv->_eds_backend;
#line 88 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_data_->_state_ = 1;
#line 88 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	eds_test_backend_commit_contacts_to_addressbook (_data_->_tmp0_, _set_roles_tests_test_set_roles_async_ready, _data_);
#line 88 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	return FALSE;
#line 437 "set-roles.c"
	_state_1:
#line 88 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	eds_test_backend_commit_contacts_to_addressbook_finish (_data_->_tmp0_, _data_->_res_);
#line 90 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_data_->_tmp1_ = NULL;
#line 90 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_data_->_tmp1_ = folks_backend_store_dup ();
#line 90 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_data_->store = _data_->_tmp1_;
#line 91 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_data_->_state_ = 2;
#line 91 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	folks_backend_store_prepare (_data_->store, _set_roles_tests_test_set_roles_async_ready, _data_);
#line 91 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	return FALSE;
#line 453 "set-roles.c"
	_state_2:
#line 91 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 92 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_data_->_tmp2_ = folks_individual_aggregator_new ();
#line 92 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 92 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_data_->self->priv->_aggregator = _data_->_tmp2_;
#line 93 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 93 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	g_signal_connect_object (_data_->_tmp3_, "individuals-changed-detailed", (GCallback) __set_roles_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 467 "set-roles.c"
	{
#line 97 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
		_data_->_tmp4_ = _data_->self->priv->_aggregator;
#line 97 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
		_data_->_state_ = 3;
#line 97 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
		folks_individual_aggregator_prepare (_data_->_tmp4_, _set_roles_tests_test_set_roles_async_ready, _data_);
#line 97 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
		return FALSE;
#line 477 "set-roles.c"
		_state_3:
#line 97 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp4_, _data_->_res_, &_data_->_inner_error_);
#line 97 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
		if (_data_->_inner_error_ != NULL) {
#line 483 "set-roles.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 95 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
		_data_->e = _data_->_inner_error_;
#line 95 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
		_data_->_inner_error_ = NULL;
#line 101 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
		_data_->_tmp5_ = _data_->e;
#line 101 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
		_data_->_tmp6_ = _data_->_tmp5_->message;
#line 101 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
		g_warning ("set-roles.vala:101: Error when calling prepare: %s\n", _data_->_tmp6_);
#line 95 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
		_g_error_free0 (_data_->e);
#line 502 "set-roles.c"
	}
	__finally0:
#line 95 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	if (_data_->_inner_error_ != NULL) {
#line 95 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
		_g_object_unref0 (_data_->store);
#line 95 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 95 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
		g_clear_error (&_data_->_inner_error_);
#line 95 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
		return FALSE;
#line 515 "set-roles.c"
	}
#line 86 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_g_object_unref0 (_data_->store);
#line 86 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	if (_data_->_state_ == 0) {
#line 86 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 523 "set-roles.c"
	} else {
#line 86 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 527 "set-roles.c"
	}
#line 86 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	g_object_unref (_data_->_async_result);
#line 86 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	return FALSE;
#line 533 "set-roles.c"
}


static void __set_roles_tests_notify_roles_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 116 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_set_roles_tests_notify_roles_cb (self, _sender, pspec);
#line 540 "set-roles.c"
}


static void _set_roles_tests_individuals_changed_cb (SetRolesTests* self, GeeMultiMap* changes) {
	GeeMultiMap* _tmp0_;
	GeeCollection* _tmp1_ = NULL;
	GeeCollection* added;
#line 105 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	g_return_if_fail (self != NULL);
#line 105 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	g_return_if_fail (changes != NULL);
#line 108 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_tmp0_ = changes;
#line 108 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 108 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	added = _tmp1_;
#line 558 "set-roles.c"
	{
		GeeCollection* _tmp2_;
		GeeIterator* _tmp3_ = NULL;
		GeeIterator* _i_it;
#line 110 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
		_tmp2_ = added;
#line 110 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
		_tmp3_ = gee_iterable_iterator ((GeeIterable*) _tmp2_);
#line 110 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
		_i_it = _tmp3_;
#line 110 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
		while (TRUE) {
#line 571 "set-roles.c"
			GeeIterator* _tmp4_;
			gboolean _tmp5_ = FALSE;
			GeeIterator* _tmp6_;
			gpointer _tmp7_ = NULL;
			FolksIndividual* i;
			FolksIndividual* _tmp8_;
			FolksNameDetails* _tmp9_;
			FolksNameDetails* name;
			FolksNameDetails* _tmp10_;
			const gchar* _tmp11_;
			const gchar* _tmp12_;
#line 110 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
			_tmp4_ = _i_it;
#line 110 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
			_tmp5_ = gee_iterator_next (_tmp4_);
#line 110 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
			if (!_tmp5_) {
#line 110 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
				break;
#line 591 "set-roles.c"
			}
#line 110 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
			_tmp6_ = _i_it;
#line 110 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
			_tmp7_ = gee_iterator_get (_tmp6_);
#line 110 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
			i = (FolksIndividual*) _tmp7_;
#line 112 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
			_tmp8_ = i;
#line 112 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
			_tmp9_ = _g_object_ref0 (FOLKS_NAME_DETAILS (_tmp8_));
#line 112 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
			name = _tmp9_;
#line 114 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
			_tmp10_ = name;
#line 114 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
			_tmp11_ = folks_name_details_get_full_name (_tmp10_);
#line 114 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
			_tmp12_ = _tmp11_;
#line 114 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
			if (g_strcmp0 (_tmp12_, "The Guard") == 0) {
#line 613 "set-roles.c"
				FolksIndividual* _tmp13_;
#line 116 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
				_tmp13_ = i;
#line 116 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
				g_signal_connect_object ((GObject*) _tmp13_, "notify::roles", (GCallback) __set_roles_tests_notify_roles_cb_g_object_notify, self, 0);
#line 117 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
				self->priv->_found_before_update = TRUE;
#line 621 "set-roles.c"
				{
					FolksIndividual* _tmp14_;
					GeeSet* _tmp15_;
					GeeSet* _tmp16_;
					GeeIterator* _tmp17_ = NULL;
					GeeIterator* _p_it;
#line 119 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
					_tmp14_ = i;
#line 119 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
					_tmp15_ = folks_individual_get_personas (_tmp14_);
#line 119 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
					_tmp16_ = _tmp15_;
#line 119 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
					_tmp17_ = gee_iterable_iterator ((GeeIterable*) _tmp16_);
#line 119 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
					_p_it = _tmp17_;
#line 119 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
					while (TRUE) {
#line 640 "set-roles.c"
						GeeIterator* _tmp18_;
						gboolean _tmp19_ = FALSE;
						GeeIterator* _tmp20_;
						gpointer _tmp21_ = NULL;
						FolksPersona* p;
						GeeHashSet* _tmp22_;
						GeeHashSet* role_fds;
						FolksRole* _tmp23_;
						FolksRole* r1;
						FolksRole* _tmp24_;
						FolksRole* _tmp25_;
						FolksRoleFieldDetails* _tmp26_;
						FolksRoleFieldDetails* role_fd1;
						GeeHashSet* _tmp27_;
						FolksRoleFieldDetails* _tmp28_;
						FolksPersona* _tmp29_;
						GeeHashSet* _tmp30_;
#line 119 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
						_tmp18_ = _p_it;
#line 119 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
						_tmp19_ = gee_iterator_next (_tmp18_);
#line 119 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
						if (!_tmp19_) {
#line 119 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
							break;
#line 666 "set-roles.c"
						}
#line 119 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
						_tmp20_ = _p_it;
#line 119 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
						_tmp21_ = gee_iterator_get (_tmp20_);
#line 119 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
						p = (FolksPersona*) _tmp21_;
#line 121 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
						_tmp22_ = gee_hash_set_new (FOLKS_TYPE_ROLE_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, (GHashFunc) folks_abstract_field_details_hash, (GEqualFunc) folks_abstract_field_details_equal);
#line 121 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
						role_fds = _tmp22_;
#line 124 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
						_tmp23_ = folks_role_new ("Dr.", "The Nut House Ltd", NULL);
#line 124 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
						r1 = _tmp23_;
#line 125 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
						_tmp24_ = r1;
#line 125 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
						folks_role_set_role (_tmp24_, "The Manager");
#line 126 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
						_tmp25_ = r1;
#line 126 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
						_tmp26_ = folks_role_field_details_new (_tmp25_, NULL);
#line 126 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
						role_fd1 = _tmp26_;
#line 127 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
						_tmp27_ = role_fds;
#line 127 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
						_tmp28_ = role_fd1;
#line 127 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
						gee_abstract_collection_add ((GeeAbstractCollection*) _tmp27_, _tmp28_);
#line 128 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
						_tmp29_ = p;
#line 128 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
						_tmp30_ = role_fds;
#line 128 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
						folks_role_details_set_roles (FOLKS_ROLE_DETAILS (_tmp29_), (GeeSet*) _tmp30_);
#line 119 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
						_g_object_unref0 (role_fd1);
#line 119 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
						_g_object_unref0 (r1);
#line 119 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
						_g_object_unref0 (role_fds);
#line 119 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
						_g_object_unref0 (p);
#line 712 "set-roles.c"
					}
#line 119 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
					_g_object_unref0 (_p_it);
#line 716 "set-roles.c"
				}
			}
#line 110 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
			_g_object_unref0 (name);
#line 110 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
			_g_object_unref0 (i);
#line 723 "set-roles.c"
		}
#line 110 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
		_g_object_unref0 (_i_it);
#line 727 "set-roles.c"
	}
#line 105 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_g_object_unref0 (added);
#line 731 "set-roles.c"
}


static void _set_roles_tests_notify_roles_cb (SetRolesTests* self, GObject* individual_obj, GParamSpec* ps) {
	GObject* _tmp0_;
	FolksIndividual* _tmp1_;
	FolksIndividual* i;
#line 134 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	g_return_if_fail (self != NULL);
#line 134 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	g_return_if_fail (individual_obj != NULL);
#line 134 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	g_return_if_fail (ps != NULL);
#line 136 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_tmp0_ = individual_obj;
#line 136 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_tmp1_ = _g_object_ref0 (FOLKS_INDIVIDUAL (_tmp0_));
#line 136 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	i = _tmp1_;
#line 751 "set-roles.c"
	{
		FolksIndividual* _tmp2_;
		GeeSet* _tmp3_;
		GeeSet* _tmp4_;
		GeeIterator* _tmp5_ = NULL;
		GeeIterator* _role_fd_it;
#line 137 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
		_tmp2_ = i;
#line 137 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
		_tmp3_ = folks_role_details_get_roles ((FolksRoleDetails*) _tmp2_);
#line 137 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
		_tmp4_ = _tmp3_;
#line 137 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 137 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
		_role_fd_it = _tmp5_;
#line 137 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
		while (TRUE) {
#line 770 "set-roles.c"
			GeeIterator* _tmp6_;
			gboolean _tmp7_ = FALSE;
			GeeIterator* _tmp8_;
			gpointer _tmp9_ = NULL;
			FolksRoleFieldDetails* role_fd;
			FolksRole* _tmp10_;
			FolksRole* r1;
			FolksRole* _tmp11_;
			FolksRole* _tmp12_;
			FolksRoleFieldDetails* _tmp13_;
			FolksRoleFieldDetails* role_fd_expected;
			FolksRoleFieldDetails* _tmp14_;
			FolksRoleFieldDetails* _tmp15_;
			gboolean _tmp16_ = FALSE;
#line 137 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
			_tmp6_ = _role_fd_it;
#line 137 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 137 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
			if (!_tmp7_) {
#line 137 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
				break;
#line 793 "set-roles.c"
			}
#line 137 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
			_tmp8_ = _role_fd_it;
#line 137 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 137 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
			role_fd = (FolksRoleFieldDetails*) _tmp9_;
#line 139 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
			_tmp10_ = folks_role_new ("Dr.", "The Nut House Ltd", NULL);
#line 139 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
			r1 = _tmp10_;
#line 140 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
			_tmp11_ = r1;
#line 140 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
			folks_role_set_role (_tmp11_, "The Manager");
#line 141 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
			_tmp12_ = r1;
#line 141 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
			_tmp13_ = folks_role_field_details_new (_tmp12_, NULL);
#line 141 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
			role_fd_expected = _tmp13_;
#line 142 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
			_tmp14_ = role_fd;
#line 142 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
			_tmp15_ = role_fd_expected;
#line 142 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
			_tmp16_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) _tmp14_, (FolksAbstractFieldDetails*) _tmp15_);
#line 142 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
			if (_tmp16_) {
#line 823 "set-roles.c"
				GMainLoop* _tmp17_;
#line 144 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
				self->priv->_found_after_update = TRUE;
#line 145 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
				_tmp17_ = self->priv->_main_loop;
#line 145 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
				g_main_loop_quit (_tmp17_);
#line 831 "set-roles.c"
			}
#line 137 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
			_g_object_unref0 (role_fd_expected);
#line 137 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
			_g_object_unref0 (r1);
#line 137 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
			_g_object_unref0 (role_fd);
#line 839 "set-roles.c"
		}
#line 137 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
		_g_object_unref0 (_role_fd_it);
#line 843 "set-roles.c"
	}
#line 134 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_g_object_unref0 (i);
#line 847 "set-roles.c"
}


static void set_roles_tests_class_init (SetRolesTestsClass * klass) {
#line 25 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	set_roles_tests_parent_class = g_type_class_peek_parent (klass);
#line 25 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	g_type_class_add_private (klass, sizeof (SetRolesTestsPrivate));
#line 25 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	FOLKS_TEST_CASE_CLASS (klass)->set_up = set_roles_tests_real_set_up;
#line 25 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	FOLKS_TEST_CASE_CLASS (klass)->tear_down = set_roles_tests_real_tear_down;
#line 25 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	G_OBJECT_CLASS (klass)->finalize = set_roles_tests_finalize;
#line 862 "set-roles.c"
}


static void set_roles_tests_instance_init (SetRolesTests * self) {
#line 25 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	self->priv = SET_ROLES_TESTS_GET_PRIVATE (self);
#line 869 "set-roles.c"
}


static void set_roles_tests_finalize (GObject* obj) {
	SetRolesTests * self;
#line 25 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	self = SET_ROLES_TESTS (obj);
#line 27 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_eds_test_backend_unref0 (self->priv->_eds_backend);
#line 28 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 29 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 25 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	G_OBJECT_CLASS (set_roles_tests_parent_class)->finalize (obj);
#line 885 "set-roles.c"
}


GType set_roles_tests_get_type (void) {
	static volatile gsize set_roles_tests_type_id__volatile = 0;
	if (g_once_init_enter (&set_roles_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SetRolesTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) set_roles_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SetRolesTests), 0, (GInstanceInitFunc) set_roles_tests_instance_init, NULL };
		GType set_roles_tests_type_id;
		set_roles_tests_type_id = g_type_register_static (FOLKS_TYPE_TEST_CASE, "SetRolesTests", &g_define_type_info, 0);
		g_once_init_leave (&set_roles_tests_type_id__volatile, set_roles_tests_type_id);
	}
	return set_roles_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	GTestSuite* _tmp0_ = NULL;
	GTestSuite* root;
	SetRolesTests* _tmp1_;
	SetRolesTests* _tmp2_;
	GTestSuite* _tmp3_ = NULL;
#line 153 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	g_test_init (&args_length1, &args, NULL);
#line 155 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_tmp0_ = g_test_get_root ();
#line 155 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	root = _tmp0_;
#line 156 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_tmp1_ = set_roles_tests_new ();
#line 156 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_tmp2_ = _tmp1_;
#line 156 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_tmp3_ = folks_test_case_get_suite ((FolksTestCase*) _tmp2_);
#line 156 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	g_test_suite_add_suite (root, _tmp3_);
#line 156 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	_g_object_unref0 (_tmp2_);
#line 158 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	g_test_run ();
#line 160 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	result = 0;
#line 160 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	return result;
#line 930 "set-roles.c"
}


int main (int argc, char ** argv) {
#line 151 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	g_type_init ();
#line 151 "/opt/gnome2/source/folks/tests/eds/set-roles.vala"
	return _vala_main (argv, argc);
#line 939 "set-roles.c"
}



