/* match-known-emails.c generated by valac 0.15.2.10-1402f, the Vala compiler
 * generated from match-known-emails.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <folks-test.h>
#include <tracker-test.h>
#include <folks/folks.h>
#include <stdlib.h>
#include <string.h>
#include <folks/folks-tracker.h>
#include <gio/gio.h>
#include <gee.h>


#define TYPE_MATCH_KNOWN_EMAILS_TESTS (match_known_emails_tests_get_type ())
#define MATCH_KNOWN_EMAILS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MATCH_KNOWN_EMAILS_TESTS, MatchKnownEmailsTests))
#define MATCH_KNOWN_EMAILS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MATCH_KNOWN_EMAILS_TESTS, MatchKnownEmailsTestsClass))
#define IS_MATCH_KNOWN_EMAILS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MATCH_KNOWN_EMAILS_TESTS))
#define IS_MATCH_KNOWN_EMAILS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MATCH_KNOWN_EMAILS_TESTS))
#define MATCH_KNOWN_EMAILS_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MATCH_KNOWN_EMAILS_TESTS, MatchKnownEmailsTestsClass))

typedef struct _MatchKnownEmailsTests MatchKnownEmailsTests;
typedef struct _MatchKnownEmailsTestsClass MatchKnownEmailsTestsClass;
typedef struct _MatchKnownEmailsTestsPrivate MatchKnownEmailsTestsPrivate;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _tracker_test_backend_unref0(var) ((var == NULL) ? NULL : (var = (tracker_test_backend_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _MatchKnownEmailsTestsTestMatchEmailAddressesAsyncData MatchKnownEmailsTestsTestMatchEmailAddressesAsyncData;
typedef struct _MatchKnownEmailsTestsTryToAddData MatchKnownEmailsTestsTryToAddData;
#define __vala_GValue_free0(var) ((var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL)))
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))
typedef struct _MatchKnownEmailsTestsAddPersonasData MatchKnownEmailsTestsAddPersonasData;

struct _MatchKnownEmailsTests {
	FolksTestCase parent_instance;
	MatchKnownEmailsTestsPrivate * priv;
};

struct _MatchKnownEmailsTestsClass {
	FolksTestCaseClass parent_class;
};

struct _MatchKnownEmailsTestsPrivate {
	GMainLoop* _main_loop;
	TrackerTestBackend* _tracker_backend;
	FolksIndividualAggregator* _aggregator;
	gchar* _persona_fullname_1;
	gchar* _persona_fullname_2;
	gchar* _email_1;
	gboolean _added_personas;
	GStaticRecMutex __lock__added_personas;
	gchar* _individual_id_1;
	gchar* _individual_id_2;
	FolksMatchResult _match;
	TrfPersonaStore* _pstore;
};

struct _MatchKnownEmailsTestsTestMatchEmailAddressesAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	MatchKnownEmailsTests* self;
	FolksBackendStore* _tmp0_;
	FolksBackendStore* store;
	FolksIndividualAggregator* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	GeeMap* _tmp4_;
	GeeMap* _tmp5_;
	GeeCollection* _tmp6_;
	GeeCollection* _tmp7_;
	GeeCollection* _tmp8_;
	GeeIterator* _tmp9_;
	GeeIterator* _tmp10_;
	GeeIterator* _backend_it;
	GeeIterator* _tmp11_;
	gboolean _tmp12_;
	GeeIterator* _tmp13_;
	gpointer _tmp14_;
	FolksBackend* backend;
	FolksBackend* _tmp15_;
	GeeMap* _tmp16_;
	GeeMap* _tmp17_;
	gpointer _tmp18_;
	TrfPersonaStore* _tmp19_;
	TrfPersonaStore* _tmp20_;
	TrfPersonaStore* _tmp21_;
	GError* e;
	GError* _tmp22_;
	const gchar* _tmp23_;
	GError * _inner_error_;
};

struct _MatchKnownEmailsTestsTryToAddData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	MatchKnownEmailsTests* self;
	gboolean _tmp0_;
	gboolean _tmp1_;
	TrfPersonaStore* _tmp2_;
	gboolean _tmp3_;
	gboolean _tmp4_;
	gboolean _tmp5_;
	gboolean _tmp6_;
	gboolean _tmp7_;
	GError * _inner_error_;
};

struct _MatchKnownEmailsTestsAddPersonasData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	MatchKnownEmailsTests* self;
	GHashFunc _tmp0_;
	GEqualFunc _tmp1_;
	GHashTable* _tmp2_;
	GHashTable* details1;
	GHashFunc _tmp3_;
	GEqualFunc _tmp4_;
	GHashTable* _tmp5_;
	GHashTable* details2;
	GValue* val;
	GValue _tmp6_;
	GValue _tmp7_;
	GValue* _tmp8_;
	GValue* _tmp9_;
	const gchar* _tmp10_;
	GHashTable* _tmp11_;
	const gchar* _tmp12_;
	gchar* _tmp13_;
	GValue* _tmp14_;
	GValue _tmp15_;
	GValue _tmp16_;
	GValue* _tmp17_;
	GeeHashSet* _tmp18_;
	GeeHashSet* emails1;
	const gchar* _tmp19_;
	FolksEmailFieldDetails* _tmp20_;
	FolksEmailFieldDetails* email_1;
	GeeHashSet* _tmp21_;
	FolksEmailFieldDetails* _tmp22_;
	GValue* _tmp23_;
	GeeHashSet* _tmp24_;
	GHashTable* _tmp25_;
	const gchar* _tmp26_;
	gchar* _tmp27_;
	GValue* _tmp28_;
	GValue _tmp29_;
	GValue _tmp30_;
	GValue* _tmp31_;
	GValue* _tmp32_;
	const gchar* _tmp33_;
	GHashTable* _tmp34_;
	const gchar* _tmp35_;
	gchar* _tmp36_;
	GValue* _tmp37_;
	GValue _tmp38_;
	GValue _tmp39_;
	GValue* _tmp40_;
	GeeHashSet* _tmp41_;
	GeeHashSet* emails2;
	const gchar* _tmp42_;
	FolksEmailFieldDetails* _tmp43_;
	FolksEmailFieldDetails* email_2;
	GeeHashSet* _tmp44_;
	FolksEmailFieldDetails* _tmp45_;
	GValue* _tmp46_;
	GeeHashSet* _tmp47_;
	GHashTable* _tmp48_;
	const gchar* _tmp49_;
	gchar* _tmp50_;
	GValue* _tmp51_;
	FolksIndividualAggregator* _tmp52_;
	TrfPersonaStore* _tmp53_;
	GHashTable* _tmp54_;
	FolksPersona* _tmp55_;
	FolksPersona* _tmp56_;
	FolksIndividualAggregator* _tmp57_;
	TrfPersonaStore* _tmp58_;
	GHashTable* _tmp59_;
	FolksPersona* _tmp60_;
	FolksPersona* _tmp61_;
	GError* e;
	GError* _tmp62_;
	const gchar* _tmp63_;
	GError * _inner_error_;
};


static gpointer match_known_emails_tests_parent_class = NULL;

GType match_known_emails_tests_get_type (void) G_GNUC_CONST;
#define MATCH_KNOWN_EMAILS_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_MATCH_KNOWN_EMAILS_TESTS, MatchKnownEmailsTestsPrivate))
enum  {
	MATCH_KNOWN_EMAILS_TESTS_DUMMY_PROPERTY
};
MatchKnownEmailsTests* match_known_emails_tests_new (void);
MatchKnownEmailsTests* match_known_emails_tests_construct (GType object_type);
void match_known_emails_tests_test_match_email_addresses (MatchKnownEmailsTests* self);
static void _match_known_emails_tests_test_match_email_addresses_folks_test_case_test_method (gpointer self);
static void match_known_emails_tests_real_set_up (FolksTestCase* base);
static void match_known_emails_tests_real_tear_down (FolksTestCase* base);
static void _match_known_emails_tests_test_match_email_addresses_async (MatchKnownEmailsTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _match_known_emails_tests_test_match_email_addresses_finish (MatchKnownEmailsTests* self, GAsyncResult* _res_);
static gboolean __lambda2_ (MatchKnownEmailsTests* self);
static gboolean ___lambda2__gsource_func (gpointer self);
static void _match_known_emails_tests_test_match_email_addresses_async_data_free (gpointer _data);
static gboolean _match_known_emails_tests_test_match_email_addresses_async_co (MatchKnownEmailsTestsTestMatchEmailAddressesAsyncData* _data_);
static void _match_known_emails_tests_test_match_email_addresses_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _match_known_emails_tests_individuals_changed_cb (MatchKnownEmailsTests* self, GeeMultiMap* changes);
static void __match_known_emails_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void _match_known_emails_tests_notify_pstore_cb (MatchKnownEmailsTests* self, GObject* _pstore, GParamSpec* ps);
static void __match_known_emails_tests_notify_pstore_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _match_known_emails_tests_try_to_add (MatchKnownEmailsTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _match_known_emails_tests_try_to_add_finish (MatchKnownEmailsTests* self, GAsyncResult* _res_);
static void _match_known_emails_tests_try_potential_match (MatchKnownEmailsTests* self);
static void _match_known_emails_tests_try_to_add_data_free (gpointer _data);
static gboolean _match_known_emails_tests_try_to_add_co (MatchKnownEmailsTestsTryToAddData* _data_);
static void _match_known_emails_tests_add_personas (MatchKnownEmailsTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _match_known_emails_tests_add_personas_finish (MatchKnownEmailsTests* self, GAsyncResult* _res_);
static void _match_known_emails_tests_try_to_add_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _match_known_emails_tests_add_personas_data_free (gpointer _data);
static gboolean _match_known_emails_tests_add_personas_co (MatchKnownEmailsTestsAddPersonasData* _data_);
static void _g_free0_ (gpointer var);
static void _vala_GValue_free (GValue* self);
static void __vala_GValue_free0_ (gpointer var);
static GValue* _g_value_dup (GValue* self);
static void _match_known_emails_tests_add_personas_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void match_known_emails_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _match_known_emails_tests_test_match_email_addresses_folks_test_case_test_method (gpointer self) {
#line 50 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	match_known_emails_tests_test_match_email_addresses (self);
#line 264 "match-known-emails.c"
}


MatchKnownEmailsTests* match_known_emails_tests_construct (GType object_type) {
	MatchKnownEmailsTests * self = NULL;
	TrackerTestBackend* _tmp0_;
#line 46 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	self = (MatchKnownEmailsTests*) folks_test_case_construct (object_type, "MatchKnownEmailsTests");
#line 48 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp0_ = tracker_test_backend_new ();
#line 48 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tracker_test_backend_unref0 (self->priv->_tracker_backend);
#line 48 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	self->priv->_tracker_backend = _tmp0_;
#line 50 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "test potential match with same email addresses ", _match_known_emails_tests_test_match_email_addresses_folks_test_case_test_method, self);
#line 44 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	return self;
#line 283 "match-known-emails.c"
}


MatchKnownEmailsTests* match_known_emails_tests_new (void) {
#line 44 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	return match_known_emails_tests_construct (TYPE_MATCH_KNOWN_EMAILS_TESTS);
#line 290 "match-known-emails.c"
}


static void match_known_emails_tests_real_set_up (FolksTestCase* base) {
	MatchKnownEmailsTests * self;
#line 54 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	self = (MatchKnownEmailsTests*) base;
#line 298 "match-known-emails.c"
}


static void match_known_emails_tests_real_tear_down (FolksTestCase* base) {
	MatchKnownEmailsTests * self;
	TrackerTestBackend* _tmp0_;
#line 58 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	self = (MatchKnownEmailsTests*) base;
#line 60 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp0_ = self->priv->_tracker_backend;
#line 60 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	tracker_test_backend_tear_down (_tmp0_);
#line 311 "match-known-emails.c"
}


static gboolean __lambda2_ (MatchKnownEmailsTests* self) {
	gboolean result = FALSE;
	GMainLoop* _tmp0_;
#line 71 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp0_ = self->priv->_main_loop;
#line 71 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_main_loop_quit (_tmp0_);
#line 72 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_assert_not_reached ();
#line 69 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	return result;
#line 326 "match-known-emails.c"
}


static gboolean ___lambda2__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda2_ (self);
#line 69 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	return result;
#line 335 "match-known-emails.c"
}


void match_known_emails_tests_test_match_email_addresses (MatchKnownEmailsTests* self) {
	GMainLoop* _tmp0_;
	GMainLoop* _tmp1_;
	FolksMatchResult _tmp2_;
#line 63 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_return_if_fail (self != NULL);
#line 65 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 65 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 65 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	self->priv->_main_loop = _tmp0_;
#line 67 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_match_known_emails_tests_test_match_email_addresses_async (self, NULL, NULL);
#line 69 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) 5, ___lambda2__gsource_func, g_object_ref (self), g_object_unref);
#line 75 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp1_ = self->priv->_main_loop;
#line 75 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_main_loop_run (_tmp1_);
#line 81 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp2_ = self->priv->_match;
#line 81 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_assert (_tmp2_ <= FOLKS_MATCH_RESULT_LOW);
#line 363 "match-known-emails.c"
}


static void _match_known_emails_tests_test_match_email_addresses_async_data_free (gpointer _data) {
	MatchKnownEmailsTestsTestMatchEmailAddressesAsyncData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_slice_free (MatchKnownEmailsTestsTestMatchEmailAddressesAsyncData, _data_);
#line 374 "match-known-emails.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 26 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	return self ? g_object_ref (self) : NULL;
#line 381 "match-known-emails.c"
}


static void _match_known_emails_tests_test_match_email_addresses_async (MatchKnownEmailsTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	MatchKnownEmailsTestsTestMatchEmailAddressesAsyncData* _data_;
	MatchKnownEmailsTests* _tmp0_;
#line 26 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_ = g_slice_new0 (MatchKnownEmailsTestsTestMatchEmailAddressesAsyncData);
#line 26 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _match_known_emails_tests_test_match_email_addresses_async);
#line 26 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _match_known_emails_tests_test_match_email_addresses_async_data_free);
#line 26 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_match_known_emails_tests_test_match_email_addresses_async_co (_data_);
#line 400 "match-known-emails.c"
}


static void _match_known_emails_tests_test_match_email_addresses_finish (MatchKnownEmailsTests* self, GAsyncResult* _res_) {
	MatchKnownEmailsTestsTestMatchEmailAddressesAsyncData* _data_;
#line 26 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 408 "match-known-emails.c"
}


static void _match_known_emails_tests_test_match_email_addresses_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	MatchKnownEmailsTestsTestMatchEmailAddressesAsyncData* _data_;
#line 87 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_ = _user_data_;
#line 87 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_source_object_ = source_object;
#line 87 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_res_ = _res_;
#line 87 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_match_known_emails_tests_test_match_email_addresses_async_co (_data_);
#line 422 "match-known-emails.c"
}


static void __match_known_emails_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 89 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_match_known_emails_tests_individuals_changed_cb (self, changes);
#line 429 "match-known-emails.c"
}


static void __match_known_emails_tests_notify_pstore_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 103 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_match_known_emails_tests_notify_pstore_cb (self, _sender, pspec);
#line 436 "match-known-emails.c"
}


static gboolean _match_known_emails_tests_test_match_email_addresses_async_co (MatchKnownEmailsTestsTestMatchEmailAddressesAsyncData* _data_) {
#line 84 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	switch (_data_->_state_) {
#line 84 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		case 0:
#line 445 "match-known-emails.c"
		goto _state_0;
#line 84 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		case 1:
#line 449 "match-known-emails.c"
		goto _state_1;
#line 84 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		case 2:
#line 453 "match-known-emails.c"
		goto _state_2;
		default:
#line 84 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		g_assert_not_reached ();
#line 458 "match-known-emails.c"
	}
	_state_0:
#line 86 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp0_ = NULL;
#line 86 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp0_ = folks_backend_store_dup ();
#line 86 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->store = _data_->_tmp0_;
#line 87 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_state_ = 1;
#line 87 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	folks_backend_store_prepare (_data_->store, _match_known_emails_tests_test_match_email_addresses_async_ready, _data_);
#line 87 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	return FALSE;
#line 473 "match-known-emails.c"
	_state_1:
#line 87 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 88 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp1_ = folks_individual_aggregator_new ();
#line 88 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 88 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->self->priv->_aggregator = _data_->_tmp1_;
#line 89 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp2_ = _data_->self->priv->_aggregator;
#line 89 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_signal_connect_object (_data_->_tmp2_, "individuals-changed-detailed", (GCallback) __match_known_emails_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 487 "match-known-emails.c"
	{
#line 93 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 93 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_data_->_state_ = 2;
#line 93 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		folks_individual_aggregator_prepare (_data_->_tmp3_, _match_known_emails_tests_test_match_email_addresses_async_ready, _data_);
#line 93 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		return FALSE;
#line 497 "match-known-emails.c"
		_state_2:
#line 93 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp3_, _data_->_res_, &_data_->_inner_error_);
#line 93 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		if (_data_->_inner_error_ != NULL) {
#line 503 "match-known-emails.c"
			goto __catch0_g_error;
		}
#line 94 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_g_object_unref0 (_data_->self->priv->_pstore);
#line 94 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_data_->self->priv->_pstore = NULL;
#line 510 "match-known-emails.c"
		{
#line 95 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_data_->_tmp4_ = folks_backend_store_get_enabled_backends (_data_->store);
#line 95 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_data_->_tmp5_ = _data_->_tmp4_;
#line 95 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_data_->_tmp6_ = gee_map_get_values (_data_->_tmp5_);
#line 95 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_data_->_tmp7_ = _data_->_tmp6_;
#line 95 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_data_->_tmp8_ = _data_->_tmp7_;
#line 95 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_data_->_tmp9_ = NULL;
#line 95 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_data_->_tmp9_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp8_);
#line 95 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_data_->_tmp10_ = _data_->_tmp9_;
#line 95 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_g_object_unref0 (_data_->_tmp8_);
#line 95 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_data_->_backend_it = _data_->_tmp10_;
#line 95 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			while (TRUE) {
#line 95 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
				_data_->_tmp11_ = _data_->_backend_it;
#line 95 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
				_data_->_tmp12_ = FALSE;
#line 95 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
				_data_->_tmp12_ = gee_iterator_next (_data_->_tmp11_);
#line 95 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
				if (!_data_->_tmp12_) {
#line 95 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
					break;
#line 544 "match-known-emails.c"
				}
#line 95 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
				_data_->_tmp13_ = _data_->_backend_it;
#line 95 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
				_data_->_tmp14_ = NULL;
#line 95 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
				_data_->_tmp14_ = gee_iterator_get (_data_->_tmp13_);
#line 95 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
				_data_->backend = (FolksBackend*) _data_->_tmp14_;
#line 97 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
				_data_->_tmp15_ = _data_->backend;
#line 97 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
				_data_->_tmp16_ = folks_backend_get_persona_stores (_data_->_tmp15_);
#line 97 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
				_data_->_tmp17_ = _data_->_tmp16_;
#line 97 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
				_data_->_tmp18_ = NULL;
#line 97 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
				_data_->_tmp18_ = gee_map_get (_data_->_tmp17_, "tracker");
#line 97 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
				_g_object_unref0 (_data_->self->priv->_pstore);
#line 97 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
				_data_->self->priv->_pstore = TRF_PERSONA_STORE ((FolksPersonaStore*) _data_->_tmp18_);
#line 99 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
				_data_->_tmp19_ = _data_->self->priv->_pstore;
#line 99 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
				if (_data_->_tmp19_ != NULL) {
#line 100 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
					_g_object_unref0 (_data_->backend);
#line 100 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
					break;
#line 576 "match-known-emails.c"
				}
#line 95 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
				_g_object_unref0 (_data_->backend);
#line 580 "match-known-emails.c"
			}
#line 95 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_g_object_unref0 (_data_->_backend_it);
#line 584 "match-known-emails.c"
		}
#line 102 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_data_->_tmp20_ = _data_->self->priv->_pstore;
#line 102 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		g_assert (_data_->_tmp20_ != NULL);
#line 103 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_data_->_tmp21_ = _data_->self->priv->_pstore;
#line 103 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		g_signal_connect_object ((GObject*) _data_->_tmp21_, "notify::is-prepared", (GCallback) __match_known_emails_tests_notify_pstore_cb_g_object_notify, _data_->self, 0);
#line 104 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_match_known_emails_tests_try_to_add (_data_->self, NULL, NULL);
#line 596 "match-known-emails.c"
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 91 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_data_->e = _data_->_inner_error_;
#line 91 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_data_->_inner_error_ = NULL;
#line 108 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_data_->_tmp22_ = _data_->e;
#line 108 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_data_->_tmp23_ = _data_->_tmp22_->message;
#line 108 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		g_warning ("match-known-emails.vala:108: Error when calling prepare: %s\n", _data_->_tmp23_);
#line 91 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_g_error_free0 (_data_->e);
#line 613 "match-known-emails.c"
	}
	__finally0:
#line 91 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	if (_data_->_inner_error_ != NULL) {
#line 91 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_g_object_unref0 (_data_->store);
#line 91 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 91 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		g_clear_error (&_data_->_inner_error_);
#line 91 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		return FALSE;
#line 626 "match-known-emails.c"
	}
#line 84 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_g_object_unref0 (_data_->store);
#line 84 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	if (_data_->_state_ == 0) {
#line 84 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 634 "match-known-emails.c"
	} else {
#line 84 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 638 "match-known-emails.c"
	}
#line 84 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_object_unref (_data_->_async_result);
#line 84 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	return FALSE;
#line 644 "match-known-emails.c"
}


static void _match_known_emails_tests_individuals_changed_cb (MatchKnownEmailsTests* self, GeeMultiMap* changes) {
	GeeMultiMap* _tmp0_;
	GeeCollection* _tmp1_ = NULL;
	GeeCollection* added;
	GeeMultiMap* _tmp2_;
	GeeSet* _tmp3_ = NULL;
	GeeSet* removed;
	gboolean _tmp27_ = FALSE;
	const gchar* _tmp28_;
	gboolean _tmp30_;
	GeeSet* _tmp31_;
	gint _tmp32_;
	gint _tmp33_;
#line 112 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_return_if_fail (self != NULL);
#line 112 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_return_if_fail (changes != NULL);
#line 115 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp0_ = changes;
#line 115 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 115 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	added = _tmp1_;
#line 116 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp2_ = changes;
#line 116 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 116 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	removed = _tmp3_;
#line 677 "match-known-emails.c"
	{
		GeeCollection* _tmp4_;
		GeeIterator* _tmp5_ = NULL;
		GeeIterator* _i_it;
#line 118 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_tmp4_ = added;
#line 118 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 118 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_i_it = _tmp5_;
#line 118 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		while (TRUE) {
#line 690 "match-known-emails.c"
			GeeIterator* _tmp6_;
			gboolean _tmp7_ = FALSE;
			GeeIterator* _tmp8_;
			gpointer _tmp9_ = NULL;
			FolksIndividual* i;
			FolksIndividual* _tmp10_;
			FolksIndividual* _tmp11_;
			const gchar* _tmp12_;
			const gchar* _tmp13_;
			const gchar* _tmp14_;
#line 118 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_tmp6_ = _i_it;
#line 118 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 118 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			if (!_tmp7_) {
#line 118 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
				break;
#line 709 "match-known-emails.c"
			}
#line 118 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_tmp8_ = _i_it;
#line 118 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 118 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			i = (FolksIndividual*) _tmp9_;
#line 120 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_tmp10_ = i;
#line 120 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			g_assert (_tmp10_ != NULL);
#line 122 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_tmp11_ = i;
#line 122 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_tmp12_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp11_);
#line 122 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_tmp13_ = _tmp12_;
#line 122 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_tmp14_ = self->priv->_persona_fullname_1;
#line 122 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			if (g_strcmp0 (_tmp13_, _tmp14_) == 0) {
#line 731 "match-known-emails.c"
				FolksIndividual* _tmp15_;
				const gchar* _tmp16_;
				const gchar* _tmp17_;
				gchar* _tmp18_;
#line 124 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
				_tmp15_ = i;
#line 124 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
				_tmp16_ = folks_individual_get_id (_tmp15_);
#line 124 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
				_tmp17_ = _tmp16_;
#line 124 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
				_tmp18_ = g_strdup (_tmp17_);
#line 124 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
				_g_free0 (self->priv->_individual_id_1);
#line 124 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
				self->priv->_individual_id_1 = _tmp18_;
#line 748 "match-known-emails.c"
			} else {
				FolksIndividual* _tmp19_;
				const gchar* _tmp20_;
				const gchar* _tmp21_;
				const gchar* _tmp22_;
#line 126 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
				_tmp19_ = i;
#line 126 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
				_tmp20_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp19_);
#line 126 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
				_tmp21_ = _tmp20_;
#line 126 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
				_tmp22_ = self->priv->_persona_fullname_2;
#line 126 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
				if (g_strcmp0 (_tmp21_, _tmp22_) == 0) {
#line 764 "match-known-emails.c"
					FolksIndividual* _tmp23_;
					const gchar* _tmp24_;
					const gchar* _tmp25_;
					gchar* _tmp26_;
#line 128 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
					_tmp23_ = i;
#line 128 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
					_tmp24_ = folks_individual_get_id (_tmp23_);
#line 128 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
					_tmp25_ = _tmp24_;
#line 128 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
					_tmp26_ = g_strdup (_tmp25_);
#line 128 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
					_g_free0 (self->priv->_individual_id_2);
#line 128 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
					self->priv->_individual_id_2 = _tmp26_;
#line 781 "match-known-emails.c"
				}
			}
#line 118 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_g_object_unref0 (i);
#line 786 "match-known-emails.c"
		}
#line 118 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_g_object_unref0 (_i_it);
#line 790 "match-known-emails.c"
	}
#line 132 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp28_ = self->priv->_individual_id_1;
#line 132 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	if (g_strcmp0 (_tmp28_, "") != 0) {
#line 796 "match-known-emails.c"
		const gchar* _tmp29_;
#line 133 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_tmp29_ = self->priv->_individual_id_2;
#line 133 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_tmp27_ = g_strcmp0 (_tmp29_, "") != 0;
#line 802 "match-known-emails.c"
	} else {
#line 132 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_tmp27_ = FALSE;
#line 806 "match-known-emails.c"
	}
#line 132 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp30_ = _tmp27_;
#line 132 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	if (_tmp30_) {
#line 135 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_match_known_emails_tests_try_potential_match (self);
#line 814 "match-known-emails.c"
	}
#line 138 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp31_ = removed;
#line 138 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp32_ = gee_collection_get_size ((GeeCollection*) _tmp31_);
#line 138 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp33_ = _tmp32_;
#line 138 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_assert (_tmp33_ == 1);
#line 824 "match-known-emails.c"
	{
		GeeSet* _tmp34_;
		GeeIterator* _tmp35_ = NULL;
		GeeIterator* _i_it;
#line 140 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_tmp34_ = removed;
#line 140 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_tmp35_ = gee_iterable_iterator ((GeeIterable*) _tmp34_);
#line 140 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_i_it = _tmp35_;
#line 140 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		while (TRUE) {
#line 837 "match-known-emails.c"
			GeeIterator* _tmp36_;
			gboolean _tmp37_ = FALSE;
			GeeIterator* _tmp38_;
			gpointer _tmp39_ = NULL;
			FolksIndividual* i;
			FolksIndividual* _tmp40_;
#line 140 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_tmp36_ = _i_it;
#line 140 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_tmp37_ = gee_iterator_next (_tmp36_);
#line 140 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			if (!_tmp37_) {
#line 140 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
				break;
#line 852 "match-known-emails.c"
			}
#line 140 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_tmp38_ = _i_it;
#line 140 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_tmp39_ = gee_iterator_get (_tmp38_);
#line 140 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			i = (FolksIndividual*) _tmp39_;
#line 142 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_tmp40_ = i;
#line 142 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			g_assert (_tmp40_ == NULL);
#line 140 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_g_object_unref0 (i);
#line 866 "match-known-emails.c"
		}
#line 140 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_g_object_unref0 (_i_it);
#line 870 "match-known-emails.c"
	}
#line 112 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_g_object_unref0 (removed);
#line 112 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_g_object_unref0 (added);
#line 876 "match-known-emails.c"
}


static void _match_known_emails_tests_try_potential_match (MatchKnownEmailsTests* self) {
	FolksIndividualAggregator* _tmp0_;
	GeeMap* _tmp1_;
	GeeMap* _tmp2_;
	const gchar* _tmp3_;
	gpointer _tmp4_ = NULL;
	FolksIndividual* ind1;
	FolksIndividualAggregator* _tmp5_;
	GeeMap* _tmp6_;
	GeeMap* _tmp7_;
	const gchar* _tmp8_;
	gpointer _tmp9_ = NULL;
	FolksIndividual* ind2;
	FolksPotentialMatch* _tmp10_;
	FolksPotentialMatch* matchObj;
	FolksMatchResult _tmp11_ = 0;
	GMainLoop* _tmp12_;
#line 146 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_return_if_fail (self != NULL);
#line 148 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp0_ = self->priv->_aggregator;
#line 148 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp1_ = folks_individual_aggregator_get_individuals (_tmp0_);
#line 148 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp2_ = _tmp1_;
#line 148 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp3_ = self->priv->_individual_id_1;
#line 148 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp4_ = gee_map_get (_tmp2_, _tmp3_);
#line 148 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	ind1 = (FolksIndividual*) _tmp4_;
#line 149 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp5_ = self->priv->_aggregator;
#line 149 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp6_ = folks_individual_aggregator_get_individuals (_tmp5_);
#line 149 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp7_ = _tmp6_;
#line 149 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp8_ = self->priv->_individual_id_2;
#line 149 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp9_ = gee_map_get (_tmp7_, _tmp8_);
#line 149 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	ind2 = (FolksIndividual*) _tmp9_;
#line 151 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp10_ = folks_potential_match_new ();
#line 151 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	matchObj = _tmp10_;
#line 152 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp11_ = folks_potential_match_potential_match (matchObj, ind1, ind2);
#line 152 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	self->priv->_match = _tmp11_;
#line 154 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp12_ = self->priv->_main_loop;
#line 154 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_main_loop_quit (_tmp12_);
#line 146 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_g_object_unref0 (matchObj);
#line 146 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_g_object_unref0 (ind2);
#line 146 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_g_object_unref0 (ind1);
#line 941 "match-known-emails.c"
}


static void _match_known_emails_tests_notify_pstore_cb (MatchKnownEmailsTests* self, GObject* _pstore, GParamSpec* ps) {
#line 157 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_return_if_fail (self != NULL);
#line 157 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_return_if_fail (_pstore != NULL);
#line 157 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_return_if_fail (ps != NULL);
#line 159 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_match_known_emails_tests_try_to_add (self, NULL, NULL);
#line 954 "match-known-emails.c"
}


static void _match_known_emails_tests_try_to_add_data_free (gpointer _data) {
	MatchKnownEmailsTestsTryToAddData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_slice_free (MatchKnownEmailsTestsTryToAddData, _data_);
#line 965 "match-known-emails.c"
}


static void _match_known_emails_tests_try_to_add (MatchKnownEmailsTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	MatchKnownEmailsTestsTryToAddData* _data_;
	MatchKnownEmailsTests* _tmp0_;
#line 26 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_ = g_slice_new0 (MatchKnownEmailsTestsTryToAddData);
#line 26 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _match_known_emails_tests_try_to_add);
#line 26 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _match_known_emails_tests_try_to_add_data_free);
#line 26 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_match_known_emails_tests_try_to_add_co (_data_);
#line 984 "match-known-emails.c"
}


static void _match_known_emails_tests_try_to_add_finish (MatchKnownEmailsTests* self, GAsyncResult* _res_) {
	MatchKnownEmailsTestsTryToAddData* _data_;
#line 26 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 992 "match-known-emails.c"
}


static void _match_known_emails_tests_try_to_add_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	MatchKnownEmailsTestsTryToAddData* _data_;
#line 170 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_ = _user_data_;
#line 170 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_source_object_ = source_object;
#line 170 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_res_ = _res_;
#line 170 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_match_known_emails_tests_try_to_add_co (_data_);
#line 1006 "match-known-emails.c"
}


static gboolean _match_known_emails_tests_try_to_add_co (MatchKnownEmailsTestsTryToAddData* _data_) {
#line 162 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	switch (_data_->_state_) {
#line 162 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		case 0:
#line 1015 "match-known-emails.c"
		goto _state_0;
#line 162 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		case 1:
#line 1019 "match-known-emails.c"
		goto _state_1;
		default:
#line 162 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		g_assert_not_reached ();
#line 1024 "match-known-emails.c"
	}
	_state_0:
	{
#line 164 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_data_->_tmp0_ = _data_->self->priv->_added_personas;
#line 164 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		g_static_rec_mutex_lock (&_data_->self->priv->__lock__added_personas);
#line 1032 "match-known-emails.c"
		{
#line 166 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_data_->_tmp2_ = _data_->self->priv->_pstore;
#line 166 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_data_->_tmp3_ = folks_persona_store_get_is_prepared ((FolksPersonaStore*) _data_->_tmp2_);
#line 166 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_data_->_tmp4_ = _data_->_tmp3_;
#line 166 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			if (_data_->_tmp4_) {
#line 167 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
				_data_->_tmp5_ = _data_->self->priv->_added_personas;
#line 167 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
				_data_->_tmp1_ = _data_->_tmp5_ == FALSE;
#line 1046 "match-known-emails.c"
			} else {
#line 166 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
				_data_->_tmp1_ = FALSE;
#line 1050 "match-known-emails.c"
			}
#line 166 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_data_->_tmp6_ = _data_->_tmp1_;
#line 166 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			if (_data_->_tmp6_) {
#line 169 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
				_data_->self->priv->_added_personas = TRUE;
#line 170 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
				_data_->_state_ = 1;
#line 170 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
				_match_known_emails_tests_add_personas (_data_->self, _match_known_emails_tests_try_to_add_ready, _data_);
#line 170 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
				return FALSE;
#line 1064 "match-known-emails.c"
				_state_1:
#line 170 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
				_match_known_emails_tests_add_personas_finish (_data_->self, _data_->_res_);
#line 1068 "match-known-emails.c"
			}
		}
		__finally1:
		{
#line 164 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_data_->_tmp7_ = _data_->self->priv->_added_personas;
#line 164 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			g_static_rec_mutex_unlock (&_data_->self->priv->__lock__added_personas);
#line 1077 "match-known-emails.c"
		}
#line 164 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		if (_data_->_inner_error_ != NULL) {
#line 164 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 164 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			g_clear_error (&_data_->_inner_error_);
#line 164 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			return FALSE;
#line 1087 "match-known-emails.c"
		}
	}
#line 162 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	if (_data_->_state_ == 0) {
#line 162 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1094 "match-known-emails.c"
	} else {
#line 162 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1098 "match-known-emails.c"
	}
#line 162 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_object_unref (_data_->_async_result);
#line 162 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	return FALSE;
#line 1104 "match-known-emails.c"
}


static void _match_known_emails_tests_add_personas_data_free (gpointer _data) {
	MatchKnownEmailsTestsAddPersonasData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_slice_free (MatchKnownEmailsTestsAddPersonasData, _data_);
#line 1115 "match-known-emails.c"
}


static void _match_known_emails_tests_add_personas (MatchKnownEmailsTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	MatchKnownEmailsTestsAddPersonasData* _data_;
	MatchKnownEmailsTests* _tmp0_;
#line 26 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_ = g_slice_new0 (MatchKnownEmailsTestsAddPersonasData);
#line 26 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _match_known_emails_tests_add_personas);
#line 26 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _match_known_emails_tests_add_personas_data_free);
#line 26 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_match_known_emails_tests_add_personas_co (_data_);
#line 1134 "match-known-emails.c"
}


static void _match_known_emails_tests_add_personas_finish (MatchKnownEmailsTests* self, GAsyncResult* _res_) {
	MatchKnownEmailsTestsAddPersonasData* _data_;
#line 26 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1142 "match-known-emails.c"
}


static void _g_free0_ (gpointer var) {
#line 177 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	var = (g_free (var), NULL);
#line 1149 "match-known-emails.c"
}


static void _vala_GValue_free (GValue* self) {
#line 177 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_value_unset (self);
#line 177 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_free (self);
#line 1158 "match-known-emails.c"
}


static void __vala_GValue_free0_ (gpointer var) {
#line 177 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	(var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL));
#line 1165 "match-known-emails.c"
}


static GValue* _g_value_dup (GValue* self) {
#line 183 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	return g_boxed_copy (G_TYPE_VALUE, self);
#line 1172 "match-known-emails.c"
}


static gpointer __g_value_dup0 (gpointer self) {
#line 183 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	return self ? _g_value_dup (self) : NULL;
#line 1179 "match-known-emails.c"
}


static void _match_known_emails_tests_add_personas_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	MatchKnownEmailsTestsAddPersonasData* _data_;
#line 217 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_ = _user_data_;
#line 217 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_source_object_ = source_object;
#line 217 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_res_ = _res_;
#line 217 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_match_known_emails_tests_add_personas_co (_data_);
#line 1193 "match-known-emails.c"
}


static gboolean _match_known_emails_tests_add_personas_co (MatchKnownEmailsTestsAddPersonasData* _data_) {
#line 175 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	switch (_data_->_state_) {
#line 175 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		case 0:
#line 1202 "match-known-emails.c"
		goto _state_0;
#line 175 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		case 1:
#line 1206 "match-known-emails.c"
		goto _state_1;
#line 175 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		case 2:
#line 1210 "match-known-emails.c"
		goto _state_2;
		default:
#line 175 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		g_assert_not_reached ();
#line 1215 "match-known-emails.c"
	}
	_state_0:
#line 177 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp0_ = g_str_hash;
#line 177 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp1_ = g_str_equal;
#line 177 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp2_ = g_hash_table_new_full (_data_->_tmp0_, _data_->_tmp1_, _g_free0_, __vala_GValue_free0_);
#line 177 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->details1 = _data_->_tmp2_;
#line 179 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp3_ = g_str_hash;
#line 179 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp4_ = g_str_equal;
#line 179 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp5_ = g_hash_table_new_full (_data_->_tmp3_, _data_->_tmp4_, _g_free0_, __vala_GValue_free0_);
#line 179 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->details2 = _data_->_tmp5_;
#line 183 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	memset (&_data_->_tmp6_, 0, sizeof (GValue));
#line 183 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_value_init (&_data_->_tmp6_, G_TYPE_STRING);
#line 183 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp7_ = _data_->_tmp6_;
#line 183 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp8_ = __g_value_dup0 (&_data_->_tmp7_);
#line 183 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	__vala_GValue_free0 (_data_->val);
#line 183 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->val = _data_->_tmp8_;
#line 183 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	G_IS_VALUE (&_data_->_tmp7_) ? (g_value_unset (&_data_->_tmp7_), NULL) : NULL;
#line 184 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp9_ = _data_->val;
#line 184 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp10_ = _data_->self->priv->_persona_fullname_1;
#line 184 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_value_set_string (_data_->_tmp9_, _data_->_tmp10_);
#line 185 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp11_ = _data_->details1;
#line 185 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp12_ = NULL;
#line 185 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp12_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_FULL_NAME);
#line 185 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp13_ = g_strdup (_data_->_tmp12_);
#line 185 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp14_ = _data_->val;
#line 185 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->val = NULL;
#line 185 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_hash_table_insert (_data_->_tmp11_, _data_->_tmp13_, _data_->_tmp14_);
#line 188 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	memset (&_data_->_tmp15_, 0, sizeof (GValue));
#line 188 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_value_init (&_data_->_tmp15_, GEE_TYPE_SET);
#line 188 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp16_ = _data_->_tmp15_;
#line 188 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp17_ = __g_value_dup0 (&_data_->_tmp16_);
#line 188 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	__vala_GValue_free0 (_data_->val);
#line 188 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->val = _data_->_tmp17_;
#line 188 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	G_IS_VALUE (&_data_->_tmp16_) ? (g_value_unset (&_data_->_tmp16_), NULL) : NULL;
#line 189 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp18_ = gee_hash_set_new (FOLKS_TYPE_EMAIL_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, (GHashFunc) folks_abstract_field_details_hash, (GEqualFunc) folks_abstract_field_details_equal);
#line 189 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->emails1 = _data_->_tmp18_;
#line 192 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp19_ = _data_->self->priv->_email_1;
#line 192 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp20_ = folks_email_field_details_new (_data_->_tmp19_, NULL);
#line 192 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->email_1 = _data_->_tmp20_;
#line 193 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp21_ = _data_->emails1;
#line 193 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp22_ = _data_->email_1;
#line 193 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _data_->_tmp21_, _data_->_tmp22_);
#line 194 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp23_ = _data_->val;
#line 194 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp24_ = _data_->emails1;
#line 194 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_value_set_object (_data_->_tmp23_, (GObject*) _data_->_tmp24_);
#line 195 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp25_ = _data_->details1;
#line 195 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp26_ = NULL;
#line 195 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp26_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_EMAIL_ADDRESSES);
#line 195 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp27_ = g_strdup (_data_->_tmp26_);
#line 195 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp28_ = _data_->val;
#line 195 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->val = NULL;
#line 195 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_hash_table_insert (_data_->_tmp25_, _data_->_tmp27_, _data_->_tmp28_);
#line 199 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	memset (&_data_->_tmp29_, 0, sizeof (GValue));
#line 199 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_value_init (&_data_->_tmp29_, G_TYPE_STRING);
#line 199 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp30_ = _data_->_tmp29_;
#line 199 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp31_ = __g_value_dup0 (&_data_->_tmp30_);
#line 199 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	__vala_GValue_free0 (_data_->val);
#line 199 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->val = _data_->_tmp31_;
#line 199 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	G_IS_VALUE (&_data_->_tmp30_) ? (g_value_unset (&_data_->_tmp30_), NULL) : NULL;
#line 200 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp32_ = _data_->val;
#line 200 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp33_ = _data_->self->priv->_persona_fullname_2;
#line 200 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_value_set_string (_data_->_tmp32_, _data_->_tmp33_);
#line 201 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp34_ = _data_->details2;
#line 201 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp35_ = NULL;
#line 201 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp35_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_FULL_NAME);
#line 201 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp36_ = g_strdup (_data_->_tmp35_);
#line 201 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp37_ = _data_->val;
#line 201 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->val = NULL;
#line 201 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_hash_table_insert (_data_->_tmp34_, _data_->_tmp36_, _data_->_tmp37_);
#line 204 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	memset (&_data_->_tmp38_, 0, sizeof (GValue));
#line 204 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_value_init (&_data_->_tmp38_, GEE_TYPE_SET);
#line 204 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp39_ = _data_->_tmp38_;
#line 204 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp40_ = __g_value_dup0 (&_data_->_tmp39_);
#line 204 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	__vala_GValue_free0 (_data_->val);
#line 204 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->val = _data_->_tmp40_;
#line 204 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	G_IS_VALUE (&_data_->_tmp39_) ? (g_value_unset (&_data_->_tmp39_), NULL) : NULL;
#line 205 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp41_ = gee_hash_set_new (FOLKS_TYPE_EMAIL_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, (GHashFunc) folks_abstract_field_details_hash, (GEqualFunc) folks_abstract_field_details_equal);
#line 205 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->emails2 = _data_->_tmp41_;
#line 208 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp42_ = _data_->self->priv->_email_1;
#line 208 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp43_ = folks_email_field_details_new (_data_->_tmp42_, NULL);
#line 208 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->email_2 = _data_->_tmp43_;
#line 209 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp44_ = _data_->emails2;
#line 209 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp45_ = _data_->email_2;
#line 209 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _data_->_tmp44_, _data_->_tmp45_);
#line 210 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp46_ = _data_->val;
#line 210 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp47_ = _data_->emails2;
#line 210 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_value_set_object (_data_->_tmp46_, (GObject*) _data_->_tmp47_);
#line 211 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp48_ = _data_->details2;
#line 211 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp49_ = NULL;
#line 211 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp49_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_EMAIL_ADDRESSES);
#line 211 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp50_ = g_strdup (_data_->_tmp49_);
#line 211 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->_tmp51_ = _data_->val;
#line 211 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_data_->val = NULL;
#line 211 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_hash_table_insert (_data_->_tmp48_, _data_->_tmp50_, _data_->_tmp51_);
#line 1402 "match-known-emails.c"
	{
#line 217 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_data_->_tmp52_ = _data_->self->priv->_aggregator;
#line 217 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_data_->_tmp53_ = _data_->self->priv->_pstore;
#line 217 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_data_->_tmp54_ = _data_->details1;
#line 217 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_data_->_state_ = 1;
#line 217 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		folks_individual_aggregator_add_persona_from_details (_data_->_tmp52_, NULL, (FolksPersonaStore*) _data_->_tmp53_, _data_->_tmp54_, _match_known_emails_tests_add_personas_ready, _data_);
#line 217 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		return FALSE;
#line 1416 "match-known-emails.c"
		_state_1:
#line 217 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_data_->_tmp55_ = NULL;
#line 217 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_data_->_tmp55_ = folks_individual_aggregator_add_persona_from_details_finish (_data_->_tmp52_, _data_->_res_, &_data_->_inner_error_);
#line 217 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_data_->_tmp56_ = _data_->_tmp55_;
#line 217 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_g_object_unref0 (_data_->_tmp56_);
#line 217 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		if (_data_->_inner_error_ != NULL) {
#line 217 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			if (_data_->_inner_error_->domain == FOLKS_INDIVIDUAL_AGGREGATOR_ERROR) {
#line 1430 "match-known-emails.c"
				goto __catch2_folks_individual_aggregator_error;
			}
#line 217 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_g_object_unref0 (_data_->email_2);
#line 217 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_g_object_unref0 (_data_->emails2);
#line 217 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_g_object_unref0 (_data_->email_1);
#line 217 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_g_object_unref0 (_data_->emails1);
#line 217 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			__vala_GValue_free0 (_data_->val);
#line 217 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_g_hash_table_unref0 (_data_->details2);
#line 217 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_g_hash_table_unref0 (_data_->details1);
#line 217 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 217 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			g_clear_error (&_data_->_inner_error_);
#line 217 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			return FALSE;
#line 1453 "match-known-emails.c"
		}
#line 220 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_data_->_tmp57_ = _data_->self->priv->_aggregator;
#line 220 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_data_->_tmp58_ = _data_->self->priv->_pstore;
#line 220 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_data_->_tmp59_ = _data_->details2;
#line 220 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_data_->_state_ = 2;
#line 220 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		folks_individual_aggregator_add_persona_from_details (_data_->_tmp57_, NULL, (FolksPersonaStore*) _data_->_tmp58_, _data_->_tmp59_, _match_known_emails_tests_add_personas_ready, _data_);
#line 220 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		return FALSE;
#line 1467 "match-known-emails.c"
		_state_2:
#line 220 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_data_->_tmp60_ = NULL;
#line 220 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_data_->_tmp60_ = folks_individual_aggregator_add_persona_from_details_finish (_data_->_tmp57_, _data_->_res_, &_data_->_inner_error_);
#line 220 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_data_->_tmp61_ = _data_->_tmp60_;
#line 220 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_g_object_unref0 (_data_->_tmp61_);
#line 220 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		if (_data_->_inner_error_ != NULL) {
#line 220 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			if (_data_->_inner_error_->domain == FOLKS_INDIVIDUAL_AGGREGATOR_ERROR) {
#line 1481 "match-known-emails.c"
				goto __catch2_folks_individual_aggregator_error;
			}
#line 220 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_g_object_unref0 (_data_->email_2);
#line 220 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_g_object_unref0 (_data_->emails2);
#line 220 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_g_object_unref0 (_data_->email_1);
#line 220 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_g_object_unref0 (_data_->emails1);
#line 220 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			__vala_GValue_free0 (_data_->val);
#line 220 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_g_hash_table_unref0 (_data_->details2);
#line 220 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			_g_hash_table_unref0 (_data_->details1);
#line 220 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 220 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			g_clear_error (&_data_->_inner_error_);
#line 220 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
			return FALSE;
#line 1504 "match-known-emails.c"
		}
	}
	goto __finally2;
	__catch2_folks_individual_aggregator_error:
	{
#line 215 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_data_->e = _data_->_inner_error_;
#line 215 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_data_->_inner_error_ = NULL;
#line 225 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_data_->_tmp62_ = _data_->e;
#line 225 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_data_->_tmp63_ = _data_->_tmp62_->message;
#line 225 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		g_warning ("match-known-emails.vala:225: [AddPersonaError] add_persona_from_detail" \
"s: %s\n", _data_->_tmp63_);
#line 215 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_g_error_free0 (_data_->e);
#line 1522 "match-known-emails.c"
	}
	__finally2:
#line 215 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	if (_data_->_inner_error_ != NULL) {
#line 215 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_g_object_unref0 (_data_->email_2);
#line 215 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_g_object_unref0 (_data_->emails2);
#line 215 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_g_object_unref0 (_data_->email_1);
#line 215 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_g_object_unref0 (_data_->emails1);
#line 215 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		__vala_GValue_free0 (_data_->val);
#line 215 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_g_hash_table_unref0 (_data_->details2);
#line 215 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		_g_hash_table_unref0 (_data_->details1);
#line 215 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 215 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		g_clear_error (&_data_->_inner_error_);
#line 215 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		return FALSE;
#line 1547 "match-known-emails.c"
	}
#line 175 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_g_object_unref0 (_data_->email_2);
#line 175 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_g_object_unref0 (_data_->emails2);
#line 175 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_g_object_unref0 (_data_->email_1);
#line 175 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_g_object_unref0 (_data_->emails1);
#line 175 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	__vala_GValue_free0 (_data_->val);
#line 175 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_g_hash_table_unref0 (_data_->details2);
#line 175 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_g_hash_table_unref0 (_data_->details1);
#line 175 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	if (_data_->_state_ == 0) {
#line 175 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1567 "match-known-emails.c"
	} else {
#line 175 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1571 "match-known-emails.c"
	}
#line 175 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_object_unref (_data_->_async_result);
#line 175 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	return FALSE;
#line 1577 "match-known-emails.c"
}


static void match_known_emails_tests_class_init (MatchKnownEmailsTestsClass * klass) {
#line 26 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	match_known_emails_tests_parent_class = g_type_class_peek_parent (klass);
#line 26 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_type_class_add_private (klass, sizeof (MatchKnownEmailsTestsPrivate));
#line 26 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	FOLKS_TEST_CASE_CLASS (klass)->set_up = match_known_emails_tests_real_set_up;
#line 26 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	FOLKS_TEST_CASE_CLASS (klass)->tear_down = match_known_emails_tests_real_tear_down;
#line 26 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	G_OBJECT_CLASS (klass)->finalize = match_known_emails_tests_finalize;
#line 1592 "match-known-emails.c"
}


static void match_known_emails_tests_instance_init (MatchKnownEmailsTests * self) {
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
#line 26 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	self->priv = MATCH_KNOWN_EMAILS_TESTS_GET_PRIVATE (self);
#line 34 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp0_ = g_strdup ("aaa");
#line 34 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	self->priv->_persona_fullname_1 = _tmp0_;
#line 35 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp1_ = g_strdup ("bbb");
#line 35 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	self->priv->_persona_fullname_2 = _tmp1_;
#line 37 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp2_ = g_strdup ("admin@jabber.example.org");
#line 37 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	self->priv->_email_1 = _tmp2_;
#line 38 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_static_rec_mutex_init (&self->priv->__lock__added_personas);
#line 38 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	self->priv->_added_personas = FALSE;
#line 39 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp3_ = g_strdup ("");
#line 39 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	self->priv->_individual_id_1 = _tmp3_;
#line 40 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp4_ = g_strdup ("");
#line 40 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	self->priv->_individual_id_2 = _tmp4_;
#line 1628 "match-known-emails.c"
}


static void match_known_emails_tests_finalize (GObject* obj) {
	MatchKnownEmailsTests * self;
#line 26 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	self = MATCH_KNOWN_EMAILS_TESTS (obj);
#line 28 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 29 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tracker_test_backend_unref0 (self->priv->_tracker_backend);
#line 30 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 34 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_g_free0 (self->priv->_persona_fullname_1);
#line 35 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_g_free0 (self->priv->_persona_fullname_2);
#line 37 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_g_free0 (self->priv->_email_1);
#line 38 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_static_rec_mutex_free (&self->priv->__lock__added_personas);
#line 39 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_g_free0 (self->priv->_individual_id_1);
#line 40 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_g_free0 (self->priv->_individual_id_2);
#line 42 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_g_object_unref0 (self->priv->_pstore);
#line 26 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	G_OBJECT_CLASS (match_known_emails_tests_parent_class)->finalize (obj);
#line 1658 "match-known-emails.c"
}


GType match_known_emails_tests_get_type (void) {
	static volatile gsize match_known_emails_tests_type_id__volatile = 0;
	if (g_once_init_enter (&match_known_emails_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (MatchKnownEmailsTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) match_known_emails_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (MatchKnownEmailsTests), 0, (GInstanceInitFunc) match_known_emails_tests_instance_init, NULL };
		GType match_known_emails_tests_type_id;
		match_known_emails_tests_type_id = g_type_register_static (FOLKS_TYPE_TEST_CASE, "MatchKnownEmailsTests", &g_define_type_info, 0);
		g_once_init_leave (&match_known_emails_tests_type_id__volatile, match_known_emails_tests_type_id);
	}
	return match_known_emails_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	GTestSuite* _tmp0_ = NULL;
	GTestSuite* root;
	MatchKnownEmailsTests* _tmp1_;
	MatchKnownEmailsTests* _tmp2_;
	GTestSuite* _tmp3_ = NULL;
#line 233 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_test_init (&args_length1, &args, NULL);
#line 235 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp0_ = g_test_get_root ();
#line 235 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	root = _tmp0_;
#line 236 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp1_ = match_known_emails_tests_new ();
#line 236 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp2_ = _tmp1_;
#line 236 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_tmp3_ = folks_test_case_get_suite ((FolksTestCase*) _tmp2_);
#line 236 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_test_suite_add_suite (root, _tmp3_);
#line 236 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	_g_object_unref0 (_tmp2_);
#line 238 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_test_run ();
#line 240 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	result = 0;
#line 240 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	return result;
#line 1703 "match-known-emails.c"
}


int main (int argc, char ** argv) {
#line 231 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	g_type_init ();
#line 231 "/opt/gnome2/source/folks/tests/tracker/match-known-emails.vala"
	return _vala_main (argv, argc);
#line 1712 "match-known-emails.c"
}



