/* email-details.c generated by valac 0.15.1.20-908e, the Vala compiler
 * generated from email-details.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <folks-test.h>
#include <eds-test.h>
#include <folks/folks.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <folks/folks-eds.h>
#include <gio/gio.h>


#define TYPE_EMAIL_DETAILS_TESTS (email_details_tests_get_type ())
#define EMAIL_DETAILS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EMAIL_DETAILS_TESTS, EmailDetailsTests))
#define EMAIL_DETAILS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EMAIL_DETAILS_TESTS, EmailDetailsTestsClass))
#define IS_EMAIL_DETAILS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EMAIL_DETAILS_TESTS))
#define IS_EMAIL_DETAILS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EMAIL_DETAILS_TESTS))
#define EMAIL_DETAILS_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EMAIL_DETAILS_TESTS, EmailDetailsTestsClass))

typedef struct _EmailDetailsTests EmailDetailsTests;
typedef struct _EmailDetailsTestsClass EmailDetailsTestsClass;
typedef struct _EmailDetailsTestsPrivate EmailDetailsTestsPrivate;
#define _eds_test_backend_unref0(var) ((var == NULL) ? NULL : (var = (eds_test_backend_unref (var), NULL)))
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define __vala_GValue_free0(var) ((var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _EmailDetailsTestsTestEmailDetailsAsyncData EmailDetailsTestsTestEmailDetailsAsyncData;

struct _EmailDetailsTests {
	FolksTestCase parent_instance;
	EmailDetailsTestsPrivate * priv;
};

struct _EmailDetailsTestsClass {
	FolksTestCaseClass parent_class;
};

struct _EmailDetailsTestsPrivate {
	EdsTestBackend* _eds_backend;
	GMainLoop* _main_loop;
	FolksIndividualAggregator* _aggregator;
	gint _email_count;
	GeeHashSet* _email_types;
	GeeHashMap* _c1;
	GeeHashMap* _c2;
	GeeHashMap* _c3;
};

struct _EmailDetailsTestsTestEmailDetailsAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	EmailDetailsTests* self;
	EdsTestBackend* _tmp0_;
	FolksBackendStore* _tmp1_;
	FolksBackendStore* store;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	FolksIndividualAggregator* _tmp4_;
	GError* e;
	GError* _tmp5_;
	const gchar* _tmp6_;
	GError * _inner_error_;
};


static gpointer email_details_tests_parent_class = NULL;

GType email_details_tests_get_type (void) G_GNUC_CONST;
#define EMAIL_DETAILS_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_EMAIL_DETAILS_TESTS, EmailDetailsTestsPrivate))
enum  {
	EMAIL_DETAILS_TESTS_DUMMY_PROPERTY
};
EmailDetailsTests* email_details_tests_new (void);
EmailDetailsTests* email_details_tests_construct (GType object_type);
void email_details_tests_test_email_details (EmailDetailsTests* self);
static void _email_details_tests_test_email_details_folks_test_case_test_method (gpointer self);
static void email_details_tests_real_set_up (FolksTestCase* base);
static void email_details_tests_real_tear_down (FolksTestCase* base);
static GValue* _g_value_dup (GValue* self);
static void _vala_GValue_free (GValue* self);
static void _email_details_tests_test_email_details_async (EmailDetailsTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _email_details_tests_test_email_details_finish (EmailDetailsTests* self, GAsyncResult* _res_);
static gboolean __lambda2_ (EmailDetailsTests* self);
static gboolean ___lambda2__gsource_func (gpointer self);
static void _email_details_tests_test_email_details_async_data_free (gpointer _data);
static gboolean _email_details_tests_test_email_details_async_co (EmailDetailsTestsTestEmailDetailsAsyncData* _data_);
static void _email_details_tests_test_email_details_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _email_details_tests_individuals_changed_cb (EmailDetailsTests* self, GeeMultiMap* changes);
static void __email_details_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void email_details_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _email_details_tests_test_email_details_folks_test_case_test_method (gpointer self) {
#line 40 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	email_details_tests_test_email_details (self);
#line 125 "email-details.c"
}


EmailDetailsTests* email_details_tests_construct (GType object_type) {
	EmailDetailsTests * self = NULL;
#line 38 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	self = (EmailDetailsTests*) folks_test_case_construct (object_type, "EmailDetails");
#line 40 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "email details interface", _email_details_tests_test_email_details_folks_test_case_test_method, self);
#line 36 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	return self;
#line 137 "email-details.c"
}


EmailDetailsTests* email_details_tests_new (void) {
#line 36 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	return email_details_tests_construct (TYPE_EMAIL_DETAILS_TESTS);
#line 144 "email-details.c"
}


static void email_details_tests_real_set_up (FolksTestCase* base) {
	EmailDetailsTests * self;
	EdsTestBackend* _tmp0_;
	EdsTestBackend* _tmp1_;
	EdsTestBackend* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	gchar* _tmp5_ = NULL;
	gchar* config_val;
#line 43 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	self = (EmailDetailsTests*) base;
#line 45 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp0_ = eds_test_backend_new ();
#line 45 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_eds_test_backend_unref0 (self->priv->_eds_backend);
#line 45 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	self->priv->_eds_backend = _tmp0_;
#line 46 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp1_ = self->priv->_eds_backend;
#line 46 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	eds_test_backend_set_up (_tmp1_, FALSE);
#line 49 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp2_ = self->priv->_eds_backend;
#line 49 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp3_ = eds_test_backend_get_address_book_uid (_tmp2_);
#line 49 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp4_ = _tmp3_;
#line 49 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp5_ = g_strdup_printf ("eds:%s", _tmp4_);
#line 49 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	config_val = _tmp5_;
#line 50 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_setenv ("FOLKS_PRIMARY_STORE", config_val, TRUE);
#line 43 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_g_free0 (config_val);
#line 183 "email-details.c"
}


static void email_details_tests_real_tear_down (FolksTestCase* base) {
	EmailDetailsTests * self;
	EdsTestBackend* _tmp0_;
#line 53 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	self = (EmailDetailsTests*) base;
#line 55 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp0_ = self->priv->_eds_backend;
#line 55 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	eds_test_backend_tear_down (_tmp0_);
#line 196 "email-details.c"
}


static GValue* _g_value_dup (GValue* self) {
#line 63 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	return g_boxed_copy (G_TYPE_VALUE, self);
#line 203 "email-details.c"
}


static void _vala_GValue_free (GValue* self) {
#line 63 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_value_unset (self);
#line 63 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_free (self);
#line 212 "email-details.c"
}


static gpointer __g_value_dup0 (gpointer self) {
#line 71 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	return self ? _g_value_dup (self) : NULL;
#line 219 "email-details.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 80 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	return self ? g_object_ref (self) : NULL;
#line 226 "email-details.c"
}


static gboolean __lambda2_ (EmailDetailsTests* self) {
	gboolean result = FALSE;
	GMainLoop* _tmp0_;
#line 108 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp0_ = self->priv->_main_loop;
#line 108 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_main_loop_quit (_tmp0_);
#line 109 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	result = FALSE;
#line 109 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	return result;
#line 241 "email-details.c"
}


static gboolean ___lambda2__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda2_ (self);
#line 106 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	return result;
#line 250 "email-details.c"
}


void email_details_tests_test_email_details (EmailDetailsTests* self) {
	GHashFunc _tmp0_;
	GEqualFunc _tmp1_;
	GeeHashSet* _tmp2_;
	GeeHashMap* _tmp3_;
	GeeHashMap* _tmp4_;
	GeeHashMap* _tmp5_;
	GMainLoop* _tmp6_;
	GValue* v = NULL;
	EdsTestBackend* _tmp7_;
	GValue _tmp8_ = {0};
	GValue _tmp9_;
	GValue* _tmp10_;
	GValue* _tmp11_;
	GeeHashMap* _tmp12_;
	GValue* _tmp13_;
	GValue* _tmp14_;
	GValue _tmp15_ = {0};
	GValue _tmp16_;
	GValue* _tmp17_;
	GValue* _tmp18_;
	GeeHashMap* _tmp19_;
	const gchar* _tmp20_;
	GValue* _tmp21_;
	GValue* _tmp22_;
	GValue _tmp23_ = {0};
	GValue _tmp24_;
	GValue* _tmp25_;
	GValue* _tmp26_;
	GeeHashMap* _tmp27_;
	const gchar* _tmp28_;
	GValue* _tmp29_;
	GValue* _tmp30_;
	EdsTestBackend* _tmp31_;
	GeeHashMap* _tmp32_;
	GeeHashMap* _tmp33_;
	GValue _tmp34_ = {0};
	GValue _tmp35_;
	GValue* _tmp36_;
	GValue* _tmp37_;
	GeeHashMap* _tmp38_;
	GValue* _tmp39_;
	GValue* _tmp40_;
	GValue _tmp41_ = {0};
	GValue _tmp42_;
	GValue* _tmp43_;
	GValue* _tmp44_;
	GeeHashMap* _tmp45_;
	const gchar* _tmp46_;
	GValue* _tmp47_;
	GValue* _tmp48_;
	GValue _tmp49_ = {0};
	GValue _tmp50_;
	GValue* _tmp51_;
	GValue* _tmp52_;
	GeeHashMap* _tmp53_;
	const gchar* _tmp54_;
	GValue* _tmp55_;
	GValue* _tmp56_;
	EdsTestBackend* _tmp57_;
	GeeHashMap* _tmp58_;
	GeeHashMap* _tmp59_;
	GValue _tmp60_ = {0};
	GValue _tmp61_;
	GValue* _tmp62_;
	GValue* _tmp63_;
	GeeHashMap* _tmp64_;
	GValue* _tmp65_;
	GValue* _tmp66_;
	GValue _tmp67_ = {0};
	GValue _tmp68_;
	GValue* _tmp69_;
	GValue* _tmp70_;
	GeeHashMap* _tmp71_;
	const gchar* _tmp72_;
	GValue* _tmp73_;
	GValue* _tmp74_;
	GValue _tmp75_ = {0};
	GValue _tmp76_;
	GValue* _tmp77_;
	GValue* _tmp78_;
	GeeHashMap* _tmp79_;
	const gchar* _tmp80_;
	GValue* _tmp81_;
	GValue* _tmp82_;
	EdsTestBackend* _tmp83_;
	GeeHashMap* _tmp84_;
	GeeHashMap* _tmp85_;
	GMainLoop* _tmp86_;
	gint _tmp87_;
	GeeHashSet* _tmp88_;
	gint _tmp89_;
	gint _tmp90_;
	GeeHashMap* _tmp91_;
	gint _tmp92_;
	gint _tmp93_;
	GeeHashMap* _tmp94_;
	gint _tmp95_;
	gint _tmp96_;
	GeeHashMap* _tmp97_;
	gint _tmp98_;
	gint _tmp99_;
#line 58 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_return_if_fail (self != NULL);
#line 60 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	self->priv->_email_count = 0;
#line 61 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp0_ = g_str_hash;
#line 61 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp1_ = g_str_equal;
#line 61 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp2_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, _tmp0_, _tmp1_);
#line 61 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_g_object_unref0 (self->priv->_email_types);
#line 61 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	self->priv->_email_types = _tmp2_;
#line 63 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp3_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL);
#line 63 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_g_object_unref0 (self->priv->_c1);
#line 63 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	self->priv->_c1 = _tmp3_;
#line 64 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp4_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL);
#line 64 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_g_object_unref0 (self->priv->_c2);
#line 64 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	self->priv->_c2 = _tmp4_;
#line 65 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp5_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL);
#line 65 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_g_object_unref0 (self->priv->_c3);
#line 65 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	self->priv->_c3 = _tmp5_;
#line 66 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp6_ = g_main_loop_new (NULL, FALSE);
#line 66 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 66 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	self->priv->_main_loop = _tmp6_;
#line 69 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp7_ = self->priv->_eds_backend;
#line 69 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	eds_test_backend_reset (_tmp7_);
#line 71 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_value_init (&_tmp8_, G_TYPE_STRING);
#line 71 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp9_ = _tmp8_;
#line 71 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp10_ = __g_value_dup0 (&_tmp9_);
#line 71 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	__vala_GValue_free0 (v);
#line 71 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	v = _tmp10_;
#line 71 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	G_IS_VALUE (&_tmp9_) ? (g_value_unset (&_tmp9_), NULL) : NULL;
#line 72 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp11_ = v;
#line 72 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_value_set_string (_tmp11_, "bernie h. innocenti");
#line 73 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp12_ = self->priv->_c1;
#line 73 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp13_ = v;
#line 73 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	v = NULL;
#line 73 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp14_ = _tmp13_;
#line 73 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp12_, "full_name", _tmp14_);
#line 73 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	__vala_GValue_free0 (_tmp14_);
#line 74 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_value_init (&_tmp15_, G_TYPE_STRING);
#line 74 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp16_ = _tmp15_;
#line 74 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp17_ = __g_value_dup0 (&_tmp16_);
#line 74 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	__vala_GValue_free0 (v);
#line 74 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	v = _tmp17_;
#line 74 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	G_IS_VALUE (&_tmp16_) ? (g_value_unset (&_tmp16_), NULL) : NULL;
#line 75 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp18_ = v;
#line 75 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_value_set_string (_tmp18_, "bernie@example.org");
#line 76 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp19_ = self->priv->_c1;
#line 76 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp20_ = EDSF_PERSONA_email_fields[0];
#line 76 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp21_ = v;
#line 76 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	v = NULL;
#line 76 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp22_ = _tmp21_;
#line 76 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp19_, _tmp20_, _tmp22_);
#line 76 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	__vala_GValue_free0 (_tmp22_);
#line 77 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_value_init (&_tmp23_, G_TYPE_STRING);
#line 77 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp24_ = _tmp23_;
#line 77 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp25_ = __g_value_dup0 (&_tmp24_);
#line 77 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	__vala_GValue_free0 (v);
#line 77 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	v = _tmp25_;
#line 77 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	G_IS_VALUE (&_tmp24_) ? (g_value_unset (&_tmp24_), NULL) : NULL;
#line 78 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp26_ = v;
#line 78 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_value_set_string (_tmp26_, "bernie.innocenti@example.org");
#line 79 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp27_ = self->priv->_c1;
#line 79 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp28_ = EDSF_PERSONA_email_fields[1];
#line 79 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp29_ = v;
#line 79 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	v = NULL;
#line 79 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp30_ = _tmp29_;
#line 79 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp27_, _tmp28_, _tmp30_);
#line 79 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	__vala_GValue_free0 (_tmp30_);
#line 80 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp31_ = self->priv->_eds_backend;
#line 80 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp32_ = self->priv->_c1;
#line 80 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp33_ = _g_object_ref0 (_tmp32_);
#line 80 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	eds_test_backend_add_contact (_tmp31_, _tmp33_);
#line 82 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_value_init (&_tmp34_, G_TYPE_STRING);
#line 82 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp35_ = _tmp34_;
#line 82 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp36_ = __g_value_dup0 (&_tmp35_);
#line 82 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	__vala_GValue_free0 (v);
#line 82 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	v = _tmp36_;
#line 82 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	G_IS_VALUE (&_tmp35_) ? (g_value_unset (&_tmp35_), NULL) : NULL;
#line 83 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp37_ = v;
#line 83 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_value_set_string (_tmp37_, "richard m. stallman");
#line 84 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp38_ = self->priv->_c2;
#line 84 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp39_ = v;
#line 84 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	v = NULL;
#line 84 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp40_ = _tmp39_;
#line 84 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp38_, "full_name", _tmp40_);
#line 84 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	__vala_GValue_free0 (_tmp40_);
#line 85 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_value_init (&_tmp41_, G_TYPE_STRING);
#line 85 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp42_ = _tmp41_;
#line 85 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp43_ = __g_value_dup0 (&_tmp42_);
#line 85 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	__vala_GValue_free0 (v);
#line 85 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	v = _tmp43_;
#line 85 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	G_IS_VALUE (&_tmp42_) ? (g_value_unset (&_tmp42_), NULL) : NULL;
#line 86 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp44_ = v;
#line 86 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_value_set_string (_tmp44_, "rms@example.org");
#line 87 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp45_ = self->priv->_c2;
#line 87 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp46_ = EDSF_PERSONA_email_fields[0];
#line 87 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp47_ = v;
#line 87 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	v = NULL;
#line 87 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp48_ = _tmp47_;
#line 87 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp45_, _tmp46_, _tmp48_);
#line 87 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	__vala_GValue_free0 (_tmp48_);
#line 88 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_value_init (&_tmp49_, G_TYPE_STRING);
#line 88 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp50_ = _tmp49_;
#line 88 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp51_ = __g_value_dup0 (&_tmp50_);
#line 88 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	__vala_GValue_free0 (v);
#line 88 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	v = _tmp51_;
#line 88 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	G_IS_VALUE (&_tmp50_) ? (g_value_unset (&_tmp50_), NULL) : NULL;
#line 89 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp52_ = v;
#line 89 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_value_set_string (_tmp52_, "rms.1@example.org");
#line 90 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp53_ = self->priv->_c2;
#line 90 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp54_ = EDSF_PERSONA_email_fields[1];
#line 90 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp55_ = v;
#line 90 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	v = NULL;
#line 90 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp56_ = _tmp55_;
#line 90 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp53_, _tmp54_, _tmp56_);
#line 90 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	__vala_GValue_free0 (_tmp56_);
#line 91 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp57_ = self->priv->_eds_backend;
#line 91 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp58_ = self->priv->_c2;
#line 91 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp59_ = _g_object_ref0 (_tmp58_);
#line 91 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	eds_test_backend_add_contact (_tmp57_, _tmp59_);
#line 93 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_value_init (&_tmp60_, G_TYPE_STRING);
#line 93 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp61_ = _tmp60_;
#line 93 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp62_ = __g_value_dup0 (&_tmp61_);
#line 93 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	__vala_GValue_free0 (v);
#line 93 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	v = _tmp62_;
#line 93 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	G_IS_VALUE (&_tmp61_) ? (g_value_unset (&_tmp61_), NULL) : NULL;
#line 94 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp63_ = v;
#line 94 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_value_set_string (_tmp63_, "foo bar");
#line 95 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp64_ = self->priv->_c3;
#line 95 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp65_ = v;
#line 95 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	v = NULL;
#line 95 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp66_ = _tmp65_;
#line 95 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp64_, "full_name", _tmp66_);
#line 95 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	__vala_GValue_free0 (_tmp66_);
#line 96 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_value_init (&_tmp67_, G_TYPE_STRING);
#line 96 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp68_ = _tmp67_;
#line 96 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp69_ = __g_value_dup0 (&_tmp68_);
#line 96 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	__vala_GValue_free0 (v);
#line 96 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	v = _tmp69_;
#line 96 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	G_IS_VALUE (&_tmp68_) ? (g_value_unset (&_tmp68_), NULL) : NULL;
#line 97 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp70_ = v;
#line 97 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_value_set_string (_tmp70_, "foo@example.org");
#line 98 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp71_ = self->priv->_c3;
#line 98 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp72_ = EDSF_PERSONA_email_fields[0];
#line 98 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp73_ = v;
#line 98 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	v = NULL;
#line 98 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp74_ = _tmp73_;
#line 98 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp71_, _tmp72_, _tmp74_);
#line 98 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	__vala_GValue_free0 (_tmp74_);
#line 99 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_value_init (&_tmp75_, G_TYPE_STRING);
#line 99 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp76_ = _tmp75_;
#line 99 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp77_ = __g_value_dup0 (&_tmp76_);
#line 99 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	__vala_GValue_free0 (v);
#line 99 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	v = _tmp77_;
#line 99 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	G_IS_VALUE (&_tmp76_) ? (g_value_unset (&_tmp76_), NULL) : NULL;
#line 100 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp78_ = v;
#line 100 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_value_set_string (_tmp78_, "foo.bar@example.org");
#line 101 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp79_ = self->priv->_c3;
#line 101 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp80_ = EDSF_PERSONA_email_fields[1];
#line 101 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp81_ = v;
#line 101 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	v = NULL;
#line 101 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp82_ = _tmp81_;
#line 101 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp79_, _tmp80_, _tmp82_);
#line 101 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	__vala_GValue_free0 (_tmp82_);
#line 102 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp83_ = self->priv->_eds_backend;
#line 102 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp84_ = self->priv->_c3;
#line 102 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp85_ = _g_object_ref0 (_tmp84_);
#line 102 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	eds_test_backend_add_contact (_tmp83_, _tmp85_);
#line 104 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_email_details_tests_test_email_details_async (self, NULL, NULL);
#line 106 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) 5, ___lambda2__gsource_func, g_object_ref (self), g_object_unref);
#line 112 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp86_ = self->priv->_main_loop;
#line 112 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_main_loop_run (_tmp86_);
#line 114 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp87_ = self->priv->_email_count;
#line 114 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_assert (_tmp87_ == 6);
#line 115 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp88_ = self->priv->_email_types;
#line 115 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp89_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp88_);
#line 115 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp90_ = _tmp89_;
#line 115 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_assert (_tmp90_ == 1);
#line 116 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp91_ = self->priv->_c1;
#line 116 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp92_ = gee_abstract_map_get_size ((GeeMap*) _tmp91_);
#line 116 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp93_ = _tmp92_;
#line 116 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_assert (_tmp93_ == 0);
#line 117 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp94_ = self->priv->_c2;
#line 117 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp95_ = gee_abstract_map_get_size ((GeeMap*) _tmp94_);
#line 117 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp96_ = _tmp95_;
#line 117 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_assert (_tmp96_ == 0);
#line 118 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp97_ = self->priv->_c3;
#line 118 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp98_ = gee_abstract_map_get_size ((GeeMap*) _tmp97_);
#line 118 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp99_ = _tmp98_;
#line 118 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_assert (_tmp99_ == 0);
#line 730 "email-details.c"
	{
		GeeHashSet* _tmp100_;
		GeeIterator* _tmp101_ = NULL;
		GeeIterator* _pt_it;
#line 120 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
		_tmp100_ = self->priv->_email_types;
#line 120 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
		_tmp101_ = gee_abstract_collection_iterator ((GeeAbstractCollection*) _tmp100_);
#line 120 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
		_pt_it = _tmp101_;
#line 120 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
		while (TRUE) {
#line 743 "email-details.c"
			GeeIterator* _tmp102_;
			gboolean _tmp103_ = FALSE;
			GeeIterator* _tmp104_;
			gpointer _tmp105_ = NULL;
			gchar* pt;
			const gchar* _tmp106_;
#line 120 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			_tmp102_ = _pt_it;
#line 120 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			_tmp103_ = gee_iterator_next (_tmp102_);
#line 120 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			if (!_tmp103_) {
#line 120 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
				break;
#line 758 "email-details.c"
			}
#line 120 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			_tmp104_ = _pt_it;
#line 120 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			_tmp105_ = gee_iterator_get (_tmp104_);
#line 120 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			pt = (gchar*) _tmp105_;
#line 122 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			_tmp106_ = pt;
#line 122 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			g_assert (g_strcmp0 (_tmp106_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_OTHER) == 0);
#line 120 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			_g_free0 (pt);
#line 772 "email-details.c"
		}
#line 120 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
		_g_object_unref0 (_pt_it);
#line 776 "email-details.c"
	}
#line 58 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	__vala_GValue_free0 (v);
#line 780 "email-details.c"
}


static void _email_details_tests_test_email_details_async_data_free (gpointer _data) {
	EmailDetailsTestsTestEmailDetailsAsyncData* _data_;
	_data_ = _data;
#line 25 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_g_object_unref0 (_data_->self);
#line 25 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_slice_free (EmailDetailsTestsTestEmailDetailsAsyncData, _data_);
#line 791 "email-details.c"
}


static void _email_details_tests_test_email_details_async (EmailDetailsTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	EmailDetailsTestsTestEmailDetailsAsyncData* _data_;
	EmailDetailsTests* _tmp0_;
#line 25 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_data_ = g_slice_new0 (EmailDetailsTestsTestEmailDetailsAsyncData);
#line 25 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _email_details_tests_test_email_details_async);
#line 25 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _email_details_tests_test_email_details_async_data_free);
#line 25 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 25 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_data_->self = _tmp0_;
#line 25 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_email_details_tests_test_email_details_async_co (_data_);
#line 810 "email-details.c"
}


static void _email_details_tests_test_email_details_finish (EmailDetailsTests* self, GAsyncResult* _res_) {
	EmailDetailsTestsTestEmailDetailsAsyncData* _data_;
#line 25 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 818 "email-details.c"
}


static void _email_details_tests_test_email_details_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	EmailDetailsTestsTestEmailDetailsAsyncData* _data_;
#line 129 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_data_ = _user_data_;
#line 129 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_data_->_source_object_ = source_object;
#line 129 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_data_->_res_ = _res_;
#line 129 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_email_details_tests_test_email_details_async_co (_data_);
#line 832 "email-details.c"
}


static void __email_details_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 134 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_email_details_tests_individuals_changed_cb (self, changes);
#line 839 "email-details.c"
}


static gboolean _email_details_tests_test_email_details_async_co (EmailDetailsTestsTestEmailDetailsAsyncData* _data_) {
#line 126 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	switch (_data_->_state_) {
#line 126 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
		case 0:
#line 848 "email-details.c"
		goto _state_0;
#line 126 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
		case 1:
#line 852 "email-details.c"
		goto _state_1;
#line 126 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
		case 2:
#line 856 "email-details.c"
		goto _state_2;
#line 126 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
		case 3:
#line 860 "email-details.c"
		goto _state_3;
		default:
#line 126 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
		g_assert_not_reached ();
#line 865 "email-details.c"
	}
	_state_0:
#line 129 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_data_->_tmp0_ = _data_->self->priv->_eds_backend;
#line 129 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_data_->_state_ = 1;
#line 129 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	eds_test_backend_commit_contacts_to_addressbook (_data_->_tmp0_, _email_details_tests_test_email_details_async_ready, _data_);
#line 129 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	return FALSE;
#line 876 "email-details.c"
	_state_1:
#line 129 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	eds_test_backend_commit_contacts_to_addressbook_finish (_data_->_tmp0_, _data_->_res_);
#line 131 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_data_->_tmp1_ = NULL;
#line 131 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_data_->_tmp1_ = folks_backend_store_dup ();
#line 131 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_data_->store = _data_->_tmp1_;
#line 132 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_data_->_state_ = 2;
#line 132 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	folks_backend_store_prepare (_data_->store, _email_details_tests_test_email_details_async_ready, _data_);
#line 132 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	return FALSE;
#line 892 "email-details.c"
	_state_2:
#line 132 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 133 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_data_->_tmp2_ = folks_individual_aggregator_new ();
#line 133 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 133 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_data_->self->priv->_aggregator = _data_->_tmp2_;
#line 134 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 134 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_signal_connect_object (_data_->_tmp3_, "individuals-changed-detailed", (GCallback) __email_details_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 906 "email-details.c"
	{
#line 138 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
		_data_->_tmp4_ = _data_->self->priv->_aggregator;
#line 138 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
		_data_->_state_ = 3;
#line 138 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
		folks_individual_aggregator_prepare (_data_->_tmp4_, _email_details_tests_test_email_details_async_ready, _data_);
#line 138 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
		return FALSE;
#line 916 "email-details.c"
		_state_3:
#line 138 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp4_, _data_->_res_, &_data_->_inner_error_);
#line 138 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
		if (_data_->_inner_error_ != NULL) {
#line 922 "email-details.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 136 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
		_data_->e = _data_->_inner_error_;
#line 136 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
		_data_->_inner_error_ = NULL;
#line 142 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
		_data_->_tmp5_ = _data_->e;
#line 142 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
		_data_->_tmp6_ = _data_->_tmp5_->message;
#line 142 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
		g_warning ("email-details.vala:142: Error when calling prepare: %s\n", _data_->_tmp6_);
#line 136 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
		_g_error_free0 (_data_->e);
#line 941 "email-details.c"
	}
	__finally0:
#line 136 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	if (_data_->_inner_error_ != NULL) {
#line 136 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
		_g_object_unref0 (_data_->store);
#line 136 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 136 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
		g_clear_error (&_data_->_inner_error_);
#line 136 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
		return FALSE;
#line 954 "email-details.c"
	}
#line 126 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_g_object_unref0 (_data_->store);
#line 126 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	if (_data_->_state_ == 0) {
#line 126 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 962 "email-details.c"
	} else {
#line 126 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 966 "email-details.c"
	}
#line 126 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_object_unref (_data_->_async_result);
#line 126 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	return FALSE;
#line 972 "email-details.c"
}


static void _email_details_tests_individuals_changed_cb (EmailDetailsTests* self, GeeMultiMap* changes) {
	GeeMultiMap* _tmp0_;
	GeeCollection* _tmp1_ = NULL;
	GeeCollection* added;
	GeeMultiMap* _tmp2_;
	GeeSet* _tmp3_ = NULL;
	GeeSet* removed;
	GeeSet* _tmp78_;
	gint _tmp79_;
	gint _tmp80_;
#line 146 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_return_if_fail (self != NULL);
#line 146 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_return_if_fail (changes != NULL);
#line 149 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp0_ = changes;
#line 149 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 149 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	added = _tmp1_;
#line 150 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp2_ = changes;
#line 150 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 150 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	removed = _tmp3_;
#line 1002 "email-details.c"
	{
		GeeCollection* _tmp4_;
		GeeIterator* _tmp5_ = NULL;
		GeeIterator* _i_it;
#line 152 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
		_tmp4_ = added;
#line 152 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 152 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
		_i_it = _tmp5_;
#line 152 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
		while (TRUE) {
#line 1015 "email-details.c"
			GeeIterator* _tmp6_;
			gboolean _tmp7_ = FALSE;
			GeeIterator* _tmp8_;
			gpointer _tmp9_ = NULL;
			FolksIndividual* i;
			FolksIndividual* _tmp10_;
			GeeHashMap* contact;
			FolksIndividual* _tmp11_;
			GeeSet* _tmp12_;
			GeeSet* _tmp13_;
			gint _tmp14_;
			gint _tmp15_;
			FolksIndividual* _tmp16_;
			const gchar* _tmp17_;
			const gchar* _tmp18_;
			GeeHashMap* _tmp28_;
			GeeHashMap* _tmp29_;
			FolksIndividual* _tmp30_;
			FolksEmailDetails* _tmp31_;
			FolksEmailDetails* email_owner;
#line 152 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			_tmp6_ = _i_it;
#line 152 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 152 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			if (!_tmp7_) {
#line 152 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
				break;
#line 1044 "email-details.c"
			}
#line 152 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			_tmp8_ = _i_it;
#line 152 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 152 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			i = (FolksIndividual*) _tmp9_;
#line 154 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			_tmp10_ = i;
#line 154 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			g_assert (_tmp10_ != NULL);
#line 156 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			contact = NULL;
#line 157 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			_tmp11_ = i;
#line 157 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			_tmp12_ = folks_individual_get_personas (_tmp11_);
#line 157 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			_tmp13_ = _tmp12_;
#line 157 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			_tmp14_ = gee_collection_get_size ((GeeCollection*) _tmp13_);
#line 157 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			_tmp15_ = _tmp14_;
#line 157 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			g_assert (_tmp15_ == 1);
#line 159 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			_tmp16_ = i;
#line 159 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			_tmp17_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp16_);
#line 159 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			_tmp18_ = _tmp17_;
#line 159 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			if (g_strcmp0 (_tmp18_, "bernie h. innocenti") == 0) {
#line 1078 "email-details.c"
				GeeHashMap* _tmp19_;
#line 161 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
				_tmp19_ = self->priv->_c1;
#line 161 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
				contact = _tmp19_;
#line 1084 "email-details.c"
			} else {
				FolksIndividual* _tmp20_;
				const gchar* _tmp21_;
				const gchar* _tmp22_;
#line 163 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
				_tmp20_ = i;
#line 163 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
				_tmp21_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp20_);
#line 163 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
				_tmp22_ = _tmp21_;
#line 163 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
				if (g_strcmp0 (_tmp22_, "richard m. stallman") == 0) {
#line 1097 "email-details.c"
					GeeHashMap* _tmp23_;
#line 165 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
					_tmp23_ = self->priv->_c2;
#line 165 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
					contact = _tmp23_;
#line 1103 "email-details.c"
				} else {
					FolksIndividual* _tmp24_;
					const gchar* _tmp25_;
					const gchar* _tmp26_;
#line 167 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
					_tmp24_ = i;
#line 167 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
					_tmp25_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp24_);
#line 167 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
					_tmp26_ = _tmp25_;
#line 167 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
					if (g_strcmp0 (_tmp26_, "foo bar") == 0) {
#line 1116 "email-details.c"
						GeeHashMap* _tmp27_;
#line 169 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
						_tmp27_ = self->priv->_c3;
#line 169 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
						contact = _tmp27_;
#line 1122 "email-details.c"
					}
				}
			}
#line 172 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			_tmp28_ = contact;
#line 172 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			if (_tmp28_ == NULL) {
#line 174 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
				_g_object_unref0 (i);
#line 174 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
				continue;
#line 1134 "email-details.c"
			}
#line 177 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			_tmp29_ = contact;
#line 177 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			gee_abstract_map_unset ((GeeAbstractMap*) _tmp29_, "full_name", NULL);
#line 178 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			_tmp30_ = i;
#line 178 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			_tmp31_ = _g_object_ref0 (FOLKS_EMAIL_DETAILS (_tmp30_));
#line 178 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			email_owner = _tmp31_;
#line 1146 "email-details.c"
			{
				FolksEmailDetails* _tmp32_;
				GeeSet* _tmp33_;
				GeeSet* _tmp34_;
				GeeIterator* _tmp35_ = NULL;
				GeeIterator* _e_it;
#line 179 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
				_tmp32_ = email_owner;
#line 179 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
				_tmp33_ = folks_email_details_get_email_addresses (_tmp32_);
#line 179 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
				_tmp34_ = _tmp33_;
#line 179 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
				_tmp35_ = gee_iterable_iterator ((GeeIterable*) _tmp34_);
#line 179 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
				_e_it = _tmp35_;
#line 179 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
				while (TRUE) {
#line 1165 "email-details.c"
					GeeIterator* _tmp36_;
					gboolean _tmp37_ = FALSE;
					GeeIterator* _tmp38_;
					gpointer _tmp39_ = NULL;
					FolksEmailFieldDetails* e;
					gint _tmp40_;
					gboolean found;
					gboolean _tmp65_;
#line 179 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
					_tmp36_ = _e_it;
#line 179 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
					_tmp37_ = gee_iterator_next (_tmp36_);
#line 179 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
					if (!_tmp37_) {
#line 179 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
						break;
#line 1182 "email-details.c"
					}
#line 179 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
					_tmp38_ = _e_it;
#line 179 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
					_tmp39_ = gee_iterator_get (_tmp38_);
#line 179 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
					e = (FolksEmailFieldDetails*) _tmp39_;
#line 181 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
					_tmp40_ = self->priv->_email_count;
#line 181 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
					self->priv->_email_count = _tmp40_ + 1;
#line 183 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
					found = FALSE;
#line 1196 "email-details.c"
					{
						gint j;
#line 184 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
						j = 0;
#line 1201 "email-details.c"
						{
							gboolean _tmp41_;
#line 184 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
							_tmp41_ = TRUE;
#line 184 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
							while (TRUE) {
#line 1208 "email-details.c"
								gboolean _tmp42_;
								gint _tmp44_;
								gint _tmp45_;
								const gchar* _tmp46_;
								gchar* _tmp47_;
								gchar* v;
								gboolean _tmp48_ = FALSE;
								GeeHashMap* _tmp49_;
								const gchar* _tmp50_;
								gpointer _tmp51_ = NULL;
								GValue* _tmp52_;
								gboolean _tmp53_;
								gboolean _tmp62_;
#line 184 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
								_tmp42_ = _tmp41_;
#line 184 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
								if (!_tmp42_) {
#line 1226 "email-details.c"
									gint _tmp43_;
#line 184 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
									_tmp43_ = j;
#line 184 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
									j = _tmp43_ + 1;
#line 1232 "email-details.c"
								}
#line 184 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
								_tmp41_ = FALSE;
#line 184 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
								_tmp44_ = j;
#line 184 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
								if (!(_tmp44_ < 2)) {
#line 184 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
									break;
#line 1242 "email-details.c"
								}
#line 185 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
								_tmp45_ = j;
#line 185 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
								_tmp46_ = EDSF_PERSONA_email_fields[_tmp45_];
#line 185 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
								_tmp47_ = g_strdup (_tmp46_);
#line 185 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
								v = _tmp47_;
#line 186 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
								_tmp49_ = contact;
#line 186 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
								_tmp50_ = v;
#line 186 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
								_tmp51_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp49_, _tmp50_);
#line 186 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
								_tmp52_ = (GValue*) _tmp51_;
#line 186 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
								_tmp53_ = _tmp52_ != NULL;
#line 186 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
								__vala_GValue_free0 (_tmp52_);
#line 186 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
								if (_tmp53_) {
#line 1266 "email-details.c"
									GeeHashMap* _tmp54_;
									const gchar* _tmp55_;
									gpointer _tmp56_ = NULL;
									GValue* _tmp57_;
									const gchar* _tmp58_ = NULL;
									FolksEmailFieldDetails* _tmp59_;
									gconstpointer _tmp60_;
									const gchar* _tmp61_;
#line 187 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
									_tmp54_ = contact;
#line 187 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
									_tmp55_ = v;
#line 187 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
									_tmp56_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp54_, _tmp55_);
#line 187 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
									_tmp57_ = (GValue*) _tmp56_;
#line 187 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
									_tmp58_ = g_value_get_string (_tmp57_);
#line 187 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
									_tmp59_ = e;
#line 187 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
									_tmp60_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp59_);
#line 187 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
									_tmp61_ = _tmp60_;
#line 187 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
									_tmp48_ = g_strcmp0 (_tmp58_, (const gchar*) _tmp61_) == 0;
#line 187 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
									__vala_GValue_free0 (_tmp57_);
#line 1295 "email-details.c"
								} else {
#line 186 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
									_tmp48_ = FALSE;
#line 1299 "email-details.c"
								}
#line 186 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
								_tmp62_ = _tmp48_;
#line 186 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
								if (_tmp62_) {
#line 1305 "email-details.c"
									GeeHashMap* _tmp63_;
									const gchar* _tmp64_;
#line 188 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
									found = TRUE;
#line 189 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
									_tmp63_ = contact;
#line 189 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
									_tmp64_ = v;
#line 189 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
									gee_abstract_map_unset ((GeeAbstractMap*) _tmp63_, _tmp64_, NULL);
#line 1316 "email-details.c"
								}
#line 184 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
								_g_free0 (v);
#line 1320 "email-details.c"
							}
						}
					}
#line 192 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
					_tmp65_ = found;
#line 192 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
					g_assert (_tmp65_);
#line 1328 "email-details.c"
					{
						FolksEmailFieldDetails* _tmp66_;
						FolksEmailFieldDetails* _tmp67_;
						GeeCollection* _tmp68_ = NULL;
						GeeCollection* _tmp69_;
						GeeIterator* _tmp70_ = NULL;
						GeeIterator* _tmp71_;
						GeeIterator* _v_it;
#line 193 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
						_tmp66_ = e;
#line 193 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
						_tmp67_ = e;
#line 193 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
						_tmp68_ = folks_abstract_field_details_get_parameter_values ((FolksAbstractFieldDetails*) _tmp66_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE);
#line 193 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
						_tmp69_ = _tmp68_;
#line 193 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
						_tmp70_ = gee_iterable_iterator ((GeeIterable*) _tmp69_);
#line 193 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
						_tmp71_ = _tmp70_;
#line 193 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
						_g_object_unref0 (_tmp69_);
#line 193 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
						_v_it = _tmp71_;
#line 193 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
						while (TRUE) {
#line 1355 "email-details.c"
							GeeIterator* _tmp72_;
							gboolean _tmp73_ = FALSE;
							GeeIterator* _tmp74_;
							gpointer _tmp75_ = NULL;
							gchar* v;
							GeeHashSet* _tmp76_;
							const gchar* _tmp77_;
#line 193 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
							_tmp72_ = _v_it;
#line 193 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
							_tmp73_ = gee_iterator_next (_tmp72_);
#line 193 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
							if (!_tmp73_) {
#line 193 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
								break;
#line 1371 "email-details.c"
							}
#line 193 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
							_tmp74_ = _v_it;
#line 193 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
							_tmp75_ = gee_iterator_get (_tmp74_);
#line 193 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
							v = (gchar*) _tmp75_;
#line 195 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
							_tmp76_ = self->priv->_email_types;
#line 195 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
							_tmp77_ = v;
#line 195 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
							gee_abstract_collection_add ((GeeAbstractCollection*) _tmp76_, _tmp77_);
#line 193 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
							_g_free0 (v);
#line 1387 "email-details.c"
						}
#line 193 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
						_g_object_unref0 (_v_it);
#line 1391 "email-details.c"
					}
#line 179 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
					_g_object_unref0 (e);
#line 1395 "email-details.c"
				}
#line 179 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
				_g_object_unref0 (_e_it);
#line 1399 "email-details.c"
			}
#line 152 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			_g_object_unref0 (email_owner);
#line 152 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			_g_object_unref0 (i);
#line 1405 "email-details.c"
		}
#line 152 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
		_g_object_unref0 (_i_it);
#line 1409 "email-details.c"
	}
#line 200 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp78_ = removed;
#line 200 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp79_ = gee_collection_get_size ((GeeCollection*) _tmp78_);
#line 200 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp80_ = _tmp79_;
#line 200 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_assert (_tmp80_ == 1);
#line 1419 "email-details.c"
	{
		GeeSet* _tmp81_;
		GeeIterator* _tmp82_ = NULL;
		GeeIterator* _i_it;
#line 202 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
		_tmp81_ = removed;
#line 202 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
		_tmp82_ = gee_iterable_iterator ((GeeIterable*) _tmp81_);
#line 202 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
		_i_it = _tmp82_;
#line 202 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
		while (TRUE) {
#line 1432 "email-details.c"
			GeeIterator* _tmp83_;
			gboolean _tmp84_ = FALSE;
			GeeIterator* _tmp85_;
			gpointer _tmp86_ = NULL;
			FolksIndividual* i;
			FolksIndividual* _tmp87_;
#line 202 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			_tmp83_ = _i_it;
#line 202 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			_tmp84_ = gee_iterator_next (_tmp83_);
#line 202 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			if (!_tmp84_) {
#line 202 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
				break;
#line 1447 "email-details.c"
			}
#line 202 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			_tmp85_ = _i_it;
#line 202 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			_tmp86_ = gee_iterator_get (_tmp85_);
#line 202 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			i = (FolksIndividual*) _tmp86_;
#line 204 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			_tmp87_ = i;
#line 204 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			g_assert (_tmp87_ == NULL);
#line 202 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
			_g_object_unref0 (i);
#line 1461 "email-details.c"
		}
#line 202 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
		_g_object_unref0 (_i_it);
#line 1465 "email-details.c"
	}
#line 146 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_g_object_unref0 (removed);
#line 146 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_g_object_unref0 (added);
#line 1471 "email-details.c"
}


static void email_details_tests_class_init (EmailDetailsTestsClass * klass) {
#line 25 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	email_details_tests_parent_class = g_type_class_peek_parent (klass);
#line 25 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_type_class_add_private (klass, sizeof (EmailDetailsTestsPrivate));
#line 25 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	FOLKS_TEST_CASE_CLASS (klass)->set_up = email_details_tests_real_set_up;
#line 25 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	FOLKS_TEST_CASE_CLASS (klass)->tear_down = email_details_tests_real_tear_down;
#line 25 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	G_OBJECT_CLASS (klass)->finalize = email_details_tests_finalize;
#line 1486 "email-details.c"
}


static void email_details_tests_instance_init (EmailDetailsTests * self) {
#line 25 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	self->priv = EMAIL_DETAILS_TESTS_GET_PRIVATE (self);
#line 1493 "email-details.c"
}


static void email_details_tests_finalize (GObject* obj) {
	EmailDetailsTests * self;
#line 25 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	self = EMAIL_DETAILS_TESTS (obj);
#line 27 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_eds_test_backend_unref0 (self->priv->_eds_backend);
#line 28 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 29 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 31 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_g_object_unref0 (self->priv->_email_types);
#line 32 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_g_object_unref0 (self->priv->_c1);
#line 33 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_g_object_unref0 (self->priv->_c2);
#line 34 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_g_object_unref0 (self->priv->_c3);
#line 25 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	G_OBJECT_CLASS (email_details_tests_parent_class)->finalize (obj);
#line 1517 "email-details.c"
}


GType email_details_tests_get_type (void) {
	static volatile gsize email_details_tests_type_id__volatile = 0;
	if (g_once_init_enter (&email_details_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (EmailDetailsTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) email_details_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (EmailDetailsTests), 0, (GInstanceInitFunc) email_details_tests_instance_init, NULL };
		GType email_details_tests_type_id;
		email_details_tests_type_id = g_type_register_static (FOLKS_TYPE_TEST_CASE, "EmailDetailsTests", &g_define_type_info, 0);
		g_once_init_leave (&email_details_tests_type_id__volatile, email_details_tests_type_id);
	}
	return email_details_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	GTestSuite* _tmp0_ = NULL;
	GTestSuite* root;
	EmailDetailsTests* _tmp1_;
	EmailDetailsTests* _tmp2_;
	GTestSuite* _tmp3_ = NULL;
#line 211 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_test_init (&args_length1, &args, NULL);
#line 213 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp0_ = g_test_get_root ();
#line 213 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	root = _tmp0_;
#line 214 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp1_ = email_details_tests_new ();
#line 214 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp2_ = _tmp1_;
#line 214 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_tmp3_ = folks_test_case_get_suite ((FolksTestCase*) _tmp2_);
#line 214 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_test_suite_add_suite (root, _tmp3_);
#line 214 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	_g_object_unref0 (_tmp2_);
#line 216 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_test_run ();
#line 218 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	result = 0;
#line 218 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	return result;
#line 1562 "email-details.c"
}


int main (int argc, char ** argv) {
#line 209 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	g_type_init ();
#line 209 "/opt/gnome2/source/folks/tests/eds/email-details.vala"
	return _vala_main (argv, argc);
#line 1571 "email-details.c"
}



