/* aggregation.c generated by valac 0.15.2.10-1402f, the Vala compiler
 * generated from aggregation.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Travis Reitter <travis.reitter@collabora.co.uk>
 */

#include <glib.h>
#include <glib-object.h>
#include <folks-test.h>
#include <kf-test.h>
#include <tp-test-contactlist.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <folks/folks.h>
#include <gio/gio.h>


#define TYPE_AGGREGATION_TESTS (aggregation_tests_get_type ())
#define AGGREGATION_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_AGGREGATION_TESTS, AggregationTests))
#define AGGREGATION_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_AGGREGATION_TESTS, AggregationTestsClass))
#define IS_AGGREGATION_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_AGGREGATION_TESTS))
#define IS_AGGREGATION_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_AGGREGATION_TESTS))
#define AGGREGATION_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_AGGREGATION_TESTS, AggregationTestsClass))

typedef struct _AggregationTests AggregationTests;
typedef struct _AggregationTestsClass AggregationTestsClass;
typedef struct _AggregationTestsPrivate AggregationTestsPrivate;

#define AGGREGATION_TESTS_TYPE_INDIVIDUAL_STATE (aggregation_tests_individual_state_get_type ())
#define _kf_test_backend_unref0(var) ((var == NULL) ? NULL : (var = (kf_test_backend_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _Block1Data Block1Data;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _Block2Data Block2Data;
typedef struct _Block3Data Block3Data;
typedef struct _Block4Data Block4Data;
typedef struct _Block5Data Block5Data;
typedef struct _Block6Data Block6Data;
typedef struct _Block7Data Block7Data;
typedef struct _Block8Data Block8Data;
typedef struct _Block9Data Block9Data;

struct _AggregationTests {
	FolksTestCase parent_instance;
	AggregationTestsPrivate * priv;
};

struct _AggregationTestsClass {
	FolksTestCaseClass parent_class;
};

struct _AggregationTestsPrivate {
	KfTestBackend* _kf_backend;
	TpTestBackend* _tp_backend;
	GeeHashSet* _default_personas;
	gint _test_timeout;
};

typedef enum  {
	AGGREGATION_TESTS_INDIVIDUAL_STATE_ADDED,
	AGGREGATION_TESTS_INDIVIDUAL_STATE_REMOVED,
	AGGREGATION_TESTS_INDIVIDUAL_STATE_FINALISED
} AggregationTestsIndividualState;

struct _Block1Data {
	int _ref_count_;
	AggregationTests * self;
	GMainLoop* main_loop;
	GeeHashSet* default_individuals;
	GeeHashSet* expected_individuals;
	GeeHashSet* expected_individuals_detailed;
	FolksIndividualAggregator* aggregator;
};

struct _Block2Data {
	int _ref_count_;
	AggregationTests * self;
	GMainLoop* main_loop;
	FolksIndividual* individual1;
	FolksIndividual* individual1_detailed;
	FolksIndividual* individual2;
	FolksIndividual* individual2_detailed;
	FolksIndividualAggregator* aggregator;
};

struct _Block3Data {
	int _ref_count_;
	AggregationTests * self;
	GMainLoop* main_loop;
	FolksIndividual* individual1;
	FolksIndividual* individual1_detailed;
	FolksIndividual* individual2;
	FolksIndividual* individual2_detailed;
	FolksIndividualAggregator* aggregator;
};

struct _Block4Data {
	int _ref_count_;
	AggregationTests * self;
	GMainLoop* main_loop;
	FolksIndividual* user_individual;
	FolksIndividual* user_individual_detailed;
	FolksIndividualAggregator* aggregator;
};

struct _Block5Data {
	int _ref_count_;
	AggregationTests * self;
	GMainLoop* main_loop;
	FolksIndividualAggregator* aggregator;
};

struct _Block6Data {
	int _ref_count_;
	AggregationTests * self;
	GMainLoop* main_loop;
	GeeHashMap* individuals_map;
	FolksIndividualAggregator* aggregator;
	gboolean aggregator_is_finalising;
};

struct _Block7Data {
	int _ref_count_;
	AggregationTests * self;
	GMainLoop* main_loop;
	FolksIndividual* individual;
	FolksIndividualAggregator* aggregator;
	FolksPersona* writeable_persona;
};

struct _Block8Data {
	int _ref_count_;
	AggregationTests * self;
	GMainLoop* main_loop;
	FolksIndividual* individual;
	FolksIndividualAggregator* aggregator;
	FolksPersona* writeable_persona;
};

struct _Block9Data {
	int _ref_count_;
	AggregationTests * self;
	GMainLoop* main_loop;
	FolksIndividual* individual;
	FolksIndividualAggregator* aggregator;
	FolksPersona* writeable_persona;
};


static gpointer aggregation_tests_parent_class = NULL;

GType aggregation_tests_get_type (void) G_GNUC_CONST;
#define AGGREGATION_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_AGGREGATION_TESTS, AggregationTestsPrivate))
enum  {
	AGGREGATION_TESTS_DUMMY_PROPERTY
};
static GType aggregation_tests_individual_state_get_type (void) G_GNUC_UNUSED;
AggregationTests* aggregation_tests_new (void);
AggregationTests* aggregation_tests_construct (GType object_type);
void aggregation_tests_test_iid (AggregationTests* self);
static void _aggregation_tests_test_iid_folks_test_case_test_method (gpointer self);
void aggregation_tests_test_linkable_properties_same_store (AggregationTests* self);
static void _aggregation_tests_test_linkable_properties_same_store_folks_test_case_test_method (gpointer self);
void aggregation_tests_test_linkable_properties_different_stores (AggregationTests* self);
static void _aggregation_tests_test_linkable_properties_different_stores_folks_test_case_test_method (gpointer self);
void aggregation_tests_test_user (AggregationTests* self);
static void _aggregation_tests_test_user_folks_test_case_test_method (gpointer self);
void aggregation_tests_test_untrusted_store (AggregationTests* self);
static void _aggregation_tests_test_untrusted_store_folks_test_case_test_method (gpointer self);
void aggregation_tests_test_linked_individual_refcounting (AggregationTests* self);
static void _aggregation_tests_test_linked_individual_refcounting_folks_test_case_test_method (gpointer self);
void aggregation_tests_test_ensure_individual_property_writeable_trivial (AggregationTests* self);
static void _aggregation_tests_test_ensure_individual_property_writeable_trivial_folks_test_case_test_method (gpointer self);
void aggregation_tests_test_ensure_individual_property_writeable_add_persona (AggregationTests* self);
static void _aggregation_tests_test_ensure_individual_property_writeable_add_persona_folks_test_case_test_method (gpointer self);
void aggregation_tests_test_ensure_individual_property_writeable_failure (AggregationTests* self);
static void _aggregation_tests_test_ensure_individual_property_writeable_failure_folks_test_case_test_method (gpointer self);
static void aggregation_tests_real_set_up (FolksTestCase* base);
static void aggregation_tests_real_tear_down (FolksTestCase* base);
static Block1Data* block1_data_ref (Block1Data* _data1_);
static void block1_data_unref (void * _userdata_);
static void __lambda2_ (Block1Data* _data1_, GeeMultiMap* changes);
static void _aggregation_tests_test_iid_individuals_changed (AggregationTests* self, gboolean detailed, GeeCollection* added, GeeSet* removed, GeeSet* default_individuals, GeeSet* expected_individuals);
static void ___lambda2__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void __lambda3_ (Block1Data* _data1_, GeeSet* added, GeeSet* removed, const gchar* m, FolksPersona* a, FolksGroupDetailsChangeReason r);
static void ___lambda3__folks_individual_aggregator_individuals_changed (FolksIndividualAggregator* _sender, GeeSet* added, GeeSet* removed, const gchar* message, FolksPersona* actor, FolksGroupDetailsChangeReason reason, gpointer self);
static gboolean __lambda4_ (Block1Data* _data1_);
static gboolean ___lambda4__gsource_func (gpointer self);
static gboolean __lambda5_ (Block1Data* _data1_);
static void __lambda6_ (Block1Data* _data1_, GObject* s, GAsyncResult* r);
static void ___lambda6__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda5__gsource_func (gpointer self);
static Block2Data* block2_data_ref (Block2Data* _data2_);
static void block2_data_unref (void * _userdata_);
static void __lambda7_ (Block2Data* _data2_, GeeMultiMap* changes);
static void _aggregation_tests_test_linkable_properties_individuals_changed (AggregationTests* self, gboolean detailed, guint num_personas, GeeCollection* added, GeeSet* removed, FolksIndividual** individual1, FolksIndividual** individual2);
static void ___lambda7__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void __lambda8_ (Block2Data* _data2_, GeeSet* added, GeeSet* removed, const gchar* m, FolksPersona* a, FolksGroupDetailsChangeReason r);
static void ___lambda8__folks_individual_aggregator_individuals_changed (FolksIndividualAggregator* _sender, GeeSet* added, GeeSet* removed, const gchar* message, FolksPersona* actor, FolksGroupDetailsChangeReason reason, gpointer self);
static gboolean __lambda9_ (Block2Data* _data2_);
static gboolean ___lambda9__gsource_func (gpointer self);
static gboolean __lambda10_ (Block2Data* _data2_);
static void __lambda11_ (Block2Data* _data2_, GObject* s, GAsyncResult* r);
static void ___lambda11__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda10__gsource_func (gpointer self);
static Block3Data* block3_data_ref (Block3Data* _data3_);
static void block3_data_unref (void * _userdata_);
static void __lambda12_ (Block3Data* _data3_, GeeMultiMap* changes);
static void ___lambda12__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void __lambda13_ (Block3Data* _data3_, GeeSet* added, GeeSet* removed, const gchar* m, FolksPersona* a, FolksGroupDetailsChangeReason r);
static void ___lambda13__folks_individual_aggregator_individuals_changed (FolksIndividualAggregator* _sender, GeeSet* added, GeeSet* removed, const gchar* message, FolksPersona* actor, FolksGroupDetailsChangeReason reason, gpointer self);
static gboolean __lambda14_ (Block3Data* _data3_);
static gboolean ___lambda14__gsource_func (gpointer self);
static gboolean __lambda15_ (Block3Data* _data3_);
static void __lambda16_ (Block3Data* _data3_, GObject* s, GAsyncResult* r);
static void ___lambda16__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda15__gsource_func (gpointer self);
static Block4Data* block4_data_ref (Block4Data* _data4_);
static void block4_data_unref (void * _userdata_);
static void __lambda17_ (Block4Data* _data4_, GeeMultiMap* changes);
static void _aggregation_tests_test_user_individuals_changed (AggregationTests* self, gboolean detailed, GeeCollection* added, GeeSet* removed, FolksIndividual** user_individual);
static void ___lambda17__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void __lambda18_ (Block4Data* _data4_, GeeSet* added, GeeSet* removed, const gchar* m, FolksPersona* a, FolksGroupDetailsChangeReason r);
static void ___lambda18__folks_individual_aggregator_individuals_changed (FolksIndividualAggregator* _sender, GeeSet* added, GeeSet* removed, const gchar* message, FolksPersona* actor, FolksGroupDetailsChangeReason reason, gpointer self);
static gboolean __lambda19_ (Block4Data* _data4_);
static gboolean ___lambda19__gsource_func (gpointer self);
static gboolean __lambda20_ (Block4Data* _data4_);
static void __lambda21_ (Block4Data* _data4_, GObject* s, GAsyncResult* r);
static void ___lambda21__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda20__gsource_func (gpointer self);
static Block5Data* block5_data_ref (Block5Data* _data5_);
static void block5_data_unref (void * _userdata_);
static void __lambda22_ (AggregationTests* self, GeeMultiMap* changes);
static void _aggregation_tests_test_untrusted_store_individuals_changed (AggregationTests* self, gboolean detailed, GeeCollection* added, GeeSet* removed);
static void ___lambda22__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void __lambda23_ (AggregationTests* self, GeeSet* added, GeeSet* removed, const gchar* m, FolksPersona* a, FolksGroupDetailsChangeReason r);
static void ___lambda23__folks_individual_aggregator_individuals_changed (FolksIndividualAggregator* _sender, GeeSet* added, GeeSet* removed, const gchar* message, FolksPersona* actor, FolksGroupDetailsChangeReason reason, gpointer self);
static gboolean __lambda24_ (Block5Data* _data5_);
static gboolean ___lambda24__gsource_func (gpointer self);
static gboolean __lambda25_ (Block5Data* _data5_);
static void __lambda26_ (Block5Data* _data5_, GObject* s, GAsyncResult* r);
static void ___lambda26__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda25__gsource_func (gpointer self);
static Block6Data* block6_data_ref (Block6Data* _data6_);
static void block6_data_unref (void * _userdata_);
static void __lambda27_ (Block6Data* _data6_, GeeSet* added, GeeSet* removed, const gchar* m, FolksPersona* a, FolksGroupDetailsChangeReason r);
static void ____lambda28_ (Block6Data* _data6_, GObject* obj);
static void _____lambda28__gweak_notify (gpointer self, GObject* object);
static void ___lambda27__folks_individual_aggregator_individuals_changed (FolksIndividualAggregator* _sender, GeeSet* added, GeeSet* removed, const gchar* message, FolksPersona* actor, FolksGroupDetailsChangeReason reason, gpointer self);
static gboolean __lambda29_ (Block6Data* _data6_);
static gboolean ___lambda29__gsource_func (gpointer self);
static gboolean __lambda30_ (Block6Data* _data6_);
static void __lambda31_ (Block6Data* _data6_, GObject* s, GAsyncResult* r);
static void ___lambda31__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda30__gsource_func (gpointer self);
static gboolean __lambda32_ (Block6Data* _data6_);
static gboolean ___lambda32__gsource_func (gpointer self);
static Block7Data* block7_data_ref (Block7Data* _data7_);
static void block7_data_unref (void * _userdata_);
static void __lambda33_ (Block7Data* _data7_, GeeMultiMap* changes);
static void ___lambda33__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static gboolean __lambda34_ (Block7Data* _data7_);
static gboolean ___lambda34__gsource_func (gpointer self);
static gboolean __lambda35_ (Block7Data* _data7_);
static void __lambda36_ (Block7Data* _data7_, GObject* s, GAsyncResult* r);
static void ___lambda36__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda35__gsource_func (gpointer self);
static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle);
static gboolean __lambda37_ (Block7Data* _data7_);
static gboolean ___lambda37__gsource_func (gpointer self);
static gboolean __lambda38_ (Block7Data* _data7_);
static void __lambda39_ (Block7Data* _data7_, GObject* obj, GAsyncResult* res);
static void ___lambda39__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda38__gsource_func (gpointer self);
static Block8Data* block8_data_ref (Block8Data* _data8_);
static void block8_data_unref (void * _userdata_);
static void __lambda40_ (Block8Data* _data8_, GeeMultiMap* changes);
static void ___lambda40__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static gboolean __lambda41_ (Block8Data* _data8_);
static gboolean ___lambda41__gsource_func (gpointer self);
static gboolean __lambda42_ (Block8Data* _data8_);
static void __lambda43_ (Block8Data* _data8_, GObject* s, GAsyncResult* r);
static void ___lambda43__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda42__gsource_func (gpointer self);
static void __lambda44_ (Block8Data* _data8_, GeeMultiMap* changes);
static void ___lambda44__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static gboolean __lambda45_ (Block8Data* _data8_);
static gboolean ___lambda45__gsource_func (gpointer self);
static gboolean __lambda46_ (Block8Data* _data8_);
static void __lambda47_ (Block8Data* _data8_, GObject* obj, GAsyncResult* res);
static void ___lambda47__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda46__gsource_func (gpointer self);
static Block9Data* block9_data_ref (Block9Data* _data9_);
static void block9_data_unref (void * _userdata_);
static void __lambda48_ (Block9Data* _data9_, GeeMultiMap* changes);
static void ___lambda48__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static gboolean __lambda49_ (Block9Data* _data9_);
static gboolean ___lambda49__gsource_func (gpointer self);
static gboolean __lambda50_ (Block9Data* _data9_);
static void __lambda51_ (Block9Data* _data9_, GObject* s, GAsyncResult* r);
static void ___lambda51__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda50__gsource_func (gpointer self);
static gboolean __lambda52_ (Block9Data* _data9_);
static gboolean ___lambda52__gsource_func (gpointer self);
static gboolean __lambda53_ (Block9Data* _data9_);
static void __lambda54_ (Block9Data* _data9_, GObject* obj, GAsyncResult* res);
static void ___lambda54__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda53__gsource_func (gpointer self);
static void aggregation_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static GType aggregation_tests_individual_state_get_type (void) {
	static volatile gsize aggregation_tests_individual_state_type_id__volatile = 0;
	if (g_once_init_enter (&aggregation_tests_individual_state_type_id__volatile)) {
		static const GEnumValue values[] = {{AGGREGATION_TESTS_INDIVIDUAL_STATE_ADDED, "AGGREGATION_TESTS_INDIVIDUAL_STATE_ADDED", "added"}, {AGGREGATION_TESTS_INDIVIDUAL_STATE_REMOVED, "AGGREGATION_TESTS_INDIVIDUAL_STATE_REMOVED", "removed"}, {AGGREGATION_TESTS_INDIVIDUAL_STATE_FINALISED, "AGGREGATION_TESTS_INDIVIDUAL_STATE_FINALISED", "finalised"}, {0, NULL, NULL}};
		GType aggregation_tests_individual_state_type_id;
		aggregation_tests_individual_state_type_id = g_enum_register_static ("AggregationTestsIndividualState", values);
		g_once_init_leave (&aggregation_tests_individual_state_type_id__volatile, aggregation_tests_individual_state_type_id);
	}
	return aggregation_tests_individual_state_type_id__volatile;
}


static void _aggregation_tests_test_iid_folks_test_case_test_method (gpointer self) {
#line 51 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	aggregation_tests_test_iid (self);
#line 348 "aggregation.c"
}


static void _aggregation_tests_test_linkable_properties_same_store_folks_test_case_test_method (gpointer self) {
#line 52 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	aggregation_tests_test_linkable_properties_same_store (self);
#line 355 "aggregation.c"
}


static void _aggregation_tests_test_linkable_properties_different_stores_folks_test_case_test_method (gpointer self) {
#line 54 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	aggregation_tests_test_linkable_properties_different_stores (self);
#line 362 "aggregation.c"
}


static void _aggregation_tests_test_user_folks_test_case_test_method (gpointer self) {
#line 56 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	aggregation_tests_test_user (self);
#line 369 "aggregation.c"
}


static void _aggregation_tests_test_untrusted_store_folks_test_case_test_method (gpointer self) {
#line 57 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	aggregation_tests_test_untrusted_store (self);
#line 376 "aggregation.c"
}


static void _aggregation_tests_test_linked_individual_refcounting_folks_test_case_test_method (gpointer self) {
#line 58 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	aggregation_tests_test_linked_individual_refcounting (self);
#line 383 "aggregation.c"
}


static void _aggregation_tests_test_ensure_individual_property_writeable_trivial_folks_test_case_test_method (gpointer self) {
#line 59 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	aggregation_tests_test_ensure_individual_property_writeable_trivial (self);
#line 390 "aggregation.c"
}


static void _aggregation_tests_test_ensure_individual_property_writeable_add_persona_folks_test_case_test_method (gpointer self) {
#line 61 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	aggregation_tests_test_ensure_individual_property_writeable_add_persona (self);
#line 397 "aggregation.c"
}


static void _aggregation_tests_test_ensure_individual_property_writeable_failure_folks_test_case_test_method (gpointer self) {
#line 63 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	aggregation_tests_test_ensure_individual_property_writeable_failure (self);
#line 404 "aggregation.c"
}


AggregationTests* aggregation_tests_construct (GType object_type) {
	AggregationTests * self = NULL;
	KfTestBackend* _tmp0_;
	TpTestBackend* _tmp1_;
	GHashFunc _tmp2_;
	GEqualFunc _tmp3_;
	GeeHashSet* _tmp4_;
	GeeHashSet* _tmp5_;
	GeeHashSet* _tmp6_;
	GeeHashSet* _tmp7_;
	GeeHashSet* _tmp8_;
	GeeHashSet* _tmp9_;
	GeeHashSet* _tmp10_;
	GeeHashSet* _tmp11_;
	GeeHashSet* _tmp12_;
	const gchar* _tmp13_ = NULL;
#line 33 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = (AggregationTests*) folks_test_case_construct (object_type, "Aggregation");
#line 35 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = kf_test_backend_new ();
#line 35 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_kf_test_backend_unref0 (self->priv->_kf_backend);
#line 35 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self->priv->_kf_backend = _tmp0_;
#line 36 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = tp_test_backend_new ();
#line 36 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (self->priv->_tp_backend);
#line 36 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self->priv->_tp_backend = _tmp1_;
#line 39 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = g_str_hash;
#line 39 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = g_str_equal;
#line 39 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp4_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, _tmp2_, _tmp3_);
#line 39 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (self->priv->_default_personas);
#line 39 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self->priv->_default_personas = _tmp4_;
#line 41 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp5_ = self->priv->_default_personas;
#line 41 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp5_, "travis@example.com");
#line 42 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp6_ = self->priv->_default_personas;
#line 42 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp6_, "olivier@example.com");
#line 43 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp7_ = self->priv->_default_personas;
#line 43 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp7_, "guillaume@example.com");
#line 44 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp8_ = self->priv->_default_personas;
#line 44 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp8_, "sjoerd@example.com");
#line 45 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp9_ = self->priv->_default_personas;
#line 45 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp9_, "christian@example.com");
#line 46 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp10_ = self->priv->_default_personas;
#line 46 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp10_, "wim@example.com");
#line 47 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp11_ = self->priv->_default_personas;
#line 47 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp11_, "helen@example.com");
#line 48 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp12_ = self->priv->_default_personas;
#line 48 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp12_, "geraldine@example.com");
#line 51 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "IID", _aggregation_tests_test_iid_folks_test_case_test_method, self);
#line 52 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "linkable properties:same store", _aggregation_tests_test_linkable_properties_same_store_folks_test_case_test_method, self);
#line 54 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "linkable properties:different stores", _aggregation_tests_test_linkable_properties_different_stores_folks_test_case_test_method, self);
#line 56 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "user", _aggregation_tests_test_user_folks_test_case_test_method, self);
#line 57 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "untrusted store", _aggregation_tests_test_untrusted_store_folks_test_case_test_method, self);
#line 58 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "refcounting", _aggregation_tests_test_linked_individual_refcounting_folks_test_case_test_method, self);
#line 59 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "ensure individual property writeable:trivial", _aggregation_tests_test_ensure_individual_property_writeable_trivial_folks_test_case_test_method, self);
#line 61 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "ensure individual property writeable:add persona", _aggregation_tests_test_ensure_individual_property_writeable_add_persona_folks_test_case_test_method, self);
#line 63 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "ensure individual property writeable:failure", _aggregation_tests_test_ensure_individual_property_writeable_failure_folks_test_case_test_method, self);
#line 66 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp13_ = g_getenv ("FOLKS_TEST_VALGRIND");
#line 66 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	if (_tmp13_ != NULL) {
#line 67 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		self->priv->_test_timeout = 10;
#line 504 "aggregation.c"
	}
#line 31 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return self;
#line 508 "aggregation.c"
}


AggregationTests* aggregation_tests_new (void) {
#line 31 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return aggregation_tests_construct (TYPE_AGGREGATION_TESTS);
#line 515 "aggregation.c"
}


static void aggregation_tests_real_set_up (FolksTestCase* base) {
	AggregationTests * self;
	TpTestBackend* _tmp0_;
#line 70 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = (AggregationTests*) base;
#line 72 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = self->priv->_tp_backend;
#line 72 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	tp_test_backend_set_up (_tmp0_);
#line 528 "aggregation.c"
}


static void aggregation_tests_real_tear_down (FolksTestCase* base) {
	AggregationTests * self;
	TpTestBackend* _tmp0_;
#line 75 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = (AggregationTests*) base;
#line 77 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = self->priv->_tp_backend;
#line 77 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	tp_test_backend_tear_down (_tmp0_);
#line 541 "aggregation.c"
}


static Block1Data* block1_data_ref (Block1Data* _data1_) {
#line 87 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_atomic_int_inc (&_data1_->_ref_count_);
#line 87 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return _data1_;
#line 550 "aggregation.c"
}


static void block1_data_unref (void * _userdata_) {
	Block1Data* _data1_;
	_data1_ = (Block1Data*) _userdata_;
#line 87 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	if (g_atomic_int_dec_and_test (&_data1_->_ref_count_)) {
#line 559 "aggregation.c"
		AggregationTests * self;
#line 87 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		self = _data1_->self;
#line 87 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data1_->aggregator);
#line 87 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data1_->expected_individuals_detailed);
#line 87 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data1_->expected_individuals);
#line 87 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data1_->default_individuals);
#line 87 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_main_loop_unref0 (_data1_->main_loop);
#line 87 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (self);
#line 87 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_slice_free (Block1Data, _data1_);
#line 577 "aggregation.c"
	}
}


static void __lambda2_ (Block1Data* _data1_, GeeMultiMap* changes) {
	AggregationTests * self;
	GeeMultiMap* _tmp0_;
	GeeSet* _tmp1_ = NULL;
	GeeSet* removed;
	GeeMultiMap* _tmp2_;
	GeeCollection* _tmp3_ = NULL;
	GeeCollection* added;
	GeeHashSet* _tmp4_;
	GeeHashSet* _tmp5_;
#line 140 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data1_->self;
#line 140 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (changes != NULL);
#line 142 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = changes;
#line 142 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = gee_multi_map_get_keys (_tmp0_);
#line 142 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	removed = _tmp1_;
#line 143 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = changes;
#line 143 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = gee_multi_map_get_values (_tmp2_);
#line 143 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	added = _tmp3_;
#line 145 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp4_ = _data1_->default_individuals;
#line 145 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp5_ = _data1_->expected_individuals_detailed;
#line 145 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_aggregation_tests_test_iid_individuals_changed (self, TRUE, added, removed, (GeeSet*) _tmp4_, (GeeSet*) _tmp5_);
#line 140 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (added);
#line 140 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (removed);
#line 618 "aggregation.c"
}


static void ___lambda2__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 140 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	__lambda2_ (self, changes);
#line 625 "aggregation.c"
}


static void __lambda3_ (Block1Data* _data1_, GeeSet* added, GeeSet* removed, const gchar* m, FolksPersona* a, FolksGroupDetailsChangeReason r) {
	AggregationTests * self;
	GeeSet* _tmp0_;
	GeeSet* _tmp1_;
	GeeHashSet* _tmp2_;
	GeeHashSet* _tmp3_;
#line 148 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data1_->self;
#line 148 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (added != NULL);
#line 148 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (removed != NULL);
#line 150 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = added;
#line 150 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = removed;
#line 150 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = _data1_->default_individuals;
#line 150 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = _data1_->expected_individuals;
#line 150 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_aggregation_tests_test_iid_individuals_changed (self, FALSE, (GeeCollection*) _tmp0_, _tmp1_, (GeeSet*) _tmp2_, (GeeSet*) _tmp3_);
#line 651 "aggregation.c"
}


static void ___lambda3__folks_individual_aggregator_individuals_changed (FolksIndividualAggregator* _sender, GeeSet* added, GeeSet* removed, const gchar* message, FolksPersona* actor, FolksGroupDetailsChangeReason reason, gpointer self) {
#line 148 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	__lambda3_ (self, added, removed, message, actor, reason);
#line 658 "aggregation.c"
}


static gboolean __lambda4_ (Block1Data* _data1_) {
	AggregationTests * self;
	gboolean result = FALSE;
	GMainLoop* _tmp0_;
#line 157 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data1_->self;
#line 159 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data1_->main_loop;
#line 159 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_main_loop_quit (_tmp0_);
#line 160 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 160 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 676 "aggregation.c"
}


static gboolean ___lambda4__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda4_ (self);
#line 157 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 685 "aggregation.c"
}


static void __lambda6_ (Block1Data* _data1_, GObject* s, GAsyncResult* r) {
	AggregationTests * self;
	GError * _inner_error_ = NULL;
#line 165 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data1_->self;
#line 165 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (r != NULL);
#line 696 "aggregation.c"
	{
		FolksIndividualAggregator* _tmp0_;
		GAsyncResult* _tmp1_;
#line 169 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp0_ = _data1_->aggregator;
#line 169 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp1_ = r;
#line 169 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		folks_individual_aggregator_prepare_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 169 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		if (_inner_error_ != NULL) {
#line 708 "aggregation.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e1 = NULL;
		const gchar* _tmp2_;
#line 167 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		e1 = _inner_error_;
#line 167 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_inner_error_ = NULL;
#line 173 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp2_ = e1->message;
#line 173 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_critical ("aggregation.vala:173: Failed to prepare aggregator: %s", _tmp2_);
#line 175 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_assert_not_reached ();
#line 167 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_error_free0 (e1);
#line 729 "aggregation.c"
	}
	__finally0:
#line 167 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	if (_inner_error_ != NULL) {
#line 167 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 167 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 167 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		return;
#line 740 "aggregation.c"
	}
}


static void ___lambda6__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 165 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	__lambda6_ (self, source_object, res);
#line 165 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	block1_data_unref (self);
#line 750 "aggregation.c"
}


static gboolean __lambda5_ (Block1Data* _data1_) {
	AggregationTests * self;
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_;
#line 163 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data1_->self;
#line 165 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data1_->aggregator;
#line 165 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	folks_individual_aggregator_prepare (_tmp0_, ___lambda6__gasync_ready_callback, block1_data_ref (_data1_));
#line 179 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 179 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 768 "aggregation.c"
}


static gboolean ___lambda5__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda5_ (self);
#line 163 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 777 "aggregation.c"
}


void aggregation_tests_test_iid (AggregationTests* self) {
	Block1Data* _data1_;
	GMainLoop* _tmp0_;
	KfTestBackend* _tmp1_;
	TpTestBackend* _tmp2_;
	void* _tmp3_ = NULL;
	void* account1_handle;
	TpTestBackend* _tmp4_;
	void* _tmp5_ = NULL;
	void* account2_handle;
	GeeHashSet* _tmp6_;
	GeeHashSet* _tmp7_;
	GeeHashSet* _tmp8_;
	GeeHashSet* _tmp9_;
	GeeHashSet* _tmp10_;
	GeeHashSet* _tmp11_;
	GeeHashSet* _tmp12_;
	GeeHashSet* _tmp13_;
	GeeHashSet* _tmp14_;
	GeeHashSet* _tmp15_;
	GeeHashSet* _tmp16_;
	FolksIndividualAggregator* _tmp27_;
	FolksIndividualAggregator* _tmp28_;
	FolksIndividualAggregator* _tmp29_;
	gint _tmp30_;
	GMainLoop* _tmp31_;
	GeeHashSet* _tmp32_;
	gint _tmp33_;
	gint _tmp34_;
	GeeHashSet* _tmp35_;
	gint _tmp36_;
	gint _tmp37_;
	TpTestBackend* _tmp38_;
	void* _tmp39_;
	TpTestBackend* _tmp40_;
	void* _tmp41_;
	KfTestBackend* _tmp42_;
#line 87 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 87 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data1_ = g_slice_new0 (Block1Data);
#line 87 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data1_->_ref_count_ = 1;
#line 87 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data1_->self = g_object_ref (self);
#line 89 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 89 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data1_->main_loop = _tmp0_;
#line 91 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = self->priv->_kf_backend;
#line 91 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	kf_test_backend_set_up (_tmp1_, "");
#line 93 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = self->priv->_tp_backend;
#line 93 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = tp_test_backend_add_account (_tmp2_, "protocol", "me@example.com", "cm", "account");
#line 93 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	account1_handle = _tmp3_;
#line 95 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp4_ = self->priv->_tp_backend;
#line 95 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp5_ = tp_test_backend_add_account (_tmp4_, "protocol", "me2@example.com", "cm", "account2");
#line 95 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	account2_handle = _tmp5_;
#line 107 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp6_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL);
#line 107 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data1_->default_individuals = _tmp6_;
#line 110 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp7_ = _data1_->default_individuals;
#line 110 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp7_, "6380b17dc511b21a1defd4811f1add97b278f92c");
#line 112 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp8_ = _data1_->default_individuals;
#line 112 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp8_, "6b08188cb2ef8cbaca140b277780069b5af8add6");
#line 114 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp9_ = _data1_->default_individuals;
#line 114 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp9_, "60c91326018f6a60604f8d260fc24a60a5b8512c");
#line 116 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp10_ = _data1_->default_individuals;
#line 116 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp10_, "0e46c5e74f61908f49550d241f2a1651892a1695");
#line 118 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp11_ = _data1_->default_individuals;
#line 118 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp11_, "07b913b8977c04d2f2011e26a46ea3e3dcfe3e3d");
#line 120 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp12_ = _data1_->default_individuals;
#line 120 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp12_, "f948d4d2af79085ab860f0ef67bf0c201c4602d4");
#line 122 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp13_ = _data1_->default_individuals;
#line 122 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp13_, "f34529a442577b840a75271b464e90666c38c464");
#line 124 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp14_ = _data1_->default_individuals;
#line 124 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp14_, "467d13f955e62bf30ebf9620fa052aaee2160260");
#line 130 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp15_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL);
#line 130 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data1_->expected_individuals = _tmp15_;
#line 131 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp16_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL);
#line 131 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data1_->expected_individuals_detailed = _tmp16_;
#line 890 "aggregation.c"
	{
		GeeHashSet* _tmp17_;
		GeeIterator* _tmp18_ = NULL;
		GeeIterator* _id_it;
#line 132 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp17_ = _data1_->default_individuals;
#line 132 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp18_ = gee_abstract_collection_iterator ((GeeAbstractCollection*) _tmp17_);
#line 132 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_id_it = _tmp18_;
#line 132 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 903 "aggregation.c"
			GeeIterator* _tmp19_;
			gboolean _tmp20_ = FALSE;
			GeeIterator* _tmp21_;
			gpointer _tmp22_ = NULL;
			gchar* id;
			GeeHashSet* _tmp23_;
			const gchar* _tmp24_;
			GeeHashSet* _tmp25_;
			const gchar* _tmp26_;
#line 132 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp19_ = _id_it;
#line 132 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp20_ = gee_iterator_next (_tmp19_);
#line 132 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (!_tmp20_) {
#line 132 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				break;
#line 921 "aggregation.c"
			}
#line 132 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp21_ = _id_it;
#line 132 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp22_ = gee_iterator_get (_tmp21_);
#line 132 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			id = (gchar*) _tmp22_;
#line 134 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp23_ = _data1_->expected_individuals;
#line 134 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp24_ = id;
#line 134 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _tmp23_, _tmp24_);
#line 135 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp25_ = _data1_->expected_individuals_detailed;
#line 135 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp26_ = id;
#line 135 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _tmp25_, _tmp26_);
#line 132 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_g_free0 (id);
#line 943 "aggregation.c"
		}
#line 132 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_id_it);
#line 947 "aggregation.c"
	}
#line 139 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp27_ = folks_individual_aggregator_new ();
#line 139 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data1_->aggregator = _tmp27_;
#line 140 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp28_ = _data1_->aggregator;
#line 140 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_signal_connect_data (_tmp28_, "individuals-changed-detailed", (GCallback) ___lambda2__folks_individual_aggregator_individuals_changed_detailed, block1_data_ref (_data1_), (GClosureNotify) block1_data_unref, 0);
#line 148 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp29_ = _data1_->aggregator;
#line 148 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_signal_connect_data (_tmp29_, "individuals-changed", (GCallback) ___lambda3__folks_individual_aggregator_individuals_changed, block1_data_ref (_data1_), (GClosureNotify) block1_data_unref, 0);
#line 157 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp30_ = self->priv->_test_timeout;
#line 157 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) _tmp30_, ___lambda4__gsource_func, block1_data_ref (_data1_), block1_data_unref);
#line 163 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda5__gsource_func, block1_data_ref (_data1_), block1_data_unref);
#line 182 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp31_ = _data1_->main_loop;
#line 182 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_main_loop_run (_tmp31_);
#line 185 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp32_ = _data1_->expected_individuals;
#line 185 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp33_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp32_);
#line 185 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp34_ = _tmp33_;
#line 185 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (_tmp34_ == 0);
#line 186 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp35_ = _data1_->expected_individuals_detailed;
#line 186 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp36_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp35_);
#line 186 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp37_ = _tmp36_;
#line 186 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (_tmp37_ == 0);
#line 189 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp38_ = self->priv->_tp_backend;
#line 189 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp39_ = account2_handle;
#line 189 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	tp_test_backend_remove_account (_tmp38_, _tmp39_);
#line 190 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp40_ = self->priv->_tp_backend;
#line 190 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp41_ = account1_handle;
#line 190 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	tp_test_backend_remove_account (_tmp40_, _tmp41_);
#line 191 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp42_ = self->priv->_kf_backend;
#line 191 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	kf_test_backend_tear_down (_tmp42_);
#line 192 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (_data1_->aggregator);
#line 192 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data1_->aggregator = NULL;
#line 87 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	block1_data_unref (_data1_);
#line 87 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data1_ = NULL;
#line 1011 "aggregation.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 227 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return self ? g_object_ref (self) : NULL;
#line 1018 "aggregation.c"
}


static void _aggregation_tests_test_iid_individuals_changed (AggregationTests* self, gboolean detailed, GeeCollection* added, GeeSet* removed, GeeSet* default_individuals, GeeSet* expected_individuals) {
#line 195 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 195 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (added != NULL);
#line 195 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (removed != NULL);
#line 195 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (default_individuals != NULL);
#line 195 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (expected_individuals != NULL);
#line 1033 "aggregation.c"
	{
		GeeSet* _tmp0_;
		GeeIterator* _tmp1_ = NULL;
		GeeIterator* _i_it;
#line 201 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp0_ = removed;
#line 201 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp1_ = gee_iterable_iterator ((GeeIterable*) _tmp0_);
#line 201 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_i_it = _tmp1_;
#line 201 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 1046 "aggregation.c"
			GeeIterator* _tmp2_;
			gboolean _tmp3_ = FALSE;
			GeeIterator* _tmp4_;
			gpointer _tmp5_ = NULL;
			FolksIndividual* i;
			gboolean _tmp6_ = FALSE;
			FolksIndividual* _tmp7_;
			gboolean _tmp9_;
			FolksIndividual* _tmp10_;
			gboolean _tmp11_ = FALSE;
			gboolean _tmp12_ = FALSE;
			FolksIndividual* _tmp13_;
			gboolean _tmp14_;
			gboolean _tmp15_;
			gboolean _tmp21_;
			gboolean _tmp27_;
#line 201 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp2_ = _i_it;
#line 201 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp3_ = gee_iterator_next (_tmp2_);
#line 201 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (!_tmp3_) {
#line 201 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				break;
#line 1071 "aggregation.c"
			}
#line 201 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp4_ = _i_it;
#line 201 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp5_ = gee_iterator_get (_tmp4_);
#line 201 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp5_;
#line 203 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp7_ = i;
#line 203 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (_tmp7_ != NULL) {
#line 203 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp6_ = TRUE;
#line 1085 "aggregation.c"
			} else {
				gboolean _tmp8_;
#line 203 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp8_ = detailed;
#line 203 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp6_ = _tmp8_ == TRUE;
#line 1092 "aggregation.c"
			}
#line 203 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp9_ = _tmp6_;
#line 203 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			g_assert (_tmp9_);
#line 204 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp10_ = i;
#line 204 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (_tmp10_ == NULL) {
#line 206 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (i);
#line 206 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				continue;
#line 1106 "aggregation.c"
			}
#line 209 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp13_ = i;
#line 209 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp14_ = folks_individual_get_is_user (_tmp13_);
#line 209 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp15_ = _tmp14_;
#line 209 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (!_tmp15_) {
#line 1116 "aggregation.c"
				FolksIndividual* _tmp16_;
				GeeSet* _tmp17_;
				GeeSet* _tmp18_;
				gint _tmp19_;
				gint _tmp20_;
#line 210 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp16_ = i;
#line 210 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp17_ = folks_individual_get_personas (_tmp16_);
#line 210 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp18_ = _tmp17_;
#line 210 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp19_ = gee_collection_get_size ((GeeCollection*) _tmp18_);
#line 210 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp20_ = _tmp19_;
#line 210 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp12_ = _tmp20_ == 2;
#line 1134 "aggregation.c"
			} else {
#line 209 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp12_ = FALSE;
#line 1138 "aggregation.c"
			}
#line 209 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp21_ = _tmp12_;
#line 209 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (_tmp21_) {
#line 1144 "aggregation.c"
				GeeSet* _tmp22_;
				FolksIndividual* _tmp23_;
				const gchar* _tmp24_;
				const gchar* _tmp25_;
				gboolean _tmp26_ = FALSE;
#line 211 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp22_ = default_individuals;
#line 211 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp23_ = i;
#line 211 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp24_ = folks_individual_get_id (_tmp23_);
#line 211 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp25_ = _tmp24_;
#line 211 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp26_ = gee_collection_contains ((GeeCollection*) _tmp22_, _tmp25_);
#line 211 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp11_ = _tmp26_;
#line 1162 "aggregation.c"
			} else {
#line 209 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp11_ = FALSE;
#line 1166 "aggregation.c"
			}
#line 209 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp27_ = _tmp11_;
#line 209 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (_tmp27_) {
#line 1172 "aggregation.c"
				GeeSet* _tmp28_;
				FolksIndividual* _tmp29_;
				const gchar* _tmp30_;
				const gchar* _tmp31_;
#line 213 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp28_ = expected_individuals;
#line 213 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp29_ = i;
#line 213 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp30_ = folks_individual_get_id (_tmp29_);
#line 213 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp31_ = _tmp30_;
#line 213 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				gee_collection_add ((GeeCollection*) _tmp28_, _tmp31_);
#line 1187 "aggregation.c"
			}
#line 201 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 1191 "aggregation.c"
		}
#line 201 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 1195 "aggregation.c"
	}
	{
		GeeCollection* _tmp32_;
		GeeIterator* _tmp33_ = NULL;
		GeeIterator* _i_it;
#line 219 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp32_ = added;
#line 219 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp33_ = gee_iterable_iterator ((GeeIterable*) _tmp32_);
#line 219 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_i_it = _tmp33_;
#line 219 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 1209 "aggregation.c"
			GeeIterator* _tmp34_;
			gboolean _tmp35_ = FALSE;
			GeeIterator* _tmp36_;
			gpointer _tmp37_ = NULL;
			FolksIndividual* i;
			gboolean _tmp38_ = FALSE;
			FolksIndividual* _tmp39_;
			gboolean _tmp41_;
			FolksIndividual* _tmp42_;
			FolksIndividual* _tmp43_;
			GeeSet* _tmp44_;
			GeeSet* _tmp45_;
			GeeSet* _tmp46_;
			GeeSet* personas;
			gboolean _tmp47_ = FALSE;
			FolksIndividual* _tmp48_;
			gboolean _tmp49_;
			gboolean _tmp50_;
			gboolean _tmp54_;
#line 219 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp34_ = _i_it;
#line 219 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp35_ = gee_iterator_next (_tmp34_);
#line 219 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (!_tmp35_) {
#line 219 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				break;
#line 1237 "aggregation.c"
			}
#line 219 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp36_ = _i_it;
#line 219 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp37_ = gee_iterator_get (_tmp36_);
#line 219 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp37_;
#line 221 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp39_ = i;
#line 221 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (_tmp39_ != NULL) {
#line 221 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp38_ = TRUE;
#line 1251 "aggregation.c"
			} else {
				gboolean _tmp40_;
#line 221 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp40_ = detailed;
#line 221 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp38_ = _tmp40_ == TRUE;
#line 1258 "aggregation.c"
			}
#line 221 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp41_ = _tmp38_;
#line 221 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			g_assert (_tmp41_);
#line 222 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp42_ = i;
#line 222 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (_tmp42_ == NULL) {
#line 224 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (i);
#line 224 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				continue;
#line 1272 "aggregation.c"
			}
#line 227 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp43_ = i;
#line 227 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp44_ = folks_individual_get_personas (_tmp43_);
#line 227 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp45_ = _tmp44_;
#line 227 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp46_ = _g_object_ref0 (_tmp45_);
#line 227 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			personas = _tmp46_;
#line 230 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp48_ = i;
#line 230 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp49_ = folks_individual_get_is_user (_tmp48_);
#line 230 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp50_ = _tmp49_;
#line 230 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (!_tmp50_) {
#line 1292 "aggregation.c"
				GeeSet* _tmp51_;
				gint _tmp52_;
				gint _tmp53_;
#line 230 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp51_ = personas;
#line 230 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp52_ = gee_collection_get_size ((GeeCollection*) _tmp51_);
#line 230 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp53_ = _tmp52_;
#line 230 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp47_ = _tmp53_ == 2;
#line 1304 "aggregation.c"
			} else {
#line 230 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp47_ = FALSE;
#line 1308 "aggregation.c"
			}
#line 230 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp54_ = _tmp47_;
#line 230 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (_tmp54_) {
#line 1314 "aggregation.c"
				GeeSet* _tmp55_;
				FolksIndividual* _tmp56_;
				const gchar* _tmp57_;
				const gchar* _tmp58_;
				gboolean _tmp59_ = FALSE;
				gchar* iid;
#line 232 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp55_ = expected_individuals;
#line 232 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp56_ = i;
#line 232 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp57_ = folks_individual_get_id (_tmp56_);
#line 232 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp58_ = _tmp57_;
#line 232 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp59_ = gee_collection_remove ((GeeCollection*) _tmp55_, _tmp58_);
#line 232 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				g_assert (_tmp59_);
#line 234 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				iid = NULL;
#line 1335 "aggregation.c"
				{
					GeeSet* _tmp60_;
					GeeIterator* _tmp61_ = NULL;
					GeeIterator* _persona_it;
#line 235 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp60_ = personas;
#line 235 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp61_ = gee_iterable_iterator ((GeeIterable*) _tmp60_);
#line 235 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_persona_it = _tmp61_;
#line 235 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					while (TRUE) {
#line 1348 "aggregation.c"
						GeeIterator* _tmp62_;
						gboolean _tmp63_ = FALSE;
						GeeIterator* _tmp64_;
						gpointer _tmp65_ = NULL;
						FolksPersona* persona;
						const gchar* _tmp66_;
#line 235 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						_tmp62_ = _persona_it;
#line 235 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						_tmp63_ = gee_iterator_next (_tmp62_);
#line 235 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						if (!_tmp63_) {
#line 235 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
							break;
#line 1363 "aggregation.c"
						}
#line 235 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						_tmp64_ = _persona_it;
#line 235 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						_tmp65_ = gee_iterator_get (_tmp64_);
#line 235 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						persona = (FolksPersona*) _tmp65_;
#line 237 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						_tmp66_ = iid;
#line 237 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						if (_tmp66_ != NULL) {
#line 1375 "aggregation.c"
							FolksPersona* _tmp67_;
							const gchar* _tmp68_;
							const gchar* _tmp69_;
							const gchar* _tmp70_;
#line 239 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
							_tmp67_ = persona;
#line 239 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
							_tmp68_ = folks_persona_get_iid (_tmp67_);
#line 239 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
							_tmp69_ = _tmp68_;
#line 239 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
							_tmp70_ = iid;
#line 239 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
							g_assert (g_strcmp0 (_tmp69_, _tmp70_) == 0);
#line 1390 "aggregation.c"
						} else {
							FolksPersona* _tmp71_;
							const gchar* _tmp72_;
							const gchar* _tmp73_;
							gchar* _tmp74_;
#line 243 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
							_tmp71_ = persona;
#line 243 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
							_tmp72_ = folks_persona_get_iid (_tmp71_);
#line 243 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
							_tmp73_ = _tmp72_;
#line 243 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
							_tmp74_ = g_strdup (_tmp73_);
#line 243 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
							_g_free0 (iid);
#line 243 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
							iid = _tmp74_;
#line 1408 "aggregation.c"
						}
#line 235 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						_g_object_unref0 (persona);
#line 1412 "aggregation.c"
					}
#line 235 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_g_object_unref0 (_persona_it);
#line 1416 "aggregation.c"
				}
#line 230 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_g_free0 (iid);
#line 1420 "aggregation.c"
			}
#line 219 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (personas);
#line 219 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 1426 "aggregation.c"
		}
#line 219 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 1430 "aggregation.c"
	}
}


static Block2Data* block2_data_ref (Block2Data* _data2_) {
#line 256 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_atomic_int_inc (&_data2_->_ref_count_);
#line 256 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return _data2_;
#line 1440 "aggregation.c"
}


static void block2_data_unref (void * _userdata_) {
	Block2Data* _data2_;
	_data2_ = (Block2Data*) _userdata_;
#line 256 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	if (g_atomic_int_dec_and_test (&_data2_->_ref_count_)) {
#line 1449 "aggregation.c"
		AggregationTests * self;
#line 256 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		self = _data2_->self;
#line 256 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data2_->aggregator);
#line 256 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_main_loop_unref0 (_data2_->main_loop);
#line 256 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (self);
#line 256 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_slice_free (Block2Data, _data2_);
#line 1461 "aggregation.c"
	}
}


static void __lambda7_ (Block2Data* _data2_, GeeMultiMap* changes) {
	AggregationTests * self;
	GeeMultiMap* _tmp0_;
	GeeSet* _tmp1_ = NULL;
	GeeSet* removed;
	GeeMultiMap* _tmp2_;
	GeeCollection* _tmp3_ = NULL;
	GeeCollection* added;
#line 279 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data2_->self;
#line 279 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (changes != NULL);
#line 281 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = changes;
#line 281 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = gee_multi_map_get_keys (_tmp0_);
#line 281 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	removed = _tmp1_;
#line 282 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = changes;
#line 282 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = gee_multi_map_get_values (_tmp2_);
#line 282 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	added = _tmp3_;
#line 284 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_aggregation_tests_test_linkable_properties_individuals_changed (self, TRUE, (guint) 5, added, removed, &_data2_->individual1_detailed, &_data2_->individual2_detailed);
#line 279 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (added);
#line 279 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (removed);
#line 1496 "aggregation.c"
}


static void ___lambda7__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 279 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	__lambda7_ (self, changes);
#line 1503 "aggregation.c"
}


static void __lambda8_ (Block2Data* _data2_, GeeSet* added, GeeSet* removed, const gchar* m, FolksPersona* a, FolksGroupDetailsChangeReason r) {
	AggregationTests * self;
	GeeSet* _tmp0_;
	GeeSet* _tmp1_;
#line 287 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data2_->self;
#line 287 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (added != NULL);
#line 287 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (removed != NULL);
#line 289 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = added;
#line 289 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = removed;
#line 289 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_aggregation_tests_test_linkable_properties_individuals_changed (self, FALSE, (guint) 5, (GeeCollection*) _tmp0_, _tmp1_, &_data2_->individual1, &_data2_->individual2);
#line 1523 "aggregation.c"
}


static void ___lambda8__folks_individual_aggregator_individuals_changed (FolksIndividualAggregator* _sender, GeeSet* added, GeeSet* removed, const gchar* message, FolksPersona* actor, FolksGroupDetailsChangeReason reason, gpointer self) {
#line 287 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	__lambda8_ (self, added, removed, message, actor, reason);
#line 1530 "aggregation.c"
}


static gboolean __lambda9_ (Block2Data* _data2_) {
	AggregationTests * self;
	gboolean result = FALSE;
	GMainLoop* _tmp0_;
#line 296 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data2_->self;
#line 298 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data2_->main_loop;
#line 298 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_main_loop_quit (_tmp0_);
#line 299 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 299 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 1548 "aggregation.c"
}


static gboolean ___lambda9__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda9_ (self);
#line 296 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 1557 "aggregation.c"
}


static void __lambda11_ (Block2Data* _data2_, GObject* s, GAsyncResult* r) {
	AggregationTests * self;
	GError * _inner_error_ = NULL;
#line 304 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data2_->self;
#line 304 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (r != NULL);
#line 1568 "aggregation.c"
	{
		FolksIndividualAggregator* _tmp0_;
		GAsyncResult* _tmp1_;
#line 308 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp0_ = _data2_->aggregator;
#line 308 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp1_ = r;
#line 308 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		folks_individual_aggregator_prepare_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 308 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		if (_inner_error_ != NULL) {
#line 1580 "aggregation.c"
			goto __catch1_g_error;
		}
	}
	goto __finally1;
	__catch1_g_error:
	{
		GError* e1 = NULL;
		const gchar* _tmp2_;
#line 306 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		e1 = _inner_error_;
#line 306 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_inner_error_ = NULL;
#line 312 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp2_ = e1->message;
#line 312 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_critical ("aggregation.vala:312: Failed to prepare aggregator: %s", _tmp2_);
#line 314 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_assert_not_reached ();
#line 306 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_error_free0 (e1);
#line 1601 "aggregation.c"
	}
	__finally1:
#line 306 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	if (_inner_error_ != NULL) {
#line 306 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 306 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 306 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		return;
#line 1612 "aggregation.c"
	}
}


static void ___lambda11__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 304 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	__lambda11_ (self, source_object, res);
#line 304 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	block2_data_unref (self);
#line 1622 "aggregation.c"
}


static gboolean __lambda10_ (Block2Data* _data2_) {
	AggregationTests * self;
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_;
#line 302 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data2_->self;
#line 304 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data2_->aggregator;
#line 304 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	folks_individual_aggregator_prepare (_tmp0_, ___lambda11__gasync_ready_callback, block2_data_ref (_data2_));
#line 318 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 318 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 1640 "aggregation.c"
}


static gboolean ___lambda10__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda10_ (self);
#line 302 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 1649 "aggregation.c"
}


void aggregation_tests_test_linkable_properties_same_store (AggregationTests* self) {
	Block2Data* _data2_;
	GMainLoop* _tmp0_;
	KfTestBackend* _tmp1_;
	TpTestBackend* _tmp2_;
	void* _tmp3_ = NULL;
	void* account_handle;
	FolksIndividualAggregator* _tmp4_;
	FolksIndividualAggregator* _tmp5_;
	FolksIndividualAggregator* _tmp6_;
	gint _tmp7_;
	GMainLoop* _tmp8_;
	FolksIndividual* _tmp9_;
	FolksIndividual* _tmp10_;
	FolksIndividual* _tmp11_;
	FolksIndividual* _tmp12_;
	GeeHashSet* _tmp13_;
	GeeHashSet* individual1_expected;
	GeeHashSet* _tmp14_;
	GeeHashSet* _tmp15_;
	GeeHashSet* _tmp16_;
	GeeHashSet* _tmp17_;
	GeeHashSet* _tmp18_;
	GeeHashSet* _tmp19_;
	GeeHashSet* individual2_expected;
	GeeHashSet* _tmp20_;
	GeeHashSet* _tmp21_;
	GeeHashSet* _tmp22_;
	GeeHashSet* _tmp23_;
	GeeHashSet* _tmp24_;
	GeeHashSet* set_in_use;
	GeeHashSet* _tmp66_;
	gint _tmp67_;
	gint _tmp68_;
	GeeHashSet* _tmp69_;
	GeeHashSet* _tmp70_;
	GeeHashSet* _tmp103_;
	gint _tmp104_;
	gint _tmp105_;
	TpTestBackend* _tmp106_;
	void* _tmp107_;
	KfTestBackend* _tmp108_;
#line 256 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 256 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data2_ = g_slice_new0 (Block2Data);
#line 256 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data2_->_ref_count_ = 1;
#line 256 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data2_->self = g_object_ref (self);
#line 258 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 258 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data2_->main_loop = _tmp0_;
#line 260 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = self->priv->_kf_backend;
#line 260 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	kf_test_backend_set_up (_tmp1_, "[0]\n" "protocol=travis@example.com;olivier@example.com;" "guillaume@example.com;sjoerd@example.com\n" "[1]\n" "protocol=christian@example.com;wim@example.com;" "helen@example.com;geraldine@example.com");
#line 267 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = self->priv->_tp_backend;
#line 267 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = tp_test_backend_add_account (_tmp2_, "protocol", "me@example.com", "cm", "account");
#line 267 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	account_handle = _tmp3_;
#line 272 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data2_->individual1 = NULL;
#line 273 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data2_->individual1_detailed = NULL;
#line 274 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data2_->individual2 = NULL;
#line 275 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data2_->individual2_detailed = NULL;
#line 278 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp4_ = folks_individual_aggregator_new ();
#line 278 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data2_->aggregator = _tmp4_;
#line 279 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp5_ = _data2_->aggregator;
#line 279 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_signal_connect_data (_tmp5_, "individuals-changed-detailed", (GCallback) ___lambda7__folks_individual_aggregator_individuals_changed_detailed, block2_data_ref (_data2_), (GClosureNotify) block2_data_unref, 0);
#line 287 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp6_ = _data2_->aggregator;
#line 287 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_signal_connect_data (_tmp6_, "individuals-changed", (GCallback) ___lambda8__folks_individual_aggregator_individuals_changed, block2_data_ref (_data2_), (GClosureNotify) block2_data_unref, 0);
#line 296 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp7_ = self->priv->_test_timeout;
#line 296 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) _tmp7_, ___lambda9__gsource_func, block2_data_ref (_data2_), block2_data_unref);
#line 302 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda10__gsource_func, block2_data_ref (_data2_), block2_data_unref);
#line 321 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp8_ = _data2_->main_loop;
#line 321 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_main_loop_run (_tmp8_);
#line 324 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp9_ = _data2_->individual1;
#line 324 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (_tmp9_ != NULL);
#line 325 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp10_ = _data2_->individual1_detailed;
#line 325 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (_tmp10_ != NULL);
#line 326 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp11_ = _data2_->individual2;
#line 326 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (_tmp11_ != NULL);
#line 327 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp12_ = _data2_->individual2_detailed;
#line 327 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (_tmp12_ != NULL);
#line 329 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp13_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL);
#line 329 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	individual1_expected = _tmp13_;
#line 330 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp14_ = individual1_expected;
#line 330 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp14_, "0");
#line 331 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp15_ = individual1_expected;
#line 331 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp15_, "travis@example.com");
#line 332 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp16_ = individual1_expected;
#line 332 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp16_, "olivier@example.com");
#line 333 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp17_ = individual1_expected;
#line 333 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp17_, "guillaume@example.com");
#line 334 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp18_ = individual1_expected;
#line 334 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp18_, "sjoerd@example.com");
#line 336 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp19_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL);
#line 336 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	individual2_expected = _tmp19_;
#line 337 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp20_ = individual2_expected;
#line 337 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp20_, "1");
#line 338 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp21_ = individual2_expected;
#line 338 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp21_, "christian@example.com");
#line 339 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp22_ = individual2_expected;
#line 339 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp22_, "wim@example.com");
#line 340 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp23_ = individual2_expected;
#line 340 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp23_, "helen@example.com");
#line 341 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp24_ = individual2_expected;
#line 341 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp24_, "geraldine@example.com");
#line 343 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	set_in_use = NULL;
#line 1813 "aggregation.c"
	{
		FolksIndividual* _tmp25_;
		GeeSet* _tmp26_;
		GeeSet* _tmp27_;
		GeeIterator* _tmp28_ = NULL;
		GeeIterator* _p_it;
#line 344 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp25_ = _data2_->individual1;
#line 344 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp26_ = folks_individual_get_personas (_tmp25_);
#line 344 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp27_ = _tmp26_;
#line 344 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp28_ = gee_iterable_iterator ((GeeIterable*) _tmp27_);
#line 344 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_p_it = _tmp28_;
#line 344 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 1832 "aggregation.c"
			GeeIterator* _tmp29_;
			gboolean _tmp30_ = FALSE;
			GeeIterator* _tmp31_;
			gpointer _tmp32_ = NULL;
			FolksPersona* p;
			gboolean _tmp33_ = FALSE;
			GeeHashSet* _tmp34_;
			gboolean _tmp40_;
			GeeHashSet* _tmp46_;
			FolksPersona* _tmp47_;
			const gchar* _tmp48_;
			const gchar* _tmp49_;
			gboolean _tmp50_ = FALSE;
			gboolean found_detailed;
			gboolean _tmp65_;
#line 344 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp29_ = _p_it;
#line 344 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp30_ = gee_iterator_next (_tmp29_);
#line 344 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (!_tmp30_) {
#line 344 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				break;
#line 1856 "aggregation.c"
			}
#line 344 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp31_ = _p_it;
#line 344 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp32_ = gee_iterator_get (_tmp31_);
#line 344 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			p = (FolksPersona*) _tmp32_;
#line 347 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp34_ = set_in_use;
#line 347 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (_tmp34_ == NULL) {
#line 1868 "aggregation.c"
				GeeHashSet* _tmp35_;
				FolksPersona* _tmp36_;
				const gchar* _tmp37_;
				const gchar* _tmp38_;
				gboolean _tmp39_ = FALSE;
#line 348 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp35_ = individual1_expected;
#line 348 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp36_ = p;
#line 348 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp37_ = folks_persona_get_display_id (_tmp36_);
#line 348 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp38_ = _tmp37_;
#line 348 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp39_ = gee_abstract_collection_contains ((GeeAbstractCollection*) _tmp35_, _tmp38_);
#line 348 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp33_ = _tmp39_;
#line 1886 "aggregation.c"
			} else {
#line 347 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp33_ = FALSE;
#line 1890 "aggregation.c"
			}
#line 347 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp40_ = _tmp33_;
#line 347 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (_tmp40_) {
#line 1896 "aggregation.c"
				GeeHashSet* _tmp41_;
				GeeHashSet* _tmp42_;
#line 350 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp41_ = individual1_expected;
#line 350 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp42_ = _g_object_ref0 (_tmp41_);
#line 350 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (set_in_use);
#line 350 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				set_in_use = _tmp42_;
#line 1907 "aggregation.c"
			} else {
				GeeHashSet* _tmp43_;
#line 352 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp43_ = set_in_use;
#line 352 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				if (_tmp43_ == NULL) {
#line 1914 "aggregation.c"
					GeeHashSet* _tmp44_;
					GeeHashSet* _tmp45_;
#line 354 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp44_ = individual2_expected;
#line 354 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp45_ = _g_object_ref0 (_tmp44_);
#line 354 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_g_object_unref0 (set_in_use);
#line 354 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					set_in_use = _tmp45_;
#line 1925 "aggregation.c"
				}
			}
#line 357 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp46_ = set_in_use;
#line 357 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp47_ = p;
#line 357 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp48_ = folks_persona_get_display_id (_tmp47_);
#line 357 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp49_ = _tmp48_;
#line 357 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp50_ = gee_abstract_collection_remove ((GeeAbstractCollection*) _tmp46_, _tmp49_);
#line 357 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			g_assert (_tmp50_);
#line 359 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			found_detailed = FALSE;
#line 1942 "aggregation.c"
			{
				FolksIndividual* _tmp51_;
				GeeSet* _tmp52_;
				GeeSet* _tmp53_;
				GeeIterator* _tmp54_ = NULL;
				GeeIterator* _pd_it;
#line 360 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp51_ = _data2_->individual1_detailed;
#line 360 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp52_ = folks_individual_get_personas (_tmp51_);
#line 360 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp53_ = _tmp52_;
#line 360 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp54_ = gee_iterable_iterator ((GeeIterable*) _tmp53_);
#line 360 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_pd_it = _tmp54_;
#line 360 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				while (TRUE) {
#line 1961 "aggregation.c"
					GeeIterator* _tmp55_;
					gboolean _tmp56_ = FALSE;
					GeeIterator* _tmp57_;
					gpointer _tmp58_ = NULL;
					FolksPersona* pd;
					FolksPersona* _tmp59_;
					const gchar* _tmp60_;
					const gchar* _tmp61_;
					FolksPersona* _tmp62_;
					const gchar* _tmp63_;
					const gchar* _tmp64_;
#line 360 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp55_ = _pd_it;
#line 360 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp56_ = gee_iterator_next (_tmp55_);
#line 360 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					if (!_tmp56_) {
#line 360 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						break;
#line 1981 "aggregation.c"
					}
#line 360 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp57_ = _pd_it;
#line 360 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp58_ = gee_iterator_get (_tmp57_);
#line 360 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					pd = (FolksPersona*) _tmp58_;
#line 362 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp59_ = pd;
#line 362 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp60_ = folks_persona_get_uid (_tmp59_);
#line 362 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp61_ = _tmp60_;
#line 362 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp62_ = p;
#line 362 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp63_ = folks_persona_get_uid (_tmp62_);
#line 362 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp64_ = _tmp63_;
#line 362 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					if (g_strcmp0 (_tmp61_, _tmp64_) == 0) {
#line 364 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						found_detailed = TRUE;
#line 2005 "aggregation.c"
					}
#line 360 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_g_object_unref0 (pd);
#line 2009 "aggregation.c"
				}
#line 360 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (_pd_it);
#line 2013 "aggregation.c"
			}
#line 367 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp65_ = found_detailed;
#line 367 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			g_assert (_tmp65_ == TRUE);
#line 344 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (p);
#line 2021 "aggregation.c"
		}
#line 344 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_p_it);
#line 2025 "aggregation.c"
	}
#line 370 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp66_ = set_in_use;
#line 370 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp67_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp66_);
#line 370 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp68_ = _tmp67_;
#line 370 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (_tmp68_ == 0);
#line 372 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp69_ = set_in_use;
#line 372 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp70_ = individual1_expected;
#line 372 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	if (_tmp69_ == _tmp70_) {
#line 2041 "aggregation.c"
		GeeHashSet* _tmp71_;
		GeeHashSet* _tmp72_;
#line 374 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp71_ = individual2_expected;
#line 374 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp72_ = _g_object_ref0 (_tmp71_);
#line 374 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (set_in_use);
#line 374 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		set_in_use = _tmp72_;
#line 2052 "aggregation.c"
	} else {
		GeeHashSet* _tmp73_;
		GeeHashSet* _tmp74_;
#line 378 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp73_ = individual1_expected;
#line 378 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp74_ = _g_object_ref0 (_tmp73_);
#line 378 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (set_in_use);
#line 378 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		set_in_use = _tmp74_;
#line 2064 "aggregation.c"
	}
	{
		FolksIndividual* _tmp75_;
		GeeSet* _tmp76_;
		GeeSet* _tmp77_;
		GeeIterator* _tmp78_ = NULL;
		GeeIterator* _p_it;
#line 381 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp75_ = _data2_->individual2;
#line 381 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp76_ = folks_individual_get_personas (_tmp75_);
#line 381 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp77_ = _tmp76_;
#line 381 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp78_ = gee_iterable_iterator ((GeeIterable*) _tmp77_);
#line 381 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_p_it = _tmp78_;
#line 381 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 2084 "aggregation.c"
			GeeIterator* _tmp79_;
			gboolean _tmp80_ = FALSE;
			GeeIterator* _tmp81_;
			gpointer _tmp82_ = NULL;
			FolksPersona* p;
			GeeHashSet* _tmp83_;
			FolksPersona* _tmp84_;
			const gchar* _tmp85_;
			const gchar* _tmp86_;
			gboolean _tmp87_ = FALSE;
			gboolean found_detailed;
			gboolean _tmp102_;
#line 381 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp79_ = _p_it;
#line 381 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp80_ = gee_iterator_next (_tmp79_);
#line 381 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (!_tmp80_) {
#line 381 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				break;
#line 2105 "aggregation.c"
			}
#line 381 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp81_ = _p_it;
#line 381 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp82_ = gee_iterator_get (_tmp81_);
#line 381 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			p = (FolksPersona*) _tmp82_;
#line 383 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp83_ = set_in_use;
#line 383 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp84_ = p;
#line 383 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp85_ = folks_persona_get_display_id (_tmp84_);
#line 383 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp86_ = _tmp85_;
#line 383 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp87_ = gee_abstract_collection_remove ((GeeAbstractCollection*) _tmp83_, _tmp86_);
#line 383 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			g_assert (_tmp87_);
#line 385 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			found_detailed = FALSE;
#line 2127 "aggregation.c"
			{
				FolksIndividual* _tmp88_;
				GeeSet* _tmp89_;
				GeeSet* _tmp90_;
				GeeIterator* _tmp91_ = NULL;
				GeeIterator* _pd_it;
#line 386 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp88_ = _data2_->individual2_detailed;
#line 386 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp89_ = folks_individual_get_personas (_tmp88_);
#line 386 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp90_ = _tmp89_;
#line 386 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp91_ = gee_iterable_iterator ((GeeIterable*) _tmp90_);
#line 386 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_pd_it = _tmp91_;
#line 386 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				while (TRUE) {
#line 2146 "aggregation.c"
					GeeIterator* _tmp92_;
					gboolean _tmp93_ = FALSE;
					GeeIterator* _tmp94_;
					gpointer _tmp95_ = NULL;
					FolksPersona* pd;
					FolksPersona* _tmp96_;
					const gchar* _tmp97_;
					const gchar* _tmp98_;
					FolksPersona* _tmp99_;
					const gchar* _tmp100_;
					const gchar* _tmp101_;
#line 386 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp92_ = _pd_it;
#line 386 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp93_ = gee_iterator_next (_tmp92_);
#line 386 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					if (!_tmp93_) {
#line 386 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						break;
#line 2166 "aggregation.c"
					}
#line 386 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp94_ = _pd_it;
#line 386 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp95_ = gee_iterator_get (_tmp94_);
#line 386 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					pd = (FolksPersona*) _tmp95_;
#line 388 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp96_ = pd;
#line 388 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp97_ = folks_persona_get_uid (_tmp96_);
#line 388 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp98_ = _tmp97_;
#line 388 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp99_ = p;
#line 388 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp100_ = folks_persona_get_uid (_tmp99_);
#line 388 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp101_ = _tmp100_;
#line 388 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					if (g_strcmp0 (_tmp98_, _tmp101_) == 0) {
#line 390 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						found_detailed = TRUE;
#line 2190 "aggregation.c"
					}
#line 386 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_g_object_unref0 (pd);
#line 2194 "aggregation.c"
				}
#line 386 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (_pd_it);
#line 2198 "aggregation.c"
			}
#line 393 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp102_ = found_detailed;
#line 393 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			g_assert (_tmp102_ == TRUE);
#line 381 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (p);
#line 2206 "aggregation.c"
		}
#line 381 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_p_it);
#line 2210 "aggregation.c"
	}
#line 396 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp103_ = set_in_use;
#line 396 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp104_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp103_);
#line 396 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp105_ = _tmp104_;
#line 396 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (_tmp105_ == 0);
#line 399 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp106_ = self->priv->_tp_backend;
#line 399 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp107_ = account_handle;
#line 399 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	tp_test_backend_remove_account (_tmp106_, _tmp107_);
#line 400 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp108_ = self->priv->_kf_backend;
#line 400 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	kf_test_backend_tear_down (_tmp108_);
#line 401 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (_data2_->aggregator);
#line 401 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data2_->aggregator = NULL;
#line 256 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (set_in_use);
#line 256 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (individual2_expected);
#line 256 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (individual1_expected);
#line 256 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	block2_data_unref (_data2_);
#line 256 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data2_ = NULL;
#line 2244 "aggregation.c"
}


static Block3Data* block3_data_ref (Block3Data* _data3_) {
#line 411 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_atomic_int_inc (&_data3_->_ref_count_);
#line 411 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return _data3_;
#line 2253 "aggregation.c"
}


static void block3_data_unref (void * _userdata_) {
	Block3Data* _data3_;
	_data3_ = (Block3Data*) _userdata_;
#line 411 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	if (g_atomic_int_dec_and_test (&_data3_->_ref_count_)) {
#line 2262 "aggregation.c"
		AggregationTests * self;
#line 411 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		self = _data3_->self;
#line 411 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data3_->aggregator);
#line 411 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_main_loop_unref0 (_data3_->main_loop);
#line 411 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (self);
#line 411 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_slice_free (Block3Data, _data3_);
#line 2274 "aggregation.c"
	}
}


static void __lambda12_ (Block3Data* _data3_, GeeMultiMap* changes) {
	AggregationTests * self;
	GeeMultiMap* _tmp0_;
	GeeSet* _tmp1_ = NULL;
	GeeSet* removed;
	GeeMultiMap* _tmp2_;
	GeeCollection* _tmp3_ = NULL;
	GeeCollection* added;
#line 440 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data3_->self;
#line 440 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (changes != NULL);
#line 442 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = changes;
#line 442 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = gee_multi_map_get_keys (_tmp0_);
#line 442 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	removed = _tmp1_;
#line 443 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = changes;
#line 443 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = gee_multi_map_get_values (_tmp2_);
#line 443 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	added = _tmp3_;
#line 445 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_aggregation_tests_test_linkable_properties_individuals_changed (self, TRUE, (guint) 9, added, removed, &_data3_->individual1_detailed, &_data3_->individual2_detailed);
#line 440 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (added);
#line 440 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (removed);
#line 2309 "aggregation.c"
}


static void ___lambda12__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 440 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	__lambda12_ (self, changes);
#line 2316 "aggregation.c"
}


static void __lambda13_ (Block3Data* _data3_, GeeSet* added, GeeSet* removed, const gchar* m, FolksPersona* a, FolksGroupDetailsChangeReason r) {
	AggregationTests * self;
	GeeSet* _tmp0_;
	GeeSet* _tmp1_;
#line 448 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data3_->self;
#line 448 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (added != NULL);
#line 448 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (removed != NULL);
#line 450 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = added;
#line 450 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = removed;
#line 450 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_aggregation_tests_test_linkable_properties_individuals_changed (self, FALSE, (guint) 9, (GeeCollection*) _tmp0_, _tmp1_, &_data3_->individual1, &_data3_->individual2);
#line 2336 "aggregation.c"
}


static void ___lambda13__folks_individual_aggregator_individuals_changed (FolksIndividualAggregator* _sender, GeeSet* added, GeeSet* removed, const gchar* message, FolksPersona* actor, FolksGroupDetailsChangeReason reason, gpointer self) {
#line 448 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	__lambda13_ (self, added, removed, message, actor, reason);
#line 2343 "aggregation.c"
}


static gboolean __lambda14_ (Block3Data* _data3_) {
	AggregationTests * self;
	gboolean result = FALSE;
	GMainLoop* _tmp0_;
#line 457 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data3_->self;
#line 459 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data3_->main_loop;
#line 459 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_main_loop_quit (_tmp0_);
#line 460 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 460 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 2361 "aggregation.c"
}


static gboolean ___lambda14__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda14_ (self);
#line 457 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 2370 "aggregation.c"
}


static void __lambda16_ (Block3Data* _data3_, GObject* s, GAsyncResult* r) {
	AggregationTests * self;
	GError * _inner_error_ = NULL;
#line 465 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data3_->self;
#line 465 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (r != NULL);
#line 2381 "aggregation.c"
	{
		FolksIndividualAggregator* _tmp0_;
		GAsyncResult* _tmp1_;
#line 469 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp0_ = _data3_->aggregator;
#line 469 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp1_ = r;
#line 469 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		folks_individual_aggregator_prepare_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 469 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		if (_inner_error_ != NULL) {
#line 2393 "aggregation.c"
			goto __catch2_g_error;
		}
	}
	goto __finally2;
	__catch2_g_error:
	{
		GError* e1 = NULL;
		const gchar* _tmp2_;
#line 467 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		e1 = _inner_error_;
#line 467 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_inner_error_ = NULL;
#line 473 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp2_ = e1->message;
#line 473 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_critical ("aggregation.vala:473: Failed to prepare aggregator: %s", _tmp2_);
#line 475 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_assert_not_reached ();
#line 467 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_error_free0 (e1);
#line 2414 "aggregation.c"
	}
	__finally2:
#line 467 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	if (_inner_error_ != NULL) {
#line 467 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 467 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 467 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		return;
#line 2425 "aggregation.c"
	}
}


static void ___lambda16__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 465 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	__lambda16_ (self, source_object, res);
#line 465 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	block3_data_unref (self);
#line 2435 "aggregation.c"
}


static gboolean __lambda15_ (Block3Data* _data3_) {
	AggregationTests * self;
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_;
#line 463 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data3_->self;
#line 465 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data3_->aggregator;
#line 465 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	folks_individual_aggregator_prepare (_tmp0_, ___lambda16__gasync_ready_callback, block3_data_ref (_data3_));
#line 479 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 479 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 2453 "aggregation.c"
}


static gboolean ___lambda15__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda15_ (self);
#line 463 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 2462 "aggregation.c"
}


void aggregation_tests_test_linkable_properties_different_stores (AggregationTests* self) {
	Block3Data* _data3_;
	GMainLoop* _tmp0_;
	KfTestBackend* _tmp1_;
	TpTestBackend* _tmp2_;
	void* _tmp3_ = NULL;
	void* account1_handle;
	TpTestBackend* _tmp4_;
	void* _tmp5_ = NULL;
	void* account2_handle;
	FolksIndividualAggregator* _tmp6_;
	FolksIndividualAggregator* _tmp7_;
	FolksIndividualAggregator* _tmp8_;
	gint _tmp9_;
	GMainLoop* _tmp10_;
	FolksIndividual* _tmp11_;
	FolksIndividual* _tmp12_;
	FolksIndividual* _tmp13_;
	FolksIndividual* _tmp14_;
	GeeHashSet* _tmp15_;
	GeeHashSet* expected_personas1;
	GeeHashSet* _tmp16_;
	GeeHashSet* expected_personas1_detailed;
	GeeHashSet* _tmp17_;
	GeeHashSet* expected_personas2;
	GeeHashSet* _tmp18_;
	GeeHashSet* expected_personas2_detailed;
	GeeHashSet* _tmp56_;
	gint _tmp57_;
	gint _tmp58_;
	GeeHashSet* _tmp82_;
	gint _tmp83_;
	gint _tmp84_;
	GeeHashSet* _tmp108_;
	gint _tmp109_;
	gint _tmp110_;
	GeeHashSet* _tmp134_;
	gint _tmp135_;
	gint _tmp136_;
	TpTestBackend* _tmp137_;
	void* _tmp138_;
	TpTestBackend* _tmp139_;
	void* _tmp140_;
	KfTestBackend* _tmp141_;
#line 411 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 411 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data3_ = g_slice_new0 (Block3Data);
#line 411 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data3_->_ref_count_ = 1;
#line 411 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data3_->self = g_object_ref (self);
#line 413 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 413 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data3_->main_loop = _tmp0_;
#line 415 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = self->priv->_kf_backend;
#line 415 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	kf_test_backend_set_up (_tmp1_, "[0]\n" "protocol=travis@example.com;olivier@example.com;" "guillaume@example.com;sjoerd@example.com\n" "protocol2=christian@example.com;wim@example.com;" "helen@example.com;geraldine@example.com\n" "[1]\n" "protocol=christian@example.com;wim@example.com;" "helen@example.com;geraldine@example.com\n" "protocol2=travis@example.com;olivier@example.com;" "guillaume@example.com;sjoerd@example.com");
#line 426 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = self->priv->_tp_backend;
#line 426 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = tp_test_backend_add_account (_tmp2_, "protocol", "me@example.com", "cm", "account");
#line 426 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	account1_handle = _tmp3_;
#line 428 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp4_ = self->priv->_tp_backend;
#line 428 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp5_ = tp_test_backend_add_account (_tmp4_, "protocol2", "me@example.com", "cm", "account2");
#line 428 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	account2_handle = _tmp5_;
#line 433 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data3_->individual1 = NULL;
#line 434 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data3_->individual1_detailed = NULL;
#line 435 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data3_->individual2 = NULL;
#line 436 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data3_->individual2_detailed = NULL;
#line 439 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp6_ = folks_individual_aggregator_new ();
#line 439 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data3_->aggregator = _tmp6_;
#line 440 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp7_ = _data3_->aggregator;
#line 440 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_signal_connect_data (_tmp7_, "individuals-changed-detailed", (GCallback) ___lambda12__folks_individual_aggregator_individuals_changed_detailed, block3_data_ref (_data3_), (GClosureNotify) block3_data_unref, 0);
#line 448 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp8_ = _data3_->aggregator;
#line 448 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_signal_connect_data (_tmp8_, "individuals-changed", (GCallback) ___lambda13__folks_individual_aggregator_individuals_changed, block3_data_ref (_data3_), (GClosureNotify) block3_data_unref, 0);
#line 457 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp9_ = self->priv->_test_timeout;
#line 457 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) _tmp9_, ___lambda14__gsource_func, block3_data_ref (_data3_), block3_data_unref);
#line 463 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda15__gsource_func, block3_data_ref (_data3_), block3_data_unref);
#line 482 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp10_ = _data3_->main_loop;
#line 482 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_main_loop_run (_tmp10_);
#line 485 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp11_ = _data3_->individual1;
#line 485 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (_tmp11_ != NULL);
#line 486 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp12_ = _data3_->individual1_detailed;
#line 486 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (_tmp12_ != NULL);
#line 487 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp13_ = _data3_->individual2;
#line 487 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (_tmp13_ != NULL);
#line 488 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp14_ = _data3_->individual2_detailed;
#line 488 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (_tmp14_ != NULL);
#line 494 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp15_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL);
#line 494 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	expected_personas1 = _tmp15_;
#line 495 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp16_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL);
#line 495 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	expected_personas1_detailed = _tmp16_;
#line 496 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp17_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL);
#line 496 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	expected_personas2 = _tmp17_;
#line 497 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp18_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL);
#line 497 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	expected_personas2_detailed = _tmp18_;
#line 2600 "aggregation.c"
	{
		GeeHashSet* _tmp19_;
		GeeIterator* _tmp20_ = NULL;
		GeeIterator* _id_it;
#line 498 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp19_ = self->priv->_default_personas;
#line 498 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp20_ = gee_abstract_collection_iterator ((GeeAbstractCollection*) _tmp19_);
#line 498 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_id_it = _tmp20_;
#line 498 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 2613 "aggregation.c"
			GeeIterator* _tmp21_;
			gboolean _tmp22_ = FALSE;
			GeeIterator* _tmp23_;
			gpointer _tmp24_ = NULL;
			gchar* id;
			GeeHashSet* _tmp25_;
			const gchar* _tmp26_;
			GeeHashSet* _tmp27_;
			const gchar* _tmp28_;
			GeeHashSet* _tmp29_;
			const gchar* _tmp30_;
			GeeHashSet* _tmp31_;
			const gchar* _tmp32_;
#line 498 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp21_ = _id_it;
#line 498 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp22_ = gee_iterator_next (_tmp21_);
#line 498 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (!_tmp22_) {
#line 498 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				break;
#line 2635 "aggregation.c"
			}
#line 498 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp23_ = _id_it;
#line 498 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp24_ = gee_iterator_get (_tmp23_);
#line 498 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			id = (gchar*) _tmp24_;
#line 500 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp25_ = expected_personas1;
#line 500 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp26_ = id;
#line 500 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _tmp25_, _tmp26_);
#line 501 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp27_ = expected_personas1_detailed;
#line 501 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp28_ = id;
#line 501 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _tmp27_, _tmp28_);
#line 502 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp29_ = expected_personas2;
#line 502 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp30_ = id;
#line 502 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _tmp29_, _tmp30_);
#line 503 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp31_ = expected_personas2_detailed;
#line 503 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp32_ = id;
#line 503 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _tmp31_, _tmp32_);
#line 498 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_g_free0 (id);
#line 2669 "aggregation.c"
		}
#line 498 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_id_it);
#line 2673 "aggregation.c"
	}
	{
		FolksIndividual* _tmp33_;
		GeeSet* _tmp34_;
		GeeSet* _tmp35_;
		GeeIterator* _tmp36_ = NULL;
		GeeIterator* _p_it;
#line 506 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp33_ = _data3_->individual1;
#line 506 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp34_ = folks_individual_get_personas (_tmp33_);
#line 506 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp35_ = _tmp34_;
#line 506 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp36_ = gee_iterable_iterator ((GeeIterable*) _tmp35_);
#line 506 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_p_it = _tmp36_;
#line 506 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 2693 "aggregation.c"
			GeeIterator* _tmp37_;
			gboolean _tmp38_ = FALSE;
			GeeIterator* _tmp39_;
			gpointer _tmp40_ = NULL;
			FolksPersona* p;
			gboolean _tmp41_ = FALSE;
			gboolean _tmp42_ = FALSE;
			GeeHashSet* _tmp43_;
			FolksPersona* _tmp44_;
			const gchar* _tmp45_;
			const gchar* _tmp46_;
			gboolean _tmp47_ = FALSE;
			gboolean _tmp51_;
			gboolean _tmp55_;
#line 506 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp37_ = _p_it;
#line 506 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp38_ = gee_iterator_next (_tmp37_);
#line 506 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (!_tmp38_) {
#line 506 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				break;
#line 2716 "aggregation.c"
			}
#line 506 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp39_ = _p_it;
#line 506 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp40_ = gee_iterator_get (_tmp39_);
#line 506 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			p = (FolksPersona*) _tmp40_;
#line 508 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp43_ = expected_personas1;
#line 508 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp44_ = p;
#line 508 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp45_ = folks_persona_get_display_id (_tmp44_);
#line 508 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp46_ = _tmp45_;
#line 508 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp47_ = gee_abstract_collection_remove ((GeeAbstractCollection*) _tmp43_, _tmp46_);
#line 508 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (_tmp47_) {
#line 508 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp42_ = TRUE;
#line 2738 "aggregation.c"
			} else {
				FolksPersona* _tmp48_;
				const gchar* _tmp49_;
				const gchar* _tmp50_;
#line 509 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp48_ = p;
#line 509 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp49_ = folks_persona_get_display_id (_tmp48_);
#line 509 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp50_ = _tmp49_;
#line 509 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp42_ = g_strcmp0 (_tmp50_, "0") == 0;
#line 2751 "aggregation.c"
			}
#line 508 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp51_ = _tmp42_;
#line 508 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (_tmp51_) {
#line 508 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp41_ = TRUE;
#line 2759 "aggregation.c"
			} else {
				FolksPersona* _tmp52_;
				const gchar* _tmp53_;
				const gchar* _tmp54_;
#line 509 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp52_ = p;
#line 509 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp53_ = folks_persona_get_display_id (_tmp52_);
#line 509 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp54_ = _tmp53_;
#line 509 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp41_ = g_strcmp0 (_tmp54_, "1") == 0;
#line 2772 "aggregation.c"
			}
#line 508 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp55_ = _tmp41_;
#line 508 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			g_assert (_tmp55_);
#line 506 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (p);
#line 2780 "aggregation.c"
		}
#line 506 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_p_it);
#line 2784 "aggregation.c"
	}
#line 512 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp56_ = expected_personas1;
#line 512 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp57_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp56_);
#line 512 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp58_ = _tmp57_;
#line 512 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (_tmp58_ == 0);
#line 2794 "aggregation.c"
	{
		FolksIndividual* _tmp59_;
		GeeSet* _tmp60_;
		GeeSet* _tmp61_;
		GeeIterator* _tmp62_ = NULL;
		GeeIterator* _p_it;
#line 514 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp59_ = _data3_->individual1_detailed;
#line 514 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp60_ = folks_individual_get_personas (_tmp59_);
#line 514 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp61_ = _tmp60_;
#line 514 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp62_ = gee_iterable_iterator ((GeeIterable*) _tmp61_);
#line 514 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_p_it = _tmp62_;
#line 514 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 2813 "aggregation.c"
			GeeIterator* _tmp63_;
			gboolean _tmp64_ = FALSE;
			GeeIterator* _tmp65_;
			gpointer _tmp66_ = NULL;
			FolksPersona* p;
			gboolean _tmp67_ = FALSE;
			gboolean _tmp68_ = FALSE;
			GeeHashSet* _tmp69_;
			FolksPersona* _tmp70_;
			const gchar* _tmp71_;
			const gchar* _tmp72_;
			gboolean _tmp73_ = FALSE;
			gboolean _tmp77_;
			gboolean _tmp81_;
#line 514 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp63_ = _p_it;
#line 514 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp64_ = gee_iterator_next (_tmp63_);
#line 514 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (!_tmp64_) {
#line 514 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				break;
#line 2836 "aggregation.c"
			}
#line 514 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp65_ = _p_it;
#line 514 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp66_ = gee_iterator_get (_tmp65_);
#line 514 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			p = (FolksPersona*) _tmp66_;
#line 516 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp69_ = expected_personas1_detailed;
#line 516 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp70_ = p;
#line 516 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp71_ = folks_persona_get_display_id (_tmp70_);
#line 516 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp72_ = _tmp71_;
#line 516 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp73_ = gee_abstract_collection_remove ((GeeAbstractCollection*) _tmp69_, _tmp72_);
#line 516 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (_tmp73_) {
#line 516 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp68_ = TRUE;
#line 2858 "aggregation.c"
			} else {
				FolksPersona* _tmp74_;
				const gchar* _tmp75_;
				const gchar* _tmp76_;
#line 517 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp74_ = p;
#line 517 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp75_ = folks_persona_get_display_id (_tmp74_);
#line 517 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp76_ = _tmp75_;
#line 517 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp68_ = g_strcmp0 (_tmp76_, "0") == 0;
#line 2871 "aggregation.c"
			}
#line 516 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp77_ = _tmp68_;
#line 516 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (_tmp77_) {
#line 516 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp67_ = TRUE;
#line 2879 "aggregation.c"
			} else {
				FolksPersona* _tmp78_;
				const gchar* _tmp79_;
				const gchar* _tmp80_;
#line 517 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp78_ = p;
#line 517 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp79_ = folks_persona_get_display_id (_tmp78_);
#line 517 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp80_ = _tmp79_;
#line 517 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp67_ = g_strcmp0 (_tmp80_, "1") == 0;
#line 2892 "aggregation.c"
			}
#line 516 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp81_ = _tmp67_;
#line 516 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			g_assert (_tmp81_);
#line 514 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (p);
#line 2900 "aggregation.c"
		}
#line 514 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_p_it);
#line 2904 "aggregation.c"
	}
#line 520 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp82_ = expected_personas1_detailed;
#line 520 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp83_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp82_);
#line 520 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp84_ = _tmp83_;
#line 520 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (_tmp84_ == 0);
#line 2914 "aggregation.c"
	{
		FolksIndividual* _tmp85_;
		GeeSet* _tmp86_;
		GeeSet* _tmp87_;
		GeeIterator* _tmp88_ = NULL;
		GeeIterator* _p_it;
#line 522 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp85_ = _data3_->individual2;
#line 522 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp86_ = folks_individual_get_personas (_tmp85_);
#line 522 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp87_ = _tmp86_;
#line 522 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp88_ = gee_iterable_iterator ((GeeIterable*) _tmp87_);
#line 522 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_p_it = _tmp88_;
#line 522 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 2933 "aggregation.c"
			GeeIterator* _tmp89_;
			gboolean _tmp90_ = FALSE;
			GeeIterator* _tmp91_;
			gpointer _tmp92_ = NULL;
			FolksPersona* p;
			gboolean _tmp93_ = FALSE;
			gboolean _tmp94_ = FALSE;
			GeeHashSet* _tmp95_;
			FolksPersona* _tmp96_;
			const gchar* _tmp97_;
			const gchar* _tmp98_;
			gboolean _tmp99_ = FALSE;
			gboolean _tmp103_;
			gboolean _tmp107_;
#line 522 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp89_ = _p_it;
#line 522 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp90_ = gee_iterator_next (_tmp89_);
#line 522 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (!_tmp90_) {
#line 522 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				break;
#line 2956 "aggregation.c"
			}
#line 522 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp91_ = _p_it;
#line 522 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp92_ = gee_iterator_get (_tmp91_);
#line 522 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			p = (FolksPersona*) _tmp92_;
#line 524 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp95_ = expected_personas2;
#line 524 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp96_ = p;
#line 524 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp97_ = folks_persona_get_display_id (_tmp96_);
#line 524 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp98_ = _tmp97_;
#line 524 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp99_ = gee_abstract_collection_remove ((GeeAbstractCollection*) _tmp95_, _tmp98_);
#line 524 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (_tmp99_) {
#line 524 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp94_ = TRUE;
#line 2978 "aggregation.c"
			} else {
				FolksPersona* _tmp100_;
				const gchar* _tmp101_;
				const gchar* _tmp102_;
#line 525 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp100_ = p;
#line 525 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp101_ = folks_persona_get_display_id (_tmp100_);
#line 525 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp102_ = _tmp101_;
#line 525 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp94_ = g_strcmp0 (_tmp102_, "0") == 0;
#line 2991 "aggregation.c"
			}
#line 524 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp103_ = _tmp94_;
#line 524 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (_tmp103_) {
#line 524 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp93_ = TRUE;
#line 2999 "aggregation.c"
			} else {
				FolksPersona* _tmp104_;
				const gchar* _tmp105_;
				const gchar* _tmp106_;
#line 525 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp104_ = p;
#line 525 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp105_ = folks_persona_get_display_id (_tmp104_);
#line 525 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp106_ = _tmp105_;
#line 525 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp93_ = g_strcmp0 (_tmp106_, "1") == 0;
#line 3012 "aggregation.c"
			}
#line 524 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp107_ = _tmp93_;
#line 524 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			g_assert (_tmp107_);
#line 522 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (p);
#line 3020 "aggregation.c"
		}
#line 522 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_p_it);
#line 3024 "aggregation.c"
	}
#line 528 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp108_ = expected_personas2;
#line 528 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp109_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp108_);
#line 528 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp110_ = _tmp109_;
#line 528 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (_tmp110_ == 0);
#line 3034 "aggregation.c"
	{
		FolksIndividual* _tmp111_;
		GeeSet* _tmp112_;
		GeeSet* _tmp113_;
		GeeIterator* _tmp114_ = NULL;
		GeeIterator* _p_it;
#line 530 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp111_ = _data3_->individual2_detailed;
#line 530 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp112_ = folks_individual_get_personas (_tmp111_);
#line 530 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp113_ = _tmp112_;
#line 530 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp114_ = gee_iterable_iterator ((GeeIterable*) _tmp113_);
#line 530 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_p_it = _tmp114_;
#line 530 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 3053 "aggregation.c"
			GeeIterator* _tmp115_;
			gboolean _tmp116_ = FALSE;
			GeeIterator* _tmp117_;
			gpointer _tmp118_ = NULL;
			FolksPersona* p;
			gboolean _tmp119_ = FALSE;
			gboolean _tmp120_ = FALSE;
			GeeHashSet* _tmp121_;
			FolksPersona* _tmp122_;
			const gchar* _tmp123_;
			const gchar* _tmp124_;
			gboolean _tmp125_ = FALSE;
			gboolean _tmp129_;
			gboolean _tmp133_;
#line 530 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp115_ = _p_it;
#line 530 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp116_ = gee_iterator_next (_tmp115_);
#line 530 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (!_tmp116_) {
#line 530 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				break;
#line 3076 "aggregation.c"
			}
#line 530 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp117_ = _p_it;
#line 530 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp118_ = gee_iterator_get (_tmp117_);
#line 530 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			p = (FolksPersona*) _tmp118_;
#line 532 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp121_ = expected_personas2_detailed;
#line 532 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp122_ = p;
#line 532 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp123_ = folks_persona_get_display_id (_tmp122_);
#line 532 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp124_ = _tmp123_;
#line 532 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp125_ = gee_abstract_collection_remove ((GeeAbstractCollection*) _tmp121_, _tmp124_);
#line 532 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (_tmp125_) {
#line 532 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp120_ = TRUE;
#line 3098 "aggregation.c"
			} else {
				FolksPersona* _tmp126_;
				const gchar* _tmp127_;
				const gchar* _tmp128_;
#line 533 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp126_ = p;
#line 533 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp127_ = folks_persona_get_display_id (_tmp126_);
#line 533 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp128_ = _tmp127_;
#line 533 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp120_ = g_strcmp0 (_tmp128_, "0") == 0;
#line 3111 "aggregation.c"
			}
#line 532 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp129_ = _tmp120_;
#line 532 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (_tmp129_) {
#line 532 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp119_ = TRUE;
#line 3119 "aggregation.c"
			} else {
				FolksPersona* _tmp130_;
				const gchar* _tmp131_;
				const gchar* _tmp132_;
#line 533 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp130_ = p;
#line 533 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp131_ = folks_persona_get_display_id (_tmp130_);
#line 533 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp132_ = _tmp131_;
#line 533 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp119_ = g_strcmp0 (_tmp132_, "1") == 0;
#line 3132 "aggregation.c"
			}
#line 532 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp133_ = _tmp119_;
#line 532 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			g_assert (_tmp133_);
#line 530 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (p);
#line 3140 "aggregation.c"
		}
#line 530 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_p_it);
#line 3144 "aggregation.c"
	}
#line 536 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp134_ = expected_personas2_detailed;
#line 536 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp135_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp134_);
#line 536 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp136_ = _tmp135_;
#line 536 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (_tmp136_ == 0);
#line 539 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp137_ = self->priv->_tp_backend;
#line 539 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp138_ = account2_handle;
#line 539 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	tp_test_backend_remove_account (_tmp137_, _tmp138_);
#line 540 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp139_ = self->priv->_tp_backend;
#line 540 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp140_ = account1_handle;
#line 540 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	tp_test_backend_remove_account (_tmp139_, _tmp140_);
#line 541 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp141_ = self->priv->_kf_backend;
#line 541 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	kf_test_backend_tear_down (_tmp141_);
#line 542 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (_data3_->aggregator);
#line 542 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data3_->aggregator = NULL;
#line 411 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (expected_personas2_detailed);
#line 411 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (expected_personas2);
#line 411 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (expected_personas1_detailed);
#line 411 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (expected_personas1);
#line 411 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	block3_data_unref (_data3_);
#line 411 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data3_ = NULL;
#line 3186 "aggregation.c"
}


static void _aggregation_tests_test_linkable_properties_individuals_changed (AggregationTests* self, gboolean detailed, guint num_personas, GeeCollection* added, GeeSet* removed, FolksIndividual** individual1, FolksIndividual** individual2) {
#line 545 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 545 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (added != NULL);
#line 545 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (removed != NULL);
#line 3197 "aggregation.c"
	{
		GeeSet* _tmp0_;
		GeeIterator* _tmp1_ = NULL;
		GeeIterator* _i_it;
#line 550 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp0_ = removed;
#line 550 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp1_ = gee_iterable_iterator ((GeeIterable*) _tmp0_);
#line 550 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_i_it = _tmp1_;
#line 550 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 3210 "aggregation.c"
			GeeIterator* _tmp2_;
			gboolean _tmp3_ = FALSE;
			GeeIterator* _tmp4_;
			gpointer _tmp5_ = NULL;
			FolksIndividual* i;
			gboolean _tmp6_ = FALSE;
			FolksIndividual* _tmp7_;
			gboolean _tmp9_;
			FolksIndividual* _tmp10_;
			gboolean _tmp11_ = FALSE;
			FolksIndividual* _tmp12_;
			gboolean _tmp13_;
			gboolean _tmp14_;
			gboolean _tmp21_;
#line 550 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp2_ = _i_it;
#line 550 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp3_ = gee_iterator_next (_tmp2_);
#line 550 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (!_tmp3_) {
#line 550 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				break;
#line 3233 "aggregation.c"
			}
#line 550 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp4_ = _i_it;
#line 550 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp5_ = gee_iterator_get (_tmp4_);
#line 550 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp5_;
#line 552 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp7_ = i;
#line 552 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (_tmp7_ != NULL) {
#line 552 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp6_ = TRUE;
#line 3247 "aggregation.c"
			} else {
				gboolean _tmp8_;
#line 552 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp8_ = detailed;
#line 552 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp6_ = _tmp8_ == TRUE;
#line 3254 "aggregation.c"
			}
#line 552 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp9_ = _tmp6_;
#line 552 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			g_assert (_tmp9_);
#line 553 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp10_ = i;
#line 553 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (_tmp10_ == NULL) {
#line 555 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (i);
#line 555 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				continue;
#line 3268 "aggregation.c"
			}
#line 558 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp12_ = i;
#line 558 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp13_ = folks_individual_get_is_user (_tmp12_);
#line 558 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp14_ = _tmp13_;
#line 558 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (!_tmp14_) {
#line 3278 "aggregation.c"
				FolksIndividual* _tmp15_;
				GeeSet* _tmp16_;
				GeeSet* _tmp17_;
				gint _tmp18_;
				gint _tmp19_;
				guint _tmp20_;
#line 558 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp15_ = i;
#line 558 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp16_ = folks_individual_get_personas (_tmp15_);
#line 558 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp17_ = _tmp16_;
#line 558 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp18_ = gee_collection_get_size ((GeeCollection*) _tmp17_);
#line 558 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp19_ = _tmp18_;
#line 558 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp20_ = num_personas;
#line 558 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp11_ = ((guint) _tmp19_) == _tmp20_;
#line 3299 "aggregation.c"
			} else {
#line 558 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp11_ = FALSE;
#line 3303 "aggregation.c"
			}
#line 558 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp21_ = _tmp11_;
#line 558 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (_tmp21_) {
#line 3309 "aggregation.c"
				FolksIndividual* _tmp22_;
				FolksIndividual* _tmp23_;
#line 560 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp22_ = i;
#line 560 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp23_ = *individual1;
#line 560 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				if (_tmp22_ == _tmp23_) {
#line 562 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					*individual1 = NULL;
#line 3320 "aggregation.c"
				} else {
					FolksIndividual* _tmp24_;
					FolksIndividual* _tmp25_;
#line 564 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp24_ = i;
#line 564 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp25_ = *individual2;
#line 564 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					if (_tmp24_ == _tmp25_) {
#line 566 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						*individual2 = NULL;
#line 3332 "aggregation.c"
					} else {
						guint _tmp26_;
						FolksIndividual* _tmp27_;
						const gchar* _tmp28_;
						const gchar* _tmp29_;
#line 570 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						_tmp26_ = num_personas;
#line 570 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						_tmp27_ = i;
#line 570 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						_tmp28_ = folks_individual_get_id (_tmp27_);
#line 570 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						_tmp29_ = _tmp28_;
#line 570 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						g_critical ("aggregation.vala:570: Unknown %u-persona individual: %s", _tmp26_, _tmp29_);
#line 572 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						g_assert_not_reached ();
#line 3350 "aggregation.c"
					}
				}
			}
#line 550 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 3356 "aggregation.c"
		}
#line 550 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 3360 "aggregation.c"
	}
	{
		GeeCollection* _tmp30_;
		GeeIterator* _tmp31_ = NULL;
		GeeIterator* _i_it;
#line 577 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp30_ = added;
#line 577 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp31_ = gee_iterable_iterator ((GeeIterable*) _tmp30_);
#line 577 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_i_it = _tmp31_;
#line 577 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 3374 "aggregation.c"
			GeeIterator* _tmp32_;
			gboolean _tmp33_ = FALSE;
			GeeIterator* _tmp34_;
			gpointer _tmp35_ = NULL;
			FolksIndividual* i;
			gboolean _tmp36_ = FALSE;
			FolksIndividual* _tmp37_;
			gboolean _tmp39_;
			FolksIndividual* _tmp40_;
			gboolean _tmp41_ = FALSE;
			FolksIndividual* _tmp42_;
			gboolean _tmp43_;
			gboolean _tmp44_;
			gboolean _tmp51_;
#line 577 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp32_ = _i_it;
#line 577 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp33_ = gee_iterator_next (_tmp32_);
#line 577 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (!_tmp33_) {
#line 577 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				break;
#line 3397 "aggregation.c"
			}
#line 577 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp34_ = _i_it;
#line 577 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp35_ = gee_iterator_get (_tmp34_);
#line 577 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp35_;
#line 579 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp37_ = i;
#line 579 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (_tmp37_ != NULL) {
#line 579 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp36_ = TRUE;
#line 3411 "aggregation.c"
			} else {
				gboolean _tmp38_;
#line 579 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp38_ = detailed;
#line 579 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp36_ = _tmp38_ == TRUE;
#line 3418 "aggregation.c"
			}
#line 579 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp39_ = _tmp36_;
#line 579 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			g_assert (_tmp39_);
#line 580 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp40_ = i;
#line 580 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (_tmp40_ == NULL) {
#line 582 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (i);
#line 582 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				continue;
#line 3432 "aggregation.c"
			}
#line 585 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp42_ = i;
#line 585 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp43_ = folks_individual_get_is_user (_tmp42_);
#line 585 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp44_ = _tmp43_;
#line 585 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (!_tmp44_) {
#line 3442 "aggregation.c"
				FolksIndividual* _tmp45_;
				GeeSet* _tmp46_;
				GeeSet* _tmp47_;
				gint _tmp48_;
				gint _tmp49_;
				guint _tmp50_;
#line 585 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp45_ = i;
#line 585 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp46_ = folks_individual_get_personas (_tmp45_);
#line 585 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp47_ = _tmp46_;
#line 585 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp48_ = gee_collection_get_size ((GeeCollection*) _tmp47_);
#line 585 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp49_ = _tmp48_;
#line 585 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp50_ = num_personas;
#line 585 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp41_ = ((guint) _tmp49_) == _tmp50_;
#line 3463 "aggregation.c"
			} else {
#line 585 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp41_ = FALSE;
#line 3467 "aggregation.c"
			}
#line 585 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp51_ = _tmp41_;
#line 585 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (_tmp51_) {
#line 3473 "aggregation.c"
				gboolean _tmp52_ = FALSE;
				FolksIndividual* _tmp53_;
				gboolean _tmp56_;
#line 587 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp53_ = *individual1;
#line 587 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				if (_tmp53_ == NULL) {
#line 3481 "aggregation.c"
					FolksIndividual* _tmp54_;
					FolksIndividual* _tmp55_;
#line 587 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp54_ = *individual2;
#line 587 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp55_ = i;
#line 587 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp52_ = _tmp54_ != _tmp55_;
#line 3490 "aggregation.c"
				} else {
#line 587 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp52_ = FALSE;
#line 3494 "aggregation.c"
				}
#line 587 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp56_ = _tmp52_;
#line 587 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				if (_tmp56_) {
#line 3500 "aggregation.c"
					FolksIndividual* _tmp57_;
#line 589 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp57_ = i;
#line 589 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					*individual1 = _tmp57_;
#line 3506 "aggregation.c"
				} else {
					gboolean _tmp58_ = FALSE;
					FolksIndividual* _tmp59_;
					gboolean _tmp62_;
#line 591 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp59_ = *individual2;
#line 591 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					if (_tmp59_ == NULL) {
#line 3515 "aggregation.c"
						FolksIndividual* _tmp60_;
						FolksIndividual* _tmp61_;
#line 591 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						_tmp60_ = *individual1;
#line 591 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						_tmp61_ = i;
#line 591 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						_tmp58_ = _tmp60_ != _tmp61_;
#line 3524 "aggregation.c"
					} else {
#line 591 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						_tmp58_ = FALSE;
#line 3528 "aggregation.c"
					}
#line 591 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp62_ = _tmp58_;
#line 591 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					if (_tmp62_) {
#line 3534 "aggregation.c"
						FolksIndividual* _tmp63_;
#line 593 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						_tmp63_ = i;
#line 593 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						*individual2 = _tmp63_;
#line 3540 "aggregation.c"
					} else {
						gboolean _tmp64_ = FALSE;
						FolksIndividual* _tmp65_;
						FolksIndividual* _tmp66_;
						gboolean _tmp69_;
#line 595 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						_tmp65_ = *individual1;
#line 595 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						_tmp66_ = i;
#line 595 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						if (_tmp65_ != _tmp66_) {
#line 3552 "aggregation.c"
							FolksIndividual* _tmp67_;
							FolksIndividual* _tmp68_;
#line 595 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
							_tmp67_ = *individual2;
#line 595 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
							_tmp68_ = i;
#line 595 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
							_tmp64_ = _tmp67_ != _tmp68_;
#line 3561 "aggregation.c"
						} else {
#line 595 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
							_tmp64_ = FALSE;
#line 3565 "aggregation.c"
						}
#line 595 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						_tmp69_ = _tmp64_;
#line 595 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						if (_tmp69_) {
#line 3571 "aggregation.c"
							guint _tmp70_;
							FolksIndividual* _tmp71_;
							const gchar* _tmp72_;
							const gchar* _tmp73_;
#line 597 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
							_tmp70_ = num_personas;
#line 597 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
							_tmp71_ = i;
#line 597 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
							_tmp72_ = folks_individual_get_id (_tmp71_);
#line 597 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
							_tmp73_ = _tmp72_;
#line 597 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
							g_critical ("aggregation.vala:597: Unknown %u-persona individual: %s", _tmp70_, _tmp73_);
#line 599 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
							g_assert_not_reached ();
#line 3588 "aggregation.c"
						}
					}
				}
			}
#line 577 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 3595 "aggregation.c"
		}
#line 577 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 3599 "aggregation.c"
	}
}


static Block4Data* block4_data_ref (Block4Data* _data4_) {
#line 607 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_atomic_int_inc (&_data4_->_ref_count_);
#line 607 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return _data4_;
#line 3609 "aggregation.c"
}


static void block4_data_unref (void * _userdata_) {
	Block4Data* _data4_;
	_data4_ = (Block4Data*) _userdata_;
#line 607 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	if (g_atomic_int_dec_and_test (&_data4_->_ref_count_)) {
#line 3618 "aggregation.c"
		AggregationTests * self;
#line 607 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		self = _data4_->self;
#line 607 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data4_->aggregator);
#line 607 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data4_->user_individual_detailed);
#line 607 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data4_->user_individual);
#line 607 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_main_loop_unref0 (_data4_->main_loop);
#line 607 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (self);
#line 607 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_slice_free (Block4Data, _data4_);
#line 3634 "aggregation.c"
	}
}


static void __lambda17_ (Block4Data* _data4_, GeeMultiMap* changes) {
	AggregationTests * self;
	GeeMultiMap* _tmp0_;
	GeeSet* _tmp1_ = NULL;
	GeeSet* removed;
	GeeMultiMap* _tmp2_;
	GeeCollection* _tmp3_ = NULL;
	GeeCollection* added;
#line 623 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data4_->self;
#line 623 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (changes != NULL);
#line 625 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = changes;
#line 625 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = gee_multi_map_get_keys (_tmp0_);
#line 625 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	removed = _tmp1_;
#line 626 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = changes;
#line 626 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = gee_multi_map_get_values (_tmp2_);
#line 626 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	added = _tmp3_;
#line 628 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_aggregation_tests_test_user_individuals_changed (self, TRUE, added, removed, &_data4_->user_individual_detailed);
#line 623 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (added);
#line 623 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (removed);
#line 3669 "aggregation.c"
}


static void ___lambda17__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 623 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	__lambda17_ (self, changes);
#line 3676 "aggregation.c"
}


static void __lambda18_ (Block4Data* _data4_, GeeSet* added, GeeSet* removed, const gchar* m, FolksPersona* a, FolksGroupDetailsChangeReason r) {
	AggregationTests * self;
	GeeSet* _tmp0_;
	GeeSet* _tmp1_;
#line 631 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data4_->self;
#line 631 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (added != NULL);
#line 631 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (removed != NULL);
#line 633 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = added;
#line 633 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = removed;
#line 633 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_aggregation_tests_test_user_individuals_changed (self, FALSE, (GeeCollection*) _tmp0_, _tmp1_, &_data4_->user_individual);
#line 3696 "aggregation.c"
}


static void ___lambda18__folks_individual_aggregator_individuals_changed (FolksIndividualAggregator* _sender, GeeSet* added, GeeSet* removed, const gchar* message, FolksPersona* actor, FolksGroupDetailsChangeReason reason, gpointer self) {
#line 631 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	__lambda18_ (self, added, removed, message, actor, reason);
#line 3703 "aggregation.c"
}


static gboolean __lambda19_ (Block4Data* _data4_) {
	AggregationTests * self;
	gboolean result = FALSE;
	GMainLoop* _tmp0_;
#line 640 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data4_->self;
#line 642 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data4_->main_loop;
#line 642 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_main_loop_quit (_tmp0_);
#line 643 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 643 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 3721 "aggregation.c"
}


static gboolean ___lambda19__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda19_ (self);
#line 640 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 3730 "aggregation.c"
}


static void __lambda21_ (Block4Data* _data4_, GObject* s, GAsyncResult* r) {
	AggregationTests * self;
	GError * _inner_error_ = NULL;
#line 648 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data4_->self;
#line 648 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (r != NULL);
#line 3741 "aggregation.c"
	{
		FolksIndividualAggregator* _tmp0_;
		GAsyncResult* _tmp1_;
#line 652 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp0_ = _data4_->aggregator;
#line 652 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp1_ = r;
#line 652 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		folks_individual_aggregator_prepare_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 652 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		if (_inner_error_ != NULL) {
#line 3753 "aggregation.c"
			goto __catch3_g_error;
		}
	}
	goto __finally3;
	__catch3_g_error:
	{
		GError* e1 = NULL;
		const gchar* _tmp2_;
#line 650 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		e1 = _inner_error_;
#line 650 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_inner_error_ = NULL;
#line 656 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp2_ = e1->message;
#line 656 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_critical ("aggregation.vala:656: Failed to prepare aggregator: %s", _tmp2_);
#line 658 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_assert_not_reached ();
#line 650 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_error_free0 (e1);
#line 3774 "aggregation.c"
	}
	__finally3:
#line 650 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	if (_inner_error_ != NULL) {
#line 650 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 650 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 650 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		return;
#line 3785 "aggregation.c"
	}
}


static void ___lambda21__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 648 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	__lambda21_ (self, source_object, res);
#line 648 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	block4_data_unref (self);
#line 3795 "aggregation.c"
}


static gboolean __lambda20_ (Block4Data* _data4_) {
	AggregationTests * self;
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_;
#line 646 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data4_->self;
#line 648 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data4_->aggregator;
#line 648 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	folks_individual_aggregator_prepare (_tmp0_, ___lambda21__gasync_ready_callback, block4_data_ref (_data4_));
#line 662 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 662 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 3813 "aggregation.c"
}


static gboolean ___lambda20__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda20_ (self);
#line 646 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 3822 "aggregation.c"
}


void aggregation_tests_test_user (AggregationTests* self) {
	Block4Data* _data4_;
	GMainLoop* _tmp0_;
	KfTestBackend* _tmp1_;
	TpTestBackend* _tmp2_;
	void* _tmp3_ = NULL;
	void* account1_handle;
	TpTestBackend* _tmp4_;
	void* _tmp5_ = NULL;
	void* account2_handle;
	FolksIndividualAggregator* _tmp6_;
	FolksIndividualAggregator* _tmp7_;
	FolksIndividualAggregator* _tmp8_;
	gint _tmp9_;
	GMainLoop* _tmp10_;
	FolksIndividualAggregator* _tmp11_;
	FolksIndividual* _tmp12_;
	FolksIndividual* _tmp13_;
	FolksIndividual* _tmp14_;
	FolksIndividualAggregator* _tmp15_;
	FolksIndividual* _tmp16_;
	FolksIndividual* _tmp17_;
	FolksIndividual* _tmp18_;
	FolksIndividual* _tmp19_;
	GeeSet* _tmp20_;
	GeeSet* _tmp21_;
	gint _tmp22_;
	gint _tmp23_;
	FolksIndividual* _tmp24_;
	GeeSet* _tmp25_;
	GeeSet* _tmp26_;
	gint _tmp27_;
	gint _tmp28_;
	GeeHashSet* _tmp29_;
	GeeHashSet* display_ids;
	gboolean _tmp42_ = FALSE;
	GeeHashSet* _tmp43_;
	gboolean _tmp44_ = FALSE;
	gboolean _tmp47_;
	GeeHashSet* _tmp48_;
	GeeHashSet* display_ids_detailed;
	gboolean _tmp61_ = FALSE;
	GeeHashSet* _tmp62_;
	gboolean _tmp63_ = FALSE;
	gboolean _tmp66_;
	TpTestBackend* _tmp67_;
	void* _tmp68_;
	TpTestBackend* _tmp69_;
	void* _tmp70_;
	KfTestBackend* _tmp71_;
#line 607 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 607 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data4_ = g_slice_new0 (Block4Data);
#line 607 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data4_->_ref_count_ = 1;
#line 607 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data4_->self = g_object_ref (self);
#line 609 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 609 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data4_->main_loop = _tmp0_;
#line 611 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = self->priv->_kf_backend;
#line 611 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	kf_test_backend_set_up (_tmp1_, "");
#line 613 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = self->priv->_tp_backend;
#line 613 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = tp_test_backend_add_account (_tmp2_, "protocol", "me@example.com", "cm", "account");
#line 613 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	account1_handle = _tmp3_;
#line 615 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp4_ = self->priv->_tp_backend;
#line 615 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp5_ = tp_test_backend_add_account (_tmp4_, "protocol", "me2@example.com", "cm", "account2");
#line 615 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	account2_handle = _tmp5_;
#line 618 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data4_->user_individual = NULL;
#line 619 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data4_->user_individual_detailed = NULL;
#line 622 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp6_ = folks_individual_aggregator_new ();
#line 622 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data4_->aggregator = _tmp6_;
#line 623 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp7_ = _data4_->aggregator;
#line 623 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_signal_connect_data (_tmp7_, "individuals-changed-detailed", (GCallback) ___lambda17__folks_individual_aggregator_individuals_changed_detailed, block4_data_ref (_data4_), (GClosureNotify) block4_data_unref, 0);
#line 631 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp8_ = _data4_->aggregator;
#line 631 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_signal_connect_data (_tmp8_, "individuals-changed", (GCallback) ___lambda18__folks_individual_aggregator_individuals_changed, block4_data_ref (_data4_), (GClosureNotify) block4_data_unref, 0);
#line 640 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp9_ = self->priv->_test_timeout;
#line 640 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) _tmp9_, ___lambda19__gsource_func, block4_data_ref (_data4_), block4_data_unref);
#line 646 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda20__gsource_func, block4_data_ref (_data4_), block4_data_unref);
#line 665 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp10_ = _data4_->main_loop;
#line 665 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_main_loop_run (_tmp10_);
#line 669 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp11_ = _data4_->aggregator;
#line 669 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp12_ = folks_individual_aggregator_get_user (_tmp11_);
#line 669 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp13_ = _tmp12_;
#line 669 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp14_ = _data4_->user_individual;
#line 669 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (_tmp13_ == _tmp14_);
#line 670 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp15_ = _data4_->aggregator;
#line 670 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp16_ = folks_individual_aggregator_get_user (_tmp15_);
#line 670 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp17_ = _tmp16_;
#line 670 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp18_ = _data4_->user_individual_detailed;
#line 670 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (_tmp17_ == _tmp18_);
#line 673 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp19_ = _data4_->user_individual;
#line 673 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp20_ = folks_individual_get_personas (_tmp19_);
#line 673 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp21_ = _tmp20_;
#line 673 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp22_ = gee_collection_get_size ((GeeCollection*) _tmp21_);
#line 673 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp23_ = _tmp22_;
#line 673 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (_tmp23_ == 2);
#line 674 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp24_ = _data4_->user_individual_detailed;
#line 674 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp25_ = folks_individual_get_personas (_tmp24_);
#line 674 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp26_ = _tmp25_;
#line 674 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp27_ = gee_collection_get_size ((GeeCollection*) _tmp26_);
#line 674 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp28_ = _tmp27_;
#line 674 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (_tmp28_ == 2);
#line 676 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp29_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL);
#line 676 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	display_ids = _tmp29_;
#line 3978 "aggregation.c"
	{
		FolksIndividual* _tmp30_;
		GeeSet* _tmp31_;
		GeeSet* _tmp32_;
		GeeIterator* _tmp33_ = NULL;
		GeeIterator* _persona_it;
#line 677 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp30_ = _data4_->user_individual;
#line 677 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp31_ = folks_individual_get_personas (_tmp30_);
#line 677 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp32_ = _tmp31_;
#line 677 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp33_ = gee_iterable_iterator ((GeeIterable*) _tmp32_);
#line 677 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_persona_it = _tmp33_;
#line 677 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 3997 "aggregation.c"
			GeeIterator* _tmp34_;
			gboolean _tmp35_ = FALSE;
			GeeIterator* _tmp36_;
			gpointer _tmp37_ = NULL;
			FolksPersona* persona;
			GeeHashSet* _tmp38_;
			FolksPersona* _tmp39_;
			const gchar* _tmp40_;
			const gchar* _tmp41_;
#line 677 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp34_ = _persona_it;
#line 677 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp35_ = gee_iterator_next (_tmp34_);
#line 677 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (!_tmp35_) {
#line 677 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				break;
#line 4015 "aggregation.c"
			}
#line 677 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp36_ = _persona_it;
#line 677 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp37_ = gee_iterator_get (_tmp36_);
#line 677 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			persona = (FolksPersona*) _tmp37_;
#line 679 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp38_ = display_ids;
#line 679 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp39_ = persona;
#line 679 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp40_ = folks_persona_get_display_id (_tmp39_);
#line 679 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp41_ = _tmp40_;
#line 679 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _tmp38_, _tmp41_);
#line 677 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (persona);
#line 4035 "aggregation.c"
		}
#line 677 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_persona_it);
#line 4039 "aggregation.c"
	}
#line 682 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp43_ = display_ids;
#line 682 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp44_ = gee_abstract_collection_contains ((GeeAbstractCollection*) _tmp43_, "me@example.com");
#line 682 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	if (_tmp44_) {
#line 4047 "aggregation.c"
		GeeHashSet* _tmp45_;
		gboolean _tmp46_ = FALSE;
#line 683 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp45_ = display_ids;
#line 683 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp46_ = gee_abstract_collection_contains ((GeeAbstractCollection*) _tmp45_, "me2@example.com");
#line 683 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp42_ = _tmp46_;
#line 4056 "aggregation.c"
	} else {
#line 682 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp42_ = FALSE;
#line 4060 "aggregation.c"
	}
#line 682 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp47_ = _tmp42_;
#line 682 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (_tmp47_);
#line 685 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp48_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL);
#line 685 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	display_ids_detailed = _tmp48_;
#line 4070 "aggregation.c"
	{
		FolksIndividual* _tmp49_;
		GeeSet* _tmp50_;
		GeeSet* _tmp51_;
		GeeIterator* _tmp52_ = NULL;
		GeeIterator* _persona_it;
#line 686 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp49_ = _data4_->user_individual_detailed;
#line 686 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp50_ = folks_individual_get_personas (_tmp49_);
#line 686 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp51_ = _tmp50_;
#line 686 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp52_ = gee_iterable_iterator ((GeeIterable*) _tmp51_);
#line 686 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_persona_it = _tmp52_;
#line 686 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 4089 "aggregation.c"
			GeeIterator* _tmp53_;
			gboolean _tmp54_ = FALSE;
			GeeIterator* _tmp55_;
			gpointer _tmp56_ = NULL;
			FolksPersona* persona;
			GeeHashSet* _tmp57_;
			FolksPersona* _tmp58_;
			const gchar* _tmp59_;
			const gchar* _tmp60_;
#line 686 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp53_ = _persona_it;
#line 686 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp54_ = gee_iterator_next (_tmp53_);
#line 686 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (!_tmp54_) {
#line 686 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				break;
#line 4107 "aggregation.c"
			}
#line 686 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp55_ = _persona_it;
#line 686 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp56_ = gee_iterator_get (_tmp55_);
#line 686 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			persona = (FolksPersona*) _tmp56_;
#line 688 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp57_ = display_ids_detailed;
#line 688 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp58_ = persona;
#line 688 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp59_ = folks_persona_get_display_id (_tmp58_);
#line 688 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp60_ = _tmp59_;
#line 688 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _tmp57_, _tmp60_);
#line 686 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (persona);
#line 4127 "aggregation.c"
		}
#line 686 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_persona_it);
#line 4131 "aggregation.c"
	}
#line 691 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp62_ = display_ids_detailed;
#line 691 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp63_ = gee_abstract_collection_contains ((GeeAbstractCollection*) _tmp62_, "me@example.com");
#line 691 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	if (_tmp63_) {
#line 4139 "aggregation.c"
		GeeHashSet* _tmp64_;
		gboolean _tmp65_ = FALSE;
#line 692 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp64_ = display_ids_detailed;
#line 692 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp65_ = gee_abstract_collection_contains ((GeeAbstractCollection*) _tmp64_, "me2@example.com");
#line 692 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp61_ = _tmp65_;
#line 4148 "aggregation.c"
	} else {
#line 691 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp61_ = FALSE;
#line 4152 "aggregation.c"
	}
#line 691 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp66_ = _tmp61_;
#line 691 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (_tmp66_);
#line 695 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp67_ = self->priv->_tp_backend;
#line 695 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp68_ = account2_handle;
#line 695 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	tp_test_backend_remove_account (_tmp67_, _tmp68_);
#line 696 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp69_ = self->priv->_tp_backend;
#line 696 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp70_ = account1_handle;
#line 696 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	tp_test_backend_remove_account (_tmp69_, _tmp70_);
#line 697 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp71_ = self->priv->_kf_backend;
#line 697 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	kf_test_backend_tear_down (_tmp71_);
#line 698 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (_data4_->aggregator);
#line 698 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data4_->aggregator = NULL;
#line 607 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (display_ids_detailed);
#line 607 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (display_ids);
#line 607 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	block4_data_unref (_data4_);
#line 607 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data4_ = NULL;
#line 4186 "aggregation.c"
}


static void _aggregation_tests_test_user_individuals_changed (AggregationTests* self, gboolean detailed, GeeCollection* added, GeeSet* removed, FolksIndividual** user_individual) {
#line 701 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 701 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (added != NULL);
#line 701 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (removed != NULL);
#line 4197 "aggregation.c"
	{
		GeeSet* _tmp0_;
		GeeIterator* _tmp1_ = NULL;
		GeeIterator* _i_it;
#line 706 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp0_ = removed;
#line 706 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp1_ = gee_iterable_iterator ((GeeIterable*) _tmp0_);
#line 706 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_i_it = _tmp1_;
#line 706 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 4210 "aggregation.c"
			GeeIterator* _tmp2_;
			gboolean _tmp3_ = FALSE;
			GeeIterator* _tmp4_;
			gpointer _tmp5_ = NULL;
			FolksIndividual* i;
			gboolean _tmp6_ = FALSE;
			FolksIndividual* _tmp7_;
			gboolean _tmp9_;
			FolksIndividual* _tmp10_;
			FolksIndividual* _tmp11_;
			gboolean _tmp12_;
			gboolean _tmp13_;
#line 706 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp2_ = _i_it;
#line 706 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp3_ = gee_iterator_next (_tmp2_);
#line 706 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (!_tmp3_) {
#line 706 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				break;
#line 4231 "aggregation.c"
			}
#line 706 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp4_ = _i_it;
#line 706 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp5_ = gee_iterator_get (_tmp4_);
#line 706 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp5_;
#line 708 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp7_ = i;
#line 708 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (_tmp7_ != NULL) {
#line 708 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp6_ = TRUE;
#line 4245 "aggregation.c"
			} else {
				gboolean _tmp8_;
#line 708 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp8_ = detailed;
#line 708 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp6_ = _tmp8_ == TRUE;
#line 4252 "aggregation.c"
			}
#line 708 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp9_ = _tmp6_;
#line 708 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			g_assert (_tmp9_);
#line 709 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp10_ = i;
#line 709 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (_tmp10_ == NULL) {
#line 711 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (i);
#line 711 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				continue;
#line 4266 "aggregation.c"
			}
#line 714 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp11_ = i;
#line 714 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp12_ = folks_individual_get_is_user (_tmp11_);
#line 714 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp13_ = _tmp12_;
#line 714 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (_tmp13_) {
#line 4276 "aggregation.c"
				FolksIndividual* _tmp14_;
				FolksIndividual* _tmp15_;
#line 716 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp14_ = *user_individual;
#line 716 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp15_ = i;
#line 716 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				g_assert (_tmp14_ == _tmp15_);
#line 717 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (*user_individual);
#line 717 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				*user_individual = NULL;
#line 4289 "aggregation.c"
			}
#line 706 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 4293 "aggregation.c"
		}
#line 706 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 4297 "aggregation.c"
	}
	{
		GeeCollection* _tmp16_;
		GeeIterator* _tmp17_ = NULL;
		GeeIterator* _i_it;
#line 721 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp16_ = added;
#line 721 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp17_ = gee_iterable_iterator ((GeeIterable*) _tmp16_);
#line 721 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_i_it = _tmp17_;
#line 721 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 4311 "aggregation.c"
			GeeIterator* _tmp18_;
			gboolean _tmp19_ = FALSE;
			GeeIterator* _tmp20_;
			gpointer _tmp21_ = NULL;
			FolksIndividual* i;
			gboolean _tmp22_ = FALSE;
			FolksIndividual* _tmp23_;
			gboolean _tmp25_;
			FolksIndividual* _tmp26_;
			FolksIndividual* _tmp27_;
			gboolean _tmp28_;
			gboolean _tmp29_;
#line 721 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp18_ = _i_it;
#line 721 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp19_ = gee_iterator_next (_tmp18_);
#line 721 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (!_tmp19_) {
#line 721 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				break;
#line 4332 "aggregation.c"
			}
#line 721 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp20_ = _i_it;
#line 721 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp21_ = gee_iterator_get (_tmp20_);
#line 721 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp21_;
#line 723 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp23_ = i;
#line 723 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (_tmp23_ != NULL) {
#line 723 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp22_ = TRUE;
#line 4346 "aggregation.c"
			} else {
				gboolean _tmp24_;
#line 723 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp24_ = detailed;
#line 723 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp22_ = _tmp24_ == TRUE;
#line 4353 "aggregation.c"
			}
#line 723 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp25_ = _tmp22_;
#line 723 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			g_assert (_tmp25_);
#line 724 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp26_ = i;
#line 724 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (_tmp26_ == NULL) {
#line 726 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (i);
#line 726 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				continue;
#line 4367 "aggregation.c"
			}
#line 729 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp27_ = i;
#line 729 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp28_ = folks_individual_get_is_user (_tmp27_);
#line 729 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp29_ = _tmp28_;
#line 729 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (_tmp29_) {
#line 4377 "aggregation.c"
				FolksIndividual* _tmp30_;
				FolksIndividual* _tmp31_;
				FolksIndividual* _tmp32_;
#line 731 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp30_ = *user_individual;
#line 731 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				g_assert (_tmp30_ == NULL);
#line 732 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp31_ = i;
#line 732 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp32_ = _g_object_ref0 (_tmp31_);
#line 732 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (*user_individual);
#line 732 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				*user_individual = _tmp32_;
#line 4393 "aggregation.c"
			}
#line 721 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 4397 "aggregation.c"
		}
#line 721 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 4401 "aggregation.c"
	}
}


static Block5Data* block5_data_ref (Block5Data* _data5_) {
#line 740 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_atomic_int_inc (&_data5_->_ref_count_);
#line 740 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return _data5_;
#line 4411 "aggregation.c"
}


static void block5_data_unref (void * _userdata_) {
	Block5Data* _data5_;
	_data5_ = (Block5Data*) _userdata_;
#line 740 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	if (g_atomic_int_dec_and_test (&_data5_->_ref_count_)) {
#line 4420 "aggregation.c"
		AggregationTests * self;
#line 740 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		self = _data5_->self;
#line 740 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data5_->aggregator);
#line 740 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_main_loop_unref0 (_data5_->main_loop);
#line 740 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (self);
#line 740 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_slice_free (Block5Data, _data5_);
#line 4432 "aggregation.c"
	}
}


static void __lambda22_ (AggregationTests* self, GeeMultiMap* changes) {
	GeeMultiMap* _tmp0_;
	GeeSet* _tmp1_ = NULL;
	GeeSet* removed;
	GeeMultiMap* _tmp2_;
	GeeCollection* _tmp3_ = NULL;
	GeeCollection* added;
#line 753 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (changes != NULL);
#line 755 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = changes;
#line 755 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = gee_multi_map_get_keys (_tmp0_);
#line 755 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	removed = _tmp1_;
#line 756 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = changes;
#line 756 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = gee_multi_map_get_values (_tmp2_);
#line 756 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	added = _tmp3_;
#line 758 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_aggregation_tests_test_untrusted_store_individuals_changed (self, TRUE, added, removed);
#line 753 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (added);
#line 753 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (removed);
#line 4464 "aggregation.c"
}


static void ___lambda22__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 753 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	__lambda22_ (self, changes);
#line 4471 "aggregation.c"
}


static void __lambda23_ (AggregationTests* self, GeeSet* added, GeeSet* removed, const gchar* m, FolksPersona* a, FolksGroupDetailsChangeReason r) {
	GeeSet* _tmp0_;
	GeeSet* _tmp1_;
#line 760 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (added != NULL);
#line 760 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (removed != NULL);
#line 762 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = added;
#line 762 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = removed;
#line 762 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_aggregation_tests_test_untrusted_store_individuals_changed (self, FALSE, (GeeCollection*) _tmp0_, _tmp1_);
#line 4488 "aggregation.c"
}


static void ___lambda23__folks_individual_aggregator_individuals_changed (FolksIndividualAggregator* _sender, GeeSet* added, GeeSet* removed, const gchar* message, FolksPersona* actor, FolksGroupDetailsChangeReason reason, gpointer self) {
#line 760 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	__lambda23_ (self, added, removed, message, actor, reason);
#line 4495 "aggregation.c"
}


static gboolean __lambda24_ (Block5Data* _data5_) {
	AggregationTests * self;
	gboolean result = FALSE;
#line 769 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data5_->self;
#line 771 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_main_loop_quit (_data5_->main_loop);
#line 772 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 772 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 4510 "aggregation.c"
}


static gboolean ___lambda24__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda24_ (self);
#line 769 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 4519 "aggregation.c"
}


static void __lambda26_ (Block5Data* _data5_, GObject* s, GAsyncResult* r) {
	AggregationTests * self;
	GError * _inner_error_ = NULL;
#line 777 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data5_->self;
#line 777 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (r != NULL);
#line 4530 "aggregation.c"
	{
		FolksIndividualAggregator* _tmp0_;
		GAsyncResult* _tmp1_;
#line 781 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp0_ = _data5_->aggregator;
#line 781 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp1_ = r;
#line 781 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		folks_individual_aggregator_prepare_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 781 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		if (_inner_error_ != NULL) {
#line 4542 "aggregation.c"
			goto __catch4_g_error;
		}
	}
	goto __finally4;
	__catch4_g_error:
	{
		GError* e1 = NULL;
		const gchar* _tmp2_;
#line 779 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		e1 = _inner_error_;
#line 779 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_inner_error_ = NULL;
#line 785 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp2_ = e1->message;
#line 785 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_critical ("aggregation.vala:785: Failed to prepare aggregator: %s", _tmp2_);
#line 787 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_assert_not_reached ();
#line 779 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_error_free0 (e1);
#line 4563 "aggregation.c"
	}
	__finally4:
#line 779 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	if (_inner_error_ != NULL) {
#line 779 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 779 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 779 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		return;
#line 4574 "aggregation.c"
	}
}


static void ___lambda26__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 777 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	__lambda26_ (self, source_object, res);
#line 777 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	block5_data_unref (self);
#line 4584 "aggregation.c"
}


static gboolean __lambda25_ (Block5Data* _data5_) {
	AggregationTests * self;
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_;
#line 775 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data5_->self;
#line 777 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data5_->aggregator;
#line 777 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	folks_individual_aggregator_prepare (_tmp0_, ___lambda26__gasync_ready_callback, block5_data_ref (_data5_));
#line 791 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 791 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 4602 "aggregation.c"
}


static gboolean ___lambda25__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda25_ (self);
#line 775 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 4611 "aggregation.c"
}


void aggregation_tests_test_untrusted_store (AggregationTests* self) {
	Block5Data* _data5_;
	GMainLoop* _tmp0_;
	KfTestBackend* _tmp1_;
	TpTestBackend* _tmp2_;
	void* _tmp3_ = NULL;
	void* account1_handle;
	TpTestBackend* _tmp4_;
	void* _tmp5_ = NULL;
	void* account2_handle;
	FolksIndividualAggregator* _tmp6_;
	FolksIndividualAggregator* _tmp7_;
	FolksIndividualAggregator* _tmp8_;
	gint _tmp9_;
	TpTestBackend* _tmp10_;
	TpTestBackend* _tmp11_;
	KfTestBackend* _tmp12_;
#line 740 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 740 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data5_ = g_slice_new0 (Block5Data);
#line 740 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data5_->_ref_count_ = 1;
#line 740 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data5_->self = g_object_ref (self);
#line 742 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 742 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data5_->main_loop = _tmp0_;
#line 744 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = self->priv->_kf_backend;
#line 744 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	kf_test_backend_set_up (_tmp1_, "");
#line 746 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = self->priv->_tp_backend;
#line 746 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = tp_test_backend_add_account (_tmp2_, "irc", "me@example.com", "cm", "account");
#line 746 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	account1_handle = _tmp3_;
#line 748 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp4_ = self->priv->_tp_backend;
#line 748 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp5_ = tp_test_backend_add_account (_tmp4_, "irc", "me2@example.com", "cm", "account2");
#line 748 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	account2_handle = _tmp5_;
#line 752 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp6_ = folks_individual_aggregator_new ();
#line 752 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data5_->aggregator = _tmp6_;
#line 753 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp7_ = _data5_->aggregator;
#line 753 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_signal_connect_object (_tmp7_, "individuals-changed-detailed", (GCallback) ___lambda22__folks_individual_aggregator_individuals_changed_detailed, self, 0);
#line 760 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp8_ = _data5_->aggregator;
#line 760 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_signal_connect_object (_tmp8_, "individuals-changed", (GCallback) ___lambda23__folks_individual_aggregator_individuals_changed, self, 0);
#line 769 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp9_ = self->priv->_test_timeout;
#line 769 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) _tmp9_, ___lambda24__gsource_func, block5_data_ref (_data5_), block5_data_unref);
#line 775 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda25__gsource_func, block5_data_ref (_data5_), block5_data_unref);
#line 794 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_main_loop_run (_data5_->main_loop);
#line 797 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp10_ = self->priv->_tp_backend;
#line 797 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	tp_test_backend_remove_account (_tmp10_, account2_handle);
#line 798 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp11_ = self->priv->_tp_backend;
#line 798 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	tp_test_backend_remove_account (_tmp11_, account1_handle);
#line 799 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp12_ = self->priv->_kf_backend;
#line 799 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	kf_test_backend_tear_down (_tmp12_);
#line 800 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (_data5_->aggregator);
#line 800 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data5_->aggregator = NULL;
#line 740 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	block5_data_unref (_data5_);
#line 740 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data5_ = NULL;
#line 4700 "aggregation.c"
}


static void _aggregation_tests_test_untrusted_store_individuals_changed (AggregationTests* self, gboolean detailed, GeeCollection* added, GeeSet* removed) {
#line 803 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 803 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (added != NULL);
#line 803 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (removed != NULL);
#line 4711 "aggregation.c"
	{
		GeeSet* _tmp0_;
		GeeIterator* _tmp1_ = NULL;
		GeeIterator* _i_it;
#line 808 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp0_ = removed;
#line 808 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp1_ = gee_iterable_iterator ((GeeIterable*) _tmp0_);
#line 808 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_i_it = _tmp1_;
#line 808 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 4724 "aggregation.c"
			GeeIterator* _tmp2_;
			gboolean _tmp3_ = FALSE;
			GeeIterator* _tmp4_;
			gpointer _tmp5_ = NULL;
			FolksIndividual* i;
			gboolean _tmp6_ = FALSE;
			FolksIndividual* _tmp7_;
			gboolean _tmp9_;
			FolksIndividual* _tmp10_;
			gboolean _tmp11_ = FALSE;
			FolksIndividual* _tmp12_;
			gboolean _tmp13_;
			gboolean _tmp14_;
			gboolean _tmp20_;
#line 808 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp2_ = _i_it;
#line 808 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp3_ = gee_iterator_next (_tmp2_);
#line 808 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (!_tmp3_) {
#line 808 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				break;
#line 4747 "aggregation.c"
			}
#line 808 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp4_ = _i_it;
#line 808 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp5_ = gee_iterator_get (_tmp4_);
#line 808 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp5_;
#line 810 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp7_ = i;
#line 810 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (_tmp7_ != NULL) {
#line 810 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp6_ = TRUE;
#line 4761 "aggregation.c"
			} else {
				gboolean _tmp8_;
#line 810 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp8_ = detailed;
#line 810 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp6_ = _tmp8_ == TRUE;
#line 4768 "aggregation.c"
			}
#line 810 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp9_ = _tmp6_;
#line 810 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			g_assert (_tmp9_);
#line 811 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp10_ = i;
#line 811 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (_tmp10_ == NULL) {
#line 813 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (i);
#line 813 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				continue;
#line 4782 "aggregation.c"
			}
#line 816 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp12_ = i;
#line 816 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp13_ = folks_individual_get_is_user (_tmp12_);
#line 816 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp14_ = _tmp13_;
#line 816 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (_tmp14_) {
#line 816 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp11_ = TRUE;
#line 4794 "aggregation.c"
			} else {
				FolksIndividual* _tmp15_;
				GeeSet* _tmp16_;
				GeeSet* _tmp17_;
				gint _tmp18_;
				gint _tmp19_;
#line 816 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp15_ = i;
#line 816 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp16_ = folks_individual_get_personas (_tmp15_);
#line 816 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp17_ = _tmp16_;
#line 816 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp18_ = gee_collection_get_size ((GeeCollection*) _tmp17_);
#line 816 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp19_ = _tmp18_;
#line 816 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp11_ = _tmp19_ == 1;
#line 4813 "aggregation.c"
			}
#line 816 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp20_ = _tmp11_;
#line 816 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			g_assert (_tmp20_);
#line 808 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 4821 "aggregation.c"
		}
#line 808 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 4825 "aggregation.c"
	}
	{
		GeeCollection* _tmp21_;
		GeeIterator* _tmp22_ = NULL;
		GeeIterator* _i_it;
#line 819 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp21_ = added;
#line 819 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp22_ = gee_iterable_iterator ((GeeIterable*) _tmp21_);
#line 819 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_i_it = _tmp22_;
#line 819 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 4839 "aggregation.c"
			GeeIterator* _tmp23_;
			gboolean _tmp24_ = FALSE;
			GeeIterator* _tmp25_;
			gpointer _tmp26_ = NULL;
			FolksIndividual* i;
			gboolean _tmp27_ = FALSE;
			FolksIndividual* _tmp28_;
			gboolean _tmp30_;
			FolksIndividual* _tmp31_;
			gboolean _tmp32_ = FALSE;
			FolksIndividual* _tmp33_;
			gboolean _tmp34_;
			gboolean _tmp35_;
			gboolean _tmp41_;
#line 819 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp23_ = _i_it;
#line 819 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp24_ = gee_iterator_next (_tmp23_);
#line 819 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (!_tmp24_) {
#line 819 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				break;
#line 4862 "aggregation.c"
			}
#line 819 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp25_ = _i_it;
#line 819 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp26_ = gee_iterator_get (_tmp25_);
#line 819 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp26_;
#line 821 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp28_ = i;
#line 821 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (_tmp28_ != NULL) {
#line 821 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp27_ = TRUE;
#line 4876 "aggregation.c"
			} else {
				gboolean _tmp29_;
#line 821 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp29_ = detailed;
#line 821 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp27_ = _tmp29_ == TRUE;
#line 4883 "aggregation.c"
			}
#line 821 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp30_ = _tmp27_;
#line 821 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			g_assert (_tmp30_);
#line 822 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp31_ = i;
#line 822 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (_tmp31_ == NULL) {
#line 824 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (i);
#line 824 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				continue;
#line 4897 "aggregation.c"
			}
#line 827 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp33_ = i;
#line 827 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp34_ = folks_individual_get_is_user (_tmp33_);
#line 827 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp35_ = _tmp34_;
#line 827 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (_tmp35_) {
#line 827 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp32_ = TRUE;
#line 4909 "aggregation.c"
			} else {
				FolksIndividual* _tmp36_;
				GeeSet* _tmp37_;
				GeeSet* _tmp38_;
				gint _tmp39_;
				gint _tmp40_;
#line 827 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp36_ = i;
#line 827 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp37_ = folks_individual_get_personas (_tmp36_);
#line 827 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp38_ = _tmp37_;
#line 827 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp39_ = gee_collection_get_size ((GeeCollection*) _tmp38_);
#line 827 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp40_ = _tmp39_;
#line 827 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp32_ = _tmp40_ == 1;
#line 4928 "aggregation.c"
			}
#line 827 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp41_ = _tmp32_;
#line 827 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			g_assert (_tmp41_);
#line 819 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 4936 "aggregation.c"
		}
#line 819 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 4940 "aggregation.c"
	}
}


static Block6Data* block6_data_ref (Block6Data* _data6_) {
#line 845 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_atomic_int_inc (&_data6_->_ref_count_);
#line 845 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return _data6_;
#line 4950 "aggregation.c"
}


static void block6_data_unref (void * _userdata_) {
	Block6Data* _data6_;
	_data6_ = (Block6Data*) _userdata_;
#line 845 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	if (g_atomic_int_dec_and_test (&_data6_->_ref_count_)) {
#line 4959 "aggregation.c"
		AggregationTests * self;
#line 845 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		self = _data6_->self;
#line 845 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data6_->aggregator);
#line 845 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data6_->individuals_map);
#line 845 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_main_loop_unref0 (_data6_->main_loop);
#line 845 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (self);
#line 845 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_slice_free (Block6Data, _data6_);
#line 4973 "aggregation.c"
	}
}


static void ____lambda28_ (Block6Data* _data6_, GObject* obj) {
	AggregationTests * self;
	GObject* _tmp0_;
	FolksIndividual* ind;
	FolksIndividual* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	FolksIndividual* _tmp4_;
	gchar* _tmp5_ = NULL;
	gchar* weak_key;
	GeeHashMap* _tmp6_;
	const gchar* _tmp7_;
	gboolean _tmp8_ = FALSE;
	GeeHashMap* _tmp9_;
	const gchar* _tmp10_;
	gpointer _tmp11_ = NULL;
	AggregationTestsIndividualState state;
	gboolean _tmp12_ = FALSE;
	AggregationTestsIndividualState _tmp13_;
	gboolean _tmp18_;
	GeeHashMap* _tmp19_;
	const gchar* _tmp20_;
#line 902 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data6_->self;
#line 902 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (obj != NULL);
#line 904 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = obj;
#line 904 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	ind = FOLKS_INDIVIDUAL (_tmp0_);
#line 905 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = ind;
#line 905 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = folks_individual_get_id (_tmp1_);
#line 905 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = _tmp2_;
#line 905 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp4_ = ind;
#line 905 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp5_ = g_strdup_printf ("%s:%p", _tmp3_, _tmp4_);
#line 905 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	weak_key = _tmp5_;
#line 907 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp6_ = _data6_->individuals_map;
#line 907 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp7_ = weak_key;
#line 907 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp8_ = gee_abstract_map_has_key ((GeeAbstractMap*) _tmp6_, _tmp7_);
#line 907 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (_tmp8_ == TRUE);
#line 908 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp9_ = _data6_->individuals_map;
#line 908 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp10_ = weak_key;
#line 908 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp11_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp9_, _tmp10_);
#line 908 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	state = GPOINTER_TO_INT (_tmp11_);
#line 909 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp13_ = state;
#line 909 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	if (_tmp13_ == AGGREGATION_TESTS_INDIVIDUAL_STATE_REMOVED) {
#line 909 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp12_ = TRUE;
#line 5042 "aggregation.c"
	} else {
		gboolean _tmp14_ = FALSE;
		gboolean _tmp15_;
		gboolean _tmp17_;
#line 910 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp15_ = _data6_->aggregator_is_finalising;
#line 910 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		if (_tmp15_ == TRUE) {
#line 5051 "aggregation.c"
			AggregationTestsIndividualState _tmp16_;
#line 911 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp16_ = state;
#line 911 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp14_ = _tmp16_ == AGGREGATION_TESTS_INDIVIDUAL_STATE_ADDED;
#line 5057 "aggregation.c"
		} else {
#line 910 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp14_ = FALSE;
#line 5061 "aggregation.c"
		}
#line 910 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp17_ = _tmp14_;
#line 910 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp12_ = _tmp17_;
#line 5067 "aggregation.c"
	}
#line 909 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp18_ = _tmp12_;
#line 909 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (_tmp18_);
#line 913 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp19_ = _data6_->individuals_map;
#line 913 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp20_ = weak_key;
#line 913 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp19_, _tmp20_, GINT_TO_POINTER (AGGREGATION_TESTS_INDIVIDUAL_STATE_FINALISED));
#line 902 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_free0 (weak_key);
#line 5081 "aggregation.c"
}


static void _____lambda28__gweak_notify (gpointer self, GObject* object) {
#line 902 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	____lambda28_ (self, object);
#line 5088 "aggregation.c"
}


static void __lambda27_ (Block6Data* _data6_, GeeSet* added, GeeSet* removed, const gchar* m, FolksPersona* a, FolksGroupDetailsChangeReason r) {
	AggregationTests * self;
#line 877 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data6_->self;
#line 877 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (added != NULL);
#line 877 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (removed != NULL);
#line 5100 "aggregation.c"
	{
		GeeSet* _tmp0_;
		GeeIterator* _tmp1_ = NULL;
		GeeIterator* _i_it;
#line 879 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp0_ = removed;
#line 879 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp1_ = gee_iterable_iterator ((GeeIterable*) _tmp0_);
#line 879 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_i_it = _tmp1_;
#line 879 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 5113 "aggregation.c"
			GeeIterator* _tmp2_;
			gboolean _tmp3_ = FALSE;
			GeeIterator* _tmp4_;
			gpointer _tmp5_ = NULL;
			FolksIndividual* i;
			FolksIndividual* _tmp6_;
			const gchar* _tmp7_;
			const gchar* _tmp8_;
			FolksIndividual* _tmp9_;
			gchar* _tmp10_ = NULL;
			gchar* key;
			GeeHashMap* _tmp11_;
			const gchar* _tmp12_;
			gboolean _tmp13_ = FALSE;
			GeeHashMap* _tmp14_;
			const gchar* _tmp15_;
			gpointer _tmp16_ = NULL;
			GeeHashMap* _tmp17_;
			const gchar* _tmp18_;
#line 879 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp2_ = _i_it;
#line 879 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp3_ = gee_iterator_next (_tmp2_);
#line 879 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (!_tmp3_) {
#line 879 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				break;
#line 5141 "aggregation.c"
			}
#line 879 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp4_ = _i_it;
#line 879 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp5_ = gee_iterator_get (_tmp4_);
#line 879 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp5_;
#line 881 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp6_ = i;
#line 881 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp7_ = folks_individual_get_id (_tmp6_);
#line 881 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp8_ = _tmp7_;
#line 881 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp9_ = i;
#line 881 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp10_ = g_strdup_printf ("%s:%p", _tmp8_, _tmp9_);
#line 881 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			key = _tmp10_;
#line 883 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp11_ = _data6_->individuals_map;
#line 883 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp12_ = key;
#line 883 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp13_ = gee_abstract_map_has_key ((GeeAbstractMap*) _tmp11_, _tmp12_);
#line 883 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			g_assert (_tmp13_ == TRUE);
#line 884 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp14_ = _data6_->individuals_map;
#line 884 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp15_ = key;
#line 884 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp16_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp14_, _tmp15_);
#line 884 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			g_assert (GPOINTER_TO_INT (_tmp16_) == AGGREGATION_TESTS_INDIVIDUAL_STATE_ADDED);
#line 886 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp17_ = _data6_->individuals_map;
#line 886 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp18_ = key;
#line 886 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			gee_abstract_map_set ((GeeAbstractMap*) _tmp17_, _tmp18_, GINT_TO_POINTER (AGGREGATION_TESTS_INDIVIDUAL_STATE_REMOVED));
#line 879 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_g_free0 (key);
#line 879 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 5187 "aggregation.c"
		}
#line 879 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 5191 "aggregation.c"
	}
	{
		GeeSet* _tmp19_;
		GeeIterator* _tmp20_ = NULL;
		GeeIterator* _i_it;
#line 889 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp19_ = added;
#line 889 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp20_ = gee_iterable_iterator ((GeeIterable*) _tmp19_);
#line 889 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_i_it = _tmp20_;
#line 889 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 5205 "aggregation.c"
			GeeIterator* _tmp21_;
			gboolean _tmp22_ = FALSE;
			GeeIterator* _tmp23_;
			gpointer _tmp24_ = NULL;
			FolksIndividual* i;
			FolksIndividual* _tmp25_;
			const gchar* _tmp26_;
			const gchar* _tmp27_;
			FolksIndividual* _tmp28_;
			gchar* _tmp29_ = NULL;
			gchar* key;
			GeeHashMap* _tmp30_;
			const gchar* _tmp31_;
			gboolean _tmp32_ = FALSE;
			GeeHashMap* _tmp33_;
			const gchar* _tmp34_;
			FolksIndividual* _tmp35_;
#line 889 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp21_ = _i_it;
#line 889 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp22_ = gee_iterator_next (_tmp21_);
#line 889 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (!_tmp22_) {
#line 889 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				break;
#line 5231 "aggregation.c"
			}
#line 889 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp23_ = _i_it;
#line 889 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp24_ = gee_iterator_get (_tmp23_);
#line 889 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp24_;
#line 891 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp25_ = i;
#line 891 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp26_ = folks_individual_get_id (_tmp25_);
#line 891 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp27_ = _tmp26_;
#line 891 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp28_ = i;
#line 891 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp29_ = g_strdup_printf ("%s:%p", _tmp27_, _tmp28_);
#line 891 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			key = _tmp29_;
#line 893 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp30_ = _data6_->individuals_map;
#line 893 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp31_ = key;
#line 893 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp32_ = gee_abstract_map_has_key ((GeeAbstractMap*) _tmp30_, _tmp31_);
#line 893 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			g_assert (_tmp32_ == FALSE);
#line 895 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp33_ = _data6_->individuals_map;
#line 895 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp34_ = key;
#line 895 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			gee_abstract_map_set ((GeeAbstractMap*) _tmp33_, _tmp34_, GINT_TO_POINTER (AGGREGATION_TESTS_INDIVIDUAL_STATE_ADDED));
#line 902 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp35_ = i;
#line 902 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			g_object_weak_ref ((GObject*) _tmp35_, _____lambda28__gweak_notify, _data6_);
#line 889 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_g_free0 (key);
#line 889 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 5273 "aggregation.c"
		}
#line 889 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 5277 "aggregation.c"
	}
}


static void ___lambda27__folks_individual_aggregator_individuals_changed (FolksIndividualAggregator* _sender, GeeSet* added, GeeSet* removed, const gchar* message, FolksPersona* actor, FolksGroupDetailsChangeReason reason, gpointer self) {
#line 877 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	__lambda27_ (self, added, removed, message, actor, reason);
#line 5285 "aggregation.c"
}


static gboolean __lambda29_ (Block6Data* _data6_) {
	AggregationTests * self;
	gboolean result = FALSE;
	GMainLoop* _tmp0_;
#line 920 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data6_->self;
#line 922 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data6_->main_loop;
#line 922 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_main_loop_quit (_tmp0_);
#line 923 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 923 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 5303 "aggregation.c"
}


static gboolean ___lambda29__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda29_ (self);
#line 920 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 5312 "aggregation.c"
}


static void __lambda31_ (Block6Data* _data6_, GObject* s, GAsyncResult* r) {
	AggregationTests * self;
	GError * _inner_error_ = NULL;
#line 928 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data6_->self;
#line 928 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (r != NULL);
#line 5323 "aggregation.c"
	{
		FolksIndividualAggregator* _tmp0_;
		GAsyncResult* _tmp1_;
#line 932 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp0_ = _data6_->aggregator;
#line 932 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp1_ = r;
#line 932 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		folks_individual_aggregator_prepare_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 932 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		if (_inner_error_ != NULL) {
#line 5335 "aggregation.c"
			goto __catch5_g_error;
		}
	}
	goto __finally5;
	__catch5_g_error:
	{
		GError* e1 = NULL;
		const gchar* _tmp2_;
#line 930 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		e1 = _inner_error_;
#line 930 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_inner_error_ = NULL;
#line 936 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp2_ = e1->message;
#line 936 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_critical ("aggregation.vala:936: Failed to prepare aggregator: %s", _tmp2_);
#line 938 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_assert_not_reached ();
#line 930 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_error_free0 (e1);
#line 5356 "aggregation.c"
	}
	__finally5:
#line 930 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	if (_inner_error_ != NULL) {
#line 930 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 930 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 930 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		return;
#line 5367 "aggregation.c"
	}
}


static void ___lambda31__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 928 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	__lambda31_ (self, source_object, res);
#line 928 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	block6_data_unref (self);
#line 5377 "aggregation.c"
}


static gboolean __lambda30_ (Block6Data* _data6_) {
	AggregationTests * self;
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_;
#line 926 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data6_->self;
#line 928 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data6_->aggregator;
#line 928 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	folks_individual_aggregator_prepare (_tmp0_, ___lambda31__gasync_ready_callback, block6_data_ref (_data6_));
#line 942 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 942 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 5395 "aggregation.c"
}


static gboolean ___lambda30__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda30_ (self);
#line 926 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 5404 "aggregation.c"
}


static gboolean __lambda32_ (Block6Data* _data6_) {
	AggregationTests * self;
	gboolean result = FALSE;
	GMainLoop* _tmp0_;
#line 965 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data6_->self;
#line 967 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data6_->main_loop;
#line 967 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_main_loop_quit (_tmp0_);
#line 968 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 968 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 5422 "aggregation.c"
}


static gboolean ___lambda32__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda32_ (self);
#line 965 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 5431 "aggregation.c"
}


void aggregation_tests_test_linked_individual_refcounting (AggregationTests* self) {
	Block6Data* _data6_;
	GMainLoop* _tmp0_;
	KfTestBackend* _tmp1_;
	TpTestBackend* _tmp2_;
	void* _tmp3_ = NULL;
	void* account_handle;
	GeeHashMap* _tmp4_;
	FolksIndividualAggregator* _tmp5_;
	FolksIndividualAggregator* _tmp6_;
	gint _tmp7_;
	GMainLoop* _tmp8_;
	GeeHashMap* _tmp9_;
	GeeMapIterator* _tmp10_ = NULL;
	GeeMapIterator* iter;
	TpTestBackend* _tmp19_;
	void* _tmp20_;
	KfTestBackend* _tmp21_;
	gint _tmp22_;
	GMainLoop* _tmp23_;
	GeeHashMap* _tmp24_;
	GeeMapIterator* _tmp25_ = NULL;
#line 845 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 845 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data6_ = g_slice_new0 (Block6Data);
#line 845 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data6_->_ref_count_ = 1;
#line 845 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data6_->self = g_object_ref (self);
#line 847 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 847 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data6_->main_loop = _tmp0_;
#line 849 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = self->priv->_kf_backend;
#line 849 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	kf_test_backend_set_up (_tmp1_, "[0]\n" "protocol=travis@example.com;olivier@example.com;" "guillaume@example.com;sjoerd@example.com\n" "[1]\n" "protocol=christian@example.com;wim@example.com;" "helen@example.com;geraldine@example.com");
#line 856 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = self->priv->_tp_backend;
#line 856 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = tp_test_backend_add_account (_tmp2_, "protocol", "me@example.com", "cm", "account");
#line 856 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	account_handle = _tmp3_;
#line 871 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp4_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, AGGREGATION_TESTS_TYPE_INDIVIDUAL_STATE, NULL, NULL, NULL, NULL, NULL);
#line 871 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data6_->individuals_map = _tmp4_;
#line 874 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp5_ = folks_individual_aggregator_new ();
#line 874 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data6_->aggregator = _tmp5_;
#line 875 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data6_->aggregator_is_finalising = FALSE;
#line 877 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp6_ = _data6_->aggregator;
#line 877 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_signal_connect_data (_tmp6_, "individuals-changed", (GCallback) ___lambda27__folks_individual_aggregator_individuals_changed, block6_data_ref (_data6_), (GClosureNotify) block6_data_unref, 0);
#line 920 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp7_ = self->priv->_test_timeout;
#line 920 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) _tmp7_, ___lambda29__gsource_func, block6_data_ref (_data6_), block6_data_unref);
#line 926 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda30__gsource_func, block6_data_ref (_data6_), block6_data_unref);
#line 945 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp8_ = _data6_->main_loop;
#line 945 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_main_loop_run (_tmp8_);
#line 949 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp9_ = _data6_->individuals_map;
#line 949 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp10_ = gee_abstract_map_map_iterator ((GeeAbstractMap*) _tmp9_);
#line 949 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	iter = _tmp10_;
#line 950 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	while (TRUE) {
#line 5511 "aggregation.c"
		GeeMapIterator* _tmp11_;
		gboolean _tmp12_ = FALSE;
		GeeMapIterator* _tmp13_;
		gpointer _tmp14_ = NULL;
		AggregationTestsIndividualState state;
		gboolean _tmp15_ = FALSE;
		AggregationTestsIndividualState _tmp16_;
		gboolean _tmp18_;
#line 950 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp11_ = iter;
#line 950 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp12_ = gee_map_iterator_next (_tmp11_);
#line 950 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		if (!(_tmp12_ == TRUE)) {
#line 950 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			break;
#line 5528 "aggregation.c"
		}
#line 952 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp13_ = iter;
#line 952 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp14_ = gee_map_iterator_get_value (_tmp13_);
#line 952 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		state = GPOINTER_TO_INT (_tmp14_);
#line 953 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp16_ = state;
#line 953 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		if (_tmp16_ == AGGREGATION_TESTS_INDIVIDUAL_STATE_ADDED) {
#line 953 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp15_ = TRUE;
#line 5542 "aggregation.c"
		} else {
			AggregationTestsIndividualState _tmp17_;
#line 954 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp17_ = state;
#line 954 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp15_ = _tmp17_ == AGGREGATION_TESTS_INDIVIDUAL_STATE_FINALISED;
#line 5549 "aggregation.c"
		}
#line 953 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp18_ = _tmp15_;
#line 953 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_assert (_tmp18_);
#line 5555 "aggregation.c"
	}
#line 958 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp19_ = self->priv->_tp_backend;
#line 958 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp20_ = account_handle;
#line 958 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	tp_test_backend_remove_account (_tmp19_, _tmp20_);
#line 959 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp21_ = self->priv->_kf_backend;
#line 959 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	kf_test_backend_tear_down (_tmp21_);
#line 960 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data6_->aggregator_is_finalising = TRUE;
#line 961 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (_data6_->aggregator);
#line 961 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data6_->aggregator = NULL;
#line 965 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp22_ = self->priv->_test_timeout;
#line 965 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) _tmp22_, ___lambda32__gsource_func, block6_data_ref (_data6_), block6_data_unref);
#line 971 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp23_ = _data6_->main_loop;
#line 971 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_main_loop_run (_tmp23_);
#line 975 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp24_ = _data6_->individuals_map;
#line 975 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp25_ = gee_abstract_map_map_iterator ((GeeAbstractMap*) _tmp24_);
#line 975 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (iter);
#line 975 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	iter = _tmp25_;
#line 976 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	while (TRUE) {
#line 5591 "aggregation.c"
		GeeMapIterator* _tmp26_;
		gboolean _tmp27_ = FALSE;
		GeeMapIterator* _tmp28_;
		gpointer _tmp29_ = NULL;
#line 976 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp26_ = iter;
#line 976 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp27_ = gee_map_iterator_next (_tmp26_);
#line 976 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		if (!(_tmp27_ == TRUE)) {
#line 976 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			break;
#line 5604 "aggregation.c"
		}
#line 978 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp28_ = iter;
#line 978 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp29_ = gee_map_iterator_get_value (_tmp28_);
#line 978 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_assert (GPOINTER_TO_INT (_tmp29_) == AGGREGATION_TESTS_INDIVIDUAL_STATE_FINALISED);
#line 5612 "aggregation.c"
	}
#line 845 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (iter);
#line 845 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	block6_data_unref (_data6_);
#line 845 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data6_ = NULL;
#line 5620 "aggregation.c"
}


static Block7Data* block7_data_ref (Block7Data* _data7_) {
#line 988 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_atomic_int_inc (&_data7_->_ref_count_);
#line 988 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return _data7_;
#line 5629 "aggregation.c"
}


static void block7_data_unref (void * _userdata_) {
	Block7Data* _data7_;
	_data7_ = (Block7Data*) _userdata_;
#line 988 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	if (g_atomic_int_dec_and_test (&_data7_->_ref_count_)) {
#line 5638 "aggregation.c"
		AggregationTests * self;
#line 988 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		self = _data7_->self;
#line 988 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data7_->writeable_persona);
#line 988 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data7_->aggregator);
#line 988 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data7_->individual);
#line 988 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_main_loop_unref0 (_data7_->main_loop);
#line 988 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (self);
#line 988 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_slice_free (Block7Data, _data7_);
#line 5654 "aggregation.c"
	}
}


static void __lambda33_ (Block7Data* _data7_, GeeMultiMap* changes) {
	AggregationTests * self;
	GeeMultiMap* _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
#line 999 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data7_->self;
#line 999 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (changes != NULL);
#line 1001 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = changes;
#line 1001 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = gee_multi_map_get_size (_tmp0_);
#line 1001 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = _tmp1_;
#line 1001 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (_tmp2_ == 1);
#line 5676 "aggregation.c"
	{
		GeeMultiMap* _tmp3_;
		GeeSet* _tmp4_ = NULL;
		GeeSet* _tmp5_;
		GeeIterator* _tmp6_ = NULL;
		GeeIterator* _tmp7_;
		GeeIterator* _removed_it;
#line 1003 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp3_ = changes;
#line 1003 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp4_ = gee_multi_map_get_keys (_tmp3_);
#line 1003 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp5_ = _tmp4_;
#line 1003 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp6_ = gee_iterable_iterator ((GeeIterable*) _tmp5_);
#line 1003 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp7_ = _tmp6_;
#line 1003 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_tmp5_);
#line 1003 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_removed_it = _tmp7_;
#line 1003 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 5700 "aggregation.c"
			GeeIterator* _tmp8_;
			gboolean _tmp9_ = FALSE;
			GeeIterator* _tmp10_;
			gpointer _tmp11_ = NULL;
			FolksIndividual* removed;
			FolksIndividual* _tmp12_;
#line 1003 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp8_ = _removed_it;
#line 1003 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp9_ = gee_iterator_next (_tmp8_);
#line 1003 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (!_tmp9_) {
#line 1003 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				break;
#line 5715 "aggregation.c"
			}
#line 1003 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp10_ = _removed_it;
#line 1003 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp11_ = gee_iterator_get (_tmp10_);
#line 1003 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			removed = (FolksIndividual*) _tmp11_;
#line 1005 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp12_ = removed;
#line 1005 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			g_assert (_tmp12_ == NULL);
#line 5727 "aggregation.c"
			{
				GeeMultiMap* _tmp13_;
				FolksIndividual* _tmp14_;
				GeeCollection* _tmp15_ = NULL;
				GeeCollection* _tmp16_;
				GeeIterator* _tmp17_ = NULL;
				GeeIterator* _tmp18_;
				GeeIterator* _i_it;
#line 1007 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp13_ = changes;
#line 1007 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp14_ = removed;
#line 1007 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp15_ = gee_multi_map_get (_tmp13_, _tmp14_);
#line 1007 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp16_ = _tmp15_;
#line 1007 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp17_ = gee_iterable_iterator ((GeeIterable*) _tmp16_);
#line 1007 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp18_ = _tmp17_;
#line 1007 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (_tmp16_);
#line 1007 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_i_it = _tmp18_;
#line 1007 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				while (TRUE) {
#line 5754 "aggregation.c"
					GeeIterator* _tmp19_;
					gboolean _tmp20_ = FALSE;
					GeeIterator* _tmp21_;
					gpointer _tmp22_ = NULL;
					FolksIndividual* i;
					FolksIndividual* _tmp23_;
					FolksIndividual* _tmp24_;
					FolksIndividual* _tmp25_;
#line 1007 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp19_ = _i_it;
#line 1007 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp20_ = gee_iterator_next (_tmp19_);
#line 1007 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					if (!_tmp20_) {
#line 1007 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						break;
#line 5771 "aggregation.c"
					}
#line 1007 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp21_ = _i_it;
#line 1007 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp22_ = gee_iterator_get (_tmp21_);
#line 1007 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					i = (FolksIndividual*) _tmp22_;
#line 1009 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp23_ = i;
#line 1009 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					g_assert (_tmp23_ != NULL);
#line 1010 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					g_assert (_data7_->individual == NULL);
#line 1012 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp24_ = i;
#line 1012 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp25_ = _g_object_ref0 (_tmp24_);
#line 1012 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_g_object_unref0 (_data7_->individual);
#line 1012 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_data7_->individual = _tmp25_;
#line 1013 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					g_main_loop_quit (_data7_->main_loop);
#line 1007 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_g_object_unref0 (i);
#line 5797 "aggregation.c"
				}
#line 1007 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (_i_it);
#line 5801 "aggregation.c"
			}
#line 1003 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (removed);
#line 5805 "aggregation.c"
		}
#line 1003 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_removed_it);
#line 5809 "aggregation.c"
	}
}


static void ___lambda33__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 999 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	__lambda33_ (self, changes);
#line 5817 "aggregation.c"
}


static gboolean __lambda34_ (Block7Data* _data7_) {
	AggregationTests * self;
	gboolean result = FALSE;
#line 1019 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data7_->self;
#line 1021 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_main_loop_quit (_data7_->main_loop);
#line 1022 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 1022 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 5832 "aggregation.c"
}


static gboolean ___lambda34__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda34_ (self);
#line 1019 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 5841 "aggregation.c"
}


static void __lambda36_ (Block7Data* _data7_, GObject* s, GAsyncResult* r) {
	AggregationTests * self;
	GError * _inner_error_ = NULL;
#line 1027 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data7_->self;
#line 1027 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (r != NULL);
#line 5852 "aggregation.c"
	{
		FolksIndividualAggregator* _tmp0_;
		GAsyncResult* _tmp1_;
#line 1031 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp0_ = _data7_->aggregator;
#line 1031 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp1_ = r;
#line 1031 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		folks_individual_aggregator_prepare_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 1031 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		if (_inner_error_ != NULL) {
#line 5864 "aggregation.c"
			goto __catch6_g_error;
		}
	}
	goto __finally6;
	__catch6_g_error:
	{
		GError* e1 = NULL;
		const gchar* _tmp2_;
#line 1029 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		e1 = _inner_error_;
#line 1029 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_inner_error_ = NULL;
#line 1035 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp2_ = e1->message;
#line 1035 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_critical ("aggregation.vala:1035: Failed to prepare aggregator: %s", _tmp2_);
#line 1037 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_assert_not_reached ();
#line 1029 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_error_free0 (e1);
#line 5885 "aggregation.c"
	}
	__finally6:
#line 1029 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	if (_inner_error_ != NULL) {
#line 1029 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1029 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 1029 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		return;
#line 5896 "aggregation.c"
	}
}


static void ___lambda36__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 1027 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	__lambda36_ (self, source_object, res);
#line 1027 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	block7_data_unref (self);
#line 5906 "aggregation.c"
}


static gboolean __lambda35_ (Block7Data* _data7_) {
	AggregationTests * self;
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_;
#line 1025 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data7_->self;
#line 1027 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data7_->aggregator;
#line 1027 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	folks_individual_aggregator_prepare (_tmp0_, ___lambda36__gasync_ready_callback, block7_data_ref (_data7_));
#line 1041 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 1041 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 5924 "aggregation.c"
}


static gboolean ___lambda35__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda35_ (self);
#line 1025 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 5933 "aggregation.c"
}


static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle) {
	int i;
#line 1058 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	for (i = 0; i < stack_length; i++) {
#line 1058 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		if (g_strcmp0 (stack[i], needle) == 0) {
#line 1058 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			return TRUE;
#line 5945 "aggregation.c"
		}
	}
#line 1058 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return FALSE;
#line 5950 "aggregation.c"
}


static gboolean __lambda37_ (Block7Data* _data7_) {
	AggregationTests * self;
	gboolean result = FALSE;
#line 1063 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data7_->self;
#line 1065 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_main_loop_quit (_data7_->main_loop);
#line 1066 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 1066 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 5965 "aggregation.c"
}


static gboolean ___lambda37__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda37_ (self);
#line 1063 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 5974 "aggregation.c"
}


static void __lambda39_ (Block7Data* _data7_, GObject* obj, GAsyncResult* res) {
	AggregationTests * self;
	GError * _inner_error_ = NULL;
#line 1072 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data7_->self;
#line 1072 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (res != NULL);
#line 5985 "aggregation.c"
	{
		FolksIndividualAggregator* _tmp0_;
		GAsyncResult* _tmp1_;
		FolksPersona* _tmp2_ = NULL;
		FolksPersona* _tmp3_;
#line 1077 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp0_ = _data7_->aggregator;
#line 1077 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp1_ = res;
#line 1077 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp2_ = folks_individual_aggregator_ensure_individual_property_writeable_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 1077 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp3_ = _tmp2_;
#line 1077 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		if (_inner_error_ != NULL) {
#line 6001 "aggregation.c"
			goto __catch7_g_error;
		}
#line 1076 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data7_->writeable_persona);
#line 1076 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_data7_->writeable_persona = _tmp3_;
#line 1079 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_main_loop_quit (_data7_->main_loop);
#line 6010 "aggregation.c"
	}
	goto __finally7;
	__catch7_g_error:
	{
		GError* e1 = NULL;
		const gchar* _tmp4_;
#line 1074 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		e1 = _inner_error_;
#line 1074 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_inner_error_ = NULL;
#line 1083 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp4_ = e1->message;
#line 1083 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_critical ("aggregation.vala:1083: Failed to ensure property writeable: %s", _tmp4_);
#line 1085 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_assert_not_reached ();
#line 1074 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_error_free0 (e1);
#line 6029 "aggregation.c"
	}
	__finally7:
#line 1074 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	if (_inner_error_ != NULL) {
#line 1074 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1074 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 1074 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		return;
#line 6040 "aggregation.c"
	}
}


static void ___lambda39__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 1071 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	__lambda39_ (self, source_object, res);
#line 1071 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	block7_data_unref (self);
#line 6050 "aggregation.c"
}


static gboolean __lambda38_ (Block7Data* _data7_) {
	AggregationTests * self;
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_;
#line 1069 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data7_->self;
#line 1071 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data7_->aggregator;
#line 1071 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	folks_individual_aggregator_ensure_individual_property_writeable (_tmp0_, _data7_->individual, "alias", ___lambda39__gasync_ready_callback, block7_data_ref (_data7_));
#line 1089 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 1089 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 6068 "aggregation.c"
}


static gboolean ___lambda38__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda38_ (self);
#line 1069 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 6077 "aggregation.c"
}


void aggregation_tests_test_ensure_individual_property_writeable_trivial (AggregationTests* self) {
	Block7Data* _data7_;
	GMainLoop* _tmp0_;
	KfTestBackend* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	gint _tmp4_;
	FolksPersona* persona;
	FolksPersona* _tmp12_;
	FolksPersona* _tmp13_;
	gchar** _tmp14_;
	gint _tmp14__length1;
	gchar** _tmp15_;
	gint _tmp15__length1;
	gint _tmp16_;
	FolksPersona* _tmp17_;
	KfTestBackend* _tmp18_;
#line 988 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 988 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data7_ = g_slice_new0 (Block7Data);
#line 988 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data7_->_ref_count_ = 1;
#line 988 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data7_->self = g_object_ref (self);
#line 990 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 990 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data7_->main_loop = _tmp0_;
#line 992 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = self->priv->_kf_backend;
#line 992 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	kf_test_backend_set_up (_tmp1_, "[0]\n" "protocol=travis@example.com\n");
#line 995 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data7_->individual = NULL;
#line 998 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = folks_individual_aggregator_new ();
#line 998 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data7_->aggregator = _tmp2_;
#line 999 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = _data7_->aggregator;
#line 999 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_signal_connect_data (_tmp3_, "individuals-changed-detailed", (GCallback) ___lambda33__folks_individual_aggregator_individuals_changed_detailed, block7_data_ref (_data7_), (GClosureNotify) block7_data_unref, 0);
#line 1019 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp4_ = self->priv->_test_timeout;
#line 1019 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) _tmp4_, ___lambda34__gsource_func, block7_data_ref (_data7_), block7_data_unref);
#line 1025 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda35__gsource_func, block7_data_ref (_data7_), block7_data_unref);
#line 1044 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_main_loop_run (_data7_->main_loop);
#line 1047 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (_data7_->individual != NULL);
#line 1049 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	persona = NULL;
#line 6136 "aggregation.c"
	{
		GeeSet* _tmp5_;
		GeeSet* _tmp6_;
		GeeIterator* _tmp7_ = NULL;
		GeeIterator* _p_it;
#line 1050 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp5_ = folks_individual_get_personas (_data7_->individual);
#line 1050 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp6_ = _tmp5_;
#line 1050 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp7_ = gee_iterable_iterator ((GeeIterable*) _tmp6_);
#line 1050 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_p_it = _tmp7_;
#line 1050 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 6152 "aggregation.c"
			gboolean _tmp8_ = FALSE;
			gpointer _tmp9_ = NULL;
			FolksPersona* p;
			FolksPersona* _tmp10_;
			FolksPersona* _tmp11_;
#line 1050 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp8_ = gee_iterator_next (_p_it);
#line 1050 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (!_tmp8_) {
#line 1050 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				break;
#line 6164 "aggregation.c"
			}
#line 1050 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp9_ = gee_iterator_get (_p_it);
#line 1050 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			p = (FolksPersona*) _tmp9_;
#line 1052 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp10_ = p;
#line 1052 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp11_ = _g_object_ref0 (_tmp10_);
#line 1052 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (persona);
#line 1052 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			persona = _tmp11_;
#line 1053 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (p);
#line 1053 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			break;
#line 6182 "aggregation.c"
		}
#line 1050 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_p_it);
#line 6186 "aggregation.c"
	}
#line 1057 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp12_ = persona;
#line 1057 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (_tmp12_ != NULL);
#line 1058 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp13_ = persona;
#line 1058 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp14_ = folks_persona_get_writeable_properties (_tmp13_, &_tmp14__length1);
#line 1058 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp15_ = _tmp14_;
#line 1058 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp15__length1 = _tmp14__length1;
#line 1058 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (_vala_string_array_contains (_tmp15_, _tmp15__length1, "alias"));
#line 1060 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data7_->writeable_persona = NULL;
#line 1063 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp16_ = self->priv->_test_timeout;
#line 1063 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) _tmp16_, ___lambda37__gsource_func, block7_data_ref (_data7_), block7_data_unref);
#line 1069 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda38__gsource_func, block7_data_ref (_data7_), block7_data_unref);
#line 1092 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_main_loop_run (_data7_->main_loop);
#line 1094 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (_data7_->writeable_persona != NULL);
#line 1095 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp17_ = persona;
#line 1095 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (_data7_->writeable_persona == _tmp17_);
#line 1098 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp18_ = self->priv->_kf_backend;
#line 1098 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	kf_test_backend_tear_down (_tmp18_);
#line 1099 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (_data7_->aggregator);
#line 1099 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data7_->aggregator = NULL;
#line 988 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (persona);
#line 988 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	block7_data_unref (_data7_);
#line 988 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data7_ = NULL;
#line 6232 "aggregation.c"
}


static Block8Data* block8_data_ref (Block8Data* _data8_) {
#line 1112 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_atomic_int_inc (&_data8_->_ref_count_);
#line 1112 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return _data8_;
#line 6241 "aggregation.c"
}


static void block8_data_unref (void * _userdata_) {
	Block8Data* _data8_;
	_data8_ = (Block8Data*) _userdata_;
#line 1112 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	if (g_atomic_int_dec_and_test (&_data8_->_ref_count_)) {
#line 6250 "aggregation.c"
		AggregationTests * self;
#line 1112 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		self = _data8_->self;
#line 1112 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data8_->writeable_persona);
#line 1112 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data8_->aggregator);
#line 1112 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data8_->individual);
#line 1112 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_main_loop_unref0 (_data8_->main_loop);
#line 1112 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (self);
#line 1112 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_slice_free (Block8Data, _data8_);
#line 6266 "aggregation.c"
	}
}


static void __lambda40_ (Block8Data* _data8_, GeeMultiMap* changes) {
	AggregationTests * self;
	GeeMultiMap* _tmp0_;
	GeeCollection* _tmp1_ = NULL;
	GeeCollection* added;
	GeeMultiMap* _tmp2_;
	GeeSet* _tmp3_ = NULL;
	GeeSet* removed;
	GeeSet* _tmp17_;
	gint _tmp18_;
	gint _tmp19_;
#line 1125 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data8_->self;
#line 1125 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (changes != NULL);
#line 1127 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = changes;
#line 1127 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 1127 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	added = _tmp1_;
#line 1128 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = changes;
#line 1128 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 1128 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	removed = _tmp3_;
#line 6298 "aggregation.c"
	{
		GeeCollection* _tmp4_;
		GeeIterator* _tmp5_ = NULL;
		GeeIterator* _i_it;
#line 1130 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp4_ = added;
#line 1130 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 1130 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_i_it = _tmp5_;
#line 1130 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 6311 "aggregation.c"
			GeeIterator* _tmp6_;
			gboolean _tmp7_ = FALSE;
			GeeIterator* _tmp8_;
			gpointer _tmp9_ = NULL;
			FolksIndividual* i;
			FolksIndividual* _tmp10_;
			FolksIndividual* _tmp11_;
			const gchar* _tmp12_;
			const gchar* _tmp13_;
#line 1130 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp6_ = _i_it;
#line 1130 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 1130 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (!_tmp7_) {
#line 1130 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				break;
#line 6329 "aggregation.c"
			}
#line 1130 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp8_ = _i_it;
#line 1130 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 1130 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp9_;
#line 1132 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp10_ = i;
#line 1132 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			g_assert (_tmp10_ != NULL);
#line 1135 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp11_ = i;
#line 1135 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp12_ = folks_individual_get_id (_tmp11_);
#line 1135 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp13_ = _tmp12_;
#line 1135 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (g_strcmp0 (_tmp13_, "0e46c5e74f61908f49550d241f2a1651892a1695") == 0) {
#line 6349 "aggregation.c"
				FolksIndividual* _tmp14_;
				FolksIndividual* _tmp15_;
				FolksIndividual* _tmp16_;
#line 1137 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp14_ = _data8_->individual;
#line 1137 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				g_assert (_tmp14_ == NULL);
#line 1138 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp15_ = i;
#line 1138 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp16_ = _g_object_ref0 (_tmp15_);
#line 1138 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (_data8_->individual);
#line 1138 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_data8_->individual = _tmp16_;
#line 1139 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (i);
#line 1139 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (_i_it);
#line 1139 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (removed);
#line 1139 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (added);
#line 1139 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				return;
#line 6375 "aggregation.c"
			}
#line 1130 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 6379 "aggregation.c"
		}
#line 1130 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 6383 "aggregation.c"
	}
#line 1143 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp17_ = removed;
#line 1143 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp18_ = gee_collection_get_size ((GeeCollection*) _tmp17_);
#line 1143 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp19_ = _tmp18_;
#line 1143 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (_tmp19_ == 1);
#line 6393 "aggregation.c"
	{
		GeeSet* _tmp20_;
		GeeIterator* _tmp21_ = NULL;
		GeeIterator* _i_it;
#line 1145 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp20_ = removed;
#line 1145 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp21_ = gee_iterable_iterator ((GeeIterable*) _tmp20_);
#line 1145 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_i_it = _tmp21_;
#line 1145 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 6406 "aggregation.c"
			GeeIterator* _tmp22_;
			gboolean _tmp23_ = FALSE;
			GeeIterator* _tmp24_;
			gpointer _tmp25_ = NULL;
			FolksIndividual* i;
			FolksIndividual* _tmp26_;
#line 1145 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp22_ = _i_it;
#line 1145 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp23_ = gee_iterator_next (_tmp22_);
#line 1145 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (!_tmp23_) {
#line 1145 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				break;
#line 6421 "aggregation.c"
			}
#line 1145 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp24_ = _i_it;
#line 1145 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp25_ = gee_iterator_get (_tmp24_);
#line 1145 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp25_;
#line 1147 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp26_ = i;
#line 1147 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			g_assert (_tmp26_ == NULL);
#line 1145 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 6435 "aggregation.c"
		}
#line 1145 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 6439 "aggregation.c"
	}
#line 1125 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (removed);
#line 1125 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (added);
#line 6445 "aggregation.c"
}


static void ___lambda40__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 1124 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	__lambda40_ (self, changes);
#line 6452 "aggregation.c"
}


static gboolean __lambda41_ (Block8Data* _data8_) {
	AggregationTests * self;
	gboolean result = FALSE;
#line 1152 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data8_->self;
#line 1154 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_main_loop_quit (_data8_->main_loop);
#line 1155 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 1155 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 6467 "aggregation.c"
}


static gboolean ___lambda41__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda41_ (self);
#line 1152 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 6476 "aggregation.c"
}


static void __lambda43_ (Block8Data* _data8_, GObject* s, GAsyncResult* r) {
	AggregationTests * self;
	GError * _inner_error_ = NULL;
#line 1160 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data8_->self;
#line 1160 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (r != NULL);
#line 6487 "aggregation.c"
	{
		FolksIndividualAggregator* _tmp0_;
		GAsyncResult* _tmp1_;
#line 1164 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp0_ = _data8_->aggregator;
#line 1164 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp1_ = r;
#line 1164 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		folks_individual_aggregator_prepare_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 1164 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		if (_inner_error_ != NULL) {
#line 6499 "aggregation.c"
			goto __catch8_g_error;
		}
	}
	goto __finally8;
	__catch8_g_error:
	{
		GError* e1 = NULL;
		const gchar* _tmp2_;
#line 1162 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		e1 = _inner_error_;
#line 1162 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_inner_error_ = NULL;
#line 1168 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp2_ = e1->message;
#line 1168 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_critical ("aggregation.vala:1168: Failed to prepare aggregator: %s", _tmp2_);
#line 1170 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_assert_not_reached ();
#line 1162 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_error_free0 (e1);
#line 6520 "aggregation.c"
	}
	__finally8:
#line 1162 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	if (_inner_error_ != NULL) {
#line 1162 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1162 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 1162 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		return;
#line 6531 "aggregation.c"
	}
}


static void ___lambda43__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 1160 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	__lambda43_ (self, source_object, res);
#line 1160 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	block8_data_unref (self);
#line 6541 "aggregation.c"
}


static gboolean __lambda42_ (Block8Data* _data8_) {
	AggregationTests * self;
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_;
#line 1158 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data8_->self;
#line 1160 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data8_->aggregator;
#line 1160 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	folks_individual_aggregator_prepare (_tmp0_, ___lambda43__gasync_ready_callback, block8_data_ref (_data8_));
#line 1174 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 1174 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 6559 "aggregation.c"
}


static gboolean ___lambda42__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda42_ (self);
#line 1158 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 6568 "aggregation.c"
}


static void __lambda44_ (Block8Data* _data8_, GeeMultiMap* changes) {
	AggregationTests * self;
	GeeMultiMap* _tmp0_;
	GeeCollection* _tmp1_ = NULL;
	GeeCollection* added;
	GeeMultiMap* _tmp2_;
	GeeSet* _tmp3_ = NULL;
	GeeSet* removed;
#line 1198 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data8_->self;
#line 1198 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (changes != NULL);
#line 1200 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = changes;
#line 1200 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 1200 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	added = _tmp1_;
#line 1201 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = changes;
#line 1201 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 1201 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	removed = _tmp3_;
#line 6596 "aggregation.c"
	{
		GeeSet* _tmp4_;
		GeeIterator* _tmp5_ = NULL;
		GeeIterator* _i_it;
#line 1203 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp4_ = removed;
#line 1203 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 1203 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_i_it = _tmp5_;
#line 1203 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 6609 "aggregation.c"
			GeeIterator* _tmp6_;
			gboolean _tmp7_ = FALSE;
			GeeIterator* _tmp8_;
			gpointer _tmp9_ = NULL;
			FolksIndividual* i;
			FolksIndividual* _tmp10_;
			FolksIndividual* _tmp11_;
			FolksIndividual* _tmp12_;
			FolksIndividual* _tmp13_;
#line 1203 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp6_ = _i_it;
#line 1203 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 1203 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (!_tmp7_) {
#line 1203 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				break;
#line 6627 "aggregation.c"
			}
#line 1203 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp8_ = _i_it;
#line 1203 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 1203 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp9_;
#line 1205 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp10_ = i;
#line 1205 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (_tmp10_ == NULL) {
#line 1207 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (i);
#line 1207 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				continue;
#line 6643 "aggregation.c"
			}
#line 1210 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp11_ = _data8_->individual;
#line 1210 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			g_assert (_tmp11_ != NULL);
#line 1211 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp12_ = i;
#line 1211 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp13_ = _data8_->individual;
#line 1211 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			g_assert (_tmp12_ == _tmp13_);
#line 1212 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (_data8_->individual);
#line 1212 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_data8_->individual = NULL;
#line 1203 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 6661 "aggregation.c"
		}
#line 1203 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 6665 "aggregation.c"
	}
	{
		GeeCollection* _tmp14_;
		GeeIterator* _tmp15_ = NULL;
		GeeIterator* _i_it;
#line 1215 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp14_ = added;
#line 1215 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp15_ = gee_iterable_iterator ((GeeIterable*) _tmp14_);
#line 1215 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_i_it = _tmp15_;
#line 1215 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 6679 "aggregation.c"
			GeeIterator* _tmp16_;
			gboolean _tmp17_ = FALSE;
			GeeIterator* _tmp18_;
			gpointer _tmp19_ = NULL;
			FolksIndividual* i;
			FolksIndividual* _tmp20_;
			gboolean got_tpf;
			gboolean got_kf;
			gboolean _tmp37_ = FALSE;
			gboolean _tmp38_;
			gboolean _tmp40_;
#line 1215 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp16_ = _i_it;
#line 1215 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp17_ = gee_iterator_next (_tmp16_);
#line 1215 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (!_tmp17_) {
#line 1215 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				break;
#line 6699 "aggregation.c"
			}
#line 1215 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp18_ = _i_it;
#line 1215 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp19_ = gee_iterator_get (_tmp18_);
#line 1215 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp19_;
#line 1217 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp20_ = i;
#line 1217 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (_tmp20_ == NULL) {
#line 1219 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (i);
#line 1219 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				continue;
#line 6715 "aggregation.c"
			}
#line 1222 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			got_tpf = FALSE;
#line 1223 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			got_kf = FALSE;
#line 6721 "aggregation.c"
			{
				FolksIndividual* _tmp21_;
				GeeSet* _tmp22_;
				GeeSet* _tmp23_;
				GeeIterator* _tmp24_ = NULL;
				GeeIterator* _p_it;
#line 1228 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp21_ = i;
#line 1228 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp22_ = folks_individual_get_personas (_tmp21_);
#line 1228 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp23_ = _tmp22_;
#line 1228 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp24_ = gee_iterable_iterator ((GeeIterable*) _tmp23_);
#line 1228 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_p_it = _tmp24_;
#line 1228 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				while (TRUE) {
#line 6740 "aggregation.c"
					GeeIterator* _tmp25_;
					gboolean _tmp26_ = FALSE;
					GeeIterator* _tmp27_;
					gpointer _tmp28_ = NULL;
					FolksPersona* p;
					FolksPersona* _tmp29_;
					const gchar* _tmp30_;
					const gchar* _tmp31_;
#line 1228 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp25_ = _p_it;
#line 1228 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp26_ = gee_iterator_next (_tmp25_);
#line 1228 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					if (!_tmp26_) {
#line 1228 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						break;
#line 6757 "aggregation.c"
					}
#line 1228 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp27_ = _p_it;
#line 1228 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp28_ = gee_iterator_get (_tmp27_);
#line 1228 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					p = (FolksPersona*) _tmp28_;
#line 1230 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp29_ = p;
#line 1230 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp30_ = folks_persona_get_uid (_tmp29_);
#line 1230 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp31_ = _tmp30_;
#line 1230 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					if (g_strcmp0 (_tmp31_, "telepathy:/org/freedesktop/Telepathy/Account/cm/protocol/account:olivi" \
"er@example.com") == 0) {
#line 1232 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						got_tpf = TRUE;
#line 6775 "aggregation.c"
					} else {
						FolksPersona* _tmp32_;
						FolksPersonaStore* _tmp33_;
						FolksPersonaStore* _tmp34_;
						const gchar* _tmp35_;
						const gchar* _tmp36_;
#line 1234 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						_tmp32_ = p;
#line 1234 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						_tmp33_ = folks_persona_get_store (_tmp32_);
#line 1234 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						_tmp34_ = _tmp33_;
#line 1234 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						_tmp35_ = folks_persona_store_get_type_id (_tmp34_);
#line 1234 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						_tmp36_ = _tmp35_;
#line 1234 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						if (g_strcmp0 (_tmp36_, "key-file") == 0) {
#line 1236 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
							got_kf = TRUE;
#line 6796 "aggregation.c"
						}
					}
#line 1228 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_g_object_unref0 (p);
#line 6801 "aggregation.c"
				}
#line 1228 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (_p_it);
#line 6805 "aggregation.c"
			}
#line 1240 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp38_ = got_tpf;
#line 1240 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (_tmp38_ == TRUE) {
#line 6811 "aggregation.c"
				gboolean _tmp39_;
#line 1240 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp39_ = got_kf;
#line 1240 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp37_ = _tmp39_ == TRUE;
#line 6817 "aggregation.c"
			} else {
#line 1240 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp37_ = FALSE;
#line 6821 "aggregation.c"
			}
#line 1240 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp40_ = _tmp37_;
#line 1240 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (_tmp40_) {
#line 6827 "aggregation.c"
				FolksIndividual* _tmp41_;
				FolksIndividual* _tmp42_;
#line 1242 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp41_ = i;
#line 1242 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp42_ = _g_object_ref0 (_tmp41_);
#line 1242 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (_data8_->individual);
#line 1242 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_data8_->individual = _tmp42_;
#line 1243 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (i);
#line 1243 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (_i_it);
#line 1243 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (removed);
#line 1243 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (added);
#line 1243 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				return;
#line 6848 "aggregation.c"
			}
#line 1215 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 6852 "aggregation.c"
		}
#line 1215 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 6856 "aggregation.c"
	}
#line 1198 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (removed);
#line 1198 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (added);
#line 6862 "aggregation.c"
}


static void ___lambda44__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 1198 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	__lambda44_ (self, changes);
#line 6869 "aggregation.c"
}


static gboolean __lambda45_ (Block8Data* _data8_) {
	AggregationTests * self;
	gboolean result = FALSE;
#line 1249 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data8_->self;
#line 1251 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_main_loop_quit (_data8_->main_loop);
#line 1252 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 1252 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 6884 "aggregation.c"
}


static gboolean ___lambda45__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda45_ (self);
#line 1249 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 6893 "aggregation.c"
}


static void __lambda47_ (Block8Data* _data8_, GObject* obj, GAsyncResult* res) {
	AggregationTests * self;
	GError * _inner_error_ = NULL;
#line 1258 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data8_->self;
#line 1258 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (res != NULL);
#line 6904 "aggregation.c"
	{
		FolksIndividualAggregator* _tmp0_;
		GAsyncResult* _tmp1_;
		FolksPersona* _tmp2_ = NULL;
		FolksPersona* _tmp3_;
#line 1263 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp0_ = _data8_->aggregator;
#line 1263 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp1_ = res;
#line 1263 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp2_ = folks_individual_aggregator_ensure_individual_property_writeable_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 1263 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp3_ = _tmp2_;
#line 1263 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		if (_inner_error_ != NULL) {
#line 6920 "aggregation.c"
			goto __catch9_g_error;
		}
#line 1262 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data8_->writeable_persona);
#line 1262 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_data8_->writeable_persona = _tmp3_;
#line 1265 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_main_loop_quit (_data8_->main_loop);
#line 6929 "aggregation.c"
	}
	goto __finally9;
	__catch9_g_error:
	{
		GError* e1 = NULL;
		const gchar* _tmp4_;
#line 1260 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		e1 = _inner_error_;
#line 1260 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_inner_error_ = NULL;
#line 1269 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp4_ = e1->message;
#line 1269 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_critical ("aggregation.vala:1269: Failed to ensure property writeable: %s", _tmp4_);
#line 1271 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_assert_not_reached ();
#line 1260 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_error_free0 (e1);
#line 6948 "aggregation.c"
	}
	__finally9:
#line 1260 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	if (_inner_error_ != NULL) {
#line 1260 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1260 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 1260 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		return;
#line 6959 "aggregation.c"
	}
}


static void ___lambda47__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 1257 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	__lambda47_ (self, source_object, res);
#line 1257 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	block8_data_unref (self);
#line 6969 "aggregation.c"
}


static gboolean __lambda46_ (Block8Data* _data8_) {
	AggregationTests * self;
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_;
	FolksIndividual* _tmp1_;
#line 1255 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data8_->self;
#line 1257 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data8_->aggregator;
#line 1257 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = _data8_->individual;
#line 1257 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	folks_individual_aggregator_ensure_individual_property_writeable (_tmp0_, _tmp1_, "im-addresses", ___lambda47__gasync_ready_callback, block8_data_ref (_data8_));
#line 1275 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 1275 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 6990 "aggregation.c"
}


static gboolean ___lambda46__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda46_ (self);
#line 1255 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 6999 "aggregation.c"
}


void aggregation_tests_test_ensure_individual_property_writeable_add_persona (AggregationTests* self) {
	Block8Data* _data8_;
	GMainLoop* _tmp0_;
	KfTestBackend* _tmp1_;
	TpTestBackend* _tmp2_;
	void* _tmp3_ = NULL;
	void* account_handle;
	FolksIndividualAggregator* _tmp4_;
	FolksIndividualAggregator* _tmp5_;
	gulong _tmp6_ = 0UL;
	gulong individuals_changed_id;
	gint _tmp7_;
	guint _tmp8_ = 0U;
	guint timeout_id;
	FolksIndividual* _tmp9_;
	FolksPersona* persona;
	FolksPersona* _tmp18_;
	FolksPersona* _tmp19_;
	gchar** _tmp20_;
	gint _tmp20__length1;
	gchar** _tmp21_;
	gint _tmp21__length1;
	FolksIndividualAggregator* _tmp22_;
	FolksIndividualAggregator* _tmp23_;
	gint _tmp24_;
	FolksPersona* _tmp25_;
	FolksPersona* _tmp26_;
	FolksPersona* _tmp27_;
	TpTestBackend* _tmp28_;
	KfTestBackend* _tmp29_;
#line 1112 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 1112 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data8_ = g_slice_new0 (Block8Data);
#line 1112 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data8_->_ref_count_ = 1;
#line 1112 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data8_->self = g_object_ref (self);
#line 1114 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 1114 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data8_->main_loop = _tmp0_;
#line 1116 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = self->priv->_kf_backend;
#line 1116 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	kf_test_backend_set_up (_tmp1_, "");
#line 1117 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = self->priv->_tp_backend;
#line 1117 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = tp_test_backend_add_account (_tmp2_, "protocol", "me@example.com", "cm", "account");
#line 1117 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	account_handle = _tmp3_;
#line 1120 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data8_->individual = NULL;
#line 1123 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp4_ = folks_individual_aggregator_new ();
#line 1123 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data8_->aggregator = _tmp4_;
#line 1124 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp5_ = _data8_->aggregator;
#line 1124 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp6_ = g_signal_connect_data (_tmp5_, "individuals-changed-detailed", (GCallback) ___lambda40__folks_individual_aggregator_individuals_changed_detailed, block8_data_ref (_data8_), (GClosureNotify) block8_data_unref, 0);
#line 1124 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	individuals_changed_id = _tmp6_;
#line 1152 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp7_ = self->priv->_test_timeout;
#line 1152 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp8_ = g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) _tmp7_, ___lambda41__gsource_func, block8_data_ref (_data8_), block8_data_unref);
#line 1152 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	timeout_id = _tmp8_;
#line 1158 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda42__gsource_func, block8_data_ref (_data8_), block8_data_unref);
#line 1177 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_main_loop_run (_data8_->main_loop);
#line 1180 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp9_ = _data8_->individual;
#line 1180 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (_tmp9_ != NULL);
#line 1182 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	persona = NULL;
#line 7083 "aggregation.c"
	{
		FolksIndividual* _tmp10_;
		GeeSet* _tmp11_;
		GeeSet* _tmp12_;
		GeeIterator* _tmp13_ = NULL;
		GeeIterator* _p_it;
#line 1183 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp10_ = _data8_->individual;
#line 1183 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp11_ = folks_individual_get_personas (_tmp10_);
#line 1183 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp12_ = _tmp11_;
#line 1183 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp13_ = gee_iterable_iterator ((GeeIterable*) _tmp12_);
#line 1183 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_p_it = _tmp13_;
#line 1183 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 7102 "aggregation.c"
			gboolean _tmp14_ = FALSE;
			gpointer _tmp15_ = NULL;
			FolksPersona* p;
			FolksPersona* _tmp16_;
			FolksPersona* _tmp17_;
#line 1183 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp14_ = gee_iterator_next (_p_it);
#line 1183 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (!_tmp14_) {
#line 1183 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				break;
#line 7114 "aggregation.c"
			}
#line 1183 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp15_ = gee_iterator_get (_p_it);
#line 1183 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			p = (FolksPersona*) _tmp15_;
#line 1185 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp16_ = p;
#line 1185 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp17_ = _g_object_ref0 (_tmp16_);
#line 1185 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (persona);
#line 1185 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			persona = _tmp17_;
#line 1186 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (p);
#line 1186 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			break;
#line 7132 "aggregation.c"
		}
#line 1183 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_p_it);
#line 7136 "aggregation.c"
	}
#line 1190 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp18_ = persona;
#line 1190 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (_tmp18_ != NULL);
#line 1191 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp19_ = persona;
#line 1191 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp20_ = folks_persona_get_writeable_properties (_tmp19_, &_tmp20__length1);
#line 1191 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp21_ = _tmp20_;
#line 1191 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp21__length1 = _tmp20__length1;
#line 1191 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (!_vala_string_array_contains (_tmp21_, _tmp21__length1, "im-addresses"));
#line 1193 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data8_->writeable_persona = NULL;
#line 1196 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp22_ = _data8_->aggregator;
#line 1196 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_signal_handler_disconnect ((GObject*) _tmp22_, individuals_changed_id);
#line 1197 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_source_remove (timeout_id);
#line 1198 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp23_ = _data8_->aggregator;
#line 1198 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_signal_connect_data (_tmp23_, "individuals-changed-detailed", (GCallback) ___lambda44__folks_individual_aggregator_individuals_changed_detailed, block8_data_ref (_data8_), (GClosureNotify) block8_data_unref, 0);
#line 1249 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp24_ = self->priv->_test_timeout;
#line 1249 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) _tmp24_, ___lambda45__gsource_func, block8_data_ref (_data8_), block8_data_unref);
#line 1255 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda46__gsource_func, block8_data_ref (_data8_), block8_data_unref);
#line 1278 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_main_loop_run (_data8_->main_loop);
#line 1280 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp25_ = _data8_->writeable_persona;
#line 1280 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (_tmp25_ != NULL);
#line 1281 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp26_ = _data8_->writeable_persona;
#line 1281 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp27_ = persona;
#line 1281 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (_tmp26_ != _tmp27_);
#line 1284 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp28_ = self->priv->_tp_backend;
#line 1284 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	tp_test_backend_remove_account (_tmp28_, account_handle);
#line 1285 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp29_ = self->priv->_kf_backend;
#line 1285 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	kf_test_backend_tear_down (_tmp29_);
#line 1286 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (_data8_->individual);
#line 1286 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data8_->individual = NULL;
#line 1287 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (persona);
#line 1287 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	persona = NULL;
#line 1288 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (_data8_->writeable_persona);
#line 1288 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data8_->writeable_persona = NULL;
#line 1289 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (_data8_->aggregator);
#line 1289 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data8_->aggregator = NULL;
#line 1112 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (persona);
#line 1112 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	block8_data_unref (_data8_);
#line 1112 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data8_ = NULL;
#line 7212 "aggregation.c"
}


static Block9Data* block9_data_ref (Block9Data* _data9_) {
#line 1301 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_atomic_int_inc (&_data9_->_ref_count_);
#line 1301 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return _data9_;
#line 7221 "aggregation.c"
}


static void block9_data_unref (void * _userdata_) {
	Block9Data* _data9_;
	_data9_ = (Block9Data*) _userdata_;
#line 1301 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	if (g_atomic_int_dec_and_test (&_data9_->_ref_count_)) {
#line 7230 "aggregation.c"
		AggregationTests * self;
#line 1301 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		self = _data9_->self;
#line 1301 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data9_->writeable_persona);
#line 1301 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data9_->aggregator);
#line 1301 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data9_->individual);
#line 1301 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_main_loop_unref0 (_data9_->main_loop);
#line 1301 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (self);
#line 1301 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_slice_free (Block9Data, _data9_);
#line 7246 "aggregation.c"
	}
}


static void __lambda48_ (Block9Data* _data9_, GeeMultiMap* changes) {
	AggregationTests * self;
	GeeMultiMap* _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
#line 1312 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data9_->self;
#line 1312 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (changes != NULL);
#line 1314 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = changes;
#line 1314 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = gee_multi_map_get_size (_tmp0_);
#line 1314 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = _tmp1_;
#line 1314 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (_tmp2_ == 1);
#line 7268 "aggregation.c"
	{
		GeeMultiMap* _tmp3_;
		GeeSet* _tmp4_ = NULL;
		GeeSet* _tmp5_;
		GeeIterator* _tmp6_ = NULL;
		GeeIterator* _tmp7_;
		GeeIterator* _removed_it;
#line 1316 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp3_ = changes;
#line 1316 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp4_ = gee_multi_map_get_keys (_tmp3_);
#line 1316 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp5_ = _tmp4_;
#line 1316 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp6_ = gee_iterable_iterator ((GeeIterable*) _tmp5_);
#line 1316 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp7_ = _tmp6_;
#line 1316 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_tmp5_);
#line 1316 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_removed_it = _tmp7_;
#line 1316 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 7292 "aggregation.c"
			GeeIterator* _tmp8_;
			gboolean _tmp9_ = FALSE;
			GeeIterator* _tmp10_;
			gpointer _tmp11_ = NULL;
			FolksIndividual* removed;
			FolksIndividual* _tmp12_;
#line 1316 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp8_ = _removed_it;
#line 1316 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp9_ = gee_iterator_next (_tmp8_);
#line 1316 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (!_tmp9_) {
#line 1316 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				break;
#line 7307 "aggregation.c"
			}
#line 1316 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp10_ = _removed_it;
#line 1316 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp11_ = gee_iterator_get (_tmp10_);
#line 1316 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			removed = (FolksIndividual*) _tmp11_;
#line 1318 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp12_ = removed;
#line 1318 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			g_assert (_tmp12_ == NULL);
#line 7319 "aggregation.c"
			{
				GeeMultiMap* _tmp13_;
				FolksIndividual* _tmp14_;
				GeeCollection* _tmp15_ = NULL;
				GeeCollection* _tmp16_;
				GeeIterator* _tmp17_ = NULL;
				GeeIterator* _tmp18_;
				GeeIterator* _i_it;
#line 1320 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp13_ = changes;
#line 1320 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp14_ = removed;
#line 1320 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp15_ = gee_multi_map_get (_tmp13_, _tmp14_);
#line 1320 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp16_ = _tmp15_;
#line 1320 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp17_ = gee_iterable_iterator ((GeeIterable*) _tmp16_);
#line 1320 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_tmp18_ = _tmp17_;
#line 1320 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (_tmp16_);
#line 1320 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_i_it = _tmp18_;
#line 1320 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				while (TRUE) {
#line 7346 "aggregation.c"
					GeeIterator* _tmp19_;
					gboolean _tmp20_ = FALSE;
					GeeIterator* _tmp21_;
					gpointer _tmp22_ = NULL;
					FolksIndividual* i;
					FolksIndividual* _tmp23_;
					FolksIndividual* _tmp24_;
					FolksIndividual* _tmp25_;
#line 1320 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp19_ = _i_it;
#line 1320 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp20_ = gee_iterator_next (_tmp19_);
#line 1320 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					if (!_tmp20_) {
#line 1320 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
						break;
#line 7363 "aggregation.c"
					}
#line 1320 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp21_ = _i_it;
#line 1320 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp22_ = gee_iterator_get (_tmp21_);
#line 1320 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					i = (FolksIndividual*) _tmp22_;
#line 1322 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp23_ = i;
#line 1322 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					g_assert (_tmp23_ != NULL);
#line 1323 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					g_assert (_data9_->individual == NULL);
#line 1325 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp24_ = i;
#line 1325 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_tmp25_ = _g_object_ref0 (_tmp24_);
#line 1325 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_g_object_unref0 (_data9_->individual);
#line 1325 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_data9_->individual = _tmp25_;
#line 1326 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					g_main_loop_quit (_data9_->main_loop);
#line 1320 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
					_g_object_unref0 (i);
#line 7389 "aggregation.c"
				}
#line 1320 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (_i_it);
#line 7393 "aggregation.c"
			}
#line 1316 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (removed);
#line 7397 "aggregation.c"
		}
#line 1316 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_removed_it);
#line 7401 "aggregation.c"
	}
}


static void ___lambda48__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 1312 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	__lambda48_ (self, changes);
#line 7409 "aggregation.c"
}


static gboolean __lambda49_ (Block9Data* _data9_) {
	AggregationTests * self;
	gboolean result = FALSE;
#line 1332 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data9_->self;
#line 1334 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_main_loop_quit (_data9_->main_loop);
#line 1335 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 1335 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 7424 "aggregation.c"
}


static gboolean ___lambda49__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda49_ (self);
#line 1332 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 7433 "aggregation.c"
}


static void __lambda51_ (Block9Data* _data9_, GObject* s, GAsyncResult* r) {
	AggregationTests * self;
	GError * _inner_error_ = NULL;
#line 1340 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data9_->self;
#line 1340 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (r != NULL);
#line 7444 "aggregation.c"
	{
		FolksIndividualAggregator* _tmp0_;
		GAsyncResult* _tmp1_;
#line 1344 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp0_ = _data9_->aggregator;
#line 1344 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp1_ = r;
#line 1344 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		folks_individual_aggregator_prepare_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 1344 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		if (_inner_error_ != NULL) {
#line 7456 "aggregation.c"
			goto __catch10_g_error;
		}
	}
	goto __finally10;
	__catch10_g_error:
	{
		GError* e1 = NULL;
		const gchar* _tmp2_;
#line 1342 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		e1 = _inner_error_;
#line 1342 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_inner_error_ = NULL;
#line 1348 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp2_ = e1->message;
#line 1348 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_critical ("aggregation.vala:1348: Failed to prepare aggregator: %s", _tmp2_);
#line 1350 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_assert_not_reached ();
#line 1342 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_error_free0 (e1);
#line 7477 "aggregation.c"
	}
	__finally10:
#line 1342 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	if (_inner_error_ != NULL) {
#line 1342 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1342 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 1342 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		return;
#line 7488 "aggregation.c"
	}
}


static void ___lambda51__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 1340 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	__lambda51_ (self, source_object, res);
#line 1340 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	block9_data_unref (self);
#line 7498 "aggregation.c"
}


static gboolean __lambda50_ (Block9Data* _data9_) {
	AggregationTests * self;
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_;
#line 1338 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data9_->self;
#line 1340 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data9_->aggregator;
#line 1340 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	folks_individual_aggregator_prepare (_tmp0_, ___lambda51__gasync_ready_callback, block9_data_ref (_data9_));
#line 1354 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 1354 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 7516 "aggregation.c"
}


static gboolean ___lambda50__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda50_ (self);
#line 1338 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 7525 "aggregation.c"
}


static gboolean __lambda52_ (Block9Data* _data9_) {
	AggregationTests * self;
	gboolean result = FALSE;
#line 1376 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data9_->self;
#line 1378 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_main_loop_quit (_data9_->main_loop);
#line 1379 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 1379 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 7540 "aggregation.c"
}


static gboolean ___lambda52__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda52_ (self);
#line 1376 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 7549 "aggregation.c"
}


static void __lambda54_ (Block9Data* _data9_, GObject* obj, GAsyncResult* res) {
	AggregationTests * self;
	GError * _inner_error_ = NULL;
#line 1385 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data9_->self;
#line 1385 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (res != NULL);
#line 7560 "aggregation.c"
	{
		FolksIndividualAggregator* _tmp0_;
		GAsyncResult* _tmp1_;
		FolksPersona* _tmp2_ = NULL;
		FolksPersona* _tmp3_;
#line 1390 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp0_ = _data9_->aggregator;
#line 1390 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp1_ = res;
#line 1390 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp2_ = folks_individual_aggregator_ensure_individual_property_writeable_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 1390 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp3_ = _tmp2_;
#line 1390 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		if (_inner_error_ != NULL) {
#line 7576 "aggregation.c"
			goto __catch11_g_error;
		}
#line 1389 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data9_->writeable_persona);
#line 1389 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_data9_->writeable_persona = _tmp3_;
#line 1391 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_assert_not_reached ();
#line 7585 "aggregation.c"
	}
	goto __finally11;
	__catch11_g_error:
	{
		GError* e1 = NULL;
#line 1387 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		e1 = _inner_error_;
#line 1387 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_inner_error_ = NULL;
#line 1396 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		if (!g_error_matches (e1, FOLKS_INDIVIDUAL_AGGREGATOR_ERROR, FOLKS_INDIVIDUAL_AGGREGATOR_ERROR_PROPERTY_NOT_WRITEABLE)) {
#line 7597 "aggregation.c"
			const gchar* _tmp4_;
#line 1398 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp4_ = e1->message;
#line 1398 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			g_critical ("aggregation.vala:1398: Wrong error received: %s", _tmp4_);
#line 1399 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			g_assert_not_reached ();
#line 7605 "aggregation.c"
		}
#line 1402 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_main_loop_quit (_data9_->main_loop);
#line 1387 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_error_free0 (e1);
#line 7611 "aggregation.c"
	}
	__finally11:
#line 1387 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	if (_inner_error_ != NULL) {
#line 1387 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1387 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 1387 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		return;
#line 7622 "aggregation.c"
	}
}


static void ___lambda54__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 1384 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	__lambda54_ (self, source_object, res);
#line 1384 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	block9_data_unref (self);
#line 7632 "aggregation.c"
}


static gboolean __lambda53_ (Block9Data* _data9_) {
	AggregationTests * self;
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_;
#line 1382 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = _data9_->self;
#line 1384 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data9_->aggregator;
#line 1384 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	folks_individual_aggregator_ensure_individual_property_writeable (_tmp0_, _data9_->individual, "is-favourite", ___lambda54__gasync_ready_callback, block9_data_ref (_data9_));
#line 1406 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 1406 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 7650 "aggregation.c"
}


static gboolean ___lambda53__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda53_ (self);
#line 1382 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 7659 "aggregation.c"
}


void aggregation_tests_test_ensure_individual_property_writeable_failure (AggregationTests* self) {
	Block9Data* _data9_;
	GMainLoop* _tmp0_;
	KfTestBackend* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	gint _tmp4_;
	FolksPersona* persona;
	FolksPersona* _tmp12_;
	FolksPersona* _tmp13_;
	gchar** _tmp14_;
	gint _tmp14__length1;
	gchar** _tmp15_;
	gint _tmp15__length1;
	gint _tmp16_;
	KfTestBackend* _tmp17_;
#line 1301 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 1301 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data9_ = g_slice_new0 (Block9Data);
#line 1301 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data9_->_ref_count_ = 1;
#line 1301 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data9_->self = g_object_ref (self);
#line 1303 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 1303 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data9_->main_loop = _tmp0_;
#line 1305 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = self->priv->_kf_backend;
#line 1305 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	kf_test_backend_set_up (_tmp1_, "[0]\n" "protocol=travis@example.com\n");
#line 1308 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data9_->individual = NULL;
#line 1311 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = folks_individual_aggregator_new ();
#line 1311 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data9_->aggregator = _tmp2_;
#line 1312 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = _data9_->aggregator;
#line 1312 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_signal_connect_data (_tmp3_, "individuals-changed-detailed", (GCallback) ___lambda48__folks_individual_aggregator_individuals_changed_detailed, block9_data_ref (_data9_), (GClosureNotify) block9_data_unref, 0);
#line 1332 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp4_ = self->priv->_test_timeout;
#line 1332 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) _tmp4_, ___lambda49__gsource_func, block9_data_ref (_data9_), block9_data_unref);
#line 1338 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda50__gsource_func, block9_data_ref (_data9_), block9_data_unref);
#line 1357 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_main_loop_run (_data9_->main_loop);
#line 1360 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (_data9_->individual != NULL);
#line 1362 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	persona = NULL;
#line 7717 "aggregation.c"
	{
		GeeSet* _tmp5_;
		GeeSet* _tmp6_;
		GeeIterator* _tmp7_ = NULL;
		GeeIterator* _p_it;
#line 1363 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp5_ = folks_individual_get_personas (_data9_->individual);
#line 1363 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp6_ = _tmp5_;
#line 1363 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_tmp7_ = gee_iterable_iterator ((GeeIterable*) _tmp6_);
#line 1363 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_p_it = _tmp7_;
#line 1363 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 7733 "aggregation.c"
			gboolean _tmp8_ = FALSE;
			gpointer _tmp9_ = NULL;
			FolksPersona* p;
			FolksPersona* _tmp10_;
			FolksPersona* _tmp11_;
#line 1363 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp8_ = gee_iterator_next (_p_it);
#line 1363 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			if (!_tmp8_) {
#line 1363 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
				break;
#line 7745 "aggregation.c"
			}
#line 1363 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp9_ = gee_iterator_get (_p_it);
#line 1363 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			p = (FolksPersona*) _tmp9_;
#line 1365 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp10_ = p;
#line 1365 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_tmp11_ = _g_object_ref0 (_tmp10_);
#line 1365 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (persona);
#line 1365 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			persona = _tmp11_;
#line 1366 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (p);
#line 1366 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
			break;
#line 7763 "aggregation.c"
		}
#line 1363 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_p_it);
#line 7767 "aggregation.c"
	}
#line 1370 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp12_ = persona;
#line 1370 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (_tmp12_ != NULL);
#line 1371 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp13_ = persona;
#line 1371 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp14_ = folks_persona_get_writeable_properties (_tmp13_, &_tmp14__length1);
#line 1371 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp15_ = _tmp14_;
#line 1371 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp15__length1 = _tmp14__length1;
#line 1371 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (!_vala_string_array_contains (_tmp15_, _tmp15__length1, "is-favourite"));
#line 1373 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data9_->writeable_persona = NULL;
#line 1376 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp16_ = self->priv->_test_timeout;
#line 1376 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) _tmp16_, ___lambda52__gsource_func, block9_data_ref (_data9_), block9_data_unref);
#line 1382 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda53__gsource_func, block9_data_ref (_data9_), block9_data_unref);
#line 1409 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_main_loop_run (_data9_->main_loop);
#line 1411 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_assert (_data9_->writeable_persona == NULL);
#line 1414 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp17_ = self->priv->_kf_backend;
#line 1414 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	kf_test_backend_tear_down (_tmp17_);
#line 1415 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (_data9_->aggregator);
#line 1415 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data9_->aggregator = NULL;
#line 1301 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (persona);
#line 1301 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	block9_data_unref (_data9_);
#line 1301 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_data9_ = NULL;
#line 7809 "aggregation.c"
}


static void aggregation_tests_class_init (AggregationTestsClass * klass) {
#line 24 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	aggregation_tests_parent_class = g_type_class_peek_parent (klass);
#line 24 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_type_class_add_private (klass, sizeof (AggregationTestsPrivate));
#line 24 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	FOLKS_TEST_CASE_CLASS (klass)->set_up = aggregation_tests_real_set_up;
#line 24 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	FOLKS_TEST_CASE_CLASS (klass)->tear_down = aggregation_tests_real_tear_down;
#line 24 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	G_OBJECT_CLASS (klass)->finalize = aggregation_tests_finalize;
#line 7824 "aggregation.c"
}


static void aggregation_tests_instance_init (AggregationTests * self) {
#line 24 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self->priv = AGGREGATION_TESTS_GET_PRIVATE (self);
#line 29 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self->priv->_test_timeout = 3;
#line 7833 "aggregation.c"
}


static void aggregation_tests_finalize (GObject* obj) {
	AggregationTests * self;
#line 24 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	self = AGGREGATION_TESTS (obj);
#line 26 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_kf_test_backend_unref0 (self->priv->_kf_backend);
#line 27 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (self->priv->_tp_backend);
#line 28 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (self->priv->_default_personas);
#line 24 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	G_OBJECT_CLASS (aggregation_tests_parent_class)->finalize (obj);
#line 7849 "aggregation.c"
}


GType aggregation_tests_get_type (void) {
	static volatile gsize aggregation_tests_type_id__volatile = 0;
	if (g_once_init_enter (&aggregation_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (AggregationTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) aggregation_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (AggregationTests), 0, (GInstanceInitFunc) aggregation_tests_instance_init, NULL };
		GType aggregation_tests_type_id;
		aggregation_tests_type_id = g_type_register_static (FOLKS_TYPE_TEST_CASE, "AggregationTests", &g_define_type_info, 0);
		g_once_init_leave (&aggregation_tests_type_id__volatile, aggregation_tests_type_id);
	}
	return aggregation_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	GTestSuite* _tmp0_ = NULL;
	GTestSuite* root;
	AggregationTests* _tmp1_;
	AggregationTests* _tmp2_;
	GTestSuite* _tmp3_ = NULL;
#line 1421 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_test_init (&args_length1, &args, NULL);
#line 1423 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = g_test_get_root ();
#line 1423 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	root = _tmp0_;
#line 1424 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = aggregation_tests_new ();
#line 1424 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = _tmp1_;
#line 1424 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = folks_test_case_get_suite ((FolksTestCase*) _tmp2_);
#line 1424 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_test_suite_add_suite (root, _tmp3_);
#line 1424 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (_tmp2_);
#line 1426 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_test_run ();
#line 1428 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	result = 0;
#line 1428 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return result;
#line 7894 "aggregation.c"
}


int main (int argc, char ** argv) {
#line 1419 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	g_type_init ();
#line 1419 "/opt/gnome2/source/folks/tests/folks/aggregation.vala"
	return _vala_main (argv, argc);
#line 7903 "aggregation.c"
}



